/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import * as i0 from "@angular/core";
import * as i1 from "./calendar.component";
import * as i2 from "./navigation.component";
import * as i3 from "./localization/calendar-custom-messages.component";
import * as i4 from "./localization/calendar-localized-messages.directive";
import * as i5 from "./view-list.component";
import * as i6 from "@angular/common";
import * as i7 from "./calendar-common.module";
import * as i8 from "./multiview-calendar.module";
import * as i9 from "@progress/kendo-angular-intl";
import * as i10 from "./templates.module";
import * as i11 from "../virtualization/virtualization.module";
import * as i12 from "@progress/kendo-angular-common";
/**
 * The exported package module.
 *
 * The package exports:
 * - `CellTemplateDirective`&mdash;The month cell template directive.
 * - `MonthCellTemplateDirective`&mdash;The month cell template directive.
 * - `YearCellTemplateDirective`&mdash;The year cell template directive.
 * - `DecadeCellTemplateDirective`&mdash;The decade cell template directive.
 * - `CenturyCellTemplateDirective`&mdash;The century cell template directive.
 * - `WeekNumberCellTemplateDirective`&mdash;The month week number cell template directive.
 * - `HeaderTitleTemplateDirective`&mdash;The header title template directive.
 * - `NavigationItemTemplateDirective`&mdash;The navigation item template directive.
 *
 * @example
 *
 * ```ts-no-run
 * // Import the Calendar module
 * import { CalendarModule } from '@progress/kendo-angular-dateinputs';
 *
 * // The browser platform with a compiler
 * import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
 *
 * import { NgModule } from '@angular/core';
 *
 * // Import the app component
 * import { AppComponent } from './app.component';
 *
 * // Define the app module
 * _@NgModule({
 *     declarations: [AppComponent], // declare app component
 *     imports:      [BrowserModule, CalendarModule], // import Calendar module
 *     bootstrap:    [AppComponent]
 * })
 * export class AppModule {}
 *
 * // Compile and launch the module
 * platformBrowserDynamic().bootstrapModule(AppModule);
 *
 * ```
 */
export declare class CalendarModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<CalendarModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<CalendarModule, [typeof i1.CalendarComponent, typeof i2.NavigationComponent, typeof i3.CalendarCustomMessagesComponent, typeof i4.CalendarLocalizedMessagesDirective, typeof i5.ViewListComponent], [typeof i6.CommonModule, typeof i7.CalendarCommonModule, typeof i8.MultiViewCalendarModule, typeof i9.IntlModule, typeof i10.TemplatesModule, typeof i11.VirtualizationModule, typeof i12.EventsModule, typeof i12.ResizeSensorModule], [typeof i1.CalendarComponent, typeof i2.NavigationComponent, typeof i3.CalendarCustomMessagesComponent, typeof i4.CalendarLocalizedMessagesDirective, typeof i5.ViewListComponent, typeof i7.CalendarCommonModule, typeof i10.TemplatesModule]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<CalendarModule>;
}
