/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, OnDestroy, Renderer2, AfterViewChecked, AfterViewInit, TemplateRef } from '@angular/core';
import { IntlService } from '@progress/kendo-angular-intl';
import { PageAction, ScrollAction } from '../virtualization/services/scroller.service';
import { VirtualizationComponent } from '../virtualization/virtualization.component';
import { BusViewService } from './services/bus-view.service';
import { CalendarDOMService } from './services/dom.service';
import { ViewService } from './models/view-service.interface';
import { CalendarViewEnum } from './models/view.enum';
import { HeaderComponent } from './header.component';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class ViewListComponent implements OnChanges, OnDestroy, AfterViewInit, AfterViewChecked {
    private bus;
    private cdr;
    private intl;
    private dom;
    private renderer;
    cellTemplateRef: TemplateRef<any>;
    weekNumberTemplateRef: TemplateRef<any>;
    headerTitleTemplateRef: TemplateRef<any>;
    activeView: CalendarViewEnum;
    cellUID: string;
    focusedDate: Date;
    isActive: boolean;
    min: Date;
    max: Date;
    selectedDates: Date[];
    tabIndex: number;
    disabled: boolean;
    id: string;
    get weekNumber(): boolean;
    set weekNumber(showWeekNumbers: boolean);
    cellClick: EventEmitter<any>;
    weekNumberCellClick: EventEmitter<Date[]>;
    activeDateChange: EventEmitter<Date>;
    todayButtonClick: EventEmitter<Date>;
    pageChange: EventEmitter<any>;
    focusCalendar: EventEmitter<void>;
    blurCalendar: EventEmitter<any>;
    focusedCellChange: EventEmitter<string>;
    virtualization: VirtualizationComponent;
    headerComponent: HeaderComponent;
    get headerTitle(): string;
    list: ElementRef;
    getComponentClass: boolean;
    get getComponentMonthClass(): boolean;
    get getComponentYearClass(): boolean;
    get getComponentDecadeClass(): boolean;
    get getComponentCenturyClass(): boolean;
    service: ViewService;
    activeDate: Date;
    dates: Date[];
    cols: number[];
    weekNames: string[];
    wideWeekNames: string[];
    take: number;
    skip: number;
    total: number;
    bottomOffset: number;
    viewHeight: number;
    viewOffset: number;
    private animateToIndex;
    private indexToScroll;
    private showWeekNumbers;
    private minViewsToRender;
    private intlSubscription;
    constructor(bus: BusViewService, cdr: ChangeDetectorRef, intl: IntlService, dom: CalendarDOMService, renderer: Renderer2);
    ngOnInit(): void;
    ngOnChanges(changes: any): void;
    ngOnDestroy(): void;
    ngAfterViewInit(): void;
    ngAfterViewChecked(): void;
    onPageChange({ skip }: PageAction): void;
    scrollChange({ offset }: ScrollAction): void;
    setActiveDate(index: number): void;
    isMonthView(): boolean;
    isScrolled(): boolean;
    getTabIndex(): number;
    private getBottomOffset;
    private getScrollableHeight;
    private getTake;
    private getWeekNames;
    private intlChange;
    static ɵfac: i0.ɵɵFactoryDeclaration<ViewListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ViewListComponent, "kendo-calendar-viewlist", never, { "cellTemplateRef": "cellTemplateRef"; "weekNumberTemplateRef": "weekNumberTemplateRef"; "headerTitleTemplateRef": "headerTitleTemplateRef"; "activeView": "activeView"; "cellUID": "cellUID"; "focusedDate": "focusedDate"; "isActive": "isActive"; "min": "min"; "max": "max"; "selectedDates": "selectedDates"; "tabIndex": "tabIndex"; "disabled": "disabled"; "id": "id"; "weekNumber": "weekNumber"; }, { "cellClick": "cellClick"; "weekNumberCellClick": "weekNumberCellClick"; "activeDateChange": "activeDateChange"; "todayButtonClick": "todayButtonClick"; "pageChange": "pageChange"; "focusCalendar": "focusCalendar"; "blurCalendar": "blurCalendar"; "focusedCellChange": "focusedCellChange"; }, never, never>;
}
