/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, ElementRef, Renderer2, NgZone, Injector, OnChanges, OnInit, OnDestroy } from '@angular/core';
import { DateFormatPart } from '@progress/kendo-angular-intl';
import { VirtualizationComponent } from '../virtualization/virtualization.component';
import { ListItem } from './models/list-item.interface';
import { ListService } from './models/list-service.interface';
import { TimePickerDOMService } from './services/dom.service';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class TimeListComponent implements OnChanges, OnInit, OnDestroy {
    private element;
    private injector;
    private dom;
    private renderer;
    private zone;
    private localization;
    min: Date;
    max: Date;
    part: DateFormatPart;
    step: number;
    disabled: boolean;
    value: Date;
    isLast: boolean;
    valueChange: EventEmitter<Date>;
    tabOutLastPart: EventEmitter<any>;
    virtualization: VirtualizationComponent;
    get roleAttribute(): string;
    get ariaLabel(): string;
    get tabIndex(): number;
    componentClass: boolean;
    get isDayPeriod(): boolean;
    get currentSelectedIndex(): number;
    animateToIndex: boolean;
    isActive: boolean;
    skip: number;
    total: number;
    service: ListService;
    itemHeight: number;
    listHeight: number;
    topOffset: number;
    bottomOffset: number;
    bottomThreshold: number;
    topThreshold: number;
    style: any;
    data: ListItem[];
    private indexToScroll;
    private scrollSubscription;
    private domEvents;
    constructor(element: ElementRef, injector: Injector, dom: TimePickerDOMService, renderer: Renderer2, zone: NgZone, localization: LocalizationService);
    ngOnChanges(changes: any): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    ngAfterViewInit(): void;
    ngAfterViewChecked(): void;
    getCurrentItem(): ListItem;
    handleChange(dataItem: ListItem): void;
    handleItemClick(args: any): void;
    /**
     * Focuses the host element of the TimeList.
     *
     * @example
     * ```ts
     * _@Component({
     * selector: 'my-app',
     * template: `
     *  <button (click)="timelist.focus()">Focus TimeList</button>
     *  <kendo-timelist #timelist></kendo-timelist>
     * `
     * })
     * export class AppComponent { }
     * ```
     */
    focus(): void;
    /**
     * Blurs the TimeList component.
     */
    blur(): void;
    private itemOffset;
    private hasMissingValue;
    private scrollOnce;
    private serviceSettings;
    private selectedIndex;
    private textHasChanged;
    private handleKeyDown;
    private bindEvents;
    static ɵfac: i0.ɵɵFactoryDeclaration<TimeListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TimeListComponent, "kendo-timelist", never, { "min": "min"; "max": "max"; "part": "part"; "step": "step"; "disabled": "disabled"; "value": "value"; "isLast": "isLast"; }, { "valueChange": "valueChange"; "tabOutLastPart": "tabOutLastPart"; }, never, never>;
}
