/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnDestroy } from '@angular/core';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { IconsService } from '../common/icons.service';
import { IconSettings, IconSize } from '../common/models';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class IconWrapperComponent implements OnDestroy {
    private iconsService;
    hostClass: boolean;
    /**
     * Defines the name for an existing font icon in a Kendo UI theme, which will be rendered.
     * All [Kendo UI Icons]({% slug icons %}#toc-list-of-font-icons) are supported.
     */
    name: string;
    /**
     * Defines an [SVGIcon](slug:api_icons_svgicon) to be rendered.
     */
    svgIcon: SVGIcon;
    /**
     * Provided by consuming components in case an additional k-specific class needs to be rendered
     * on the internal Icon component.
     */
    innerCssClass: string;
    /**
     * Provided by consuming components in case a custom font icon class is set
     * by the developer using the consuming component through its API.
     */
    customFontClass: string;
    /**
     * Specifies the size of the Icon.
     *
     * The possible values are:
     * * `default` (Default) (Font-size: 16px; Width: 16px; Height: 16px)
     * * `xsmall` (Font-size: 12px; Width: 12px; Height: 12px;)
     * * `small` (Font-size: 14px; Width: 14px; Height: 14px;)
     * * `medium` (Font-size: 16px; Width: 16px; Height: 16px;)
     * * `large` (Font-size: 20px; Width: 20px; Height: 20px;)
     * * `xlarge` (Font-size: 24px; Width: 24px; Height: 24px;)
     * * `xxlarge` (Font-size: 32px; Width: 32px; Height: 32px;)
     * * `xxxlarge` (Font-size: 48px; Width: 48px; Height: 48px;)
     *
     */
    size: IconSize;
    get customClasses(): string;
    iconSettings: IconSettings;
    get hasSvgIcon(): boolean;
    get customFontIconClass(): string;
    private subs;
    constructor(iconsService: IconsService);
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IconWrapperComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IconWrapperComponent, "kendo-icon-wrapper", ["kendoIconWrapper"], { "name": "name"; "svgIcon": "svgIcon"; "innerCssClass": "innerCssClass"; "customFontClass": "customFontClass"; "size": "size"; }, {}, never, never>;
}
