/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { PopupModule } from '@progress/kendo-angular-popup';
import { DraggableModule } from '@progress/kendo-angular-common';
import { SliderModule } from './slider.module';
import { NumericTextBoxModule } from './numerictextbox.module';
import { ColorPickerComponent } from './colorpicker/colorpicker.component';
import { ColorPaletteComponent } from './colorpicker/color-palette.component';
import { ColorGradientComponent } from './colorpicker/color-gradient.component';
import { ColorInputComponent } from './colorpicker/color-input.component';
import { FlatColorPickerHeaderComponent } from './colorpicker/flatcolorpicker-header.component';
import { FlatColorPickerActionButtonsComponent } from './colorpicker/flatcolorpicker-actions.component';
import { FlatColorPickerComponent } from './colorpicker/flatcolorpicker.component';
import { ColorPickerCustomMessagesComponent } from './colorpicker/localization/custom-messages.component';
import { LocalizedColorPickerMessagesDirective } from './colorpicker/localization/localized-colorpicker-messages.directive';
import { FocusOnDomReadyDirective } from './colorpicker/focus-on-dom-ready.directive';
import { ContrastValidationComponent } from './colorpicker/contrast-validation.component';
import { ContrastComponent } from './colorpicker/contrast.component';
import { ColorContrastSvgComponent } from './colorpicker/color-contrast-svg.component';
import { NumericLabelDirective } from './colorpicker/color-gradient-numeric-label.directive';
import { ButtonModule } from '@progress/kendo-angular-buttons';
import { IconsModule } from '@progress/kendo-angular-icons';
import * as i0 from "@angular/core";
const PUBLIC_DIRECTIVES = [
    ColorPickerComponent,
    ColorPaletteComponent,
    ColorGradientComponent,
    FlatColorPickerComponent,
    LocalizedColorPickerMessagesDirective,
    ColorPickerCustomMessagesComponent
];
const INTERNAL_DIRECTIVES = [
    NumericLabelDirective,
    ColorInputComponent,
    FocusOnDomReadyDirective,
    ContrastComponent,
    ContrastValidationComponent,
    FlatColorPickerHeaderComponent,
    FlatColorPickerActionButtonsComponent,
    ColorContrastSvgComponent
];
/**
 * Represents the [NgModule](link:site.data.urls.angular['ngmoduleapi'])
 * definition for the ColorPicker.
 */
export class ColorPickerModule {
}
ColorPickerModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ColorPickerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ColorPickerModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ColorPickerModule, declarations: [ColorPickerComponent,
        ColorPaletteComponent,
        ColorGradientComponent,
        FlatColorPickerComponent,
        LocalizedColorPickerMessagesDirective,
        ColorPickerCustomMessagesComponent, NumericLabelDirective,
        ColorInputComponent,
        FocusOnDomReadyDirective,
        ContrastComponent,
        ContrastValidationComponent,
        FlatColorPickerHeaderComponent,
        FlatColorPickerActionButtonsComponent,
        ColorContrastSvgComponent], imports: [SliderModule,
        NumericTextBoxModule,
        CommonModule,
        PopupModule,
        DraggableModule,
        ButtonModule,
        IconsModule], exports: [ColorPickerComponent,
        ColorPaletteComponent,
        ColorGradientComponent,
        FlatColorPickerComponent,
        LocalizedColorPickerMessagesDirective,
        ColorPickerCustomMessagesComponent] });
ColorPickerModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ColorPickerModule, imports: [[
            SliderModule,
            NumericTextBoxModule,
            CommonModule,
            PopupModule,
            DraggableModule,
            ButtonModule,
            IconsModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: ColorPickerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        PUBLIC_DIRECTIVES,
                        INTERNAL_DIRECTIVES
                    ],
                    exports: [PUBLIC_DIRECTIVES],
                    imports: [
                        SliderModule,
                        NumericTextBoxModule,
                        CommonModule,
                        PopupModule,
                        DraggableModule,
                        ButtonModule,
                        IconsModule
                    ]
                }]
        }] });
