/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "agq",
    likelySubtags: {
        agq: "agq-Latn-CM"
    },
    identity: {
        language: "agq"
    },
    territory: "CM",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE d MMMM y",
            m: "d MMM",
            M: "MMMM d",
            y: "MMM y",
            Y: "y MMMM",
            F: "EEEE d MMMM y HH:mm:ss",
            g: "d/M/y HH:mm",
            G: "d/M/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E d/M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E d MMM",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "m:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E d/M/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E d MMM y",
                yMMMM: "y MMMM",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE d MMMM y",
            long: "d MMMM y",
            medium: "d MMM, y",
            short: "d/M/y"
        },
        days: {
            format: {
                abbreviated: [
                    "nts",
                    "kpa",
                    "ghɔ",
                    "tɔm",
                    "ume",
                    "ghɨ",
                    "dzk"
                ],
                narrow: [
                    "n",
                    "k",
                    "g",
                    "t",
                    "u",
                    "g",
                    "d"
                ],
                short: [
                    "nts",
                    "kpa",
                    "ghɔ",
                    "tɔm",
                    "ume",
                    "ghɨ",
                    "dzk"
                ],
                wide: [
                    "tsuʔntsɨ",
                    "tsuʔukpà",
                    "tsuʔughɔe",
                    "tsuʔutɔ̀mlò",
                    "tsuʔumè",
                    "tsuʔughɨ̂m",
                    "tsuʔndzɨkɔʔɔ"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "nts",
                    "kpa",
                    "ghɔ",
                    "tɔm",
                    "ume",
                    "ghɨ",
                    "dzk"
                ],
                narrow: [
                    "n",
                    "k",
                    "g",
                    "t",
                    "u",
                    "g",
                    "d"
                ],
                short: [
                    "nts",
                    "kpa",
                    "ghɔ",
                    "tɔm",
                    "ume",
                    "ghɨ",
                    "dzk"
                ],
                wide: [
                    "tsuʔntsɨ",
                    "tsuʔukpà",
                    "tsuʔughɔe",
                    "tsuʔutɔ̀mlò",
                    "tsuʔumè",
                    "tsuʔughɨ̂m",
                    "tsuʔndzɨkɔʔɔ"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "nùm",
                    "kɨz",
                    "tɨd",
                    "taa",
                    "see",
                    "nzu",
                    "dum",
                    "fɔe",
                    "dzu",
                    "lɔm",
                    "kaa",
                    "fwo"
                ],
                narrow: [
                    "n",
                    "k",
                    "t",
                    "t",
                    "s",
                    "z",
                    "k",
                    "f",
                    "d",
                    "l",
                    "c",
                    "f"
                ],
                wide: [
                    "ndzɔ̀ŋɔ̀nùm",
                    "ndzɔ̀ŋɔ̀kƗ̀zùʔ",
                    "ndzɔ̀ŋɔ̀tƗ̀dʉ̀ghà",
                    "ndzɔ̀ŋɔ̀tǎafʉ̄ghā",
                    "ndzɔ̀ŋèsèe",
                    "ndzɔ̀ŋɔ̀nzùghò",
                    "ndzɔ̀ŋɔ̀dùmlo",
                    "ndzɔ̀ŋɔ̀kwîfɔ̀e",
                    "ndzɔ̀ŋɔ̀tƗ̀fʉ̀ghàdzughù",
                    "ndzɔ̀ŋɔ̀ghǔuwelɔ̀m",
                    "ndzɔ̀ŋɔ̀chwaʔàkaa wo",
                    "ndzɔ̀ŋèfwòo"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "nùm",
                    "kɨz",
                    "tɨd",
                    "taa",
                    "see",
                    "nzu",
                    "dum",
                    "fɔe",
                    "dzu",
                    "lɔm",
                    "kaa",
                    "fwo"
                ],
                narrow: [
                    "n",
                    "k",
                    "t",
                    "t",
                    "s",
                    "z",
                    "k",
                    "f",
                    "d",
                    "l",
                    "c",
                    "f"
                ],
                wide: [
                    "ndzɔ̀ŋɔ̀nùm",
                    "ndzɔ̀ŋɔ̀kƗ̀zùʔ",
                    "ndzɔ̀ŋɔ̀tƗ̀dʉ̀ghà",
                    "ndzɔ̀ŋɔ̀tǎafʉ̄ghā",
                    "ndzɔ̀ŋèsèe",
                    "ndzɔ̀ŋɔ̀nzùghò",
                    "ndzɔ̀ŋɔ̀dùmlo",
                    "ndzɔ̀ŋɔ̀kwîfɔ̀e",
                    "ndzɔ̀ŋɔ̀tƗ̀fʉ̀ghàdzughù",
                    "ndzɔ̀ŋɔ̀ghǔuwelɔ̀m",
                    "ndzɔ̀ŋɔ̀chwaʔàkaa wo",
                    "ndzɔ̀ŋèfwòo"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "kɨbâ kɨ 1",
                    "ugbâ u 2",
                    "ugbâ u 3",
                    "ugbâ u 4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "kɨbâ kɨ 1",
                    "ugbâ u 2",
                    "ugbâ u 3",
                    "ugbâ u 4"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "kɨbâ kɨ 1",
                    "ugbâ u 2",
                    "ugbâ u 3",
                    "ugbâ u 4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "kɨbâ kɨ 1",
                    "ugbâ u 2",
                    "ugbâ u 3",
                    "ugbâ u 4"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "a.g",
                    pm: "a.k"
                },
                narrow: {
                    am: "a.g",
                    pm: "a.k"
                },
                wide: {
                    am: "a.g",
                    pm: "a.k"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "a.g",
                    pm: "a.k"
                },
                narrow: {
                    am: "a.g",
                    pm: "a.k"
                },
                wide: {
                    am: "a.g",
                    pm: "a.k"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Sěe Kɨ̀lesto",
                    "1": "Bǎa Kɨ̀lesto",
                    "0-alt-variant": "SK",
                    "1-alt-variant": "BK"
                },
                abbreviated: {
                    "0": "SK",
                    "1": "BK",
                    "0-alt-variant": "SK",
                    "1-alt-variant": "BK"
                },
                narrow: {
                    "0": "SK",
                    "1": "BK",
                    "0-alt-variant": "SK",
                    "1-alt-variant": "BK"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "kɨtîgh",
                short: "kɨtîgh",
                narrow: "kɨtîgh"
            },
            year: {
                wide: "kɨnûm",
                short: "kɨnûm",
                narrow: "kɨnûm"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "ndzɔŋ",
                short: "ndzɔŋ",
                narrow: "ndzɔŋ"
            },
            week: {
                wide: "ewɨn",
                short: "ewɨn",
                narrow: "ewɨn"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "utsuʔ",
                short: "utsuʔ",
                narrow: "utsuʔ"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "tsuʔu mɨ̀ èwɨ̄n",
                short: "tsuʔu mɨ̀ èwɨ̄n",
                narrow: "tsuʔu mɨ̀ èwɨ̄n"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "â tsɨ̀",
                wide: "â tsɨ̀",
                narrow: "â tsɨ̀"
            },
            hour: {
                wide: "tàm",
                short: "tàm",
                narrow: "tàm"
            },
            minute: {
                wide: "menè",
                short: "menè",
                narrow: "menè"
            },
            second: {
                wide: "sɛkɔ̀n",
                short: "sɛkɔ̀n",
                narrow: "sɛkɔ̀n"
            },
            zone: {
                wide: "dɨŋò kɨ enɨ̀gha",
                short: "dɨŋò kɨ enɨ̀gha",
                narrow: "dɨŋò kɨ enɨ̀gha"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

