/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ar-TN",
    likelySubtags: {
        ar: "ar-Arab-EG"
    },
    identity: {
        language: "ar",
        territory: "TN"
    },
    territory: "TN",
    calendar: {
        patterns: {
            d: "d‏/M‏/y",
            D: "EEEE، d MMMM y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE، d MMMM y h:mm:ss a",
            g: "d‏/M‏/y h:mm a",
            G: "d‏/M‏/y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} في {0}",
            long: "{1} في {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E، d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "dd-MM-y GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "d MMM y G",
                GyMMMEd: "E، d MMM y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/‏M",
                MEd: "E، d/‏M",
                MMdd: "dd‏/MM",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E، d MMM",
                MMMMd: "d MMMM",
                MMMMEd: "E، d MMMM",
                "MMMMW-count-zero": "الأسبوع W من MMMM",
                "MMMMW-count-one": "الأسبوع W من MMMM",
                "MMMMW-count-two": "الأسبوع W من MMMM",
                "MMMMW-count-few": "الأسبوع W من MMMM",
                "MMMMW-count-many": "الأسبوع W من MMMM",
                "MMMMW-count-other": "الأسبوع W من MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M‏/y",
                yMd: "d‏/M‏/y",
                yMEd: "E، d/‏M/‏y",
                yMM: "MM‏/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E، d MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-zero": "الأسبوع w من سنة Y",
                "yw-count-one": "الأسبوع w من سنة Y",
                "yw-count-two": "الأسبوع w من سنة Y",
                "yw-count-few": "الأسبوع w من سنة Y",
                "yw-count-many": "الأسبوع w من سنة Y",
                "yw-count-other": "الأسبوع w من سنة Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "EEEE، d MMMM y",
            long: "d MMMM y",
            medium: "dd‏/MM‏/y",
            short: "d‏/M‏/y"
        },
        days: {
            format: {
                abbreviated: [
                    "الأحد",
                    "الاثنين",
                    "الثلاثاء",
                    "الأربعاء",
                    "الخميس",
                    "الجمعة",
                    "السبت"
                ],
                narrow: [
                    "ح",
                    "ن",
                    "ث",
                    "ر",
                    "خ",
                    "ج",
                    "س"
                ],
                short: [
                    "أحد",
                    "إثنين",
                    "ثلاثاء",
                    "أربعاء",
                    "خميس",
                    "جمعة",
                    "سبت"
                ],
                wide: [
                    "الأحد",
                    "الاثنين",
                    "الثلاثاء",
                    "الأربعاء",
                    "الخميس",
                    "الجمعة",
                    "السبت"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "الأحد",
                    "الاثنين",
                    "الثلاثاء",
                    "الأربعاء",
                    "الخميس",
                    "الجمعة",
                    "السبت"
                ],
                narrow: [
                    "ح",
                    "ن",
                    "ث",
                    "ر",
                    "خ",
                    "ج",
                    "س"
                ],
                short: [
                    "أحد",
                    "إثنين",
                    "ثلاثاء",
                    "أربعاء",
                    "خميس",
                    "جمعة",
                    "سبت"
                ],
                wide: [
                    "الأحد",
                    "الاثنين",
                    "الثلاثاء",
                    "الأربعاء",
                    "الخميس",
                    "الجمعة",
                    "السبت"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "جانفي",
                    "فيفري",
                    "مارس",
                    "أفريل",
                    "ماي",
                    "جوان",
                    "جويلية",
                    "أوت",
                    "سبتمبر",
                    "أكتوبر",
                    "نوفمبر",
                    "ديسمبر"
                ],
                narrow: [
                    "ج",
                    "ف",
                    "م",
                    "أ",
                    "م",
                    "ج",
                    "ج",
                    "أ",
                    "س",
                    "أ",
                    "ن",
                    "د"
                ],
                wide: [
                    "جانفي",
                    "فيفري",
                    "مارس",
                    "أفريل",
                    "ماي",
                    "جوان",
                    "جويلية",
                    "أوت",
                    "سبتمبر",
                    "أكتوبر",
                    "نوفمبر",
                    "ديسمبر"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "جانفي",
                    "فيفري",
                    "مارس",
                    "أفريل",
                    "ماي",
                    "جوان",
                    "جويلية",
                    "أوت",
                    "سبتمبر",
                    "أكتوبر",
                    "نوفمبر",
                    "ديسمبر"
                ],
                narrow: [
                    "ج",
                    "ف",
                    "م",
                    "أ",
                    "م",
                    "ج",
                    "ج",
                    "أ",
                    "س",
                    "أ",
                    "ن",
                    "د"
                ],
                wide: [
                    "جانفي",
                    "فيفري",
                    "مارس",
                    "أفريل",
                    "ماي",
                    "جوان",
                    "جويلية",
                    "أوت",
                    "سبتمبر",
                    "أكتوبر",
                    "نوفمبر",
                    "ديسمبر"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "الربع الأول",
                    "الربع الثاني",
                    "الربع الثالث",
                    "الربع الرابع"
                ],
                narrow: [
                    "١",
                    "٢",
                    "٣",
                    "٤"
                ],
                wide: [
                    "الربع الأول",
                    "الربع الثاني",
                    "الربع الثالث",
                    "الربع الرابع"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "الربع الأول",
                    "الربع الثاني",
                    "الربع الثالث",
                    "الربع الرابع"
                ],
                narrow: [
                    "١",
                    "٢",
                    "٣",
                    "٤"
                ],
                wide: [
                    "الربع الأول",
                    "الربع الثاني",
                    "الربع الثالث",
                    "الربع الرابع"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "ص",
                    pm: "م",
                    morning1: "فجرًا",
                    morning2: "ص",
                    afternoon1: "ظهرًا",
                    afternoon2: "بعد الظهر",
                    evening1: "مساءً",
                    night1: "في المساء",
                    night2: "ليلاً"
                },
                narrow: {
                    am: "ص",
                    pm: "م",
                    morning1: "فجرًا",
                    morning2: "صباحًا",
                    afternoon1: "ظهرًا",
                    afternoon2: "بعد الظهر",
                    evening1: "مساءً",
                    night1: "منتصف الليل",
                    night2: "ليلاً"
                },
                wide: {
                    am: "ص",
                    pm: "م",
                    morning1: "في الصباح",
                    morning2: "صباحًا",
                    afternoon1: "ظهرًا",
                    afternoon2: "بعد الظهر",
                    evening1: "مساءً",
                    night1: "في المساء",
                    night2: "ليلاً"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "ص",
                    pm: "م",
                    morning1: "فجرًا",
                    morning2: "ص",
                    afternoon1: "ظهرًا",
                    afternoon2: "بعد الظهر",
                    evening1: "مساءً",
                    night1: "منتصف الليل",
                    night2: "ليلاً"
                },
                narrow: {
                    am: "ص",
                    pm: "م",
                    morning1: "فجرًا",
                    morning2: "صباحًا",
                    afternoon1: "ظهرًا",
                    afternoon2: "بعد الظهر",
                    evening1: "مساءً",
                    night1: "منتصف الليل",
                    night2: "ليلاً"
                },
                wide: {
                    am: "صباحًا",
                    pm: "مساءً",
                    morning1: "فجرًا",
                    morning2: "صباحًا",
                    afternoon1: "ظهرًا",
                    afternoon2: "بعد الظهر",
                    evening1: "مساءً",
                    night1: "منتصف الليل",
                    night2: "ليلاً"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "قبل الميلاد",
                    "1": "ميلادي",
                    "0-alt-variant": "قبل الحقبة الحالية",
                    "1-alt-variant": "بعد الميلاد"
                },
                abbreviated: {
                    "0": "ق.م",
                    "1": "م",
                    "0-alt-variant": "ق. م",
                    "1-alt-variant": "ب.م"
                },
                narrow: {
                    "0": "ق.م",
                    "1": "م",
                    "0-alt-variant": "ق. م",
                    "1-alt-variant": "ب.م"
                }
            }
        },
        gmtFormat: "غرينتش{0}",
        gmtZeroFormat: "غرينتش",
        dateFields: {
            era: {
                wide: "العصر",
                short: "العصر",
                narrow: "العصر"
            },
            year: {
                wide: "السنة",
                short: "السنة",
                narrow: "السنة"
            },
            quarter: {
                wide: "ربع السنة",
                short: "ربع السنة",
                narrow: "ربع السنة"
            },
            month: {
                wide: "الشهر",
                short: "الشهر",
                narrow: "الشهر"
            },
            week: {
                wide: "الأسبوع",
                short: "الأسبوع",
                narrow: "الأسبوع"
            },
            weekOfMonth: {
                wide: "الأسبوع من الشهر",
                short: "أسبوع من شهر",
                narrow: "أسبوع/شهر"
            },
            day: {
                wide: "يوم",
                short: "يوم",
                narrow: "يوم"
            },
            dayOfYear: {
                wide: "يوم من السنة",
                short: "يوم من سنة",
                narrow: "يوم/سنة"
            },
            weekday: {
                wide: "اليوم",
                short: "اليوم",
                narrow: "اليوم"
            },
            weekdayOfMonth: {
                wide: "يوم عمل من الشهر",
                short: "يوم عمل من شهر",
                narrow: "يوم عمل/شهر"
            },
            dayperiod: {
                short: "ص/م",
                wide: "ص/م",
                narrow: "ص/م"
            },
            hour: {
                wide: "الساعات",
                short: "الساعات",
                narrow: "الساعات"
            },
            minute: {
                wide: "الدقائق",
                short: "الدقائق",
                narrow: "الدقائق"
            },
            second: {
                wide: "الثواني",
                short: "الثواني",
                narrow: "الثواني"
            },
            zone: {
                wide: "التوقيت",
                short: "توقيت",
                narrow: "توقيت"
            },
            millisecond: {
                narrow: "ملي ث",
                short: "ملي ث",
                wide: "ملي ثانية"
            }
        }
    },
    firstDay: 1
});

