/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ast",
    likelySubtags: {
        ast: "ast-Latn-ES"
    },
    identity: {
        language: "ast"
    },
    territory: "ES",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE, d MMMM 'de' y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "LLLL 'de' y",
            F: "EEEE, d MMMM 'de' y HH:mm:ss",
            g: "d/M/y HH:mm",
            G: "d/M/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} 'a' 'les' {0}",
            long: "{1} 'a' 'les' {0}",
            medium: "{1}, {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "MMM y G",
                GyMMMd: "d MMM y G",
                GyMMMEd: "E, d MMM y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E, d/M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E, d MMM",
                MMMMd: "d MMMM",
                "MMMMW-count-one": "'selmana' W 'de' MMMM",
                "MMMMW-count-other": "'selmana' W 'de' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E, d/M/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E, d MMM y",
                yMMMM: "LLLL 'de' y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ 'de' y",
                "yw-count-one": "'selmana' w 'de' Y",
                "yw-count-other": "'selmana' w 'de' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM 'de' y",
            long: "d MMMM 'de' y",
            medium: "d MMM y",
            short: "d/M/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "dom",
                    "llu",
                    "mar",
                    "mié",
                    "xue",
                    "vie",
                    "sáb"
                ],
                narrow: [
                    "D",
                    "L",
                    "M",
                    "M",
                    "X",
                    "V",
                    "S"
                ],
                short: [
                    "do",
                    "ll",
                    "ma",
                    "mi",
                    "xu",
                    "vi",
                    "sá"
                ],
                wide: [
                    "domingu",
                    "llunes",
                    "martes",
                    "miércoles",
                    "xueves",
                    "vienres",
                    "sábadu"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "dom",
                    "llu",
                    "mar",
                    "mié",
                    "xue",
                    "vie",
                    "sáb"
                ],
                narrow: [
                    "D",
                    "L",
                    "M",
                    "M",
                    "X",
                    "V",
                    "S"
                ],
                short: [
                    "do",
                    "ll",
                    "ma",
                    "mi",
                    "xu",
                    "vi",
                    "sá"
                ],
                wide: [
                    "domingu",
                    "llunes",
                    "martes",
                    "miércoles",
                    "xueves",
                    "vienres",
                    "sábadu"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "xin",
                    "feb",
                    "mar",
                    "abr",
                    "may",
                    "xun",
                    "xnt",
                    "ago",
                    "set",
                    "och",
                    "pay",
                    "avi"
                ],
                narrow: [
                    "X",
                    "F",
                    "M",
                    "A",
                    "M",
                    "X",
                    "X",
                    "A",
                    "S",
                    "O",
                    "P",
                    "A"
                ],
                wide: [
                    "de xineru",
                    "de febreru",
                    "de marzu",
                    "d’abril",
                    "de mayu",
                    "de xunu",
                    "de xunetu",
                    "d’agostu",
                    "de setiembre",
                    "d’ochobre",
                    "de payares",
                    "d’avientu"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Xin",
                    "Feb",
                    "Mar",
                    "Abr",
                    "May",
                    "Xun",
                    "Xnt",
                    "Ago",
                    "Set",
                    "Och",
                    "Pay",
                    "Avi"
                ],
                narrow: [
                    "X",
                    "F",
                    "M",
                    "A",
                    "M",
                    "X",
                    "X",
                    "A",
                    "S",
                    "O",
                    "P",
                    "A"
                ],
                wide: [
                    "xineru",
                    "febreru",
                    "marzu",
                    "abril",
                    "mayu",
                    "xunu",
                    "xunetu",
                    "agostu",
                    "setiembre",
                    "ochobre",
                    "payares",
                    "avientu"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1T",
                    "2T",
                    "3T",
                    "4T"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1er trimestre",
                    "2u trimestre",
                    "3er trimestre",
                    "4u trimestre"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1T",
                    "2T",
                    "3T",
                    "4T"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1er trimestre",
                    "2u trimestre",
                    "3er trimestre",
                    "4u trimestre"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "a",
                    pm: "p"
                },
                wide: {
                    am: "de la mañana",
                    pm: "de la tarde"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "a",
                    pm: "p"
                },
                wide: {
                    am: "mañana",
                    pm: "tarde"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "enantes de Cristu",
                    "1": "después de Cristu",
                    "0-alt-variant": "enantes de la dómina común",
                    "1-alt-variant": "dómina común"
                },
                abbreviated: {
                    "0": "e.C.",
                    "1": "d.C.",
                    "0-alt-variant": "EDC",
                    "1-alt-variant": "DC"
                },
                narrow: {
                    "0": "e.C.",
                    "1": "d.C.",
                    "0-alt-variant": "EDC",
                    "1-alt-variant": "DC"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "era",
                short: "era",
                narrow: "era"
            },
            year: {
                wide: "añu",
                short: "añu",
                narrow: "añu"
            },
            quarter: {
                wide: "trimestre",
                short: "tri.",
                narrow: "tri."
            },
            month: {
                wide: "mes",
                short: "mes",
                narrow: "mes"
            },
            week: {
                wide: "selmana",
                short: "sel.",
                narrow: "sel."
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "día",
                short: "día",
                narrow: "día"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "día de la selmana",
                short: "día de la selmana",
                narrow: "día de la selmana"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "periodu del día",
                wide: "periodu del día",
                narrow: "periodu del día"
            },
            hour: {
                wide: "hora",
                short: "h.",
                narrow: "h."
            },
            minute: {
                wide: "minutu",
                short: "min.",
                narrow: "m."
            },
            second: {
                wide: "segundu",
                short: "s.",
                narrow: "s."
            },
            zone: {
                wide: "estaya horaria",
                short: "estaya horaria",
                narrow: "estaya horaria"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "milisegundu"
            }
        }
    },
    firstDay: 1
});

