/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "bas",
    likelySubtags: {
        bas: "bas-Latn-CM"
    },
    identity: {
        language: "bas"
    },
    territory: "CM",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE d MMMM y",
            m: "d MMM",
            M: "MMMM d",
            y: "MMM y",
            Y: "y MMMM",
            F: "EEEE d MMMM y HH:mm:ss",
            g: "d/M/y HH:mm",
            G: "d/M/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E d/M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E d MMM",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "m:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E d/M/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E d MMM y",
                yMMMM: "y MMMM",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE d MMMM y",
            long: "d MMMM y",
            medium: "d MMM, y",
            short: "d/M/y"
        },
        days: {
            format: {
                abbreviated: [
                    "nɔy",
                    "nja",
                    "uum",
                    "ŋge",
                    "mbɔ",
                    "kɔɔ",
                    "jon"
                ],
                narrow: [
                    "n",
                    "n",
                    "u",
                    "ŋ",
                    "m",
                    "k",
                    "j"
                ],
                short: [
                    "nɔy",
                    "nja",
                    "uum",
                    "ŋge",
                    "mbɔ",
                    "kɔɔ",
                    "jon"
                ],
                wide: [
                    "ŋgwà nɔ̂y",
                    "ŋgwà njaŋgumba",
                    "ŋgwà ûm",
                    "ŋgwà ŋgê",
                    "ŋgwà mbɔk",
                    "ŋgwà kɔɔ",
                    "ŋgwà jôn"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "nɔy",
                    "nja",
                    "uum",
                    "ŋge",
                    "mbɔ",
                    "kɔɔ",
                    "jon"
                ],
                narrow: [
                    "n",
                    "n",
                    "u",
                    "ŋ",
                    "m",
                    "k",
                    "j"
                ],
                short: [
                    "nɔy",
                    "nja",
                    "uum",
                    "ŋge",
                    "mbɔ",
                    "kɔɔ",
                    "jon"
                ],
                wide: [
                    "ŋgwà nɔ̂y",
                    "ŋgwà njaŋgumba",
                    "ŋgwà ûm",
                    "ŋgwà ŋgê",
                    "ŋgwà mbɔk",
                    "ŋgwà kɔɔ",
                    "ŋgwà jôn"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "kɔn",
                    "mac",
                    "mat",
                    "mto",
                    "mpu",
                    "hil",
                    "nje",
                    "hik",
                    "dip",
                    "bio",
                    "may",
                    "liɓ"
                ],
                narrow: [
                    "k",
                    "m",
                    "m",
                    "m",
                    "m",
                    "h",
                    "n",
                    "h",
                    "d",
                    "b",
                    "m",
                    "l"
                ],
                wide: [
                    "Kɔndɔŋ",
                    "Màcɛ̂l",
                    "Màtùmb",
                    "Màtop",
                    "M̀puyɛ",
                    "Hìlòndɛ̀",
                    "Njèbà",
                    "Hìkaŋ",
                    "Dìpɔ̀s",
                    "Bìòôm",
                    "Màyɛsèp",
                    "Lìbuy li ńyèe"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "kɔn",
                    "mac",
                    "mat",
                    "mto",
                    "mpu",
                    "hil",
                    "nje",
                    "hik",
                    "dip",
                    "bio",
                    "may",
                    "liɓ"
                ],
                narrow: [
                    "k",
                    "m",
                    "m",
                    "m",
                    "m",
                    "h",
                    "n",
                    "h",
                    "d",
                    "b",
                    "m",
                    "l"
                ],
                wide: [
                    "Kɔndɔŋ",
                    "Màcɛ̂l",
                    "Màtùmb",
                    "Màtop",
                    "M̀puyɛ",
                    "Hìlòndɛ̀",
                    "Njèbà",
                    "Hìkaŋ",
                    "Dìpɔ̀s",
                    "Bìòôm",
                    "Màyɛsèp",
                    "Lìbuy li ńyèe"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "K1s3",
                    "K2s3",
                    "K3s3",
                    "K4s3"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Kèk bisu i soŋ iaâ",
                    "Kèk i ńyonos biɓaà i soŋ iaâ",
                    "Kèk i ńyonos biaâ i soŋ iaâ",
                    "Kèk i ńyonos binâ i soŋ iaâ"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "K1s3",
                    "K2s3",
                    "K3s3",
                    "K4s3"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Kèk bisu i soŋ iaâ",
                    "Kèk i ńyonos biɓaà i soŋ iaâ",
                    "Kèk i ńyonos biaâ i soŋ iaâ",
                    "Kèk i ńyonos binâ i soŋ iaâ"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "I bikɛ̂glà",
                    pm: "I ɓugajɔp"
                },
                narrow: {
                    am: "I bikɛ̂glà",
                    pm: "I ɓugajɔp"
                },
                wide: {
                    am: "I bikɛ̂glà",
                    pm: "I ɓugajɔp"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "I bikɛ̂glà",
                    pm: "I ɓugajɔp"
                },
                narrow: {
                    am: "I bikɛ̂glà",
                    pm: "I ɓugajɔp"
                },
                wide: {
                    am: "I bikɛ̂glà",
                    pm: "I ɓugajɔp"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "bisū bi Yesù Krǐstò",
                    "1": "i mbūs Yesù Krǐstò",
                    "0-alt-variant": "b.Y.K",
                    "1-alt-variant": "m.Y.K"
                },
                abbreviated: {
                    "0": "b.Y.K",
                    "1": "m.Y.K",
                    "0-alt-variant": "b.Y.K",
                    "1-alt-variant": "m.Y.K"
                },
                narrow: {
                    "0": "b.Y.K",
                    "1": "m.Y.K",
                    "0-alt-variant": "b.Y.K",
                    "1-alt-variant": "m.Y.K"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "kèk",
                short: "kèk",
                narrow: "kèk"
            },
            year: {
                wide: "ŋwìi",
                short: "ŋwìi",
                narrow: "ŋwìi"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "soŋ",
                short: "soŋ",
                narrow: "soŋ"
            },
            week: {
                wide: "sɔndɛ̂",
                short: "sɔndɛ̂",
                narrow: "sɔndɛ̂"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "kɛl",
                short: "kɛl",
                narrow: "kɛl"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "hìlɔ hi sɔndɛ̂",
                short: "hìlɔ hi sɔndɛ̂",
                narrow: "hìlɔ hi sɔndɛ̂"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "njǎmùha",
                wide: "njǎmùha",
                narrow: "njǎmùha"
            },
            hour: {
                wide: "ŋgɛŋ",
                short: "ŋgɛŋ",
                narrow: "ŋgɛŋ"
            },
            minute: {
                wide: "ŋget",
                short: "ŋget",
                narrow: "ŋget"
            },
            second: {
                wide: "hìŋgeŋget",
                short: "hìŋgeŋget",
                narrow: "hìŋgeŋget"
            },
            zone: {
                wide: "komboo i ŋgɛŋ",
                short: "komboo i ŋgɛŋ",
                narrow: "komboo i ŋgɛŋ"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

