/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "be-tarask",
    likelySubtags: {
        be: "be-Cyrl-BY"
    },
    identity: {
        language: "be",
        variant: "TARASK"
    },
    territory: "BY",
    calendar: {
        patterns: {
            d: "d.MM.y",
            D: "EEEE, d MMMM y 'г'.",
            m: "d MMM",
            M: "d MMMM",
            y: "LLL y",
            Y: "LLLL y",
            F: "EEEE, d MMMM y 'г'. HH:mm:ss",
            g: "d.M.y HH:mm",
            G: "d.M.y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} 'у' {0}",
            long: "{1} 'у' {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y 'г'. G",
                GyMd: "dd.MM.y GGGGG",
                GyMMM: "LLL y 'г'. G",
                GyMMMd: "d MMM y 'г'. G",
                GyMMMEd: "E, d MMM y 'г'. G",
                h: "hh a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d.M",
                MEd: "E, d.M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E, d MMM",
                MMMMd: "d MMMM",
                MMMMEd: "E, d MMMM",
                "MMMMW-count-one": "W 'тыдзень' MMMM",
                "MMMMW-count-few": "W 'тыдзень' MMMM",
                "MMMMW-count-many": "W 'тыдзень' MMMM",
                "MMMMW-count-other": "W 'тыдзень' MMMM",
                ms: "mm.ss",
                y: "y",
                yM: "M.y",
                yMd: "d.M.y",
                yMEd: "E, d.M.y",
                yMMM: "LLL y",
                yMMMd: "d MMM y",
                yMMMEd: "E, d MMM y",
                yMMMM: "LLLL y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "w 'тыдзень' Y",
                "yw-count-few": "w 'тыдзень' Y",
                "yw-count-many": "w 'тыдзень' Y",
                "yw-count-other": "w 'тыдзень' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss, zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM y 'г'.",
            long: "d MMMM y 'г'.",
            medium: "d MMM y 'г'.",
            short: "d.MM.yy"
        },
        days: {
            format: {
                abbreviated: [
                    "нд",
                    "пн",
                    "аў",
                    "ср",
                    "чц",
                    "пт",
                    "сб"
                ],
                narrow: [
                    "н",
                    "п",
                    "а",
                    "с",
                    "ч",
                    "п",
                    "с"
                ],
                short: [
                    "нд",
                    "пн",
                    "аў",
                    "ср",
                    "чц",
                    "пт",
                    "сб"
                ],
                wide: [
                    "нядзеля",
                    "панядзелак",
                    "аўторак",
                    "серада",
                    "чацвер",
                    "пятніца",
                    "субота"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "нд",
                    "пн",
                    "аў",
                    "ср",
                    "чц",
                    "пт",
                    "сб"
                ],
                narrow: [
                    "н",
                    "п",
                    "а",
                    "с",
                    "ч",
                    "п",
                    "с"
                ],
                short: [
                    "нд",
                    "пн",
                    "аў",
                    "ср",
                    "чц",
                    "пт",
                    "сб"
                ],
                wide: [
                    "нядзеля",
                    "панядзелак",
                    "аўторак",
                    "серада",
                    "чацвер",
                    "пятніца",
                    "субота"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "сту",
                    "лют",
                    "сак",
                    "кра",
                    "мая",
                    "чэр",
                    "ліп",
                    "жні",
                    "вер",
                    "кас",
                    "ліс",
                    "сне"
                ],
                narrow: [
                    "с",
                    "л",
                    "с",
                    "к",
                    "м",
                    "ч",
                    "л",
                    "ж",
                    "в",
                    "к",
                    "л",
                    "с"
                ],
                wide: [
                    "студзеня",
                    "лютага",
                    "сакавіка",
                    "красавіка",
                    "мая",
                    "чэрвеня",
                    "ліпеня",
                    "жніўня",
                    "верасня",
                    "кастрычніка",
                    "лістапада",
                    "снежня"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "сту",
                    "лют",
                    "сак",
                    "кра",
                    "май",
                    "чэр",
                    "ліп",
                    "жні",
                    "вер",
                    "кас",
                    "ліс",
                    "сне"
                ],
                narrow: [
                    "с",
                    "л",
                    "с",
                    "к",
                    "м",
                    "ч",
                    "л",
                    "ж",
                    "в",
                    "к",
                    "л",
                    "с"
                ],
                wide: [
                    "студзень",
                    "люты",
                    "сакавік",
                    "красавік",
                    "май",
                    "чэрвень",
                    "ліпень",
                    "жнівень",
                    "верасень",
                    "кастрычнік",
                    "лістапад",
                    "снежань"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1-шы кв.",
                    "2-гі кв.",
                    "3-ці кв.",
                    "4-ты кв."
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1-шы квартал",
                    "2-гі квартал",
                    "3-ці квартал",
                    "4-ты квартал"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1-шы кв.",
                    "2-гі кв.",
                    "3-ці кв.",
                    "4-ты кв."
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1-шы квартал",
                    "2-гі квартал",
                    "3-ці квартал",
                    "4-ты квартал"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "am",
                    pm: "pm"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "да нараджэння Хрыстова",
                    "1": "ад нараджэння Хрыстова",
                    "0-alt-variant": "да нашай эры",
                    "1-alt-variant": "нашай эры"
                },
                abbreviated: {
                    "0": "да н.э.",
                    "1": "н.э.",
                    "0-alt-variant": "да н.э.",
                    "1-alt-variant": "н.э."
                },
                narrow: {
                    "0": "да н.э.",
                    "1": "н.э.",
                    "0-alt-variant": "да н.э.",
                    "1-alt-variant": "н.э."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "эра",
                short: "эра",
                narrow: "эра"
            },
            year: {
                wide: "год",
                short: "г.",
                narrow: "г."
            },
            quarter: {
                wide: "квартал",
                short: "кв.",
                narrow: "кв."
            },
            month: {
                wide: "месяц",
                short: "мес.",
                narrow: "мес."
            },
            week: {
                wide: "тыд",
                short: "тыд",
                narrow: "тыд"
            },
            weekOfMonth: {
                wide: "тыдзень месяца",
                short: "тыдзень месяца",
                narrow: "тыдзень месяца"
            },
            day: {
                wide: "дзень",
                short: "дзень",
                narrow: "д."
            },
            dayOfYear: {
                wide: "дзень года",
                short: "дзень года",
                narrow: "дзень года"
            },
            weekday: {
                wide: "дзень тыдня",
                short: "дзень тыдня",
                narrow: "дзень тыдня"
            },
            weekdayOfMonth: {
                wide: "дзень месяца",
                short: "дзень месяца",
                narrow: "дзень месяца"
            },
            dayperiod: {
                short: "AM/PM",
                wide: "AM/PM",
                narrow: "AM/PM"
            },
            hour: {
                wide: "гадзіна",
                short: "гадз",
                narrow: "гадз"
            },
            minute: {
                wide: "хвіліна",
                short: "хв",
                narrow: "хв"
            },
            second: {
                wide: "секунда",
                short: "с",
                narrow: "с"
            },
            zone: {
                wide: "часавы пояс",
                short: "часавы пояс",
                narrow: "часавы пояс"
            },
            millisecond: {
                narrow: "мс",
                short: "мс",
                wide: "мілісекунда"
            }
        }
    },
    firstDay: 1
});

