/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "bm",
    likelySubtags: {
        bm: "bm-Latn-ML"
    },
    identity: {
        language: "bm"
    },
    territory: "ML",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE d MMMM y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE d MMMM y HH:mm:ss",
            g: "d/M/y HH:mm",
            G: "d/M/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "M",
                Md: "d/M",
                MEd: "MM-dd, E",
                MMd: "d/MM",
                MMdd: "dd/MM",
                MMM: "MMM",
                MMMd: "d MMM",
                MMMEd: "E d MMM",
                MMMMd: "d MMMM",
                MMMMEd: "E d MMMM",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "m:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E d/M/y",
                yMM: "MM/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E d MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE d MMMM y",
            long: "d MMMM y",
            medium: "d MMM, y",
            short: "d/M/y"
        },
        days: {
            format: {
                abbreviated: [
                    "kar",
                    "ntɛ",
                    "tar",
                    "ara",
                    "ala",
                    "jum",
                    "sib"
                ],
                narrow: [
                    "K",
                    "N",
                    "T",
                    "A",
                    "A",
                    "J",
                    "S"
                ],
                short: [
                    "kar",
                    "ntɛ",
                    "tar",
                    "ara",
                    "ala",
                    "jum",
                    "sib"
                ],
                wide: [
                    "kari",
                    "ntɛnɛ",
                    "tarata",
                    "araba",
                    "alamisa",
                    "juma",
                    "sibiri"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "kar",
                    "ntɛ",
                    "tar",
                    "ara",
                    "ala",
                    "jum",
                    "sib"
                ],
                narrow: [
                    "K",
                    "N",
                    "T",
                    "A",
                    "A",
                    "J",
                    "S"
                ],
                short: [
                    "kar",
                    "ntɛ",
                    "tar",
                    "ara",
                    "ala",
                    "jum",
                    "sib"
                ],
                wide: [
                    "kari",
                    "ntɛnɛ",
                    "tarata",
                    "araba",
                    "alamisa",
                    "juma",
                    "sibiri"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "zan",
                    "feb",
                    "mar",
                    "awi",
                    "mɛ",
                    "zuw",
                    "zul",
                    "uti",
                    "sɛt",
                    "ɔku",
                    "now",
                    "des"
                ],
                narrow: [
                    "Z",
                    "F",
                    "M",
                    "A",
                    "M",
                    "Z",
                    "Z",
                    "U",
                    "S",
                    "Ɔ",
                    "N",
                    "D"
                ],
                wide: [
                    "zanwuye",
                    "feburuye",
                    "marisi",
                    "awirili",
                    "mɛ",
                    "zuwɛn",
                    "zuluye",
                    "uti",
                    "sɛtanburu",
                    "ɔkutɔburu",
                    "nowanburu",
                    "desanburu"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "zan",
                    "feb",
                    "mar",
                    "awi",
                    "mɛ",
                    "zuw",
                    "zul",
                    "uti",
                    "sɛt",
                    "ɔku",
                    "now",
                    "des"
                ],
                narrow: [
                    "Z",
                    "F",
                    "M",
                    "A",
                    "M",
                    "Z",
                    "Z",
                    "U",
                    "S",
                    "Ɔ",
                    "N",
                    "D"
                ],
                wide: [
                    "zanwuye",
                    "feburuye",
                    "marisi",
                    "awirili",
                    "mɛ",
                    "zuwɛn",
                    "zuluye",
                    "uti",
                    "sɛtanburu",
                    "ɔkutɔburu",
                    "nowanburu",
                    "desanburu"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "KS1",
                    "KS2",
                    "KS3",
                    "KS4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "kalo saba fɔlɔ",
                    "kalo saba filanan",
                    "kalo saba sabanan",
                    "kalo saba naaninan"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "KS1",
                    "KS2",
                    "KS3",
                    "KS4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "kalo saba fɔlɔ",
                    "kalo saba filanan",
                    "kalo saba sabanan",
                    "kalo saba naaninan"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "jezu krisiti ɲɛ",
                    "1": "jezu krisiti minkɛ",
                    "0-alt-variant": "J.-C. ɲɛ",
                    "1-alt-variant": "ni J.-C."
                },
                abbreviated: {
                    "0": "J.-C. ɲɛ",
                    "1": "ni J.-C.",
                    "0-alt-variant": "J.-C. ɲɛ",
                    "1-alt-variant": "ni J.-C."
                },
                narrow: {
                    "0": "J.-C. ɲɛ",
                    "1": "ni J.-C.",
                    "0-alt-variant": "J.-C. ɲɛ",
                    "1-alt-variant": "ni J.-C."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "tile",
                short: "tile",
                narrow: "tile"
            },
            year: {
                wide: "san",
                short: "san",
                narrow: "san"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "kalo",
                short: "kalo",
                narrow: "kalo"
            },
            week: {
                wide: "dɔgɔkun",
                short: "dɔgɔkun",
                narrow: "dɔgɔkun"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "don",
                short: "don",
                narrow: "don"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Day of the Week",
                short: "Day of the Week",
                narrow: "Day of the Week"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "sɔgɔma/tile/wula/su",
                wide: "sɔgɔma/tile/wula/su",
                narrow: "sɔgɔma/tile/wula/su"
            },
            hour: {
                wide: "lɛrɛ",
                short: "lɛrɛ",
                narrow: "lɛrɛ"
            },
            minute: {
                wide: "miniti",
                short: "miniti",
                narrow: "miniti"
            },
            second: {
                wide: "sekondi",
                short: "sekondi",
                narrow: "sekondi"
            },
            zone: {
                wide: "sigikun tilena",
                short: "sigikun tilena",
                narrow: "sigikun tilena"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

