/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "brx",
    likelySubtags: {
        brx: "brx-Deva-IN"
    },
    identity: {
        language: "brx"
    },
    territory: "IN",
    calendar: {
        patterns: {
            d: "y-MM-dd",
            D: "y MMMM d, EEEE",
            m: "d-MMM",
            M: "MMMM d",
            y: "MMM y",
            Y: "MMMM y",
            F: "y MMMM d, EEEE a h:mm:ss",
            g: "y-MM-dd a नि h:mm",
            G: "y-MM-dd a h:mm:ss",
            t: "a नि h:mm",
            T: "a h:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} नि {0} याव",
            long: "{1} नि {0} याव",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "B नि h",
                Bhm: "B नि h:mm",
                Bhms: "B नि h:mm:ss",
                d: "d",
                E: "ccc",
                EBhm: "E B नि h:mm",
                EBhms: "E B नि h:mm:ss",
                Ed: "d, E",
                Ehm: "E, a h:mm",
                EHm: "E HH:mm",
                Ehms: "E a h:mm:ss",
                EHms: "E HH:mm:ss",
                Gy: "Gy",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM E d",
                h: "a नि h",
                H: "HH",
                hm: "a नि h:mm",
                Hm: "HH:mm",
                hms: "a h:mm:ss",
                Hms: "HH:mm:ss",
                hmsv: "a नि h:mm:ss v",
                Hmsv: "HH:mm:ss v",
                hmv: "a h:mm v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "M/d",
                MEd: "E, M/d",
                MMM: "LLL",
                MMMd: "d-MMM",
                MMMEd: "E, MMM d",
                MMMMd: "MMMM d",
                MMMMEd: "E, MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "y-MM-dd",
                yMEd: "E, M/d/y",
                yMMM: "MMM y",
                yMMMd: "MMM d, y",
                yMMMEd: "E, MMM d, y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "a h:mm:ss zzzz",
            long: "a h:mm:ss z",
            medium: "a h:mm:ss",
            short: "a नि h:mm"
        },
        dateFormats: {
            full: "y MMMM d, EEEE",
            long: "MMMM d, y",
            medium: "MMM d, y",
            short: "y-MM-dd"
        },
        days: {
            format: {
                abbreviated: [
                    "रबि",
                    "सम",
                    "मंगल",
                    "बुध",
                    "बिस्थि",
                    "सुखुर",
                    "सुनि"
                ],
                narrow: [
                    "र",
                    "स",
                    "मं",
                    "बु",
                    "बि",
                    "सु",
                    "सु"
                ],
                short: [
                    "रबि",
                    "सम",
                    "मंगल",
                    "बुध",
                    "बिस्थि",
                    "सुखुर",
                    "सुनि"
                ],
                wide: [
                    "रबिबार",
                    "समबार",
                    "मंगलबार",
                    "बुधबार",
                    "बिस्थिबार",
                    "सुखुरबार",
                    "सुनिबार"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "रबि",
                    "सम",
                    "मंगल",
                    "बुध",
                    "बिस्थि",
                    "सुखुर",
                    "सुनि"
                ],
                narrow: [
                    "र",
                    "स",
                    "मं",
                    "बु",
                    "बि",
                    "सु",
                    "सु"
                ],
                short: [
                    "रबि",
                    "सम",
                    "मंगल",
                    "बुध",
                    "बिस्थि",
                    "सुखुर",
                    "सुनि"
                ],
                wide: [
                    "रबिबार",
                    "समबार",
                    "मंगलबार",
                    "बुधबार",
                    "बिस्थिबार",
                    "सुखुरबार",
                    "सुनिबार"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "जान",
                    "फेब",
                    "मार्च",
                    "एप्रि",
                    "मे",
                    "जुन",
                    "जुल",
                    "आग",
                    "सेप",
                    "अक्ट’",
                    "नवे",
                    "डिसे"
                ],
                narrow: [
                    "ज",
                    "फ",
                    "म",
                    "ए",
                    "म",
                    "ज",
                    "ज",
                    "आ",
                    "स",
                    "अ",
                    "न",
                    "ड"
                ],
                wide: [
                    "जानुवारी",
                    "फेब्रूवारी",
                    "मार्च",
                    "एप्रिल",
                    "मे",
                    "जुन",
                    "जुलाई",
                    "आगष्ट",
                    "सेप्थेम्बर",
                    "अक्ट’बर",
                    "नवेम्बर",
                    "डिसेम्बर"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "जान",
                    "फेब",
                    "मार्च",
                    "एप्रि",
                    "मे",
                    "जुन",
                    "जुल",
                    "आग",
                    "सेप",
                    "अक्ट’",
                    "नवे",
                    "डिसे"
                ],
                narrow: [
                    "ज",
                    "फ",
                    "म",
                    "ए",
                    "म",
                    "ज",
                    "ज",
                    "आ",
                    "स",
                    "अ",
                    "न",
                    "ड"
                ],
                wide: [
                    "जानुवारी",
                    "फेब्रूवारी",
                    "मार्च",
                    "एप्रिल",
                    "मे",
                    "जुन",
                    "जुलाई",
                    "आगष्ट",
                    "सेप्थेम्बर",
                    "अक्ट’बर",
                    "नवेम्बर",
                    "डिसेम्बर"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "किउ 1",
                    "किउ 2",
                    "किउ 3",
                    "किउ 4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "ब्रै बाहागोनि सेथि खोन्दो",
                    "ब्रै बाहागोनि नैथि खोन्दो",
                    "ब्रै बाहागोनि थामथि खोन्दो",
                    "ब्रै बाहागोनि ब्रैथि खोन्दो"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "किउ 1",
                    "किउ 2",
                    "किउ 3",
                    "किउ 4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "ब्रै बाहागोनि सेथि खोन्दो",
                    "ब्रै बाहागोनि नैथि खोन्दो",
                    "ब्रै बाहागोनि थामथि खोन्दो",
                    "ब्रै बाहागोनि ब्रैथि खोन्दो"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "फुं",
                    pm: "बेलासे"
                },
                narrow: {
                    am: "फुं",
                    pm: "बेलासे"
                },
                wide: {
                    am: "फुं",
                    pm: "बेलासे"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "फुं",
                    pm: "बेलासे"
                },
                narrow: {
                    am: "फुं",
                    pm: "बेलासे"
                },
                wide: {
                    am: "फुं",
                    pm: "बेलासे"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "बि.सि.",
                    "1": "ए.दि",
                    "0-alt-variant": "बिसिइ",
                    "1-alt-variant": "सि.इ."
                },
                abbreviated: {
                    "0": "बि.सि.",
                    "1": "ए.दि",
                    "0-alt-variant": "बिसिइ",
                    "1-alt-variant": "सि.इ."
                },
                narrow: {
                    "0": "बि.सि.",
                    "1": "ए.दि",
                    "0-alt-variant": "बिसिइ",
                    "1-alt-variant": "सि.इ."
                }
            }
        },
        gmtFormat: "जि.एम.ति {0}",
        gmtZeroFormat: "जि.एम.ति",
        dateFields: {
            era: {
                wide: "मुगा",
                short: "मुगा",
                narrow: "मुगा"
            },
            year: {
                wide: "बोसोर",
                short: "बोसोर",
                narrow: "बोसोर"
            },
            quarter: {
                wide: "ब्रै बाहागो खोन्दोेसे",
                short: "खोन्दोेसे",
                narrow: "खोन्दोेसे"
            },
            month: {
                wide: "दान",
                short: "दान",
                narrow: "दान"
            },
            week: {
                wide: "सप्थाह",
                short: "सप्थाह",
                narrow: "सप्थाह"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "सान",
                short: "सान",
                narrow: "सान"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "सप्थाहनि सान",
                short: "सप्थाहनि सान",
                narrow: "सप्थाहनि सान"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "फुं/बेलासे",
                wide: "फुं/बेलासे",
                narrow: "फुं/बेलासे"
            },
            hour: {
                wide: "घन्टा",
                short: "घन्टा",
                narrow: "घन्टा"
            },
            minute: {
                wide: "मिनित",
                short: "मिनित",
                narrow: "मिनित"
            },
            second: {
                wide: "सेकेण्ड",
                short: "सेकेण्ड",
                narrow: "सेकेण्ड"
            },
            zone: {
                wide: "सम मण्डल",
                short: "सम मण्डल",
                narrow: "सम मण्डल"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

