/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "bs-Cyrl",
    likelySubtags: {
        bs: "bs-Latn-BA"
    },
    identity: {
        language: "bs",
        script: "Cyrl"
    },
    territory: "BA",
    calendar: {
        patterns: {
            d: "d.M.y.",
            D: "EEEE, dd. MMMM y.",
            m: "dd. MMM",
            M: "d. MMMM",
            y: "MMM y.",
            Y: "MMMM y.",
            F: "EEEE, dd. MMMM y. HH:mm:ss",
            g: "dd.MM.y. HH:mm",
            G: "dd.MM.y. HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E, d.",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y. G",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "MMM y. G",
                GyMMMd: "dd. MMM y. G",
                GyMMMEd: "E, dd. MMM y. G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "dd.MM.",
                MEd: "E, dd.MM.",
                MMM: "LLL",
                MMMd: "dd. MMM",
                MMMEd: "E, dd. MMM",
                MMMMd: "d. MMMM",
                "MMMMW-count-one": "'седмица' W 'мјесец' MMMM",
                "MMMMW-count-few": "'седмица' W 'мјесец' MMMM",
                "MMMMW-count-other": "'седмица' W 'мјесец' MMMM",
                ms: "mm:ss",
                y: "y.",
                yM: "MM.y.",
                yMd: "dd.MM.y.",
                yMEd: "E, dd.MM.y.",
                yMMM: "MMM y.",
                yMMMd: "dd. MMM y.",
                yMMMEd: "E, dd. MMM y.",
                yMMMM: "MMMM y.",
                yQQQ: "y QQQ",
                yQQQQ: "y QQQQ",
                "yw-count-one": "'седмица' w 'година' Y",
                "yw-count-few": "'седмица' w 'година' Y",
                "yw-count-other": "'седмица' w 'година' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, dd. MMMM y.",
            long: "dd. MMMM y.",
            medium: "dd.MM.y.",
            short: "d.M.yy."
        },
        days: {
            format: {
                abbreviated: [
                    "нед",
                    "пон",
                    "уто",
                    "сри",
                    "чет",
                    "пет",
                    "суб"
                ],
                narrow: [
                    "н",
                    "п",
                    "у",
                    "с",
                    "ч",
                    "п",
                    "с"
                ],
                short: [
                    "нед",
                    "пон",
                    "уто",
                    "сри",
                    "чет",
                    "пет",
                    "суб"
                ],
                wide: [
                    "недјеља",
                    "понедјељак",
                    "уторак",
                    "сриједа",
                    "четвртак",
                    "петак",
                    "субота"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "нед",
                    "пон",
                    "уто",
                    "сри",
                    "чет",
                    "пет",
                    "суб"
                ],
                narrow: [
                    "н",
                    "п",
                    "у",
                    "с",
                    "ч",
                    "п",
                    "с"
                ],
                short: [
                    "нед",
                    "пон",
                    "уто",
                    "сри",
                    "чет",
                    "пет",
                    "суб"
                ],
                wide: [
                    "недјеља",
                    "понедјељак",
                    "уторак",
                    "сриједа",
                    "четвртак",
                    "петак",
                    "субота"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "јан",
                    "феб",
                    "мар",
                    "апр",
                    "мај",
                    "јун",
                    "јул",
                    "ауг",
                    "сеп",
                    "окт",
                    "нов",
                    "дец"
                ],
                narrow: [
                    "ј",
                    "ф",
                    "м",
                    "а",
                    "м",
                    "ј",
                    "ј",
                    "а",
                    "с",
                    "о",
                    "н",
                    "д"
                ],
                wide: [
                    "јануар",
                    "фебруар",
                    "март",
                    "април",
                    "мај",
                    "јуни",
                    "јули",
                    "аугуст",
                    "септембар",
                    "октобар",
                    "новембар",
                    "децембар"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "јан",
                    "феб",
                    "мар",
                    "апр",
                    "мај",
                    "јун",
                    "јул",
                    "ауг",
                    "сеп",
                    "окт",
                    "нов",
                    "дец"
                ],
                narrow: [
                    "ј",
                    "ф",
                    "м",
                    "а",
                    "м",
                    "ј",
                    "ј",
                    "а",
                    "с",
                    "о",
                    "н",
                    "д"
                ],
                wide: [
                    "јануар",
                    "фебруар",
                    "март",
                    "април",
                    "мај",
                    "јуни",
                    "јули",
                    "аугуст",
                    "септембар",
                    "октобар",
                    "новембар",
                    "децембар"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "К1",
                    "К2",
                    "К3",
                    "К4"
                ],
                narrow: [
                    "1.",
                    "2.",
                    "3.",
                    "4."
                ],
                wide: [
                    "Прво тромесечје",
                    "Друго тромесечје",
                    "Треће тромесечје",
                    "Четврто тромесечје"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "К1",
                    "К2",
                    "К3",
                    "К4"
                ],
                narrow: [
                    "1.",
                    "2.",
                    "3.",
                    "4."
                ],
                wide: [
                    "Прво тромесечје",
                    "Друго тромесечје",
                    "Треће тромесечје",
                    "Четврто тромесечје"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "поноћ",
                    am: "пре подне",
                    noon: "подне",
                    pm: "поподне",
                    morning1: "ујутру",
                    afternoon1: "у подне",
                    evening1: "увече",
                    night1: "ноћу"
                },
                narrow: {
                    midnight: "поноћ",
                    am: "пре подне",
                    noon: "подне",
                    pm: "поподне",
                    morning1: "ујутру",
                    afternoon1: "у подне",
                    evening1: "увече",
                    night1: "ноћу"
                },
                wide: {
                    midnight: "поноћ",
                    am: "прије подне",
                    noon: "подне",
                    pm: "послије подне",
                    morning1: "ујутру",
                    afternoon1: "у подне",
                    evening1: "увече",
                    night1: "ноћу"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "поноћ",
                    am: "пре подне",
                    noon: "подне",
                    pm: "поподне",
                    morning1: "јутро",
                    afternoon1: "послийеподне",
                    evening1: "вече",
                    night1: "ноћ"
                },
                narrow: {
                    midnight: "поноћ",
                    am: "пре подне",
                    noon: "подне",
                    pm: "поподне",
                    morning1: "јутро",
                    afternoon1: "послийеподне",
                    evening1: "вече",
                    night1: "ноћ"
                },
                wide: {
                    midnight: "поноћ",
                    am: "прије подне",
                    noon: "подне",
                    pm: "послије подне",
                    morning1: "јутро",
                    afternoon1: "послийеподне",
                    evening1: "вече",
                    night1: "ноћ"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "прије нове ере",
                    "1": "нове ере",
                    "0-alt-variant": "п.н.е",
                    "1-alt-variant": "н.е."
                },
                abbreviated: {
                    "0": "п. н. е.",
                    "1": "н. е.",
                    "0-alt-variant": "п. н. е.",
                    "1-alt-variant": "н. е."
                },
                narrow: {
                    "0": "п.н.е.",
                    "1": "н.е.",
                    "0-alt-variant": "п. н. е.",
                    "1-alt-variant": "н. е."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "ера",
                short: "ера",
                narrow: "ера"
            },
            year: {
                wide: "година",
                short: "год",
                narrow: "год."
            },
            quarter: {
                wide: "тромјесечје",
                short: "тромје.",
                narrow: "qtr."
            },
            month: {
                wide: "мјесец",
                short: "мјес.",
                narrow: "мјес."
            },
            week: {
                wide: "седмица",
                short: "седм.",
                narrow: "седм."
            },
            weekOfMonth: {
                wide: "седмица у мјесецу",
                short: "седм. у мјесецу",
                narrow: "седм. у мјес."
            },
            day: {
                wide: "дан",
                short: "дан",
                narrow: "дан"
            },
            dayOfYear: {
                wide: "дан у години",
                short: "дан у год.",
                narrow: "дан у год."
            },
            weekday: {
                wide: "дан у седмици",
                short: "дан у седм.",
                narrow: "дан у седм."
            },
            weekdayOfMonth: {
                wide: "радни дан у мјесецу",
                short: "рад. дан у мјесецу",
                narrow: "рад. дан у мјес."
            },
            dayperiod: {
                short: "прије подне/послије подне",
                wide: "прије подне/послије подне",
                narrow: "прије подне/послије подне"
            },
            hour: {
                wide: "сат",
                short: "сат",
                narrow: "сат"
            },
            minute: {
                wide: "минут",
                short: "мин.",
                narrow: "мин"
            },
            second: {
                wide: "секунд",
                short: "сек.",
                narrow: "сек"
            },
            zone: {
                wide: "зона",
                short: "зона",
                narrow: "зона"
            },
            millisecond: {
                narrow: "мс",
                short: "мс",
                wide: "милисекунда"
            }
        }
    },
    firstDay: 1
});

