/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ca-IT",
    identity: {
        language: "ca",
        territory: "IT"
    },
    territory: "IT",
    numbers: {
        symbols: {
            decimal: ",",
            group: ".",
            list: ";",
            percentSign: "%",
            plusSign: "+",
            minusSign: "-",
            approximatelySign: "~",
            exponential: "E",
            superscriptingExponent: "×",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "n%"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-one": "n $",
            "unitPattern-count-other": "n $"
        },
        accounting: {
            patterns: [
                "n $",
                "(n $)"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "pesseta andorrana",
                "displayName-count-one": "pesseta andorrana",
                "displayName-count-other": "pessetes andorranes",
                symbol: "ADP"
            },
            AED: {
                displayName: "dírham dels Emirats Àrabs Units",
                "displayName-count-one": "dírham dels Emirats Àrabs Units",
                "displayName-count-other": "dírhams dels Emirats Àrabs Units",
                symbol: "AED"
            },
            AFA: {
                displayName: "afgani afganès (1927–2002)",
                "displayName-count-one": "afgani afganès (1927–2002)",
                "displayName-count-other": "afganis afganesos (1927–2002)",
                symbol: "AFA"
            },
            AFN: {
                displayName: "afgani afganès",
                "displayName-count-one": "afgani afganès",
                "displayName-count-other": "afganis afganesos",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "lek albanès (1946–1965)",
                "displayName-count-one": "lek albanès (1946–1965)",
                "displayName-count-other": "lekë albanesos (1946–1965)",
                symbol: "ALK"
            },
            ALL: {
                displayName: "lek",
                "displayName-count-one": "lek",
                "displayName-count-other": "lekë",
                symbol: "ALL"
            },
            AMD: {
                displayName: "dram",
                "displayName-count-one": "dram",
                "displayName-count-other": "drams",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "florí de les Antilles Neerlandeses",
                "displayName-count-one": "florí de les Antilles Neerlandeses",
                "displayName-count-other": "florins de les Antilles Neerlandeses",
                symbol: "ANG"
            },
            AOA: {
                displayName: "kwanza angolès",
                "displayName-count-one": "kwanza angolès",
                "displayName-count-other": "kwanzas angolesos",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "kwanza angolès (1977–1991)",
                "displayName-count-one": "kwanza angolès (1977–1991)",
                "displayName-count-other": "kwanzas angolesos (1977–1991)",
                symbol: "AOK"
            },
            AON: {
                displayName: "nou kwanza angolès (1990–2000)",
                "displayName-count-one": "nou kwanza angolès (1990–2000)",
                "displayName-count-other": "nous kwanzas angolesos (1990–2000)",
                symbol: "AON"
            },
            AOR: {
                displayName: "kwanza angolès reajustat (1995–1999)",
                "displayName-count-one": "kwanza angolès reajustat (1995–1999)",
                "displayName-count-other": "kwanzas angolesos (1995–1999)",
                symbol: "AOR"
            },
            ARA: {
                displayName: "austral argentí",
                "displayName-count-one": "austral argentí",
                "displayName-count-other": "australs argentins",
                symbol: "ARA"
            },
            ARL: {
                displayName: "peso ley argentí (1970–1983)",
                "displayName-count-one": "peso ley argentí (1970–1983)",
                "displayName-count-other": "pesos ley argentins (1970–1983)",
                symbol: "ARL"
            },
            ARM: {
                displayName: "peso argentí (1981–1970)",
                "displayName-count-one": "peso argentí moneda nacional",
                "displayName-count-other": "pesos argentins moneda nacional",
                symbol: "ARM"
            },
            ARP: {
                displayName: "peso argentí (1983–1985)",
                "displayName-count-one": "peso argentí (1983–1985)",
                "displayName-count-other": "pesos argentins (1983–1985)",
                symbol: "ARP"
            },
            ARS: {
                displayName: "peso argentí",
                "displayName-count-one": "peso argentí",
                "displayName-count-other": "pesos argentins",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "xíling austríac",
                "displayName-count-one": "xíling austríac",
                "displayName-count-other": "xílings austríacs",
                symbol: "ATS"
            },
            AUD: {
                displayName: "dòlar australià",
                "displayName-count-one": "dòlar australià",
                "displayName-count-other": "dòlars australians",
                symbol: "AU$",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "florí d’Aruba",
                "displayName-count-one": "florí d’Aruba",
                "displayName-count-other": "florins d’Aruba",
                symbol: "AWG"
            },
            AZM: {
                displayName: "manat azerbaidjanès (1993–2006)",
                "displayName-count-one": "manat azerbaidjanès (1993–2006)",
                "displayName-count-other": "manats azerbaidjanesos (1993–2006)",
                symbol: "AZM"
            },
            AZN: {
                displayName: "manat azerbaidjanès",
                "displayName-count-one": "manat azerbaidjanès",
                "displayName-count-other": "manats azerbaidjanesos",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "dinar de Bòsnia i Hercegovina (1992–1994)",
                "displayName-count-one": "dinar de Bòsnia i Hercegovina (1992–1994)",
                "displayName-count-other": "dinars de Bòsnia i Hercegovina (1992–1994)",
                symbol: "BAD"
            },
            BAM: {
                displayName: "marc convertible de Bòsnia i Hercegovina",
                "displayName-count-one": "marc convertible de Bòsnia i Hercegovina",
                "displayName-count-other": "marcs convertibles de Bòsnia i Hercegovina",
                symbol: "BAM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "nou dinar de Bòsnia i Hercegovina (1994–1997)",
                "displayName-count-one": "nou dinar de Bòsnia i Hercegovina (1994–1997)",
                "displayName-count-other": "nous dinars de Bòsnia i Hercegovina (1994–1997)",
                symbol: "BAN"
            },
            BBD: {
                displayName: "dòlar de Barbados",
                "displayName-count-one": "dòlar de Barbados",
                "displayName-count-other": "dòlars de Barbados",
                symbol: "BBD",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "taka",
                "displayName-count-one": "taka",
                "displayName-count-other": "taka",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "franc belga (convertible)",
                "displayName-count-one": "franc belga (convertible)",
                "displayName-count-other": "francs belgues (convertibles)",
                symbol: "BEC"
            },
            BEF: {
                displayName: "franc belga",
                "displayName-count-one": "franc belga",
                "displayName-count-other": "francs belgues",
                symbol: "BEF"
            },
            BEL: {
                displayName: "franc belga (financer)",
                "displayName-count-one": "franc belga (financer)",
                "displayName-count-other": "francs belgues (financers)",
                symbol: "BEL"
            },
            BGL: {
                displayName: "lev fort búlgar",
                "displayName-count-one": "lev fort búlgar",
                "displayName-count-other": "leva forts búlgars",
                symbol: "BGL"
            },
            BGM: {
                displayName: "lev socialista búlgar",
                "displayName-count-one": "lev socialista búlgar",
                "displayName-count-other": "leva socialistes búlgars",
                symbol: "BGM"
            },
            BGN: {
                displayName: "lev",
                "displayName-count-one": "lev",
                "displayName-count-other": "leva",
                symbol: "BGN"
            },
            BGO: {
                displayName: "lev búlgar (1879–1952)",
                "displayName-count-one": "lev búlgar (1879–1952)",
                "displayName-count-other": "leva búlgars (1879–1952)",
                symbol: "BGO"
            },
            BHD: {
                displayName: "dinar de Bahrain",
                "displayName-count-one": "dinar de Bahrain",
                "displayName-count-other": "dinars de Bahrain",
                symbol: "BHD"
            },
            BIF: {
                displayName: "franc de Burundi",
                "displayName-count-one": "franc de Burundi",
                "displayName-count-other": "francs de Burundi",
                symbol: "BIF"
            },
            BMD: {
                displayName: "dòlar de les Bermudes",
                "displayName-count-one": "dòlar de les Bermudes",
                "displayName-count-other": "dòlars de les Bermudes",
                symbol: "BMD",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "dòlar de Brunei",
                "displayName-count-one": "dòlar de Brunei",
                "displayName-count-other": "dòlars de Brunei",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "bolivià",
                "displayName-count-one": "bolivià",
                "displayName-count-other": "bolivians",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "boliviano bolivià (1863–1963)",
                "displayName-count-one": "boliviano bolivià (1863–1963)",
                "displayName-count-other": "bolivianos bolivians (1863–1963)",
                symbol: "BOL"
            },
            BOP: {
                displayName: "peso bolivià",
                "displayName-count-one": "peso bolivià",
                "displayName-count-other": "pesos bolivians",
                symbol: "BOP"
            },
            BOV: {
                displayName: "MVDOL bolivià",
                "displayName-count-one": "MVDOL bolivià",
                "displayName-count-other": "MVDOL bolivians",
                symbol: "BOV"
            },
            BRB: {
                displayName: "cruzeiro novo brasiler (1967–1986)",
                "displayName-count-one": "cruzeiro novo brasiler (1967–1986)",
                "displayName-count-other": "cruzeiros novos brasilers (1967–1986)",
                symbol: "BRB"
            },
            BRC: {
                displayName: "cruzado brasiler",
                "displayName-count-one": "cruzado brasiler",
                "displayName-count-other": "cruzados brasilers",
                symbol: "BRC"
            },
            BRE: {
                displayName: "cruzeiro brasiler (1990–1993)",
                "displayName-count-one": "cruzeiro brasiler (1990–1993)",
                "displayName-count-other": "cruzeiros brasilers (1990–1993)",
                symbol: "BRE"
            },
            BRL: {
                displayName: "real brasiler",
                "displayName-count-one": "real brasiler",
                "displayName-count-other": "reals brasilers",
                symbol: "BRL",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "cruzado novo brasiler",
                "displayName-count-one": "cruzado novo brasiler",
                "displayName-count-other": "cruzados novos brasilers",
                symbol: "BRN"
            },
            BRR: {
                displayName: "cruzeiro brasiler",
                "displayName-count-one": "cruzeiro brasiler",
                "displayName-count-other": "cruzeiros brasilers",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "antic cruzeiro brasiler",
                "displayName-count-one": "antic cruzeiro brasiler",
                "displayName-count-other": "antics cruzeiros brasilers",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "dòlar de les Bahames",
                "displayName-count-one": "dòlar de les Bahames",
                "displayName-count-other": "dòlars de les Bahames",
                symbol: "BSD",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "ngultrum de Bhutan",
                "displayName-count-one": "ngultrum de Bhutan",
                "displayName-count-other": "ngultrums de Bhutan",
                symbol: "BTN"
            },
            BUK: {
                displayName: "kyat birmà",
                "displayName-count-one": "kyat birmà",
                "displayName-count-other": "kyats birmans",
                symbol: "BUK"
            },
            BWP: {
                displayName: "pula de Botswana",
                "displayName-count-one": "pula de Botswana",
                "displayName-count-other": "pula de Botswana",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "nou ruble bielorús (1994–1999)",
                "displayName-count-one": "nou ruble bielorús (1994–1999)",
                "displayName-count-other": "nous rubles bielorussos (1994–1999)",
                symbol: "BYB"
            },
            BYN: {
                displayName: "ruble bielorús",
                "displayName-count-one": "ruble bielorús",
                "displayName-count-other": "rubles bielorussos",
                symbol: "BYN",
                "symbol-alt-narrow": "р."
            },
            BYR: {
                displayName: "ruble bielorús (2000–2016)",
                "displayName-count-one": "ruble bielorús (2000–2016)",
                "displayName-count-other": "rubles bielorussos (2000–2016)",
                symbol: "BYR"
            },
            BZD: {
                displayName: "dòlar de Belize",
                "displayName-count-one": "dòlar de Belize",
                "displayName-count-other": "dòlars de Belize",
                symbol: "BZD",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "dòlar canadenc",
                "displayName-count-one": "dòlar canadenc",
                "displayName-count-other": "dòlars canadencs",
                symbol: "CAD",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "franc congolès",
                "displayName-count-one": "franc congolès",
                "displayName-count-other": "francs congolesos",
                symbol: "CDF"
            },
            CHE: {
                displayName: "euro WIR",
                "displayName-count-one": "euro WIR",
                "displayName-count-other": "euros WIR",
                symbol: "CHE"
            },
            CHF: {
                displayName: "franc suís",
                "displayName-count-one": "franc suís",
                "displayName-count-other": "francs suïssos",
                symbol: "CHF"
            },
            CHW: {
                displayName: "franc WIR",
                "displayName-count-one": "franc WIR",
                "displayName-count-other": "francs WIR",
                symbol: "CHW"
            },
            CLE: {
                displayName: "escut xilè",
                "displayName-count-one": "escudo xilè",
                "displayName-count-other": "escudos xilens",
                symbol: "CLE"
            },
            CLF: {
                displayName: "unidad de fomento xilena",
                "displayName-count-one": "unidad de fomento xilena",
                "displayName-count-other": "unidades de fomento xilenes",
                symbol: "CLF"
            },
            CLP: {
                displayName: "peso xilè",
                "displayName-count-one": "peso xilè",
                "displayName-count-other": "pesos xilens",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "iuan xinès extracontinental",
                "displayName-count-one": "iuan xinès extracontinental",
                "displayName-count-other": "iuans xinesos extracontinentals",
                symbol: "CNH"
            },
            CNX: {
                displayName: "CNX",
                "displayName-count-one": "dòlar del Banc Popular Xinès",
                "displayName-count-other": "dòlars del Banc Popular Xinès",
                symbol: "CNX"
            },
            CNY: {
                displayName: "iuan",
                "displayName-count-one": "iuan",
                "displayName-count-other": "iuans",
                symbol: "CNY",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "peso colombià",
                "displayName-count-one": "peso colombià",
                "displayName-count-other": "pesos colombians",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "unidad de valor real colombiana",
                "displayName-count-one": "unidad de valor real colombiana",
                "displayName-count-other": "unidades de valor real colombianes",
                symbol: "COU"
            },
            CRC: {
                displayName: "colon costa-riqueny",
                "displayName-count-one": "colon costa-riqueny",
                "displayName-count-other": "colons costa-riquenys",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "dinar serbi antic",
                "displayName-count-one": "dinar serbi antic",
                "displayName-count-other": "dinars serbis antics",
                symbol: "CSD"
            },
            CSK: {
                displayName: "corona forta txecoslovaca",
                "displayName-count-one": "corona forta txecoslovaca",
                "displayName-count-other": "corones fortes txecoslovaques",
                symbol: "CSK"
            },
            CUC: {
                displayName: "peso convertible cubà",
                "displayName-count-one": "peso convertible cubà",
                "displayName-count-other": "pesos convertibles cubans",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "peso cubà",
                "displayName-count-one": "peso cubà",
                "displayName-count-other": "pesos cubans",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "escut de Cap Verd",
                "displayName-count-one": "escut de Cap Verd",
                "displayName-count-other": "escuts de Cap Verd",
                symbol: "CVE"
            },
            CYP: {
                displayName: "lliura xipriota",
                "displayName-count-one": "lliura xipriota",
                "displayName-count-other": "lliures xipriotes",
                symbol: "CYP"
            },
            CZK: {
                displayName: "corona txeca",
                "displayName-count-one": "corona txeca",
                "displayName-count-other": "corones txeques",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "marc de l’Alemanya Oriental",
                "displayName-count-one": "marc de l’Alemanya Oriental",
                "displayName-count-other": "marcs de l’Alemanya Oriental",
                symbol: "DDM"
            },
            DEM: {
                displayName: "marc alemany",
                "displayName-count-one": "marc alemany",
                "displayName-count-other": "marcs alemanys",
                symbol: "DEM"
            },
            DJF: {
                displayName: "franc de Djibouti",
                "displayName-count-one": "franc de Djibouti",
                "displayName-count-other": "francs de Djibouti",
                symbol: "DJF"
            },
            DKK: {
                displayName: "corona danesa",
                "displayName-count-one": "corona danesa",
                "displayName-count-other": "corones daneses",
                symbol: "DKK",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "peso dominicà",
                "displayName-count-one": "peso dominicà",
                "displayName-count-other": "pesos dominicans",
                symbol: "DOP",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "dinar algerià",
                "displayName-count-one": "dinar algerià",
                "displayName-count-other": "dinars algerians",
                symbol: "DZD"
            },
            ECS: {
                displayName: "sucre equatorià",
                "displayName-count-one": "sucre equatorià",
                "displayName-count-other": "sucres equatorians",
                symbol: "ECS"
            },
            ECV: {
                displayName: "unidad de valor constante (UVC) equatoriana",
                "displayName-count-one": "unidad de valor constante (UVC) equatoriana",
                "displayName-count-other": "unidades de valor constante (UVC) equatorianes",
                symbol: "ECV"
            },
            EEK: {
                displayName: "corona estoniana",
                "displayName-count-one": "corona estoniana",
                "displayName-count-other": "corones estonianes",
                symbol: "EEK"
            },
            EGP: {
                displayName: "lliura egípcia",
                "displayName-count-one": "lliura egípcia",
                "displayName-count-other": "lliures egípcies",
                symbol: "EGP",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "nakfa eritreu",
                "displayName-count-one": "nakfa eritreu",
                "displayName-count-other": "nakfes eritreus",
                symbol: "ERN"
            },
            ESA: {
                displayName: "pesseta espanyola (compte A)",
                "displayName-count-one": "pesseta espanyola (compte A)",
                "displayName-count-other": "pessetes espanyoles (compte A)",
                symbol: "ESA"
            },
            ESB: {
                displayName: "pesseta espanyola (compte convertible)",
                "displayName-count-one": "pesseta espanyola (compte convertible)",
                "displayName-count-other": "pessetes espanyoles (compte convertible)",
                symbol: "ESB"
            },
            ESP: {
                pattern: "¤ #,##0.00",
                displayName: "pesseta espanyola",
                "displayName-count-one": "pesseta espanyola",
                "displayName-count-other": "pessetes espanyoles",
                symbol: "₧",
                "symbol-alt-narrow": "₧",
                decimal: ",",
                group: "."
            },
            ETB: {
                displayName: "birr etíop",
                "displayName-count-one": "birr etíop",
                "displayName-count-other": "birrs etíops",
                symbol: "ETB"
            },
            EUR: {
                displayName: "euro",
                "displayName-count-one": "euro",
                "displayName-count-other": "euros",
                symbol: "€",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "marc finlandès",
                "displayName-count-one": "marc finlandès",
                "displayName-count-other": "marcs finlandesos",
                symbol: "FIM"
            },
            FJD: {
                displayName: "dòlar fijià",
                "displayName-count-one": "dòlar fijià",
                "displayName-count-other": "dòlars fijians",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "lliura de les illes Malvines",
                "displayName-count-one": "lliura de les illes Malvines",
                "displayName-count-other": "lliures de les illes Malvines",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "franc francès",
                "displayName-count-one": "franc francès",
                "displayName-count-other": "francs francesos",
                symbol: "FRF"
            },
            GBP: {
                displayName: "lliura esterlina",
                "displayName-count-one": "lliura esterlina",
                "displayName-count-other": "lliures esterlines",
                symbol: "£",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "cupó de lari georgià",
                "displayName-count-one": "cupó de lari georgià",
                "displayName-count-other": "cupons de lari georgians",
                symbol: "GEK"
            },
            GEL: {
                displayName: "lari",
                "displayName-count-one": "lari",
                "displayName-count-other": "laris",
                symbol: "GEL",
                "symbol-alt-narrow": "₾"
            },
            GHC: {
                displayName: "cedi ghanès (1979–2007)",
                "displayName-count-one": "cedi ghanès (1979–2007)",
                "displayName-count-other": "cedis ghanesos (1979–2007)",
                symbol: "GHC"
            },
            GHS: {
                displayName: "cedi ghanès",
                "displayName-count-one": "cedi ghanès",
                "displayName-count-other": "cedis ghanesos",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "lliura de Gibraltar",
                "displayName-count-one": "lliura de Gibraltar",
                "displayName-count-other": "lliures de Gibraltar",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "dalasi gambià",
                "displayName-count-one": "dalasi gambià",
                "displayName-count-other": "dalasis gambians",
                symbol: "GMD"
            },
            GNF: {
                displayName: "franc guineà",
                "displayName-count-one": "franc guineà",
                "displayName-count-other": "francs guineans",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "syli guineà",
                "displayName-count-one": "syli guineà",
                "displayName-count-other": "sylis guineans",
                symbol: "GNS"
            },
            GQE: {
                displayName: "ekwele de Guinea Equatorial",
                "displayName-count-one": "ekwele de Guinea Equatorial",
                "displayName-count-other": "bipkwele de Guinea Equatorial",
                symbol: "GQE"
            },
            GRD: {
                displayName: "dracma grega",
                "displayName-count-one": "dracma grega",
                "displayName-count-other": "dracmes gregues",
                symbol: "GRD"
            },
            GTQ: {
                displayName: "quetzal",
                "displayName-count-one": "quetzal",
                "displayName-count-other": "quetzals",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "escut de la Guinea Portuguesa",
                "displayName-count-one": "escut de la Guinea Portuguesa",
                "displayName-count-other": "escuts de la Guinea Portuguesa",
                symbol: "GWE"
            },
            GWP: {
                displayName: "peso de Guinea Bissau",
                "displayName-count-one": "peso de Guinea Bissau",
                "displayName-count-other": "pesos de Guinea Bissau",
                symbol: "GWP"
            },
            GYD: {
                displayName: "dòlar de Guyana",
                "displayName-count-one": "dòlar de Guyana",
                "displayName-count-other": "dòlars de Guyana",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "dòlar de Hong Kong",
                "displayName-count-one": "dòlar de Hong Kong",
                "displayName-count-other": "dòlars de Hong Kong",
                symbol: "HK$",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "lempira",
                "displayName-count-one": "lempira",
                "displayName-count-other": "lempires",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "dinar croat",
                "displayName-count-one": "dinar croat",
                "displayName-count-other": "dinars croats",
                symbol: "HRD"
            },
            HRK: {
                displayName: "kuna",
                "displayName-count-one": "kuna",
                "displayName-count-other": "kunes",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "gourde",
                "displayName-count-one": "gourde",
                "displayName-count-other": "gourdes",
                symbol: "HTG"
            },
            HUF: {
                displayName: "fòrint",
                "displayName-count-one": "fòrint",
                "displayName-count-other": "fòrints",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "rupia indonèsia",
                "displayName-count-one": "rupia indonèsia",
                "displayName-count-other": "rupies indonèsies",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "lliura irlandesa",
                "displayName-count-one": "lliura irlandesa",
                "displayName-count-other": "lliures irlandeses",
                symbol: "IEP"
            },
            ILP: {
                displayName: "lliura israeliana",
                "displayName-count-one": "lliura israeliana",
                "displayName-count-other": "lliures israelianes",
                symbol: "ILP"
            },
            ILR: {
                displayName: "xéquel israelià",
                "displayName-count-one": "xéquel israelià",
                "displayName-count-other": "xéquel israelià",
                symbol: "ILR"
            },
            ILS: {
                displayName: "nou xéquel israelià",
                "displayName-count-one": "nou xéquel israelià",
                "displayName-count-other": "nous xéquels israelians",
                symbol: "₪",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "rupia índia",
                "displayName-count-one": "rupia índia",
                "displayName-count-other": "rupies índies",
                symbol: "₹",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "dinar iraquià",
                "displayName-count-one": "dinar iraquià",
                "displayName-count-other": "dinars iraquians",
                symbol: "IQD"
            },
            IRR: {
                displayName: "rial iranià",
                "displayName-count-one": "rial iranià",
                "displayName-count-other": "rials iranians",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "corona islandesa antiga",
                "displayName-count-one": "corona islandesa antiga",
                "displayName-count-other": "corones islandeses antigues",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "corona islandesa",
                "displayName-count-one": "corona islandesa",
                "displayName-count-other": "corones islandeses",
                symbol: "ISK",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "lira italiana",
                "displayName-count-one": "lira italiana",
                "displayName-count-other": "lires italianes",
                symbol: "ITL"
            },
            JMD: {
                displayName: "dòlar jamaicà",
                "displayName-count-one": "dòlar jamaicà",
                "displayName-count-other": "dòlars jamaicans",
                symbol: "JMD",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "dinar jordà",
                "displayName-count-one": "dinar jordà",
                "displayName-count-other": "dinars jordans",
                symbol: "JOD"
            },
            JPY: {
                displayName: "ien",
                "displayName-count-one": "ien",
                "displayName-count-other": "iens",
                symbol: "¥",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "xíling kenyà",
                "displayName-count-one": "xíling kenyà",
                "displayName-count-other": "xílings kenyans",
                symbol: "KES"
            },
            KGS: {
                displayName: "som kirguís",
                "displayName-count-one": "som kirguís",
                "displayName-count-other": "soms kirguisos",
                symbol: "KGS"
            },
            KHR: {
                displayName: "riel cambodjà",
                "displayName-count-one": "riel cambodjà",
                "displayName-count-other": "riels cambodjans",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "franc de les Comores",
                "displayName-count-one": "franc de les Comores",
                "displayName-count-other": "francs de les Comores",
                symbol: "KMF",
                "symbol-alt-narrow": "CF"
            },
            KPW: {
                displayName: "won nord-coreà",
                "displayName-count-one": "won nord-coreà",
                "displayName-count-other": "wons nord-coreans",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "hwan sud-coreà (1953–1962)",
                "displayName-count-one": "hwan sud-coreà",
                "displayName-count-other": "hwans sud-coreans",
                symbol: "KRH"
            },
            KRO: {
                displayName: "antic won sud-coreà",
                "displayName-count-one": "antic won sud-coreà",
                "displayName-count-other": "antics wons sud-coreans",
                symbol: "KRO"
            },
            KRW: {
                displayName: "won sud-coreà",
                "displayName-count-one": "won sud-coreà",
                "displayName-count-other": "wons sud-coreans",
                symbol: "₩",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "dinar kuwaitià",
                "displayName-count-one": "dinar kuwaitià",
                "displayName-count-other": "dinars kuwaitians",
                symbol: "KWD"
            },
            KYD: {
                displayName: "dòlar de les illes Caiman",
                "displayName-count-one": "dòlar de les illes Caiman",
                "displayName-count-other": "dòlars de les illes Caiman",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "tenge",
                "displayName-count-one": "tenge",
                "displayName-count-other": "tenges",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "kip laosià",
                "displayName-count-one": "kip laosià",
                "displayName-count-other": "kips laosians",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "lliura libanesa",
                "displayName-count-one": "lliura libanesa",
                "displayName-count-other": "lliures libaneses",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "rupia de Sri Lanka",
                "displayName-count-one": "rupia de Sri Lanka",
                "displayName-count-other": "rupies de Sri Lanka",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "dòlar liberià",
                "displayName-count-one": "dòlar liberià",
                "displayName-count-other": "dòlars liberians",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "loti",
                "displayName-count-one": "loti",
                "displayName-count-other": "lotis",
                symbol: "LSL"
            },
            LTL: {
                displayName: "litas lituà",
                "displayName-count-one": "litas lituà",
                "displayName-count-other": "litai lituans",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "talonas lituà",
                "displayName-count-one": "talonas lituà",
                "displayName-count-other": "talonai lituans",
                symbol: "LTT"
            },
            LUC: {
                displayName: "franc convertible luxemburguès",
                "displayName-count-one": "franc convertible luxemburguès",
                "displayName-count-other": "francs convertibles luxemburguesos",
                symbol: "LUC"
            },
            LUF: {
                displayName: "franc luxemburguès",
                "displayName-count-one": "franc luxemburguès",
                "displayName-count-other": "francs luxemburguesos",
                symbol: "LUF"
            },
            LUL: {
                displayName: "franc financer luxemburguès",
                "displayName-count-one": "franc financer luxemburguès",
                "displayName-count-other": "francs financers luxemburguesos",
                symbol: "LUL"
            },
            LVL: {
                displayName: "lats letó",
                "displayName-count-one": "lats letó",
                "displayName-count-other": "lati letons",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "ruble letó",
                "displayName-count-one": "ruble letó",
                "displayName-count-other": "rubles letons",
                symbol: "LVR"
            },
            LYD: {
                displayName: "dinar libi",
                "displayName-count-one": "dinar libi",
                "displayName-count-other": "dinars libis",
                symbol: "LYD"
            },
            MAD: {
                displayName: "dírham marroquí",
                "displayName-count-one": "dírham marroquí",
                "displayName-count-other": "dírhams marroquins",
                symbol: "MAD"
            },
            MAF: {
                displayName: "franc marroquí",
                "displayName-count-one": "franc marroquí",
                "displayName-count-other": "francs marroquins",
                symbol: "MAF"
            },
            MCF: {
                displayName: "franc monegasc",
                "displayName-count-one": "franc monegasc",
                "displayName-count-other": "francs monegascos",
                symbol: "MCF"
            },
            MDC: {
                displayName: "cupó moldau",
                "displayName-count-one": "cupó moldau",
                "displayName-count-other": "cupons moldaus",
                symbol: "MDC"
            },
            MDL: {
                displayName: "leu moldau",
                "displayName-count-one": "leu moldau",
                "displayName-count-other": "lei moldaus",
                symbol: "MDL"
            },
            MGA: {
                displayName: "ariary malgaix",
                "displayName-count-one": "ariary malgaix",
                "displayName-count-other": "ariarys malgaixos",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "franc malgaix",
                "displayName-count-one": "franc malgaix",
                "displayName-count-other": "francs malgaixos",
                symbol: "MGF"
            },
            MKD: {
                displayName: "dinar macedoni",
                "displayName-count-one": "dinar macedoni",
                "displayName-count-other": "dinars macedonis",
                symbol: "MKD"
            },
            MKN: {
                displayName: "denar macedoni (1992–1993)",
                "displayName-count-one": "denar macedoni (1992–1993)",
                "displayName-count-other": "denari macedonis (1992–1993)",
                symbol: "MKN"
            },
            MLF: {
                displayName: "franc malià",
                "displayName-count-one": "franc malià",
                "displayName-count-other": "francs malians",
                symbol: "MLF"
            },
            MMK: {
                displayName: "kyat de Myanmar",
                "displayName-count-one": "kyat de Myanmar",
                "displayName-count-other": "kyats de Myanmar",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "tögrög mongol",
                "displayName-count-one": "tögrög mongol",
                "displayName-count-other": "tögrögs mongols",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "pataca de Macau",
                "displayName-count-one": "pataca de Macau",
                "displayName-count-other": "pataques de Macau",
                symbol: "MOP"
            },
            MRO: {
                displayName: "ouguiya maurità (1973–2017)",
                "displayName-count-one": "ouguiya maurità (1973–2017)",
                "displayName-count-other": "ouguiyas mauritans (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "ouguiya maurità",
                "displayName-count-one": "ouguiya maurità",
                "displayName-count-other": "ouguiyas mauritans",
                symbol: "MRU"
            },
            MTL: {
                displayName: "lira maltesa",
                "displayName-count-one": "lira maltesa",
                "displayName-count-other": "lires malteses",
                symbol: "MTL"
            },
            MTP: {
                displayName: "lliura maltesa",
                "displayName-count-one": "lliura maltesa",
                "displayName-count-other": "lliures malteses",
                symbol: "MTP"
            },
            MUR: {
                displayName: "rupia mauriciana",
                "displayName-count-one": "rupia mauriciana",
                "displayName-count-other": "rupies mauricianes",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "MVP",
                symbol: "MVP"
            },
            MVR: {
                displayName: "rupia de les Maldives",
                "displayName-count-one": "rupia de les Maldives",
                "displayName-count-other": "rupies de les Maldives",
                symbol: "MVR"
            },
            MWK: {
                displayName: "kwacha malawià",
                "displayName-count-one": "kwacha malawià",
                "displayName-count-other": "kwacha malawians",
                symbol: "MWK"
            },
            MXN: {
                displayName: "peso mexicà",
                "displayName-count-one": "peso mexicà",
                "displayName-count-other": "pesos mexicans",
                symbol: "MXN",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "peso de plata mexicà (1861–1992)",
                "displayName-count-one": "peso de plata mexicà (1861–1992)",
                "displayName-count-other": "pesos de plata mexicans (1861–1992)",
                symbol: "MXP"
            },
            MXV: {
                displayName: "unidad de inversión (UDI) mexicana",
                "displayName-count-one": "unidad de inversión (UDI) mexicana",
                "displayName-count-other": "unidades de inversión (UDI) mexicanes",
                symbol: "MXV"
            },
            MYR: {
                displayName: "ringgit",
                "displayName-count-one": "ringgit",
                "displayName-count-other": "ringgits",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "escut moçambiquès",
                "displayName-count-one": "escut moçambiquès",
                "displayName-count-other": "escuts moçambiquesos",
                symbol: "MZE"
            },
            MZM: {
                displayName: "antic metical moçambiquès",
                "displayName-count-one": "antic metical moçambiquès",
                "displayName-count-other": "antics meticals moçambiquesos",
                symbol: "MZM"
            },
            MZN: {
                displayName: "metical moçambiquès",
                "displayName-count-one": "metical moçambiquès",
                "displayName-count-other": "meticals moçambiquesos",
                symbol: "MZN"
            },
            NAD: {
                displayName: "dòlar namibià",
                "displayName-count-one": "dòlar namibià",
                "displayName-count-other": "dòlars namibians",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "naira nigerià",
                "displayName-count-one": "naira nigerià",
                "displayName-count-other": "naires nigerians",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "córdoba nicaragüenca",
                "displayName-count-one": "córdoba nicaragüenca",
                "displayName-count-other": "córdobas nicaragüenques",
                symbol: "NIC"
            },
            NIO: {
                displayName: "córdoba nicaragüenc",
                "displayName-count-one": "córdoba nicaragüenc",
                "displayName-count-other": "córdobas nicaragüencs",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "florí neerlandès",
                "displayName-count-one": "florí neerlandès",
                "displayName-count-other": "florins neerlandesos",
                symbol: "NLG"
            },
            NOK: {
                displayName: "corona noruega",
                "displayName-count-one": "corona noruega",
                "displayName-count-other": "corones noruegues",
                symbol: "NOK",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "rupia nepalesa",
                "displayName-count-one": "rupia nepalesa",
                "displayName-count-other": "rupies nepaleses",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "dòlar neozelandès",
                "displayName-count-one": "dòlar neozelandès",
                "displayName-count-other": "dòlars neozelandesos",
                symbol: "NZ$",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "rial omanita",
                "displayName-count-one": "rial omanita",
                "displayName-count-other": "rials omanites",
                symbol: "OMR"
            },
            PAB: {
                displayName: "balboa",
                "displayName-count-one": "balboa",
                "displayName-count-other": "balboes",
                symbol: "PAB"
            },
            PEI: {
                displayName: "inti peruà",
                "displayName-count-one": "inti peruà",
                "displayName-count-other": "intis peruans",
                symbol: "PEI"
            },
            PEN: {
                displayName: "sol",
                "displayName-count-one": "sol",
                "displayName-count-other": "sols",
                symbol: "PEN"
            },
            PES: {
                displayName: "sol peruà (1863–1965)",
                "displayName-count-one": "sol peruà (1863–1965)",
                "displayName-count-other": "sols peruans (1863–1965)",
                symbol: "PES"
            },
            PGK: {
                displayName: "kina",
                "displayName-count-one": "kina",
                "displayName-count-other": "kines",
                symbol: "PGK"
            },
            PHP: {
                displayName: "peso filipí",
                "displayName-count-one": "peso filipí",
                "displayName-count-other": "pesos filipins",
                symbol: "PHP",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "rupia pakistanesa",
                "displayName-count-one": "rupia pakistanesa",
                "displayName-count-other": "rupies pakistaneses",
                symbol: "PKR",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "zloty",
                "displayName-count-one": "zloty",
                "displayName-count-other": "zlote",
                symbol: "PLN",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "zloty polonès (1950–1995)",
                "displayName-count-one": "zloty polonès (1950–1995)",
                "displayName-count-other": "zlote polonesos (1950–1995)",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "escut portuguès",
                "displayName-count-one": "escut portuguès",
                "displayName-count-other": "escuts portuguesos",
                symbol: "PTE"
            },
            PYG: {
                displayName: "guaraní",
                "displayName-count-one": "guaraní",
                "displayName-count-other": "guaranís",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "rial de Qatar",
                "displayName-count-one": "rial de Qatar",
                "displayName-count-other": "rials de Qatar",
                symbol: "QAR"
            },
            RHD: {
                displayName: "dòlar rhodesià",
                "displayName-count-one": "dòlar rhodesià",
                "displayName-count-other": "dòlars rhodesians",
                symbol: "RHD"
            },
            ROL: {
                displayName: "antic leu romanès",
                "displayName-count-one": "antic leu romanès",
                "displayName-count-other": "antics lei romanesos",
                symbol: "ROL"
            },
            RON: {
                displayName: "leu romanès",
                "displayName-count-one": "leu romanès",
                "displayName-count-other": "lei romanesos",
                symbol: "RON",
                "symbol-alt-narrow": "lei"
            },
            RSD: {
                displayName: "dinar serbi",
                "displayName-count-one": "dinar serbi",
                "displayName-count-other": "dinars serbis",
                symbol: "RSD"
            },
            RUB: {
                displayName: "ruble",
                "displayName-count-one": "ruble",
                "displayName-count-other": "rubles",
                symbol: "RUB",
                "symbol-alt-narrow": "₽"
            },
            RUR: {
                displayName: "ruble rus (1991–1998)",
                "displayName-count-one": "ruble rus (1991–1998)",
                "displayName-count-other": "rubles russos (1991–1998)",
                symbol: "RUR"
            },
            RWF: {
                displayName: "franc de Ruanda",
                "displayName-count-one": "franc de Ruanda",
                "displayName-count-other": "francs de Ruanda",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "rial saudita",
                "displayName-count-one": "rial saudita",
                "displayName-count-other": "rials saudites",
                symbol: "SAR"
            },
            SBD: {
                displayName: "dòlar de les illes Salomó",
                "displayName-count-one": "dòlar de les illes Salomó",
                "displayName-count-other": "dòlars de les illes Salomó",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "rupia de les Seychelles",
                "displayName-count-one": "rupia de les Seychelles",
                "displayName-count-other": "rupies de les Seychelles",
                symbol: "SCR"
            },
            SDD: {
                displayName: "dinar sudanès",
                "displayName-count-one": "dinar sudanès",
                "displayName-count-other": "dinars sudanesos",
                symbol: "SDD"
            },
            SDG: {
                displayName: "lliura sudanesa",
                "displayName-count-one": "lliura sudanesa",
                "displayName-count-other": "lliures sudaneses",
                symbol: "SDG"
            },
            SDP: {
                displayName: "antiga lliura sudanesa",
                "displayName-count-one": "antiga lliura sudanesa",
                "displayName-count-other": "antigues lliures sudaneses",
                symbol: "SDP"
            },
            SEK: {
                displayName: "corona sueca",
                "displayName-count-one": "corona sueca",
                "displayName-count-other": "corones sueques",
                symbol: "SEK",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "dòlar de Singapur",
                "displayName-count-one": "dòlar de Singapur",
                "displayName-count-other": "dòlars de Singapur",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "lliura de Santa Helena",
                "displayName-count-one": "lliura de Santa Helena",
                "displayName-count-other": "lliures de Santa Helena",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "tolar eslovè",
                "displayName-count-one": "tolar eslovè",
                "displayName-count-other": "tolars eslovens",
                symbol: "SIT"
            },
            SKK: {
                displayName: "corona eslovaca",
                "displayName-count-one": "corona eslovaca",
                "displayName-count-other": "corones eslovaques",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "leone de Sierra Leone",
                "displayName-count-one": "leone de Sierra Leone",
                "displayName-count-other": "leones de Sierra Leone",
                symbol: "SLL"
            },
            SOS: {
                displayName: "xíling somali",
                "displayName-count-one": "xíling somali",
                "displayName-count-other": "xílings somalis",
                symbol: "SOS"
            },
            SRD: {
                displayName: "dòlar de Surinam",
                "displayName-count-one": "dòlar de Surinam",
                "displayName-count-other": "dòlars de Surinam",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "florí de Surinam",
                "displayName-count-one": "florí de Surinam",
                "displayName-count-other": "florins de Surinam",
                symbol: "SRG"
            },
            SSP: {
                displayName: "lliura del Sudan del Sud",
                "displayName-count-one": "lliura del Sudan del Sud",
                "displayName-count-other": "lliures del Sudan del Sud",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "dobra de São Tomé i Príncipe (1977–2017)",
                "displayName-count-one": "dobra de São Tomé i Príncipe (1977–2017)",
                "displayName-count-other": "dobras de São Tomé i Príncipe (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "dobra de São Tomé i Príncipe",
                "displayName-count-one": "dobra de São Tomé i Príncipe",
                "displayName-count-other": "dobras de São Tomé i Príncipe",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "ruble soviètic",
                "displayName-count-one": "ruble soviètic",
                "displayName-count-other": "rubles soviètics",
                symbol: "SUR"
            },
            SVC: {
                displayName: "colon salvadorenc",
                "displayName-count-one": "colón salvadorenc",
                "displayName-count-other": "colones salvadorencs",
                symbol: "SVC"
            },
            SYP: {
                displayName: "lliura siriana",
                "displayName-count-one": "lliura siriana",
                "displayName-count-other": "lliures sirianes",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "lilangeni swazi",
                "displayName-count-one": "lilangeni swazi",
                "displayName-count-other": "emalangeni swazis",
                symbol: "SZL"
            },
            THB: {
                displayName: "baht",
                "displayName-count-one": "baht",
                "displayName-count-other": "bahts",
                symbol: "฿",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "ruble tadjik",
                "displayName-count-one": "ruble tadjik",
                "displayName-count-other": "rubles tadjiks",
                symbol: "TJR"
            },
            TJS: {
                displayName: "somoni tadjik",
                "displayName-count-one": "somoni tadjik",
                "displayName-count-other": "somonis tadjiks",
                symbol: "TJS"
            },
            TMM: {
                displayName: "manat turcman (1993–2009)",
                "displayName-count-one": "manat turcman (1993–2009)",
                "displayName-count-other": "manats turcmans (1993–2009)",
                symbol: "TMM"
            },
            TMT: {
                displayName: "manat turcman",
                "displayName-count-one": "manat turcman",
                "displayName-count-other": "manats turcmans",
                symbol: "TMT"
            },
            TND: {
                displayName: "dinar tunisià",
                "displayName-count-one": "dinar tunisià",
                "displayName-count-other": "dinars tunisians",
                symbol: "TND"
            },
            TOP: {
                displayName: "pa‘anga tongà",
                "displayName-count-one": "pa‘anga tongà",
                "displayName-count-other": "pa‘angas tongans",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "escut de Timor",
                "displayName-count-one": "escut de Timor",
                "displayName-count-other": "escuts de Timor",
                symbol: "TPE"
            },
            TRL: {
                displayName: "lira turca (1922–2005)",
                "displayName-count-one": "lira turca (1922–2005)",
                "displayName-count-other": "lires turques (1922–2005)",
                symbol: "TRL"
            },
            TRY: {
                displayName: "lira turca",
                "displayName-count-one": "lira turca",
                "displayName-count-other": "lires turques",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "dòlar de Trinitat i Tobago",
                "displayName-count-one": "dòlar de Trinitat i Tobago",
                "displayName-count-other": "dòlars de Trinitat i Tobago",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "nou dòlar de Taiwan",
                "displayName-count-one": "nou dòlar de Taiwan",
                "displayName-count-other": "nous dòlars de Taiwan",
                symbol: "NT$",
                "symbol-alt-narrow": "$"
            },
            TZS: {
                displayName: "xíling tanzà",
                "displayName-count-one": "xíling tanzà",
                "displayName-count-other": "xílings tanzans",
                symbol: "TZS"
            },
            UAH: {
                displayName: "hrívnia",
                "displayName-count-one": "hrívnia",
                "displayName-count-other": "hrívnies",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "karbóvanets ucraïnès",
                "displayName-count-one": "karbóvanets ucraïnès",
                "displayName-count-other": "karbóvantsiv ucraïnesos",
                symbol: "UAK"
            },
            UGS: {
                displayName: "xíling ugandès (1966–1987)",
                "displayName-count-one": "xíling ugandès (1966–1987)",
                "displayName-count-other": "xílings ugandesos (1966–1987)",
                symbol: "UGS"
            },
            UGX: {
                displayName: "xíling ugandès",
                "displayName-count-one": "xíling ugandès",
                "displayName-count-other": "xílings ugandesos",
                symbol: "UGX"
            },
            USD: {
                displayName: "dòlar dels Estats Units",
                "displayName-count-one": "dòlar dels Estats Units",
                "displayName-count-other": "dòlars dels Estats Units",
                symbol: "USD",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "dòlar dels Estats Units (dia següent)",
                "displayName-count-one": "dòlar dels Estats Units (dia següent)",
                "displayName-count-other": "dòlars dels Estats Units (dia següent)",
                symbol: "USN"
            },
            USS: {
                displayName: "dòlar dels Estats Units (mateix dia)",
                "displayName-count-one": "dòlar dels Estats Units (mateix dia)",
                "displayName-count-other": "dòlars dels Estats Units (mateix dia)",
                symbol: "USS"
            },
            UYI: {
                displayName: "peso uruguaià en unitats indexades",
                "displayName-count-one": "peso uruguaià en unitats indexades",
                "displayName-count-other": "pesos uruguaians en unitats indexades",
                symbol: "UYI"
            },
            UYP: {
                displayName: "peso uruguaià (1975–1993)",
                "displayName-count-one": "peso uruguaià (1975–1993)",
                "displayName-count-other": "pesos uruguaians (1975–1993)",
                symbol: "UYP"
            },
            UYU: {
                displayName: "peso uruguaià",
                "displayName-count-one": "peso uruguaià",
                "displayName-count-other": "pesos uruguaians",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "UYW",
                symbol: "UYW"
            },
            UZS: {
                displayName: "som uzbek",
                "displayName-count-one": "som uzbek",
                "displayName-count-other": "soms uzbeks",
                symbol: "UZS"
            },
            VEB: {
                displayName: "bolívar veneçolà (1871–2008)",
                "displayName-count-one": "bolívar veneçolà (1871–2008)",
                "displayName-count-other": "bolívars veneçolans (1871–2008)",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "bolívar veneçolà (2008–2018)",
                "displayName-count-one": "bolívar veneçolà (2008–2018)",
                "displayName-count-other": "bolívars veneçolans (2008–2018)",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs F"
            },
            VES: {
                displayName: "bolívar veneçolà",
                "displayName-count-one": "bolívar veneçolà",
                "displayName-count-other": "bolívars veneçolans",
                symbol: "VES"
            },
            VND: {
                displayName: "dong vietnamita",
                "displayName-count-one": "dong vietnamita",
                "displayName-count-other": "dongs vietnamites",
                symbol: "₫",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "dong vietnamita (1978–1985)",
                "displayName-count-one": "dong vietnamita (1978–1985)",
                "displayName-count-other": "dongs vietnamites (1978–1985)",
                symbol: "VNN"
            },
            VUV: {
                displayName: "vatu de Vanuatu",
                "displayName-count-one": "vatu de Vanuatu",
                "displayName-count-other": "vatus de Vanuatu",
                symbol: "VUV"
            },
            WST: {
                displayName: "tala samoà",
                "displayName-count-one": "tala samoà",
                "displayName-count-other": "tales samoans",
                symbol: "WST"
            },
            XAF: {
                displayName: "franc CFA BEAC",
                "displayName-count-one": "franc CFA BEAC",
                "displayName-count-other": "francs CFA BEAC",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "plata",
                "displayName-count-one": "plata",
                "displayName-count-other": "plata",
                symbol: "XAG"
            },
            XAU: {
                displayName: "or",
                "displayName-count-one": "or",
                "displayName-count-other": "or",
                symbol: "XAU"
            },
            XBA: {
                displayName: "unitat compensatòria europea",
                "displayName-count-one": "unitat compensatòria europea",
                "displayName-count-other": "unitats compensatòries europees",
                symbol: "XBA"
            },
            XBB: {
                displayName: "unitat monetària europea",
                "displayName-count-one": "unitat monetària europea",
                "displayName-count-other": "unitats monetàries europees",
                symbol: "XBB"
            },
            XBC: {
                displayName: "unitat de compte europea (XBC)",
                "displayName-count-one": "unitat de compte europea (XBC)",
                "displayName-count-other": "unitats de compte europees (XBC)",
                symbol: "XBC"
            },
            XBD: {
                displayName: "unitat de compte europea (XBD)",
                "displayName-count-one": "unitat de compte europea (XBD)",
                "displayName-count-other": "unitats de compte europees (XBD)",
                symbol: "XBD"
            },
            XCD: {
                displayName: "dòlar del Carib Oriental",
                "displayName-count-one": "dòlar del Carib Oriental",
                "displayName-count-other": "dòlars del Carib Oriental",
                symbol: "XCD",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "drets especials de gir",
                "displayName-count-one": "drets especials de gir",
                "displayName-count-other": "drets especials de gir",
                symbol: "XDR"
            },
            XEU: {
                displayName: "unitat de moneda europea",
                "displayName-count-one": "unitat de moneda europea",
                "displayName-count-other": "unitats de moneda europees",
                symbol: "XEU"
            },
            XFO: {
                displayName: "franc or francès",
                "displayName-count-one": "franc or francès",
                "displayName-count-other": "francs or francesos",
                symbol: "XFO"
            },
            XFU: {
                displayName: "franc UIC francès",
                "displayName-count-one": "franc UIC francès",
                "displayName-count-other": "francs UIC francesos",
                symbol: "XFU"
            },
            XOF: {
                displayName: "franc CFA BCEAO",
                "displayName-count-one": "franc CFA BCEAO",
                "displayName-count-other": "francs CFA BCEAO",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "pal·ladi",
                "displayName-count-one": "pal·ladi",
                "displayName-count-other": "pal·ladi",
                symbol: "XPD"
            },
            XPF: {
                displayName: "franc CFP",
                "displayName-count-one": "franc CFP",
                "displayName-count-other": "francs CFP",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "platí",
                "displayName-count-one": "platí",
                "displayName-count-other": "platí",
                symbol: "XPT"
            },
            XRE: {
                displayName: "fons RINET",
                "displayName-count-one": "fons RINET",
                "displayName-count-other": "fons RINET",
                symbol: "XRE"
            },
            XSU: {
                displayName: "XSU",
                symbol: "XSU"
            },
            XTS: {
                displayName: "codi reservat per a proves",
                "displayName-count-one": "codi reservat per a proves",
                "displayName-count-other": "codi reservat per a proves",
                symbol: "XTS"
            },
            XUA: {
                displayName: "XUA",
                symbol: "XUA"
            },
            XXX: {
                displayName: "moneda desconeguda",
                "displayName-count-one": "(unitat monetària desconeguda)",
                "displayName-count-other": "(moneda desconeguda)",
                symbol: "XXX"
            },
            YDD: {
                displayName: "dinar iemenita",
                "displayName-count-one": "dinar iemenita",
                "displayName-count-other": "dinars iemenites",
                symbol: "YDD"
            },
            YER: {
                displayName: "rial iemenita",
                "displayName-count-one": "rial iemenita",
                "displayName-count-other": "rials iemenites",
                symbol: "YER"
            },
            YUD: {
                displayName: "dinar fort iugoslau",
                "displayName-count-one": "dinar fort iugoslau",
                "displayName-count-other": "dinars forts iugoslaus",
                symbol: "YUD"
            },
            YUM: {
                displayName: "nou dinar iugoslau",
                "displayName-count-one": "nou dinar iugoslau",
                "displayName-count-other": "nous dinars iugoslaus",
                symbol: "YUM"
            },
            YUN: {
                displayName: "dinar convertible iugoslau",
                "displayName-count-one": "dinar convertible iugoslau",
                "displayName-count-other": "dinars convertibles iugoslaus",
                symbol: "YUN"
            },
            YUR: {
                displayName: "dinar iugoslau reformat (1992–1993)",
                "displayName-count-one": "dinar reformat iugoslau",
                "displayName-count-other": "dinars reformats iugoslaus",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "rand sud-africà (financer)",
                "displayName-count-one": "rand sud-africà (financer)",
                "displayName-count-other": "rands sud-africans (financers)",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "rand sud-africà",
                "displayName-count-one": "rand sud-africà",
                "displayName-count-other": "rands sud-africans",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "kwacha zambià (1968–2012)",
                "displayName-count-one": "kwacha zambià (1968–2012)",
                "displayName-count-other": "kwacha zambians (1968–2012)",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "kwacha zambià",
                "displayName-count-one": "kwacha zambià",
                "displayName-count-other": "kwacha zambians",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "nou zaire zairès",
                "displayName-count-one": "nou zaire zairès",
                "displayName-count-other": "nous zaires zairesos",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "zaire zairès",
                "displayName-count-one": "zaire zairès",
                "displayName-count-other": "zaires zairesos",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "dòlar zimbabuès (1980–2008)",
                "displayName-count-one": "dòlar zimbabuès (1980–2008)",
                "displayName-count-other": "dòlars zimbabuesos (1980–2008)",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "dòlar zimbabuès (2009)",
                "displayName-count-one": "dòlar zimbabuès (2009)",
                "displayName-count-other": "dòlars zimbabuesos (2009)",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "dòlar zimbabuès (2008)",
                "displayName-count-one": "dòlar zimbabuès (2008)",
                "displayName-count-other": "dòlars zimbabuesos (2008)",
                symbol: "ZWR"
            }
        },
        localeCurrency: "EUR"
    },
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE, d MMMM 'de' y",
            m: "d MMM",
            M: "d MMMM",
            y: "LLL 'de' y",
            Y: "LLLL 'de' y",
            F: "EEEE, d MMMM 'de' y H:mm:ss",
            g: "d/M/y H:mm",
            G: "d/M/y H:mm:ss",
            t: "H:mm",
            T: "H:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1}, 'a' 'les' {0}",
            long: "{1}, 'a' 'les' {0}",
            medium: "{1}, {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E H:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E H:mm:ss",
                Gy: "y G",
                GyMd: "dd-MM-y GGGGG",
                GyMMM: "LLL y G",
                GyMMMd: "d MMM 'de' y G",
                GyMMMEd: "E, d MMM 'de' y G",
                GyMMMM: "LLLL 'de' y G",
                GyMMMMd: "d MMMM 'de' y G",
                GyMMMMEd: "E, d MMMM 'de' y G",
                h: "h a",
                H: "H",
                hm: "h:mm a",
                Hm: "H:mm",
                hms: "h:mm:ss a",
                Hms: "H:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "H:mm:ss v",
                hmsvvvv: "h:mm:ss a (vvvv)",
                Hmsvvvv: "H:mm:ss (vvvv)",
                hmv: "h:mm a v",
                Hmv: "H:mm v",
                hmvvvv: "h:mm a (vvvv)",
                Hmvvvv: "H:mm (vvvv)",
                M: "L",
                Md: "d/M",
                MEd: "E d/M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E, d MMM",
                MMMMd: "d MMMM",
                MMMMEd: "E, d MMMM",
                "MMMMW-count-one": "'setmana' W MMMM",
                "MMMMW-count-other": "'setmana' W MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E, d/M/y",
                yMMM: "LLL 'de' y",
                yMMMd: "d MMM 'de' y",
                yMMMEd: "E, d MMM y",
                yMMMM: "LLLL 'de' y",
                yMMMMd: "d MMMM 'de' y",
                yMMMMEd: "E, d MMMM 'de' y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "'setmana' w 'de' Y",
                "yw-count-other": "'setmana' w 'de' Y"
            }
        },
        timeFormats: {
            full: "H:mm:ss (zzzz)",
            long: "H:mm:ss z",
            medium: "H:mm:ss",
            short: "H:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM 'de' y",
            long: "d MMMM 'de' y",
            medium: "d MMM y",
            short: "d/M/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "dg.",
                    "dl.",
                    "dt.",
                    "dc.",
                    "dj.",
                    "dv.",
                    "ds."
                ],
                narrow: [
                    "dg",
                    "dl",
                    "dt",
                    "dc",
                    "dj",
                    "dv",
                    "ds"
                ],
                short: [
                    "dg.",
                    "dl.",
                    "dt.",
                    "dc.",
                    "dj.",
                    "dv.",
                    "ds."
                ],
                wide: [
                    "diumenge",
                    "dilluns",
                    "dimarts",
                    "dimecres",
                    "dijous",
                    "divendres",
                    "dissabte"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "dg.",
                    "dl.",
                    "dt.",
                    "dc.",
                    "dj.",
                    "dv.",
                    "ds."
                ],
                narrow: [
                    "dg",
                    "dl",
                    "dt",
                    "dc",
                    "dj",
                    "dv",
                    "ds"
                ],
                short: [
                    "dg.",
                    "dl.",
                    "dt.",
                    "dc.",
                    "dj.",
                    "dv.",
                    "ds."
                ],
                wide: [
                    "diumenge",
                    "dilluns",
                    "dimarts",
                    "dimecres",
                    "dijous",
                    "divendres",
                    "dissabte"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "de gen.",
                    "de febr.",
                    "de març",
                    "d’abr.",
                    "de maig",
                    "de juny",
                    "de jul.",
                    "d’ag.",
                    "de set.",
                    "d’oct.",
                    "de nov.",
                    "de des."
                ],
                narrow: [
                    "GN",
                    "FB",
                    "MÇ",
                    "AB",
                    "MG",
                    "JN",
                    "JL",
                    "AG",
                    "ST",
                    "OC",
                    "NV",
                    "DS"
                ],
                wide: [
                    "de gener",
                    "de febrer",
                    "de març",
                    "d’abril",
                    "de maig",
                    "de juny",
                    "de juliol",
                    "d’agost",
                    "de setembre",
                    "d’octubre",
                    "de novembre",
                    "de desembre"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "gen.",
                    "febr.",
                    "març",
                    "abr.",
                    "maig",
                    "juny",
                    "jul.",
                    "ag.",
                    "set.",
                    "oct.",
                    "nov.",
                    "des."
                ],
                narrow: [
                    "GN",
                    "FB",
                    "MÇ",
                    "AB",
                    "MG",
                    "JN",
                    "JL",
                    "AG",
                    "ST",
                    "OC",
                    "NV",
                    "DS"
                ],
                wide: [
                    "gener",
                    "febrer",
                    "març",
                    "abril",
                    "maig",
                    "juny",
                    "juliol",
                    "agost",
                    "setembre",
                    "octubre",
                    "novembre",
                    "desembre"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1T",
                    "2T",
                    "3T",
                    "4T"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1r trimestre",
                    "2n trimestre",
                    "3r trimestre",
                    "4t trimestre"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1T",
                    "2T",
                    "3T",
                    "4T"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1r trimestre",
                    "2n trimestre",
                    "3r trimestre",
                    "4t trimestre"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "mitjanit",
                    am: "a. m.",
                    pm: "p. m.",
                    morning1: "matinada",
                    morning2: "matí",
                    afternoon1: "migdia",
                    afternoon2: "tarda",
                    evening1: "vespre",
                    night1: "nit"
                },
                narrow: {
                    midnight: "mitjanit",
                    am: "a. m.",
                    pm: "p. m.",
                    morning1: "mat.",
                    morning2: "matí",
                    afternoon1: "md",
                    afternoon2: "tarda",
                    evening1: "vespre",
                    night1: "nit"
                },
                wide: {
                    midnight: "mitjanit",
                    am: "a. m.",
                    pm: "p. m.",
                    morning1: "matinada",
                    morning2: "matí",
                    afternoon1: "migdia",
                    afternoon2: "tarda",
                    evening1: "vespre",
                    night1: "nit"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "mitjanit",
                    am: "a. m.",
                    pm: "p. m.",
                    morning1: "matinada",
                    morning2: "matí",
                    afternoon1: "migdia",
                    afternoon2: "tarda",
                    evening1: "vespre",
                    night1: "nit"
                },
                narrow: {
                    midnight: "mitjanit",
                    am: "a. m.",
                    pm: "p. m.",
                    morning1: "matinada",
                    morning2: "matí",
                    afternoon1: "migdia",
                    afternoon2: "tarda",
                    evening1: "vespre",
                    night1: "nit"
                },
                wide: {
                    midnight: "mitjanit",
                    am: "a. m.",
                    pm: "p. m.",
                    morning1: "matinada",
                    morning2: "matí",
                    afternoon1: "migdia",
                    afternoon2: "tarda",
                    evening1: "vespre",
                    night1: "nit"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "abans de Crist",
                    "1": "després de Crist",
                    "0-alt-variant": "abans de l’era cristiana",
                    "1-alt-variant": "era cristiana"
                },
                abbreviated: {
                    "0": "aC",
                    "1": "dC",
                    "0-alt-variant": "AEC",
                    "1-alt-variant": "EC"
                },
                narrow: {
                    "0": "aC",
                    "1": "dC",
                    "0-alt-variant": "AEC",
                    "1-alt-variant": "EC"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "era",
                short: "era",
                narrow: "era"
            },
            year: {
                wide: "any",
                short: "any",
                narrow: "any"
            },
            quarter: {
                wide: "trimestre",
                short: "trim.",
                narrow: "trim."
            },
            month: {
                wide: "mes",
                short: "mes",
                narrow: "mes"
            },
            week: {
                wide: "setmana",
                short: "setm.",
                narrow: "setm."
            },
            weekOfMonth: {
                wide: "setmana del mes",
                short: "setm. del mes",
                narrow: "setm. del mes"
            },
            day: {
                wide: "dia",
                short: "dia",
                narrow: "dia"
            },
            dayOfYear: {
                wide: "dia de l’any",
                short: "dia de l’any",
                narrow: "dia de l’any"
            },
            weekday: {
                wide: "dia de la setmana",
                short: "dia de la setm.",
                narrow: "dia de la setm."
            },
            weekdayOfMonth: {
                wide: "dia de la setmana del mes",
                short: "dia de la setm. del mes",
                narrow: "dia de la setm. del mes"
            },
            dayperiod: {
                short: "a. m./p. m.",
                wide: "a. m./p. m.",
                narrow: "a. m./p. m."
            },
            hour: {
                wide: "hora",
                short: "h",
                narrow: "h"
            },
            minute: {
                wide: "minut",
                short: "min",
                narrow: "min"
            },
            second: {
                wide: "segon",
                short: "s",
                narrow: "s"
            },
            zone: {
                wide: "fus horari",
                short: "fus horari",
                narrow: "fus horari"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "mil·lisegon"
            }
        }
    },
    firstDay: 1,
    weekendRange: {
        start: 6,
        end: 0
    },
    likelySubtags: {
        ca: "ca-Latn-ES"
    }
});

