/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "chr",
    identity: {
        language: "chr"
    },
    territory: "US",
    numbers: {
        symbols: {
            decimal: ".",
            group: ",",
            list: ";",
            percentSign: "%",
            plusSign: "+",
            minusSign: "-",
            approximatelySign: "~",
            exponential: "E",
            superscriptingExponent: "×",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "n%"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "$n"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-one": "n $",
            "unitPattern-count-other": "n $"
        },
        accounting: {
            patterns: [
                "$n",
                "($n)"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "ADP",
                symbol: "ADP"
            },
            AED: {
                displayName: "ᏌᏊ ᎢᏳᎾᎵᏍᏔᏅ ᎡᎳᏈ ᎢᎹᎵᏘᏏ ᎠᏕᎳ",
                "displayName-count-one": "UAE ᎠᏕᎳ",
                "displayName-count-other": "UAE ᎠᏕᎳ",
                symbol: "AED"
            },
            AFA: {
                displayName: "AFA",
                symbol: "AFA"
            },
            AFN: {
                displayName: "ᎠᏫᎨᏂᏍᏖᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᎠᏫᎨᏂᏍᏖᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᎠᏫᎨᏂᏍᏖᏂ ᎠᏕᎳ",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "ALK",
                symbol: "ALK"
            },
            ALL: {
                displayName: "ᎠᎵᏇᏂᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᎠᎵᏇᏂᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᎠᎵᏇᏂᏯ ᎠᏕᎳ",
                symbol: "ALL"
            },
            AMD: {
                displayName: "ᎠᎵᎻᏂᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᎠᎵᎻᏂᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᎠᎵᎻᏂᎠ ᎠᏕᎳ",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "ᎾᏍᎩᏁᏛᎳᏂ ᎠᏂᏘᎵᏏ ᎠᏕᎳ",
                "displayName-count-one": "ᎾᏍᎩᏁᏛᎳᏂ ᎠᏂᏘᎵᏏ ᎠᏕᎳ",
                "displayName-count-other": "ᎾᏍᎩᏁᏛᎳᏂ ᎠᏂᏘᎵᏏ ᎠᏕᎳ",
                symbol: "ANG"
            },
            AOA: {
                displayName: "ᎠᏂᎪᎳ ᎠᏕᎳ",
                "displayName-count-one": "ᎠᏂᎪᎳ ᎠᏕᎳ",
                "displayName-count-other": "ᎠᏂᎪᎳ ᎠᏕᎳ",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "AOK",
                symbol: "AOK"
            },
            AON: {
                displayName: "AON",
                symbol: "AON"
            },
            AOR: {
                displayName: "AOR",
                symbol: "AOR"
            },
            ARA: {
                displayName: "ARA",
                symbol: "ARA"
            },
            ARL: {
                displayName: "ARL",
                symbol: "ARL"
            },
            ARM: {
                displayName: "ARM",
                symbol: "ARM"
            },
            ARP: {
                displayName: "ARP",
                symbol: "ARP"
            },
            ARS: {
                displayName: "ᎠᏥᏂᏘᏂᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᎠᏥᏂᏘᏂᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᎠᏥᏂᏘᏂᎠ ᎠᏕᎳ",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "ATS",
                symbol: "ATS"
            },
            AUD: {
                displayName: "ᎡᎳᏗᏜ ᎠᏕᎳ",
                "displayName-count-one": "ᎡᎳᏗᏜ ᎠᏕᎳ",
                "displayName-count-other": "ᎡᎳᏗᏜ ᎠᏕᎳ",
                symbol: "A$",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "ᎠᎷᏆ ᎠᏕᎳ",
                "displayName-count-one": "ᎠᎷᏆ ᎠᏕᎳ",
                "displayName-count-other": "ᎠᎷᏆ ᎠᏕᎳ",
                symbol: "AWG"
            },
            AZM: {
                displayName: "AZM",
                symbol: "AZM"
            },
            AZN: {
                displayName: "ᎠᏏᎵᏆᏌᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᎠᏏᎵᏆᏌᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᎠᏏᎵᏆᏌᏂ ᎠᏕᎳ",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "BAD",
                symbol: "BAD"
            },
            BAM: {
                displayName: "ᏉᏏᏂᎠ-ᎲᏤᎪᏫ ᎦᏁᏟᏴᏍᏔᏅ ᎠᏕᎳ",
                "displayName-count-one": "ᏉᏏᏂᎠ-ᎲᏤᎪᏫ ᎦᏁᏟᏴᏍᏔᏅ ᎠᏕᎳ",
                "displayName-count-other": "ᏉᏏᏂᎠ-ᎲᏤᎪᏫ ᎦᏁᏟᏴᏍᏔᏅ ᎠᏕᎳ",
                symbol: "BAM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "BAN",
                symbol: "BAN"
            },
            BBD: {
                displayName: "ᏆᏇᏙᏍ ᎠᏕᎳ",
                "displayName-count-one": "ᏆᏇᏙᏍ ᎠᏕᎳ",
                "displayName-count-other": "ᏆᏇᏙᏍ ᎠᏕᎳ",
                symbol: "BBD",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "ᏆᏂᎦᎵᏕᏍ ᎠᏕᎳ",
                "displayName-count-one": "ᏆᏂᎦᎵᏕᏍ ᎠᏕᎳ",
                "displayName-count-other": "ᏆᏂᎦᎵᏕᏍ ᎠᏕᎳ",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "BEC",
                symbol: "BEC"
            },
            BEF: {
                displayName: "BEF",
                symbol: "BEF"
            },
            BEL: {
                displayName: "BEL",
                symbol: "BEL"
            },
            BGL: {
                displayName: "BGL",
                symbol: "BGL"
            },
            BGM: {
                displayName: "BGM",
                symbol: "BGM"
            },
            BGN: {
                displayName: "ᏊᎵᎨᎵᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᏊᎵᎨᎵᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᏊᎵᎨᎵᎠ ᎠᏕᎳ",
                symbol: "BGN"
            },
            BGO: {
                displayName: "BGO",
                symbol: "BGO"
            },
            BHD: {
                displayName: "ᏆᎭᎴᎢᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏆᎭᎴᎢᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏆᎭᎴᎢᏂ ᎠᏕᎳ",
                symbol: "BHD"
            },
            BIF: {
                displayName: "ᏋᎷᏂᏗ ᎠᏕᎳ",
                "displayName-count-one": "ᏋᎷᏂᏗ ᎠᏕᎳ",
                "displayName-count-other": "ᏋᎷᏂᏗ ᎠᏕᎳ",
                symbol: "BIF"
            },
            BMD: {
                displayName: "ᏆᏊᏓ ᎠᏕᎳ",
                "displayName-count-one": "ᏆᏊᏓ ᎠᏕᎳ",
                "displayName-count-other": "ᏆᏊᏓ ᎠᏕᎳ",
                symbol: "BMD",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "ᏊᎾᎢ ᎠᏕᎳ",
                "displayName-count-one": "ᏊᎾᎢ ᎠᏕᎳ",
                "displayName-count-other": "ᏊᎾᎢ ᎠᏕᎳ",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "ᏉᎵᏫᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᏉᎵᏫᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᏉᎵᏫᎠ ᎠᏕᎳ",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "BOL",
                symbol: "BOL"
            },
            BOP: {
                displayName: "BOP",
                symbol: "BOP"
            },
            BOV: {
                displayName: "BOV",
                symbol: "BOV"
            },
            BRB: {
                displayName: "BRB",
                symbol: "BRB"
            },
            BRC: {
                displayName: "BRC",
                symbol: "BRC"
            },
            BRE: {
                displayName: "BRE",
                symbol: "BRE"
            },
            BRL: {
                displayName: "ᏆᏏᎵᎢ ᎠᏕᎳ",
                "displayName-count-one": "ᏆᏏᎵᎢ ᎠᏕᎳ",
                "displayName-count-other": "ᏆᏏᎵᎢ ᎠᏕᎳ",
                symbol: "R$",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "BRN",
                symbol: "BRN"
            },
            BRR: {
                displayName: "BRR",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "BRZ",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "ᏆᎭᎹ ᎠᏕᎳ",
                "displayName-count-one": "ᏆᎭᎹ ᎠᏕᎳ",
                "displayName-count-other": "ᏆᎭᎹ ᎠᏕᎳ",
                symbol: "BSD",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "ᏊᏔᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏊᏔᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏊᏔᏂ ᎠᏕᎳ",
                symbol: "BTN"
            },
            BUK: {
                displayName: "BUK",
                symbol: "BUK"
            },
            BWP: {
                displayName: "ᏆᏣᏩᎾ ᎠᏕᎳ",
                "displayName-count-one": "ᏆᏣᏩᎾ ᎠᏕᎳ",
                "displayName-count-other": "ᏆᏣᏩᎾ ᎠᏕᎳ",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "BYB",
                symbol: "BYB"
            },
            BYN: {
                displayName: "ᏇᎳᎷᏍ ᎠᏕᎳ",
                "displayName-count-one": "ᏇᎳᎷᏍ ᎠᏕᎳ",
                "displayName-count-other": "ᏇᎳᎷᏍ ᎠᏕᎳ",
                symbol: "BYN",
                "symbol-alt-narrow": "р."
            },
            BYR: {
                displayName: "ᏇᎳᎷᏍ ᎠᏕᎳ (2000–2016)",
                "displayName-count-one": "ᏇᎳᎷᏍ ᎠᏕᎳ (2000–2016)",
                "displayName-count-other": "ᏇᎳᎷᏍ ᎠᏕᎳ (2000–2016)",
                symbol: "BYR"
            },
            BZD: {
                displayName: "ᏇᎵᏍ ᎠᏕᎳ",
                "displayName-count-one": "ᏇᎵᏍ ᎠᏕᎳ",
                "displayName-count-other": "ᏇᎵᏍ ᎠᏕᎳ",
                symbol: "BZD",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "ᎨᎾᏓ ᎠᏕᎳ",
                "displayName-count-one": "ᎨᎾᏓ ᎠᏕᎳ",
                "displayName-count-other": "ᎨᎾᏓ ᎠᏕᎳ",
                symbol: "CA$",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "ᎧᏂᎪ ᎠᏕᎳ",
                "displayName-count-one": "ᎧᏂᎪ ᎠᏕᎳ",
                "displayName-count-other": "ᎧᏂᎪ ᎠᏕᎳ",
                symbol: "CDF"
            },
            CHE: {
                displayName: "CHE",
                symbol: "CHE"
            },
            CHF: {
                displayName: "ᏍᏫᏏ ᎠᏕᎳ",
                "displayName-count-one": "ᏍᏫᏏ ᎠᏕᎳ",
                "displayName-count-other": "ᏍᏫᏏ ᎠᏕᎳ",
                symbol: "CHF"
            },
            CHW: {
                displayName: "CHW",
                symbol: "CHW"
            },
            CLE: {
                displayName: "CLE",
                symbol: "CLE"
            },
            CLF: {
                displayName: "CLF",
                symbol: "CLF"
            },
            CLP: {
                displayName: "ᏥᎵ ᎠᏕᎳ",
                "displayName-count-one": "ᏥᎵ ᎠᏕᎳ",
                "displayName-count-other": "ᏥᎵ ᎠᏕᎳ",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "ᏣᏂᏏ ᎠᏕᎳ (ᏓᎹᏳᏟᏗ)",
                "displayName-count-one": "ᏣᏂᏏ ᎠᏕᎳ (ᏓᎹᏳᏟᏗ)",
                "displayName-count-other": "ᏣᏂᏏ ᎠᏕᎳ (ᏓᎹᏳᏟᏗ)",
                symbol: "CNH"
            },
            CNX: {
                displayName: "CNX",
                symbol: "CNX"
            },
            CNY: {
                displayName: "ᏓᎶᏂᎨ ᎠᏕᎳ",
                "displayName-count-one": "ᏓᎶᏂᎨ ᎠᏕᎳ",
                "displayName-count-other": "ᏓᎶᏂᎨ ᎠᏕᎳ",
                symbol: "CN¥",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "ᎪᎸᎻᏈᎢᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᎪᎸᎻᏈᎢᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᎪᎸᎻᏈᎢᎠ ᎠᏕᎳ",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "COU",
                symbol: "COU"
            },
            CRC: {
                displayName: "ᎪᏍᏓᎵᎧ ᎠᏕᎳ",
                "displayName-count-one": "ᎪᏍᏓᎵᎧ ᎠᏕᎳ",
                "displayName-count-other": "ᎪᏍᏓᎵᎧ ᎠᏕᎳ",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "CSD",
                symbol: "CSD"
            },
            CSK: {
                displayName: "CSK",
                symbol: "CSK"
            },
            CUC: {
                displayName: "ᎫᏆ ᎦᏁᏟᏴᏍᏔᏅ ᎠᏕᎳ",
                "displayName-count-one": "ᎫᏆ ᎦᏁᏟᏴᏍᏔᏅ ᎠᏕᎳ",
                "displayName-count-other": "ᎫᏆ ᎦᏁᏟᏴᏍᏔᏅ ᎠᏕᎳ",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "ᎫᏆ ᎠᏕᎳ",
                "displayName-count-one": "ᎫᏆ ᎠᏕᎳ",
                "displayName-count-other": "ᎫᏆ ᎠᏕᎳ",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "ᎢᎬᎾᏕᎾ ᎢᏤᏳᏍᏗ ᎠᏕᎳ",
                "displayName-count-one": "ᎢᎬᎾᏕᎾ ᎢᏤᏳᏍᏗ ᎠᏕᎳ",
                "displayName-count-other": "ᎢᎬᎾᏕᎾ ᎢᏤᏳᏍᏗ ᎠᏕᎳ",
                symbol: "CVE"
            },
            CYP: {
                displayName: "CYP",
                symbol: "CYP"
            },
            CZK: {
                displayName: "ᏤᎩ ᎠᏕᎳ",
                "displayName-count-one": "ᏤᎩ ᎠᏕᎳ",
                "displayName-count-other": "ᏤᎩ ᎠᏕᎳ",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "DDM",
                symbol: "DDM"
            },
            DEM: {
                displayName: "DEM",
                symbol: "DEM"
            },
            DJF: {
                displayName: "ᏥᏊᏗ ᎠᏕᎳ",
                "displayName-count-one": "ᏥᏊᏗ ᎠᏕᎳ",
                "displayName-count-other": "ᏥᏊᏗ ᎠᏕᎳ",
                symbol: "DJF"
            },
            DKK: {
                displayName: "ᏕᏂᏍ ᎠᏕᎳ",
                "displayName-count-one": "ᏕᏂᏍ ᎠᏕᎳ",
                "displayName-count-other": "ᏕᏂᏍ ᎠᏕᎳ",
                symbol: "DKK",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "ᏙᎻᏂᎧᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏙᎻᏂᎧᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏙᎻᏂᎧᏂ ᎠᏕᎳ",
                symbol: "DOP",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "ᎠᎵᏥᎵᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᎠᎵᏥᎵᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᎠᎵᏥᎵᏯ ᎠᏕᎳ",
                symbol: "DZD"
            },
            ECS: {
                displayName: "ECS",
                symbol: "ECS"
            },
            ECV: {
                displayName: "ECV",
                symbol: "ECV"
            },
            EEK: {
                displayName: "EEK",
                symbol: "EEK"
            },
            EGP: {
                displayName: "ᎢᏥᏈᎢ ᎠᏕᎳ",
                "displayName-count-one": "ᎢᏥᏈᎢ ᎠᏕᎳ",
                "displayName-count-other": "ᎢᏥᏈᎢ ᎠᏕᎳ",
                symbol: "EGP",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "ᎡᎵᏟᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᎡᎵᏟᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᎡᎵᏟᏯ ᎠᏕᎳ",
                symbol: "ERN"
            },
            ESA: {
                displayName: "ESA",
                symbol: "ESA"
            },
            ESB: {
                displayName: "ESB",
                symbol: "ESB"
            },
            ESP: {
                displayName: "ESP",
                symbol: "ESP",
                "symbol-alt-narrow": "₧"
            },
            ETB: {
                displayName: "ᎢᏗᎣᏈᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᎢᏗᎣᏈᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᎢᏗᎣᏈᎠ ᎠᏕᎳ",
                symbol: "ETB"
            },
            EUR: {
                displayName: "ᏳᎳᏛ ᎠᏕᎳ",
                "displayName-count-one": "ᏳᎳᏛ ᎠᏕᎳ",
                "displayName-count-other": "ᏳᎳᏛ ᎠᏕᎳ",
                symbol: "€",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "FIM",
                symbol: "FIM"
            },
            FJD: {
                displayName: "ᏫᎩ ᎠᏕᎳ",
                "displayName-count-one": "ᏫᎩ ᎠᏕᎳ",
                "displayName-count-other": "ᏫᎩ ᎠᏕᎳ",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "ᏩᎩᎤ ᏚᎦᏚᏛᎢ ᎠᏕᎳ",
                "displayName-count-one": "ᏩᎩᎤ ᏚᎦᏚᏛᎢ ᎠᏕᎳ",
                "displayName-count-other": "ᏩᎩᎤ ᏚᎦᏚᏛᎢ ᎠᏕᎳ",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "FRF",
                symbol: "FRF"
            },
            GBP: {
                displayName: "ᎩᎵᏏᏲ ᎠᏕᎳ",
                "displayName-count-one": "ᎩᎵᏏᏲ ᎠᏕᎳ",
                "displayName-count-other": "ᎩᎵᏏᏲ ᎠᏕᎳ",
                symbol: "£",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "GEK",
                symbol: "GEK"
            },
            GEL: {
                displayName: "ᏣᎠᏥᎢ ᎠᏕᎳ",
                "displayName-count-one": "ᏣᎠᏥᎢ ᎠᏕᎳ",
                "displayName-count-other": "ᏣᎠᏥᎢ ᎠᏕᎳ",
                symbol: "GEL",
                "symbol-alt-narrow": "₾"
            },
            GHC: {
                displayName: "GHC",
                symbol: "GHC"
            },
            GHS: {
                displayName: "ᎦᎠᎾ ᎠᏕᎳ",
                "displayName-count-one": "ᎦᎠᎾ ᎠᏕᎳ",
                "displayName-count-other": "ᎦᎠᎾ ᎠᏕᎳ",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "ᏥᏆᎵᏓ ᎠᏕᎳ",
                "displayName-count-one": "ᏥᏆᎵᏓ ᎠᏕᎳ",
                "displayName-count-other": "ᏥᏆᎵᏓ ᎠᏕᎳ",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "ᎦᎹᏈᎢᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᎦᎹᏈᎢᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᎦᎹᏈᎢᎠ ᎠᏕᎳ",
                symbol: "GMD"
            },
            GNF: {
                displayName: "ᎩᎢᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᎩᎢᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᎩᎢᏂ ᎠᏕᎳ",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "GNS",
                symbol: "GNS"
            },
            GQE: {
                displayName: "GQE",
                symbol: "GQE"
            },
            GRD: {
                displayName: "GRD",
                symbol: "GRD"
            },
            GTQ: {
                displayName: "ᏆᏖᎹᎳ ᎠᏕᎳ",
                "displayName-count-one": "ᏆᏖᎹᎳ ᎠᏕᎳ",
                "displayName-count-other": "ᏆᏖᎹᎳ ᎠᏕᎳ",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "GWE",
                symbol: "GWE"
            },
            GWP: {
                displayName: "GWP",
                symbol: "GWP"
            },
            GYD: {
                displayName: "ᎦᏯᎾ ᎠᏕᎳ",
                "displayName-count-one": "ᎦᏯᎾ ᎠᏕᎳ",
                "displayName-count-other": "ᎦᏯᎾ ᎠᏕᎳ",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "ᎰᏂᎩ ᎪᏂᎩ ᎠᏕᎳ",
                "displayName-count-one": "ᎰᏂᎩ ᎪᏂᎩ ᎠᏕᎳ",
                "displayName-count-other": "ᎰᏂᎩ ᎪᏂᎩ ᎠᏕᎳ",
                symbol: "HK$",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "ᎭᏂᏚᎳᏍ ᎠᏕᎳ",
                "displayName-count-one": "ᎭᏂᏚᎳᏍ ᎠᏕᎳ",
                "displayName-count-other": "ᎭᏂᏚᎳᏍ ᎠᏕᎳ",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "HRD",
                symbol: "HRD"
            },
            HRK: {
                displayName: "ᎧᎶᎡᏏᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᎧᎶᎡᏏᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᎧᎶᎡᏏᎠ ᎠᏕᎳ",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "ᎮᏘ ᎠᏕᎳ",
                "displayName-count-one": "ᎮᏘ ᎠᏕᎳ",
                "displayName-count-other": "ᎮᏘ ᎠᏕᎳ",
                symbol: "HTG"
            },
            HUF: {
                displayName: "ᎲᏂᎦᎵ ᎠᏕᎳ",
                "displayName-count-one": "ᎲᏂᎦᎵ ᎠᏕᎳ",
                "displayName-count-other": "ᎲᏂᎦᎵ ᎠᏕᎳ",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "ᎢᏂᏙᏂᏍᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᎢᏂᏙᏂᏍᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᎢᏂᏙᏂᏍᏯ ᎠᏕᎳ",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "IEP",
                symbol: "IEP"
            },
            ILP: {
                displayName: "ILP",
                symbol: "ILP"
            },
            ILR: {
                displayName: "ILR",
                symbol: "ILR"
            },
            ILS: {
                displayName: "ᎢᏏᎵᏱ ᎢᏤ ᎠᏕᎳ",
                "displayName-count-one": "ᎢᏏᎵᏱ ᎢᏤ ᎠᏕᎳ",
                "displayName-count-other": "ᎢᏏᎵᏱ ᎢᏤ ᎠᏕᎳ",
                symbol: "₪",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "ᎢᏂᏗᎢᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᎢᏂᏗᎢᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᎢᏂᏗᎢᎠ ᎠᏕᎳ",
                symbol: "₹",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "ᎢᎳᎩ ᎠᏕᎳ",
                "displayName-count-one": "ᎢᎳᎩ ᎠᏕᎳ",
                "displayName-count-other": "ᎢᎳᎩ ᎠᏕᎳ",
                symbol: "IQD"
            },
            IRR: {
                displayName: "ᎢᎴᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᎢᎴᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᎢᎴᏂ ᎠᏕᎳ",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "ISJ",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "ᏧᏁᏍᏓᎸᎯ ᎠᏕᎳ",
                "displayName-count-one": "ᏧᏁᏍᏓᎸᎯ ᎠᏕᎳ",
                "displayName-count-other": "ᏧᏁᏍᏓᎸᎯ ᎠᏕᎳ",
                symbol: "ISK",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "ITL",
                symbol: "ITL"
            },
            JMD: {
                displayName: "ᏣᎺᎢᎧ ᎠᏕᎳ",
                "displayName-count-one": "ᏣᎺᎢᎧ ᎠᏕᎳ",
                "displayName-count-other": "ᏣᎺᎢᎧ ᎠᏕᎳ",
                symbol: "JMD",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "ᏦᏓᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏦᏓᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏦᏓᏂ ᎠᏕᎳ",
                symbol: "JOD"
            },
            JPY: {
                displayName: "ᏣᏩᏂᏏ ᎠᏕᎳ",
                "displayName-count-one": "ᏣᏩᏂᏏ ᎠᏕᎳ",
                "displayName-count-other": "ᏣᏩᏂᏏ ᎠᏕᎳ",
                symbol: "JP¥",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "ᎨᏂᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᎨᏂᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᎨᏂᏯ ᎠᏕᎳ",
                symbol: "KES"
            },
            KGS: {
                displayName: "ᎩᎵᏣᎢᏍ ᎠᏕᎳ",
                "displayName-count-one": "ᎩᎵᏣᎢᏍ ᎠᏕᎳ",
                "displayName-count-other": "ᎩᎵᏣᎢᏍ ᎠᏕᎳ",
                symbol: "KGS"
            },
            KHR: {
                displayName: "ᎧᎹᏉᏗᎠᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᎧᎹᏉᏗᎠᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᎧᎹᏉᏗᎠᏂ ᎠᏕᎳ",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "ᎪᎼᎳᏍ ᎠᏕᎳ",
                "displayName-count-one": "ᎪᎼᎳᏍ ᎠᏕᎳ",
                "displayName-count-other": "ᎪᎼᎳᏍ ᎠᏕᎳ",
                symbol: "KMF",
                "symbol-alt-narrow": "CF"
            },
            KPW: {
                displayName: "ᏧᏴᏢ ᎪᎵᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᏧᏴᏢ ᎪᎵᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᏧᏴᏢ ᎪᎵᎠ ᎠᏕᎳ",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "KRH",
                symbol: "KRH"
            },
            KRO: {
                displayName: "KRO",
                symbol: "KRO"
            },
            KRW: {
                displayName: "ᏧᎦᎾᏮ ᎪᎵᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᏧᎦᎾᏮ ᎪᎵᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᏧᎦᎾᏮ ᎪᎵᎠ ᎠᏕᎳ",
                symbol: "₩",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "ᎫᏪᎢᏘ ᎠᏕᎳ",
                "displayName-count-one": "ᎫᏪᎢᏘ ᎠᏕᎳ",
                "displayName-count-other": "ᎫᏪᎢᏘ ᎠᏕᎳ",
                symbol: "KWD"
            },
            KYD: {
                displayName: "ᎨᎢᎹᏂ ᏚᎦᏚᏛᎢ ᎠᏕᎳ",
                "displayName-count-one": "ᎨᎢᎹᏂ ᏚᎦᏚᏛᎢ ᎠᏕᎳ",
                "displayName-count-other": "ᎨᎢᎹᏂ ᏚᎦᏚᏛᎢ ᎠᏕᎳ",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "ᎧᏎᎧᏍᏕᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᎧᏎᎧᏍᏕᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᎧᏎᎧᏍᏕᏂ ᎠᏕᎳ",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "ᎳᎣ ᎠᏕᎳ",
                "displayName-count-one": "ᎳᎣ ᎠᏕᎳ",
                "displayName-count-other": "ᎳᎣ ᎠᏕᎳ",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "ᎴᏆᎾᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᎴᏆᎾᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᎴᏆᎾᏂ ᎠᏕᎳ",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "ᏍᎵ ᎳᏂᎧ ᎠᏕᎳ",
                "displayName-count-one": "ᏍᎵ ᎳᏂᎧ ᎠᏕᎳ",
                "displayName-count-other": "ᏍᎵ ᎳᏂᎧ ᎠᏕᎳ",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "ᎳᏈᎵᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᎳᏈᎵᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᎳᏈᎵᏯ ᎠᏕᎳ",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "ᎴᏐᏠ ᎶᏘ",
                "displayName-count-one": "ᎴᏐᏠ ᎶᏘ",
                "displayName-count-other": "ᎴᏐᏠ ᎶᏘᏍ",
                symbol: "LSL"
            },
            LTL: {
                displayName: "LTL",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "LTT",
                symbol: "LTT"
            },
            LUC: {
                displayName: "LUC",
                symbol: "LUC"
            },
            LUF: {
                displayName: "LUF",
                symbol: "LUF"
            },
            LUL: {
                displayName: "LUL",
                symbol: "LUL"
            },
            LVL: {
                displayName: "LVL",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "LVR",
                symbol: "LVR"
            },
            LYD: {
                displayName: "ᎵᏈᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᎵᏈᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᎵᏈᏯ ᎠᏕᎳ",
                symbol: "LYD"
            },
            MAD: {
                displayName: "ᎼᎶᎪ ᎠᏕᎳ",
                "displayName-count-one": "ᎼᎶᎪ ᎠᏕᎳ",
                "displayName-count-other": "ᎼᎶᎪ ᎠᏕᎳ",
                symbol: "MAD"
            },
            MAF: {
                displayName: "MAF",
                symbol: "MAF"
            },
            MCF: {
                displayName: "MCF",
                symbol: "MCF"
            },
            MDC: {
                displayName: "MDC",
                symbol: "MDC"
            },
            MDL: {
                displayName: "ᎹᎵᏙᏫᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᎹᎵᏙᏫᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᎹᎵᏙᏫᎠ ᎠᏕᎳ",
                symbol: "MDL"
            },
            MGA: {
                displayName: "ᎹᎳᎦᏏ ᎠᏕᎳ",
                "displayName-count-one": "ᎹᎳᎦᏏ ᎠᏕᎳ",
                "displayName-count-other": "ᎹᎳᎦᏏ ᎠᏕᎳ",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "MGF",
                symbol: "MGF"
            },
            MKD: {
                displayName: "ᎹᏎᏙᏂᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᎹᏎᏙᏂᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᎹᏎᏙᏂᎠ ᎠᏕᎳ",
                symbol: "MKD"
            },
            MKN: {
                displayName: "MKN",
                symbol: "MKN"
            },
            MLF: {
                displayName: "MLF",
                symbol: "MLF"
            },
            MMK: {
                displayName: "ᎹᏯᎹᎵ ᎠᏕᎳ",
                "displayName-count-one": "ᎹᏯᎹᎵ ᎠᏕᎳ",
                "displayName-count-other": "ᎹᏯᎹᎵ ᎠᏕᎳ",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "ᎹᏂᎪᎵᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᎹᏂᎪᎵᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᎹᏂᎪᎵᎠ ᎠᏕᎳ",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "ᎹᎧᎣ ᎠᏕᎳ",
                "displayName-count-one": "ᎹᎧᎣ ᎠᏕᎳ",
                "displayName-count-other": "ᎹᎧᎣ ᎠᏕᎳ",
                symbol: "MOP"
            },
            MRO: {
                displayName: "ᎹᏈᏔᏂᎠ ᎠᏕᎳ (1973–2017)",
                "displayName-count-one": "ᎹᏈᏔᏂᎠ ᎠᏕᎳ (1973–2017)",
                "displayName-count-other": "ᎹᏈᏔᏂᎠ ᎠᏕᎳ (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "ᎹᏈᏔᏂᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᎹᏈᏔᏂᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᎹᏈᏔᏂᎠ ᎠᏕᎳ",
                symbol: "MRU"
            },
            MTL: {
                displayName: "MTL",
                symbol: "MTL"
            },
            MTP: {
                displayName: "MTP",
                symbol: "MTP"
            },
            MUR: {
                displayName: "ᎹᏘᎢᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᎹᏘᎢᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᎹᏘᎢᏯ ᎠᏕᎳ",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "MVP",
                symbol: "MVP"
            },
            MVR: {
                displayName: "ᎹᎵᏗᏫᏍ ᎠᏕᎳ",
                "displayName-count-one": "ᎹᎵᏗᏫᏍ ᎠᏕᎳ",
                "displayName-count-other": "ᎹᎵᏗᏫᏍ ᎠᏕᎳ",
                symbol: "MVR"
            },
            MWK: {
                displayName: "ᎹᎳᏫ ᎠᏕᎳ",
                "displayName-count-one": "ᎹᎳᏫ ᎠᏕᎳ",
                "displayName-count-other": "ᎹᎳᏫ ᎠᏕᎳ",
                symbol: "MWK"
            },
            MXN: {
                displayName: "ᏍᏆᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏍᏆᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏍᏆᏂ ᎠᏕᎳ",
                symbol: "MX$",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "MXP",
                symbol: "MXP"
            },
            MXV: {
                displayName: "MXV",
                symbol: "MXV"
            },
            MYR: {
                displayName: "ᎹᎴᏏᎢᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᎹᎴᏏᎢᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᎹᎴᏏᎢᎠ ᎠᏕᎳ",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "MZE",
                symbol: "MZE"
            },
            MZM: {
                displayName: "MZM",
                symbol: "MZM"
            },
            MZN: {
                displayName: "ᎼᏎᎻᏇᎩ ᎠᏕᎳ",
                "displayName-count-one": "ᎼᏎᎻᏇᎩ ᎠᏕᎳ",
                "displayName-count-other": "ᎼᏎᎻᏇᎩ ᎠᏕᎳ",
                symbol: "MZN"
            },
            NAD: {
                displayName: "ᎾᎻᏈᎢᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᎾᎻᏈᎢᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᎾᎻᏈᎢᏯ ᎠᏕᎳ",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "ᏂᏥᎵᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᏂᏥᎵᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᏂᏥᎵᏯ ᎠᏕᎳ",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "NIC",
                symbol: "NIC"
            },
            NIO: {
                displayName: "ᏂᎧᎳᏆ ᎠᏕᎳ",
                "displayName-count-one": "ᏂᎧᎳᏆ ᎠᏕᎳ",
                "displayName-count-other": "ᏂᎧᎳᏆ ᎠᏕᎳ",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "NLG",
                symbol: "NLG"
            },
            NOK: {
                displayName: "ᏃᏪ ᎠᏕᎳ",
                "displayName-count-one": "ᏃᏪ ᎠᏕᎳ",
                "displayName-count-other": "ᏃᏪ ᎠᏕᎳ",
                symbol: "NOK",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "ᏁᏆᎵ ᎠᏕᎳ",
                "displayName-count-one": "ᏁᏆᎵ ᎠᏕᎳ",
                "displayName-count-other": "ᏁᏆᎵ ᎠᏕᎳ",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "ᎢᏤ ᏏᎢᎴᏂᏗ ᎠᏕᎳ",
                "displayName-count-one": "ᎢᏤ ᏏᎢᎴᏂᏗ ᎠᏕᎳ",
                "displayName-count-other": "ᎢᏤ ᏏᎢᎴᏂᏗ ᎠᏕᎳ",
                symbol: "NZ$",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "ᎣᎺᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᎣᎺᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᎣᎺᏂ ᎠᏕᎳ",
                symbol: "OMR"
            },
            PAB: {
                displayName: "ᏆᎾᎹ ᎠᏕᎳ",
                "displayName-count-one": "ᏆᎾᎹ ᎠᏕᎳ",
                "displayName-count-other": "ᏆᎾᎹ ᎠᏕᎳ",
                symbol: "PAB"
            },
            PEI: {
                displayName: "PEI",
                symbol: "PEI"
            },
            PEN: {
                displayName: "ᏇᎷ ᎠᏕᎳ",
                "displayName-count-one": "ᏇᎷ ᎠᏕᎳ",
                "displayName-count-other": "ᏇᎷ ᎠᏕᎳ",
                symbol: "PEN"
            },
            PES: {
                displayName: "PES",
                symbol: "PES"
            },
            PGK: {
                displayName: "ᏆᏇ ᎢᏤ ᎩᎢᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏆᏇ ᎢᏤ ᎩᎢᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏆᏇ ᎢᏤ ᎩᎢᏂ ᎠᏕᎳ",
                symbol: "PGK"
            },
            PHP: {
                displayName: "ᎠᏂᏈᎵᎩᏃ ᎠᏕᎳ",
                "displayName-count-one": "ᎠᏂᏈᎵᎩᏃ ᎠᏕᎳ",
                "displayName-count-other": "ᎠᏂᏈᎵᎩᏃ ᎠᏕᎳ",
                symbol: "PHP",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "ᏆᎩᏍᏖᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏆᎩᏍᏖᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏆᎩᏍᏖᏂ ᎠᏕᎳ",
                symbol: "PKR",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "ᏉᎳᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏉᎳᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏉᎳᏂ ᎠᏕᎳ",
                symbol: "PLN",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "PLZ",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "PTE",
                symbol: "PTE"
            },
            PYG: {
                displayName: "ᏆᎳᏇᎢᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᏆᎳᏇᎢᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᏆᎳᏇᎢᏯ ᎠᏕᎳ",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "ᎧᏔᎵ ᎠᏕᎳ",
                "displayName-count-one": "ᎧᏔᎵ ᎠᏕᎳ",
                "displayName-count-other": "ᎧᏔᎵ ᎠᏕᎳ",
                symbol: "QAR"
            },
            RHD: {
                displayName: "RHD",
                symbol: "RHD"
            },
            ROL: {
                displayName: "ROL",
                symbol: "ROL"
            },
            RON: {
                displayName: "ᎶᎹᏂᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᎶᎹᏂᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᎶᎹᏂᏯ ᎠᏕᎳ",
                symbol: "RON",
                "symbol-alt-narrow": "lei"
            },
            RSD: {
                displayName: "ᏒᏈᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᏒᏈᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᏒᏈᏯ ᎠᏕᎳ",
                symbol: "RSD"
            },
            RUB: {
                displayName: "ᏲᏂᎢ ᎠᏕᎳ",
                "displayName-count-one": "ᏲᏂᎢ ᎠᏕᎳ",
                "displayName-count-other": "ᏲᏂᎢ ᎠᏕᎳ",
                symbol: "RUB",
                "symbol-alt-narrow": "₽"
            },
            RUR: {
                displayName: "RUR",
                symbol: "RUR"
            },
            RWF: {
                displayName: "ᎶᏩᏂᏓ ᎠᏕᎳ",
                "displayName-count-one": "ᎶᏩᏂᏓ ᎠᏕᎳ",
                "displayName-count-other": "ᎶᏩᏂᏓ ᎠᏕᎳ",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "ᏌᎤᏗ ᎠᏕᎳ",
                "displayName-count-one": "ᏌᎤᏗ ᎠᏕᎳ",
                "displayName-count-other": "ᏌᎤᏗ ᎠᏕᎳ",
                symbol: "SAR"
            },
            SBD: {
                displayName: "ᏐᎶᎹᏂ ᏚᎦᏚᏛᎢ ᎠᏕᎳ",
                "displayName-count-one": "ᏐᎶᎹᏂ ᏚᎦᏚᏛᎢ ᎠᏕᎳ",
                "displayName-count-other": "ᏐᎶᎹᏂ ᏚᎦᏚᏛᎢ ᎠᏕᎳ",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "ᏏᎡᏥᎵᏍ ᎠᏕᎳ",
                "displayName-count-one": "ᏏᎡᏥᎵᏍ ᎠᏕᎳ",
                "displayName-count-other": "ᏏᎡᏥᎵᏍ ᎠᏕᎳ",
                symbol: "SCR"
            },
            SDD: {
                displayName: "SDD",
                symbol: "SDD"
            },
            SDG: {
                displayName: "ᏑᏕᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏑᏕᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏑᏕᏂ ᎠᏕᎳ",
                symbol: "SDG"
            },
            SDP: {
                displayName: "SDP",
                symbol: "SDP"
            },
            SEK: {
                displayName: "ᏍᏫᏕᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏍᏫᏕᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏍᏫᏕᏂ ᎠᏕᎳ",
                symbol: "SEK",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "ᏏᏂᎦᏉᎵ ᎠᏕᎳ",
                "displayName-count-one": "ᏏᏂᎦᏉᎵ ᎠᏕᎳ",
                "displayName-count-other": "ᏏᏂᎦᏉᎵ ᎠᏕᎳ",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "ᎤᏓᏅᏘ ᎮᎵᎾ ᎠᏕᎳ",
                "displayName-count-one": "ᎤᏓᏅᏘ ᎮᎵᎾ ᎠᏕᎳ",
                "displayName-count-other": "ᎤᏓᏅᏘ ᎮᎵᎾ ᎠᏕᎳ",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "SIT",
                symbol: "SIT"
            },
            SKK: {
                displayName: "SKK",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "ᏏᎡᎳᎴᎣᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏏᎡᎳᎴᎣᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏏᎡᎳᎴᎣᏂ ᎠᏕᎳ",
                symbol: "SLL"
            },
            SOS: {
                displayName: "ᏐᎹᎵ ᎠᏕᎳ",
                "displayName-count-one": "ᏐᎹᎵ ᎠᏕᎳ",
                "displayName-count-other": "ᏐᎹᎵ ᎠᏕᎳ",
                symbol: "SOS"
            },
            SRD: {
                displayName: "ᏒᎵᎾᎻ ᎠᏕᎳ",
                "displayName-count-one": "ᏒᎵᎾᎻ ᎠᏕᎳ",
                "displayName-count-other": "ᏒᎵᎾᎻ ᎠᏕᎳ",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "SRG",
                symbol: "SRG"
            },
            SSP: {
                displayName: "ᏧᎦᎾᏮ ᏑᏕᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏧᎦᎾᏮ ᏑᏕᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏧᎦᎾᏮ ᏑᏕᏂ ᎠᏕᎳ",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "ᏌᎣᏙᎺ ᎠᎴ ᏈᏂᏏᏇ ᎠᏕᎳ (1977–2017)",
                "displayName-count-one": "ᏌᎣᏙᎺ ᎠᎴ ᏈᏂᏏᏇ ᎠᏕᎳ (1977–2017)",
                "displayName-count-other": "ᏌᎣᏙᎺ ᎠᎴ ᏈᏂᏏᏇ ᎠᏕᎳ (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "ᏌᎣᏙᎺ & ᏈᏂᏏᏇ ᎠᏕᎳ",
                "displayName-count-one": "ᏌᎣᏙᎺ & ᏈᏂᏏᏇ ᎠᏕᎳ",
                "displayName-count-other": "ᏌᎣᏙᎺ & ᏈᏂᏏᏇ ᎠᏕᎳ",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "SUR",
                symbol: "SUR"
            },
            SVC: {
                displayName: "SVC",
                symbol: "SVC"
            },
            SYP: {
                displayName: "ᏏᎵᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᏏᎵᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᏏᎵᎠ ᎠᏕᎳ",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "ᏍᏩᏏ ᎠᏕᎳ",
                "displayName-count-one": "ᏍᏩᏏ ᎠᏕᎳ",
                "displayName-count-other": "ᏍᏩᏏ ᎠᏕᎳ",
                symbol: "SZL"
            },
            THB: {
                displayName: "ᏔᏯᎴᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏔᏯᎴᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏔᏯᎴᏂ ᎠᏕᎳ",
                symbol: "THB",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "TJR",
                symbol: "TJR"
            },
            TJS: {
                displayName: "ᏔᏥᎩᏍᏕᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏔᏥᎩᏍᏕᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏔᏥᎩᏍᏕᏂ ᎠᏕᎳ",
                symbol: "TJS"
            },
            TMM: {
                displayName: "TMM",
                symbol: "TMM"
            },
            TMT: {
                displayName: "ᏛᎵᎩᎺᏂᏍᏔᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏛᎵᎩᎺᏂᏍᏔᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏛᎵᎩᎺᏂᏍᏔᏂ ᎠᏕᎳ",
                symbol: "TMT"
            },
            TND: {
                displayName: "ᏚᏂᏏᏍᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᏚᏂᏏᏍᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᏚᏂᏏᏍᎠ ᎠᏕᎳ",
                symbol: "TND"
            },
            TOP: {
                displayName: "ᏔᏂᎪ ᎠᏕᎳ",
                "displayName-count-one": "ᏔᏂᎪ ᎠᏕᎳ",
                "displayName-count-other": "ᏔᏂᎪ ᎠᏕᎳ",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "TPE",
                symbol: "TPE"
            },
            TRL: {
                displayName: "TRL",
                symbol: "TRL"
            },
            TRY: {
                displayName: "ᎬᏃ ᎠᏕᎳ",
                "displayName-count-one": "ᎬᏃ ᎠᏕᎳ",
                "displayName-count-other": "ᎬᏃ ᎠᏕᎳ",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "ᏟᏂᏕᏗ & ᏙᏆᎪ ᎠᏕᎳ",
                "displayName-count-one": "ᏟᏂᏕᏗ & ᏙᏆᎪ ᎠᏕᎳ",
                "displayName-count-other": "ᏟᏂᏕᏗ & ᏙᏆᎪ ᎠᏕᎳ",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "ᎢᏤ ᏔᎢᏩᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᎢᏤ ᏔᎢᏩᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᎢᏤ ᏔᎢᏩᏂ ᎠᏕᎳ",
                symbol: "NT$",
                "symbol-alt-narrow": "$"
            },
            TZS: {
                displayName: "ᏖᏂᏏᏂᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᏖᏂᏏᏂᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᏖᏂᏏᏂᏯ ᎠᏕᎳ",
                symbol: "TZS"
            },
            UAH: {
                displayName: "ᏳᎧᎴᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏳᎧᎴᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏳᎧᎴᏂ ᎠᏕᎳ",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "UAK",
                symbol: "UAK"
            },
            UGS: {
                displayName: "UGS",
                symbol: "UGS"
            },
            UGX: {
                displayName: "ᏳᎦᏂᏓ ᎠᏕᎳ",
                "displayName-count-one": "ᏳᎦᏂᏓ ᎠᏕᎳ",
                "displayName-count-other": "ᏳᎦᏂᏓ ᎠᏕᎳ",
                symbol: "UGX"
            },
            USD: {
                displayName: "US ᎠᏕᎳ",
                "displayName-count-one": "US ᎠᏕᎳ",
                "displayName-count-other": "US ᎠᏕᎳ",
                symbol: "$",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "USN",
                symbol: "USN"
            },
            USS: {
                displayName: "USS",
                symbol: "USS"
            },
            UYI: {
                displayName: "UYI",
                symbol: "UYI"
            },
            UYP: {
                displayName: "UYP",
                symbol: "UYP"
            },
            UYU: {
                displayName: "ᏳᎷᏇ ᎠᏕᎳ",
                "displayName-count-one": "ᏳᎷᏇ ᎠᏕᎳ",
                "displayName-count-other": "ᏳᎷᏇ ᎠᏕᎳ",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "UYW",
                symbol: "UYW"
            },
            UZS: {
                displayName: "ᎤᏍᏇᎩᏍᏖᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᎤᏍᏇᎩᏍᏖᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᎤᏍᏇᎩᏍᏖᏂ ᎠᏕᎳ",
                symbol: "UZS"
            },
            VEB: {
                displayName: "VEB",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "ᏪᏁᏑᏪ ᎠᏕᎳ (2008–2018)",
                "displayName-count-one": "ᏪᏁᏑᏪᎳ ᎠᏕᎳ",
                "displayName-count-other": "ᏪᏁᏑᏪᎳ ᎠᏕᎳ",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs"
            },
            VES: {
                displayName: "ᏪᏁᏑᏪ ᎠᏕᎳ",
                "displayName-count-one": "ᏪᏁᏑᏪ ᎠᏕᎳ",
                "displayName-count-other": "ᏪᏁᏑᏪ ᎠᏕᎳ",
                symbol: "VES"
            },
            VND: {
                displayName: "ᏫᎡᏘᎾᎻᏍ ᎠᏕᎳ",
                "displayName-count-one": "ᏫᎡᏘᎾᎻᏍ ᎠᏕᎳ",
                "displayName-count-other": "ᏫᎡᏘᎾᎻᏍ ᎠᏕᎳ",
                symbol: "₫",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "VNN",
                symbol: "VNN"
            },
            VUV: {
                displayName: "ᏩᏂᎤᏩᏚ ᎠᏕᎳ",
                "displayName-count-one": "ᏩᏂᎤᏩᏚ ᎠᏕᎳ",
                "displayName-count-other": "ᏩᏂᎤᏩᏚ ᎠᏕᎳ",
                symbol: "VUV"
            },
            WST: {
                displayName: "ᏌᎼᎠ ᎠᏕᎳ",
                "displayName-count-one": "ᏌᎼᎠ ᎠᏕᎳ",
                "displayName-count-other": "ᏌᎼᎠ ᎠᏕᎳ",
                symbol: "WST"
            },
            XAF: {
                displayName: "ᎠᏰᏟ ᎬᎿᎨᏍᏛ CFA ᎠᏕᎳ",
                "displayName-count-one": "ᎠᏰᏟ ᎬᎿᎨᏍᏛ CFA ᎠᏕᎳ",
                "displayName-count-other": "ᎠᏰᏟ ᎬᎿᎨᏍᏛ CFA ᎠᏕᎳ",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "XAG",
                symbol: "XAG"
            },
            XAU: {
                displayName: "XAU",
                symbol: "XAU"
            },
            XBA: {
                displayName: "XBA",
                symbol: "XBA"
            },
            XBB: {
                displayName: "XBB",
                symbol: "XBB"
            },
            XBC: {
                displayName: "XBC",
                symbol: "XBC"
            },
            XBD: {
                displayName: "XBD",
                symbol: "XBD"
            },
            XCD: {
                displayName: "ᏗᎧᎸᎬ ᎨᏆᏙᏯ ᎠᏕᎳ",
                "displayName-count-one": "ᏗᎧᎸᎬ ᎨᏆᏙᏯ ᎠᏕᎳ",
                "displayName-count-other": "ᏗᎧᎸᎬ ᎨᏆᏙᏯ ᎠᏕᎳ",
                symbol: "EC$",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "XDR",
                symbol: "XDR"
            },
            XEU: {
                displayName: "XEU",
                symbol: "XEU"
            },
            XFO: {
                displayName: "XFO",
                symbol: "XFO"
            },
            XFU: {
                displayName: "XFU",
                symbol: "XFU"
            },
            XOF: {
                displayName: "ᏭᏕᎵᎬ ᎬᎿᎨᏍᏛ CFA ᎠᏕᎳ",
                "displayName-count-one": "ᏭᏕᎵᎬ ᎬᎿᎨᏍᏛ CFA ᎠᏕᎳ",
                "displayName-count-other": "ᏭᏕᎵᎬ ᎬᎿᎨᏍᏛ CFA ᎠᏕᎳ",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "XPD",
                symbol: "XPD"
            },
            XPF: {
                displayName: "CFP ᎠᏕᎳ",
                "displayName-count-one": "CFP ᎠᏕᎳ",
                "displayName-count-other": "CFP ᎠᏕᎳ",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "XPT",
                symbol: "XPT"
            },
            XRE: {
                displayName: "XRE",
                symbol: "XRE"
            },
            XSU: {
                displayName: "XSU",
                symbol: "XSU"
            },
            XTS: {
                displayName: "XTS",
                symbol: "XTS"
            },
            XUA: {
                displayName: "XUA",
                symbol: "XUA"
            },
            XXX: {
                displayName: "ᏄᏬᎵᏍᏛᎾ ᎠᏕᎳ",
                "displayName-count-one": "(ᏄᏬᎵᏍᏛᎾ ᎠᏕᎳ)",
                "displayName-count-other": "(ᏄᏬᎵᏍᏛᎾ ᎠᏕᎳ)",
                symbol: "¤"
            },
            YDD: {
                displayName: "YDD",
                symbol: "YDD"
            },
            YER: {
                displayName: "ᏰᎺᏂ ᎠᏕᎳ",
                "displayName-count-one": "ᏰᎺᏂ ᎠᏕᎳ",
                "displayName-count-other": "ᏰᎺᏂ ᎠᏕᎳ",
                symbol: "YER"
            },
            YUD: {
                displayName: "YUD",
                symbol: "YUD"
            },
            YUM: {
                displayName: "YUM",
                symbol: "YUM"
            },
            YUN: {
                displayName: "YUN",
                symbol: "YUN"
            },
            YUR: {
                displayName: "YUR",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "ZAL",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "ᏧᎦᎾᏮ ᎬᎿᎨᏍᏛ ᎠᏕᎳ",
                "displayName-count-one": "ᏧᎦᎾᏮ ᎬᎿᎨᏍᏛ ᎠᏕᎳ",
                "displayName-count-other": "ᏧᎦᎾᏮ ᎬᎿᎨᏍᏛ ᎠᏕᎳ",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "ZMK",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "ᏏᎻᏆᏇ ᎠᏕᎳ",
                "displayName-count-one": "ᏏᎻᏆᏇ ᎠᏕᎳ",
                "displayName-count-other": "ᏏᎻᏆᏇ ᎠᏕᎳ",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "ZRN",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "ZRZ",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "ZWD",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "ZWL",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "ZWR",
                symbol: "ZWR"
            }
        },
        localeCurrency: "USD"
    },
    calendar: {
        patterns: {
            d: "M/d/y",
            D: "EEEE, MMMM d, y",
            m: "MMM d",
            M: "MMMM d",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, MMMM d, y h:mm:ss a",
            g: "M/d/y h:mm a",
            G: "M/d/y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} ᎤᎾᎢ {0}",
            long: "{1} ᎤᎾᎢ {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "M/d/y GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "MMM d, y G",
                GyMMMEd: "E, MMM d, y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "M/d",
                MEd: "E, M/d",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, MMM d",
                MMMMd: "MMMM d",
                "MMMMW-count-one": "’ᏒᎾᏙᏓᏆᏍᏗ’ W ’ᎾᎿ’ MMMM",
                "MMMMW-count-other": "’ᏒᎾᏙᏓᏆᏍᏗ’ W ’ᎾᎿ’ MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "M/d/y",
                yMEd: "E, M/d/y",
                yMMM: "MMM y",
                yMMMd: "MMM d, y",
                yMMMEd: "E, MMM d, y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "’ᏒᎾᏙᏓᏆᏍᏗ’ w ’ᎾᎿ’ Y",
                "yw-count-other": "’ᏒᎾᏙᏓᏆᏍᏗ’ w ’ᎾᎿ’ Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "EEEE, MMMM d, y",
            long: "MMMM d, y",
            medium: "MMM d, y",
            short: "M/d/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "ᏆᏍᎬ",
                    "ᏉᏅᎯ",
                    "ᏔᎵᏁ",
                    "ᏦᎢᏁ",
                    "ᏅᎩᏁ",
                    "ᏧᎾᎩ",
                    "ᏈᏕᎾ"
                ],
                narrow: [
                    "Ꮖ",
                    "Ꮙ",
                    "Ꮤ",
                    "Ꮶ",
                    "Ꮕ",
                    "Ꮷ",
                    "Ꭴ"
                ],
                short: [
                    "ᏍᎬ",
                    "ᏅᎯ",
                    "ᏔᎵ",
                    "ᏦᎢ",
                    "ᏅᎩ",
                    "ᏧᎾ",
                    "ᏕᎾ"
                ],
                wide: [
                    "ᎤᎾᏙᏓᏆᏍᎬ",
                    "ᎤᎾᏙᏓᏉᏅᎯ",
                    "ᏔᎵᏁᎢᎦ",
                    "ᏦᎢᏁᎢᎦ",
                    "ᏅᎩᏁᎢᎦ",
                    "ᏧᎾᎩᎶᏍᏗ",
                    "ᎤᎾᏙᏓᏈᏕᎾ"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ᏆᏍᎬ",
                    "ᏉᏅᎯ",
                    "ᏔᎵᏁ",
                    "ᏦᎢᏁ",
                    "ᏅᎩᏁ",
                    "ᏧᎾᎩ",
                    "ᏈᏕᎾ"
                ],
                narrow: [
                    "Ꮖ",
                    "Ꮙ",
                    "Ꮤ",
                    "Ꮶ",
                    "Ꮕ",
                    "Ꮷ",
                    "Ꭴ"
                ],
                short: [
                    "ᏍᎬ",
                    "ᏅᎯ",
                    "ᏔᎵ",
                    "ᏦᎢ",
                    "ᏅᎩ",
                    "ᏧᎾ",
                    "ᏕᎾ"
                ],
                wide: [
                    "ᎤᎾᏙᏓᏆᏍᎬ",
                    "ᎤᎾᏙᏓᏉᏅᎯ",
                    "ᏔᎵᏁᎢᎦ",
                    "ᏦᎢᏁᎢᎦ",
                    "ᏅᎩᏁᎢᎦ",
                    "ᏧᎾᎩᎶᏍᏗ",
                    "ᎤᎾᏙᏓᏈᏕᎾ"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "ᎤᏃ",
                    "ᎧᎦ",
                    "ᎠᏅ",
                    "ᎧᏬ",
                    "ᎠᏂ",
                    "ᏕᎭ",
                    "ᎫᏰ",
                    "ᎦᎶ",
                    "ᏚᎵ",
                    "ᏚᏂ",
                    "ᏅᏓ",
                    "ᎥᏍ"
                ],
                narrow: [
                    "Ꭴ",
                    "Ꭷ",
                    "Ꭰ",
                    "Ꭷ",
                    "Ꭰ",
                    "Ꮥ",
                    "Ꭻ",
                    "Ꭶ",
                    "Ꮪ",
                    "Ꮪ",
                    "Ꮕ",
                    "Ꭵ"
                ],
                wide: [
                    "ᎤᏃᎸᏔᏅ",
                    "ᎧᎦᎵ",
                    "ᎠᏅᏱ",
                    "ᎧᏬᏂ",
                    "ᎠᏂᏍᎬᏘ",
                    "ᏕᎭᎷᏱ",
                    "ᎫᏰᏉᏂ",
                    "ᎦᎶᏂ",
                    "ᏚᎵᏍᏗ",
                    "ᏚᏂᏅᏗ",
                    "ᏅᏓᏕᏆ",
                    "ᎥᏍᎩᏱ"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ᎤᏃ",
                    "ᎧᎦ",
                    "ᎠᏅ",
                    "ᎧᏬ",
                    "ᎠᏂ",
                    "ᏕᎭ",
                    "ᎫᏰ",
                    "ᎦᎶ",
                    "ᏚᎵ",
                    "ᏚᏂ",
                    "ᏅᏓ",
                    "ᎥᏍ"
                ],
                narrow: [
                    "Ꭴ",
                    "Ꭷ",
                    "Ꭰ",
                    "Ꭷ",
                    "Ꭰ",
                    "Ꮥ",
                    "Ꭻ",
                    "Ꭶ",
                    "Ꮪ",
                    "Ꮪ",
                    "Ꮕ",
                    "Ꭵ"
                ],
                wide: [
                    "ᎤᏃᎸᏔᏅ",
                    "ᎧᎦᎵ",
                    "ᎠᏅᏱ",
                    "ᎧᏬᏂ",
                    "ᎠᏂᏍᎬᏘ",
                    "ᏕᎭᎷᏱ",
                    "ᎫᏰᏉᏂ",
                    "ᎦᎶᏂ",
                    "ᏚᎵᏍᏗ",
                    "ᏚᏂᏅᏗ",
                    "ᏅᏓᏕᏆ",
                    "ᎥᏍᎩᏱ"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1st ᎩᏄᏙᏗ",
                    "2nd ᎩᏄᏙᏗ",
                    "3rd ᎩᏄᏙᏗ",
                    "4th ᎩᏄᏙᏗ"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1st ᎩᏄᏙᏗ",
                    "2nd ᎩᏄᏙᏗ",
                    "3rd ᎩᏄᏙᏗ",
                    "4th ᎩᏄᏙᏗ"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "ᏌᎾᎴ",
                    noon: "ᎢᎦ",
                    pm: "ᏒᎯᏱᎢ",
                    morning1: "ᏌᎾᎴ",
                    afternoon1: "ᏒᎯᏱᎢᏗᏢ"
                },
                narrow: {
                    am: "Ꮜ",
                    noon: "Ꭲ",
                    pm: "Ꮢ",
                    morning1: "ᏌᎾᎴ",
                    afternoon1: "ᏒᎯᏱᎢᏗᏢ"
                },
                wide: {
                    am: "ᏌᎾᎴ",
                    noon: "ᎢᎦ",
                    pm: "ᏒᎯᏱᎢᏗᏢ",
                    morning1: "ᏌᎾᎴ",
                    afternoon1: "ᏒᎯᏱᎢᏗᏢ"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "ᏌᎾᎴ",
                    noon: "ᎢᎦ",
                    pm: "ᏒᎯᏱᎢ",
                    morning1: "ᏌᎾᎴ",
                    afternoon1: "ᏒᎯᏱᎢᏗᏢ"
                },
                narrow: {
                    am: "ᏌᎾᎴ",
                    noon: "ᎢᎦ",
                    pm: "ᏒᎯᏱᎢ",
                    morning1: "ᏌᎾᎴ",
                    afternoon1: "ᏒᎯᏱᎢᏗᏢ"
                },
                wide: {
                    am: "ᏌᎾᎴ",
                    noon: "ᎢᎦ",
                    pm: "ᏒᎯᏱᎢᏗᏢ",
                    morning1: "ᏌᎾᎴ",
                    afternoon1: "ᏒᎯᏱᎢᏗᏢ"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "ᏧᏓᎷᎸ ᎤᎷᎯᏍᏗ ᎦᎶᏁᏛ",
                    "1": "ᎠᏃ ᏙᎻᏂ",
                    "0-alt-variant": "ᏧᏓᎷᎸ ᏯᏃᏉ ᏱᎬᏍᏛᏭ ᎠᏓᎴᏂᏍᎬ",
                    "1-alt-variant": "ᏯᏃᏉ ᏱᎬᏍᏛᏭ ᎠᏓᎴᏂᏍᎬ"
                },
                abbreviated: {
                    "0": "BC",
                    "1": "AD",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                narrow: {
                    "0": "BC",
                    "1": "AD",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "ᏗᏓᎴᏂᏍᎬ",
                short: "ᏗᏓᎴᏂᏍᎬ",
                narrow: "ᏗᏓᎴᏂᏍᎬ"
            },
            year: {
                wide: "ᎤᏕᏘᏴᏌᏗᏒᎢ",
                short: "ᎤᏕ.",
                narrow: "ᎤᏕ."
            },
            quarter: {
                wide: "ᎩᏄᏙᏗ",
                short: "ᎩᏄᏘ.",
                narrow: "ᎩᏄᏘ."
            },
            month: {
                wide: "ᎧᎸᎢ",
                short: "ᎧᎸ.",
                narrow: "ᎧᎸ."
            },
            week: {
                wide: "ᏒᎾᏙᏓᏆᏍᏗ",
                short: "ᏒᎾ.",
                narrow: "ᏒᎾ."
            },
            weekOfMonth: {
                wide: "ᏒᎾᏙᏓᏆᏍᏗ ᎧᎸᎢ",
                short: "ᎡᎾ. ᎧᎸ.",
                narrow: "ᎡᎾ. ᎧᎸ."
            },
            day: {
                wide: "ᎢᎦ",
                short: "ᎢᎦ",
                narrow: "ᎢᎦ"
            },
            dayOfYear: {
                wide: "ᎢᎦ ᎤᏕᏘᏴᏌᏗᏒᎢ",
                short: "ᎢᎦ ᎤᏕ.",
                narrow: "ᎢᎦ ᎤᏕ."
            },
            weekday: {
                wide: "ᎢᎦ ᏕᎨᏌᏗᏒ",
                short: "ᎢᎦ ᏕᎨ.",
                narrow: "ᎢᎦ ᏕᎨ."
            },
            weekdayOfMonth: {
                wide: "ᏒᎾᏙᏓᏆᏍᏗ ᎢᎦ ᎧᎸᎢ",
                short: "ᏒᎾ. ᎢᎦ ᎧᎸ.",
                narrow: "ᏒᎾ. ᎢᎦ ᎧᎸ."
            },
            dayperiod: {
                short: "ᏌᎾᎴ/ᏒᎯᏱ",
                wide: "ᏌᎾᎴ/ᏒᎯᏱ",
                narrow: "ᏌᎾᎴ/ᏒᎯᏱ"
            },
            hour: {
                wide: "ᏑᏟᎶᏓ",
                short: "ᏑᏟ.",
                narrow: "ᏑᏟ."
            },
            minute: {
                wide: "ᎢᏯᏔᏬᏍᏔᏅ",
                short: "ᎢᏯᏔ.",
                narrow: "ᎢᏯᏔ."
            },
            second: {
                wide: "ᎠᏎᏢ",
                short: "ᎠᏎ.",
                narrow: "ᎠᏎ."
            },
            zone: {
                wide: "ᏂᎬᎾᏛ ᏧᏓᎴᏅᏓ ᏓᏟᎢᎵᏍᏒᎢ",
                short: "ᏂᎬᎾᏛ ᏧᏓᎴᏅᏓ",
                narrow: "ᏂᎬᎾᏛ ᏧᏓᎴᏅᏓ"
            },
            millisecond: {
                narrow: "ᏌᎠ",
                short: "ᏌᎠ",
                wide: "ᏌᏉ ᎢᏯᎦᎨᎵᏁᎢ ᎠᏎᏢ"
            }
        }
    },
    firstDay: 0,
    weekendRange: {
        start: 6,
        end: 0
    },
    likelySubtags: {
        chr: "chr-Cher-US"
    }
});

