/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ckb",
    likelySubtags: {
        ckb: "ckb-Arab-IQ"
    },
    identity: {
        language: "ckb"
    },
    territory: "IQ",
    calendar: {
        patterns: {
            d: "y-MM-dd",
            D: "y MMMM d, EEEE",
            m: "dی MMM",
            M: "MMMM d",
            y: "MMMی y",
            Y: "y MMMM",
            F: "y MMMM d, EEEE h:mm:ss a",
            g: "d/M/y h:mm a",
            G: "d/M/y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E dھەم",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "hی a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "MM-dd",
                MEd: "E، M/d",
                MMM: "LLL",
                MMMd: "dی MMM",
                MMMEd: "E، dی MMM",
                MMMMd: "MMMM d",
                "MMMMW-count-one": "هەفتەی W ی MMMM",
                "MMMMW-count-other": "هەفتەی W ی MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E، d/M/y",
                yMMM: "MMMی y",
                yMMMd: "dی MMMی y",
                yMMMEd: "E، dی MMMی y",
                yMMMM: "y MMMM",
                yQQQ: "y QQQ",
                yQQQQ: "y QQQQ",
                "yw-count-one": "هەفتەی w ی Y",
                "yw-count-other": "هەفتەی w ی Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "y MMMM d, EEEE",
            long: "dی MMMMی y",
            medium: "y MMM d",
            short: "y-MM-dd"
        },
        days: {
            format: {
                abbreviated: [
                    "یەکشەممە",
                    "دووشەممە",
                    "سێشەممە",
                    "چوارشەممە",
                    "پێنجشەممە",
                    "ھەینی",
                    "شەممە"
                ],
                narrow: [
                    "ی",
                    "د",
                    "س",
                    "چ",
                    "پ",
                    "ھ",
                    "ش"
                ],
                short: [
                    "١ش",
                    "٢ش",
                    "٣ش",
                    "٤ش",
                    "٥ش",
                    "ھ",
                    "ش"
                ],
                wide: [
                    "یەکشەممە",
                    "دووشەممە",
                    "سێشەممە",
                    "چوارشەممە",
                    "پێنجشەممە",
                    "ھەینی",
                    "شەممە"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "یەکشەممە",
                    "دووشەممە",
                    "سێشەممە",
                    "چوارشەممە",
                    "پێنجشەممە",
                    "ھەینی",
                    "شەممە"
                ],
                narrow: [
                    "ی",
                    "د",
                    "س",
                    "چ",
                    "پ",
                    "ھ",
                    "ش"
                ],
                short: [
                    "١ش",
                    "٢ش",
                    "٣ش",
                    "٤ش",
                    "٥ش",
                    "ھ",
                    "ش"
                ],
                wide: [
                    "یەکشەممە",
                    "دووشەممە",
                    "سێشەممە",
                    "چوارشەممە",
                    "پێنجشەممە",
                    "ھەینی",
                    "شەممە"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "کانوونی دووەم",
                    "شوبات",
                    "ئازار",
                    "نیسان",
                    "ئایار",
                    "حوزەیران",
                    "تەمووز",
                    "ئاب",
                    "ئەیلوول",
                    "تشرینی یەکەم",
                    "تشرینی دووەم",
                    "کانونی یەکەم"
                ],
                narrow: [
                    "ک",
                    "ش",
                    "ئ",
                    "ن",
                    "ئ",
                    "ح",
                    "ت",
                    "ئ",
                    "ئ",
                    "ت",
                    "ت",
                    "ک"
                ],
                wide: [
                    "کانوونی دووەم",
                    "شوبات",
                    "ئازار",
                    "نیسان",
                    "ئایار",
                    "حوزەیران",
                    "تەمووز",
                    "ئاب",
                    "ئەیلوول",
                    "تشرینی یەکەم",
                    "تشرینی دووەم",
                    "کانونی یەکەم"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "کانوونی دووەم",
                    "شوبات",
                    "ئازار",
                    "نیسان",
                    "ئایار",
                    "حوزەیران",
                    "تەمووز",
                    "ئاب",
                    "ئەیلوول",
                    "تشرینی یەکەم",
                    "تشرینی دووەم",
                    "کانونی یەکەم"
                ],
                narrow: [
                    "ک",
                    "ش",
                    "ئ",
                    "ن",
                    "ئ",
                    "ح",
                    "ت",
                    "ئ",
                    "ئ",
                    "ت",
                    "ت",
                    "ک"
                ],
                wide: [
                    "کانوونی دووەم",
                    "شوبات",
                    "ئازار",
                    "نیسان",
                    "ئایار",
                    "حوزەیران",
                    "تەمووز",
                    "ئاب",
                    "ئەیلوول",
                    "تشرینی یەکەم",
                    "تشرینی دووەم",
                    "کانونی یەکەم"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "چ١",
                    "چ٢",
                    "چ٣",
                    "چ٤"
                ],
                narrow: [
                    "١",
                    "٢",
                    "٣",
                    "٤"
                ],
                wide: [
                    "چارەکی یەکەم",
                    "چارەکی دووەم",
                    "چارەکی سێەم",
                    "چارەکی چوارەم"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "چ١",
                    "چ٢",
                    "چ٣",
                    "چ٤"
                ],
                narrow: [
                    "١",
                    "٢",
                    "٣",
                    "٤"
                ],
                wide: [
                    "چارەکی یەکەم",
                    "چارەکی دووەم",
                    "چارەکی سێەم",
                    "چارەکی چوارەم"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "ب.ن",
                    pm: "د.ن"
                },
                narrow: {
                    am: "ب.ن",
                    pm: "د.ن"
                },
                wide: {
                    am: "ب.ن",
                    pm: "د.ن"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "ب.ن",
                    pm: "د.ن"
                },
                narrow: {
                    am: "ب.ن",
                    pm: "د.ن"
                },
                wide: {
                    am: "ب.ن",
                    pm: "د.ن"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "پێش زایین",
                    "1": "زایینی",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                abbreviated: {
                    "0": "پێش زایین",
                    "1": "زایینی",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                narrow: {
                    "0": "پێش زایین",
                    "1": "زایینی",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Era",
                short: "Era",
                narrow: "Era"
            },
            year: {
                wide: "Year",
                short: "Year",
                narrow: "Year"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Month",
                short: "Month",
                narrow: "Month"
            },
            week: {
                wide: "Week",
                short: "Week",
                narrow: "Week"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Day",
                short: "Day",
                narrow: "Day"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Day of the Week",
                short: "Day of the Week",
                narrow: "Day of the Week"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Dayperiod",
                wide: "Dayperiod",
                narrow: "Dayperiod"
            },
            hour: {
                wide: "Hour",
                short: "Hour",
                narrow: "Hour"
            },
            minute: {
                wide: "Minute",
                short: "Minute",
                narrow: "Minute"
            },
            second: {
                wide: "Second",
                short: "Second",
                narrow: "Second"
            },
            zone: {
                wide: "Zone",
                short: "Zone",
                narrow: "Zone"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 6
});

