/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "doi",
    likelySubtags: {
        doi: "doi-Deva-IN"
    },
    identity: {
        language: "doi"
    },
    territory: "IN",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE, d, MMMM y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d, MMMM y h:mm:ss a",
            g: "d/M/y h:mm a",
            G: "d/M/y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} गी {0}",
            long: "{1} गी {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "d, MMM G y",
                GyMMMEd: "E, d, MMM G y",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E, d/M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E, d MMM",
                MMMMd: "d MMMM",
                "MMMMW-count-one": "MMMM दा हफ्ता W",
                "MMMMW-count-other": "MMMM दा हफ्ता W",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E, d/M/y",
                yMMM: "MMM y",
                yMMMd: "d, MMM y",
                yMMMEd: "E, d, MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "Y दा हफ्ता w",
                "yw-count-other": "Y दा हफ्ता w"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "EEEE, d, MMMM y",
            long: "d, MMMM y",
            medium: "d, MMM y",
            short: "d/M/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "ऐत",
                    "सोम",
                    "मंगल",
                    "बुध",
                    "बीर",
                    "शुक्र",
                    "शनि"
                ],
                narrow: [
                    "ऐ.",
                    "सो.",
                    "म.",
                    "बु.",
                    "बी.",
                    "शु.",
                    "श."
                ],
                short: [
                    "ऐत",
                    "सोम",
                    "मंगल",
                    "बुध",
                    "बीर",
                    "शुक्र",
                    "शनि"
                ],
                wide: [
                    "ऐतबार",
                    "सोमबार",
                    "मंगलबार",
                    "बुधबार",
                    "बीरबार",
                    "शुक्रबार",
                    "शनीबार"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ऐत",
                    "सोम",
                    "मंगल",
                    "बुध",
                    "बीर",
                    "शुक्र",
                    "शनि"
                ],
                narrow: [
                    "ऐ",
                    "सो",
                    "म.",
                    "बु.",
                    "बी.",
                    "शु.",
                    "श."
                ],
                short: [
                    "ऐत",
                    "सोम",
                    "मंगल",
                    "बुध",
                    "बीर",
                    "शुक्र",
                    "शनि"
                ],
                wide: [
                    "ऐतबार",
                    "सोमबार",
                    "मंगलबार",
                    "बुधबार",
                    "बीरबार",
                    "शुक्रबार",
                    "शनिबार"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "जन.",
                    "फर.",
                    "मार्च",
                    "अप्रैल",
                    "मेई",
                    "जून",
                    "जुलाई",
                    "अग.",
                    "सित.",
                    "अक्तू.",
                    "नव.",
                    "दिस."
                ],
                narrow: [
                    "ज",
                    "फ",
                    "मा",
                    "अ",
                    "मे",
                    "जू",
                    "जु",
                    "अ",
                    "सि",
                    "अ",
                    "न",
                    "दि"
                ],
                wide: [
                    "जनवरी",
                    "फरवरी",
                    "मार्च",
                    "अप्रैल",
                    "मेई",
                    "जून",
                    "जुलाई",
                    "अगस्त",
                    "सितंबर",
                    "अत्तूबर",
                    "नवंबर",
                    "दिसंबर"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "जन.",
                    "फर.",
                    "मार्च",
                    "अप्रैल",
                    "मेई",
                    "जून",
                    "जुलाई",
                    "अग.",
                    "सित.",
                    "अक्तू.",
                    "नव.",
                    "दिस."
                ],
                narrow: [
                    "ज",
                    "फ",
                    "मा",
                    "अ",
                    "मे",
                    "जू",
                    "जु",
                    "अ",
                    "सि",
                    "अ",
                    "न",
                    "दि"
                ],
                wide: [
                    "जनवरी",
                    "फरवरी",
                    "मार्च",
                    "अप्रैल",
                    "मेई",
                    "जून",
                    "जुलाई",
                    "अगस्त",
                    "सितंबर",
                    "अक्तूबर",
                    "नवंबर",
                    "दिसंबर"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "त्र.1",
                    "त्र.2",
                    "त्र.3",
                    "त्र.4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "पैहली त्रमाही",
                    "दूई त्रमाही",
                    "त्री त्रमाही",
                    "चौथी त्रमाही"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "त्र.1",
                    "त्र.2",
                    "त्र.3",
                    "त्र.4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "पैहली त्रमाही",
                    "दूई त्रमाही",
                    "त्री त्रमाही",
                    "चौथी त्रमाही"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "सवेर",
                    pm: "स’ञ"
                },
                narrow: {
                    am: "सवेर",
                    pm: "स’ञ"
                },
                wide: {
                    am: "सवेर",
                    pm: "बाद दपैहर"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "सवेर",
                    pm: "स’ञ"
                },
                narrow: {
                    am: "सवेर",
                    pm: "स’ञ"
                },
                wide: {
                    am: "सवेर",
                    pm: "स’ञ"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "ई.पू.",
                    "1": "ई. सन्",
                    "0-alt-variant": "ई.पू.",
                    "1-alt-variant": "सन्"
                },
                abbreviated: {
                    "0": "ई.पू.",
                    "1": "ईसवी",
                    "0-alt-variant": "ई.पू.",
                    "1-alt-variant": "सन्"
                },
                narrow: {
                    "0": "ई.पू.",
                    "1": "ईसवी",
                    "0-alt-variant": "ई.पू.",
                    "1-alt-variant": "सन्"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "जुग",
                short: "जुग",
                narrow: "जुग"
            },
            year: {
                wide: "ब’रा",
                short: "ब.",
                narrow: "ब."
            },
            quarter: {
                wide: "त्रमाही",
                short: "त्रमा.",
                narrow: "त्रमा."
            },
            month: {
                wide: "म्हीना",
                short: "म्ही.",
                narrow: "म्ही."
            },
            week: {
                wide: "हफ्ता",
                short: "ह.",
                narrow: "ह."
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "दिन",
                short: "दिन",
                narrow: "दिन"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "हफ्ते दा दिन",
                short: "हफ्ते दा दिन",
                narrow: "हफ्ते दा दिन"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "सवेर/बा.दपै.",
                wide: "सवेर/बा.दपै.",
                narrow: "सवेर/बा.दपै."
            },
            hour: {
                wide: "घैंटा",
                short: "घैं.",
                narrow: "घैं."
            },
            minute: {
                wide: "मिंट्‌ट",
                short: "मिं.",
                narrow: "मिं."
            },
            second: {
                wide: "सकैंट",
                short: "सकैं.",
                narrow: "सकैं."
            },
            zone: {
                wide: "समां खेत्तर",
                short: "समां खेत्तर",
                narrow: "समां खेत्तर"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

