/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ebu",
    likelySubtags: {
        ebu: "ebu-Latn-KE"
    },
    identity: {
        language: "ebu"
    },
    territory: "KE",
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, d MMMM y",
            m: "MMM d",
            M: "MMMM d",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d MMMM y HH:mm:ss",
            g: "d/M/y HH:mm",
            G: "d/M/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "M/d",
                MEd: "E, M/d",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, MMM d",
                MMMMd: "MMMM d",
                MMMMEd: "E, MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E, M/d/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E, MMM d, y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "dd/MM/y"
        },
        days: {
            format: {
                abbreviated: [
                    "Kma",
                    "Tat",
                    "Ine",
                    "Tan",
                    "Arm",
                    "Maa",
                    "NMM"
                ],
                narrow: [
                    "K",
                    "N",
                    "N",
                    "N",
                    "A",
                    "M",
                    "N"
                ],
                short: [
                    "Kma",
                    "Tat",
                    "Ine",
                    "Tan",
                    "Arm",
                    "Maa",
                    "NMM"
                ],
                wide: [
                    "Kiumia",
                    "Njumatatu",
                    "Njumaine",
                    "Njumatano",
                    "Aramithi",
                    "Njumaa",
                    "NJumamothii"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Kma",
                    "Tat",
                    "Ine",
                    "Tan",
                    "Arm",
                    "Maa",
                    "NMM"
                ],
                narrow: [
                    "K",
                    "N",
                    "N",
                    "N",
                    "A",
                    "M",
                    "N"
                ],
                short: [
                    "Kma",
                    "Tat",
                    "Ine",
                    "Tan",
                    "Arm",
                    "Maa",
                    "NMM"
                ],
                wide: [
                    "Kiumia",
                    "Njumatatu",
                    "Njumaine",
                    "Njumatano",
                    "Aramithi",
                    "Njumaa",
                    "NJumamothii"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Mbe",
                    "Kai",
                    "Kat",
                    "Kan",
                    "Gat",
                    "Gan",
                    "Mug",
                    "Knn",
                    "Ken",
                    "Iku",
                    "Imw",
                    "Igi"
                ],
                narrow: [
                    "M",
                    "K",
                    "K",
                    "K",
                    "G",
                    "G",
                    "M",
                    "K",
                    "K",
                    "I",
                    "I",
                    "I"
                ],
                wide: [
                    "Mweri wa mbere",
                    "Mweri wa kaĩri",
                    "Mweri wa kathatũ",
                    "Mweri wa kana",
                    "Mweri wa gatano",
                    "Mweri wa gatantatũ",
                    "Mweri wa mũgwanja",
                    "Mweri wa kanana",
                    "Mweri wa kenda",
                    "Mweri wa ikũmi",
                    "Mweri wa ikũmi na ũmwe",
                    "Mweri wa ikũmi na Kaĩrĩ"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Mbe",
                    "Kai",
                    "Kat",
                    "Kan",
                    "Gat",
                    "Gan",
                    "Mug",
                    "Knn",
                    "Ken",
                    "Iku",
                    "Imw",
                    "Igi"
                ],
                narrow: [
                    "M",
                    "K",
                    "K",
                    "K",
                    "G",
                    "G",
                    "M",
                    "K",
                    "K",
                    "I",
                    "I",
                    "I"
                ],
                wide: [
                    "Mweri wa mbere",
                    "Mweri wa kaĩri",
                    "Mweri wa kathatũ",
                    "Mweri wa kana",
                    "Mweri wa gatano",
                    "Mweri wa gatantatũ",
                    "Mweri wa mũgwanja",
                    "Mweri wa kanana",
                    "Mweri wa kenda",
                    "Mweri wa ikũmi",
                    "Mweri wa ikũmi na ũmwe",
                    "Mweri wa ikũmi na Kaĩrĩ"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Kuota ya mbere",
                    "Kuota ya Kaĩrĩ",
                    "Kuota ya kathatu",
                    "Kuota ya kana"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Kuota ya mbere",
                    "Kuota ya Kaĩrĩ",
                    "Kuota ya kathatu",
                    "Kuota ya kana"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "KI",
                    pm: "UT"
                },
                narrow: {
                    am: "KI",
                    pm: "UT"
                },
                wide: {
                    am: "KI",
                    pm: "UT"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "KI",
                    pm: "UT"
                },
                narrow: {
                    am: "KI",
                    pm: "UT"
                },
                wide: {
                    am: "KI",
                    pm: "UT"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Mbere ya Kristo",
                    "1": "Thutha wa Kristo",
                    "0-alt-variant": "MK",
                    "1-alt-variant": "TK"
                },
                abbreviated: {
                    "0": "MK",
                    "1": "TK",
                    "0-alt-variant": "MK",
                    "1-alt-variant": "TK"
                },
                narrow: {
                    "0": "MK",
                    "1": "TK",
                    "0-alt-variant": "MK",
                    "1-alt-variant": "TK"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Ivinda",
                short: "Ivinda",
                narrow: "Ivinda"
            },
            year: {
                wide: "Mwaka",
                short: "Mwaka",
                narrow: "Mwaka"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Mweri",
                short: "Mweri",
                narrow: "Mweri"
            },
            week: {
                wide: "Kiumia",
                short: "Kiumia",
                narrow: "Kiumia"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Mũthenya",
                short: "Mũthenya",
                narrow: "Mũthenya"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Mũthenya kiumia-inĩ",
                short: "Mũthenya kiumia-inĩ",
                narrow: "Mũthenya kiumia-inĩ"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Dayperiod",
                wide: "Dayperiod",
                narrow: "Dayperiod"
            },
            hour: {
                wide: "Ithaa",
                short: "Ithaa",
                narrow: "Ithaa"
            },
            minute: {
                wide: "Ndagĩka",
                short: "Ndagĩka",
                narrow: "Ndagĩka"
            },
            second: {
                wide: "Sekondi",
                short: "Sekondi",
                narrow: "Sekondi"
            },
            zone: {
                wide: "Gĩthaa",
                short: "Gĩthaa",
                narrow: "Gĩthaa"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

