/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "el",
    identity: {
        language: "el"
    },
    territory: "GR",
    numbers: {
        symbols: {
            decimal: ",",
            group: ".",
            list: ";",
            percentSign: "%",
            plusSign: "+",
            minusSign: "-",
            approximatelySign: "~",
            exponential: "e",
            superscriptingExponent: "×",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "n%"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-one": "n $",
            "unitPattern-count-other": "n $"
        },
        accounting: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "Πεσέτα Ανδόρας",
                "displayName-count-one": "πεσέτα Ανδόρας",
                "displayName-count-other": "πεσέτες Ανδόρας",
                symbol: "ADP"
            },
            AED: {
                displayName: "Ντιράμ Ηνωμένων Αραβικών Εμιράτων",
                "displayName-count-one": "ντιράμ Ηνωμένων Αραβικών Εμιράτων",
                "displayName-count-other": "ντιράμ Ηνωμένων Αραβικών Εμιράτων",
                symbol: "AED"
            },
            AFA: {
                displayName: "Αφγανί Αφγανιστάν (1927–2002)",
                "displayName-count-one": "αφγάνι Αφγανιστάν (AFA)",
                "displayName-count-other": "αφγάνι Αφγανιστάν (AFA)",
                symbol: "AFA"
            },
            AFN: {
                displayName: "Αφγάνι Αφγανιστάν",
                "displayName-count-one": "αφγάνι Αφγανιστάν",
                "displayName-count-other": "αφγάνια Αφγανιστάν",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "ALK",
                symbol: "ALK"
            },
            ALL: {
                displayName: "Λεκ Αλβανίας",
                "displayName-count-one": "λεκ Αλβανίας",
                "displayName-count-other": "λεκ Αλβανίας",
                symbol: "ALL"
            },
            AMD: {
                displayName: "Ντραμ Αρμενίας",
                "displayName-count-one": "ντραμ Αρμενίας",
                "displayName-count-other": "ντραμ Αρμενίας",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "Γκίλντα Ολλανδικών Αντιλλών",
                "displayName-count-one": "γκίλντα Ολλανδικών Αντιλλών",
                "displayName-count-other": "γκίλντες Ολλανδικών Αντιλλών",
                symbol: "ANG"
            },
            AOA: {
                displayName: "Κουάνζα Ανγκόλας",
                "displayName-count-one": "κουάνζα Ανγκόλας",
                "displayName-count-other": "κουάνζα Ανγκόλας",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "Κουάνζα Ανγκόλας (1977–1990)",
                "displayName-count-one": "κουάνζα Ανγκόλας (AOK)",
                "displayName-count-other": "κουάνζα Ανγκόλας (AOK)",
                symbol: "AOK"
            },
            AON: {
                displayName: "Νέα Κουάνζα Ανγκόλας (1990–2000)",
                "displayName-count-one": "νέο κουάνζα Ανγκόλας (1990–2000)",
                "displayName-count-other": "νέα κουάνζα Ανγκόλας (1990–2000)",
                symbol: "AON"
            },
            AOR: {
                displayName: "AOR",
                symbol: "AOR"
            },
            ARA: {
                displayName: "Ωστράλ Αργετινής",
                "displayName-count-one": "αουστράλ Αργεντινής",
                "displayName-count-other": "αουστράλ Αργεντινής",
                symbol: "ARA"
            },
            ARL: {
                displayName: "ARL",
                symbol: "ARL"
            },
            ARM: {
                displayName: "ARM",
                symbol: "ARM"
            },
            ARP: {
                displayName: "Πέσο Αργεντινής (1983–1985)",
                "displayName-count-one": "πέσο Αργεντινής (ARP)",
                "displayName-count-other": "πέσο Αργεντινής (ARP)",
                symbol: "ARP"
            },
            ARS: {
                displayName: "Πέσο Αργεντινής",
                "displayName-count-one": "πέσο Αργεντινής",
                "displayName-count-other": "πέσο Αργεντινής",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "Σελίνι Αυστρίας",
                "displayName-count-one": "σελίνι Αυστρίας",
                "displayName-count-other": "σελίνια Αυστρίας",
                symbol: "ATS"
            },
            AUD: {
                displayName: "Δολάριο Αυστραλίας",
                "displayName-count-one": "δολάριο Αυστραλίας",
                "displayName-count-other": "δολάρια Αυστραλίας",
                symbol: "A$",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "Φλορίνι Αρούμπας",
                "displayName-count-one": "φλορίνι Αρούμπας",
                "displayName-count-other": "φλορίνια Αρούμπας",
                symbol: "AWG"
            },
            AZM: {
                displayName: "Μανάτ Αζερμπαϊτζάν (1993–2006)",
                "displayName-count-one": "μανάτ Αζερμπαϊτζάν (1993–2006)",
                "displayName-count-other": "μανάτ Αζερμπαϊτζάν (1993–2006)",
                symbol: "AZM"
            },
            AZN: {
                displayName: "Μανάτ Αζερμπαϊτζάν",
                "displayName-count-one": "μανάτ Αζερμπαϊτζάν",
                "displayName-count-other": "μανάτ Αζερμπαϊτζάν",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "Δηνάριο Βοσνίας-Ερζεγοβίνης",
                "displayName-count-one": "δηνάριο Βοσνίας-Ερζεγοβίνης",
                "displayName-count-other": "δηνάρια Βοσνίας-Ερζεγοβίνης",
                symbol: "BAD"
            },
            BAM: {
                displayName: "Μετατρέψιμο Μάρκο Βοσνίας-Ερζεγοβίνης",
                "displayName-count-one": "μετατρέψιμο μάρκο Βοσνίας-Ερζεγοβίνης",
                "displayName-count-other": "μετατρέψιμα μάρκα Βοσνίας-Ερζεγοβίνης",
                symbol: "BAM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "BAN",
                symbol: "BAN"
            },
            BBD: {
                displayName: "Δολάριο Μπαρμπέιντος",
                "displayName-count-one": "δολάριο Μπαρμπέιντος",
                "displayName-count-other": "δολάρια Μπαρμπέιντος",
                symbol: "BBD",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "Τάκα Μπαγκλαντές",
                "displayName-count-one": "τάκα Μπαγκλαντές",
                "displayName-count-other": "τάκα Μπαγκλαντές",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "Φράγκο Βελγίου (μετατρέψιμο)",
                "displayName-count-one": "φράγκο Βελγίου (μετατρέψιμο)",
                "displayName-count-other": "φράγκα Βελγίου (μετατρέψιμα)",
                symbol: "BEC"
            },
            BEF: {
                displayName: "Φράγκο Βελγίου",
                "displayName-count-one": "φράγκο Βελγίου",
                "displayName-count-other": "φράγκα Βελγίου",
                symbol: "BEF"
            },
            BEL: {
                displayName: "Φράγκο Βελγίου (οικονομικό)",
                "displayName-count-one": "φράγκο Βελγίου (οικονομικό)",
                "displayName-count-other": "φράγκα Βελγίου (οικονομικό)",
                symbol: "BEL"
            },
            BGL: {
                displayName: "Μεταλλικό Λεβ Βουλγαρίας",
                "displayName-count-one": "μεταλλικό λεβ Βουλγαρίας",
                "displayName-count-other": "μεταλλικά λεβ Βουλγαρίας",
                symbol: "BGL"
            },
            BGM: {
                displayName: "BGM",
                symbol: "BGM"
            },
            BGN: {
                displayName: "Λεβ Βουλγαρίας",
                "displayName-count-one": "λεβ Βουλγαρίας",
                "displayName-count-other": "λεβ Βουλγαρίας",
                symbol: "BGN"
            },
            BGO: {
                displayName: "BGO",
                symbol: "BGO"
            },
            BHD: {
                displayName: "Δηνάριο Μπαχρέιν",
                "displayName-count-one": "δηνάριο Μπαχρέιν",
                "displayName-count-other": "δηνάρια Μπαχρέιν",
                symbol: "BHD"
            },
            BIF: {
                displayName: "Φράγκο Μπουρούντι",
                "displayName-count-one": "φράγκο Μπουρούντι",
                "displayName-count-other": "φράγκα Μπουρούντι",
                symbol: "BIF"
            },
            BMD: {
                displayName: "Δολάριο Βερμούδων",
                "displayName-count-one": "δολάριο Βερμούδων",
                "displayName-count-other": "δολάρια Βερμούδων",
                symbol: "BMD",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "Δολάριο Μπρουνέι",
                "displayName-count-one": "δολάριο Μπρουνέι",
                "displayName-count-other": "δολάρια Μπρουνέι",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "Μπολιβιάνο Βολιβίας",
                "displayName-count-one": "μπολιβιάνο Βολιβίας",
                "displayName-count-other": "μπολιβιάνο Βολιβίας",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "BOL",
                symbol: "BOL"
            },
            BOP: {
                displayName: "Πέσο Βολιβίας",
                "displayName-count-one": "πέσο Βολιβίας",
                "displayName-count-other": "πέσο Βολιβίας",
                symbol: "BOP"
            },
            BOV: {
                displayName: "Μβδολ Βολιβίας",
                "displayName-count-one": "μβντολ Βολιβίας",
                "displayName-count-other": "μβντολ Βολιβίας",
                symbol: "BOV"
            },
            BRB: {
                displayName: "Νέο Κρουζιέρο Βραζιλίας (1967–1986)",
                "displayName-count-one": "νέο κρουζέιρο Βραζιλίας (BRB)",
                "displayName-count-other": "νέα κρουζέιρο Βραζιλίας (BRB)",
                symbol: "BRB"
            },
            BRC: {
                displayName: "Κρουζάντο Βραζιλίας",
                "displayName-count-one": "κρουζάντο Βραζιλίας",
                "displayName-count-other": "κρουζάντο Βραζιλίας",
                symbol: "BRC"
            },
            BRE: {
                displayName: "Κρουζιέρο Βραζιλίας (1990–1993)",
                "displayName-count-one": "κρουζέιρο Βραζιλίας (BRE)",
                "displayName-count-other": "κρουζέιρο Βραζιλίας (BRE)",
                symbol: "BRE"
            },
            BRL: {
                displayName: "Ρεάλ Βραζιλίας",
                "displayName-count-one": "ρεάλ Βραζιλίας",
                "displayName-count-other": "ρεάλ Βραζιλίας",
                symbol: "R$",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "Νέο Κρουζάντο Βραζιλίας",
                "displayName-count-one": "νέο κρουζάντο Βραζιλίας",
                "displayName-count-other": "νέα κρουζάντο Βραζιλίας",
                symbol: "BRN"
            },
            BRR: {
                displayName: "Κρουζιέρο Βραζιλίας",
                "displayName-count-one": "κρουζέιρο Βραζιλίας",
                "displayName-count-other": "κρουζέιρο Βραζιλίας",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "BRZ",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "Δολάριο Μπαχαμών",
                "displayName-count-one": "δολάριο Μπαχαμών",
                "displayName-count-other": "δολάρια Μπαχαμών",
                symbol: "BSD",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "Νγκούλτρουμ Μπουτάν",
                "displayName-count-one": "νγκούλτρουμ Μπουτάν",
                "displayName-count-other": "νγκούλτρουμ Μπουτάν",
                symbol: "BTN"
            },
            BUK: {
                displayName: "Κιατ Βιρμανίας",
                "displayName-count-one": "κιάτ Βιρμανίας",
                "displayName-count-other": "κιάτ Βιρμανίας",
                symbol: "BUK"
            },
            BWP: {
                displayName: "Πούλα Μποτσουάνας",
                "displayName-count-one": "πούλα Μποτσουάνας",
                "displayName-count-other": "πούλα Μποτσουάνας",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "Νέο Ρούβλι Λευκορωσίας (1994–1999)",
                "displayName-count-one": "νέο ρούβλι Λευκορωσίας (1994–1999)",
                "displayName-count-other": "νέα ρούβλια Λευκορωσίας (1994–1999)",
                symbol: "BYB"
            },
            BYN: {
                displayName: "Ρούβλι Λευκορωσίας",
                "displayName-count-one": "ρούβλι Λευκορωσίας",
                "displayName-count-other": "ρούβλια Λευκορωσίας",
                symbol: "BYN",
                "symbol-alt-narrow": "р."
            },
            BYR: {
                displayName: "Ρούβλι Λευκορωσίας (2000–2016)",
                "displayName-count-one": "ρούβλι Λευκορωσίας (2000–2016)",
                "displayName-count-other": "ρούβλια Λευκορωσίας (2000–2016)",
                symbol: "BYR"
            },
            BZD: {
                displayName: "Δολάριο Μπελίζ",
                "displayName-count-one": "δολάριο Μπελίζ",
                "displayName-count-other": "δολάρια Μπελίζ",
                symbol: "BZD",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "Δολάριο Καναδά",
                "displayName-count-one": "δολάριο Καναδά",
                "displayName-count-other": "δολάρια Καναδά",
                symbol: "CA$",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "Φράγκο Κονγκό",
                "displayName-count-one": "φράγκο Κονγκό",
                "displayName-count-other": "φράγκα Κονγκό",
                symbol: "CDF"
            },
            CHE: {
                displayName: "Ευρώ WIR",
                "displayName-count-one": "ευρώ WIR",
                "displayName-count-other": "ευρώ WIR",
                symbol: "CHE"
            },
            CHF: {
                displayName: "Φράγκο Ελβετίας",
                "displayName-count-one": "φράγκο Ελβετίας",
                "displayName-count-other": "φράγκα Ελβετίας",
                symbol: "CHF"
            },
            CHW: {
                displayName: "Φράγκο WIR",
                "displayName-count-one": "φράγκο WIR",
                "displayName-count-other": "φράγκα WIR",
                symbol: "CHW"
            },
            CLE: {
                displayName: "CLE",
                symbol: "CLE"
            },
            CLF: {
                displayName: "Ουνιδάδες ντε φομέντο Χιλής",
                "displayName-count-one": "ουνιδάδες ντε φομέντο Χιλής",
                "displayName-count-other": "ουνιδάδες ντε φομέντο Χιλής",
                symbol: "CLF"
            },
            CLP: {
                displayName: "Πέσο Χιλής",
                "displayName-count-one": "πέσο Χιλής",
                "displayName-count-other": "πέσο Χιλής",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "Γουάν Κίνας (υπεράκτιο)",
                "displayName-count-one": "γουάν Κίνας (υπεράκτιο)",
                "displayName-count-other": "γουάν Κίνας (υπεράκτια)",
                symbol: "CNH"
            },
            CNX: {
                displayName: "CNX",
                symbol: "CNX"
            },
            CNY: {
                displayName: "Γουάν Κίνας",
                "displayName-count-one": "γουάν Κίνας",
                "displayName-count-other": "γουάν Κίνας",
                symbol: "CN¥",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "Πέσο Κολομβίας",
                "displayName-count-one": "πέσο Κολομβίας",
                "displayName-count-other": "πέσο Κολομβίας",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "COU",
                symbol: "COU"
            },
            CRC: {
                displayName: "Κολόν Κόστα Ρίκα",
                "displayName-count-one": "κολόν Κόστα Ρίκα",
                "displayName-count-other": "κολόν Κόστα Ρίκα",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "Παλαιό Δηνάριο Σερβίας",
                "displayName-count-one": "παλιό δινάρη Σερβίας",
                "displayName-count-other": "παλιά δινάρια Σερβίας",
                symbol: "CSD"
            },
            CSK: {
                displayName: "Σκληρή Κορόνα Τσεχοσλοβακίας",
                "displayName-count-one": "σκληρή κορόνα Τσεχοσλοβακίας",
                "displayName-count-other": "σκληρές κορόνες Τσεχοσλοβακίας",
                symbol: "CSK"
            },
            CUC: {
                displayName: "Μετατρέψιμο πέσο Κούβας",
                "displayName-count-one": "μετατρέψιμο πέσο Κούβας",
                "displayName-count-other": "μετατρέψιμα πέσο Κούβας",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "Πέσο Κούβας",
                "displayName-count-one": "πέσο Κούβας",
                "displayName-count-other": "πέσο Κούβας",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "Εσκούδο Πράσινου Ακρωτηρίου",
                "displayName-count-one": "εσκούδο Πράσινου Ακρωτηρίου",
                "displayName-count-other": "εσκούδο Πράσινου Ακρωτηρίου",
                symbol: "CVE"
            },
            CYP: {
                displayName: "Λίρα Κύπρου",
                "displayName-count-one": "λίρα Κύπρου",
                "displayName-count-other": "λίρες Κύπρου",
                symbol: "CYP"
            },
            CZK: {
                displayName: "Κορόνα Τσεχίας",
                "displayName-count-one": "κορόνα Τσεχίας",
                "displayName-count-other": "κορόνες Τσεχίας",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "Οστμάρκ Ανατολικής Γερμανίας",
                "displayName-count-one": "όστμαρκ Ανατολικής Γερμανίας",
                "displayName-count-other": "όστμαρκ Ανατολικής Γερμανίας",
                symbol: "DDM"
            },
            DEM: {
                displayName: "Μάρκο Γερμανίας",
                "displayName-count-one": "μάρκο Γερμανίας",
                "displayName-count-other": "μάρκα Γερμανίας",
                symbol: "DEM"
            },
            DJF: {
                displayName: "Φράγκο Τζιμπουτί",
                "displayName-count-one": "φράγκο Τζιμπουτί",
                "displayName-count-other": "φράγκα Τζιμπουτί",
                symbol: "DJF"
            },
            DKK: {
                displayName: "Κορόνα Δανίας",
                "displayName-count-one": "κορόνα Δανίας",
                "displayName-count-other": "κορόνες Δανίας",
                symbol: "DKK",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "Πέσο Δομινικανής Δημοκρατίας",
                "displayName-count-one": "πέσο Δομινικανής Δημοκρατίας",
                "displayName-count-other": "πέσο Δομινικανής Δημοκρατίας",
                symbol: "DOP",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "Δηνάριο Αλγερίας",
                "displayName-count-one": "δηνάριο Αλγερίας",
                "displayName-count-other": "δηνάρια Αλγερίας",
                symbol: "DZD"
            },
            ECS: {
                displayName: "Σούκρε Εκουαδόρ",
                "displayName-count-one": "σούκρε Εκουαδόρ",
                "displayName-count-other": "σούκρε Εκουαδόρ",
                symbol: "ECS"
            },
            ECV: {
                displayName: "ECV",
                symbol: "ECV"
            },
            EEK: {
                displayName: "Κορόνα Εσθονίας",
                "displayName-count-one": "κορόνα Εσθονίας",
                "displayName-count-other": "κορόνες Εσθονίας",
                symbol: "EEK"
            },
            EGP: {
                displayName: "Λίρα Αιγύπτου",
                "displayName-count-one": "λίρα Αιγύπτου",
                "displayName-count-other": "λίρες Αιγύπτου",
                symbol: "EGP",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "Νάκφα Ερυθραίας",
                "displayName-count-one": "νάκφα Ερυθραίας",
                "displayName-count-other": "νάκφα Ερυθραίας",
                symbol: "ERN"
            },
            ESA: {
                displayName: "πεσέτα Ισπανίας (λογαριασμός Α)",
                "displayName-count-one": "πεσέτα Ισπανίας (λογαριασμός Α)",
                "displayName-count-other": "πεσέτες Ισπανίας (λογαριασμός Α)",
                symbol: "ESA"
            },
            ESB: {
                displayName: "πεσέτα Ισπανίας (μετατρέψιμος λογαριασμός)",
                "displayName-count-one": "πεσέτα Ισπανίας (μετατρέψιμος λογαριασμός)",
                "displayName-count-other": "πεσέτες Ισπανίας (μετατρέψιμες)",
                symbol: "ESB"
            },
            ESP: {
                displayName: "Πεσέτα Ισπανίας",
                "displayName-count-one": "πεσέτα Ισπανίας",
                "displayName-count-other": "πεσέτες Ισπανίας",
                symbol: "ESP",
                "symbol-alt-narrow": "₧"
            },
            ETB: {
                displayName: "Μπιρ Αιθιοπίας",
                "displayName-count-one": "μπιρ Αιθιοπίας",
                "displayName-count-other": "μπιρ Αιθιοπίας",
                symbol: "ETB"
            },
            EUR: {
                displayName: "Ευρώ",
                "displayName-count-one": "ευρώ",
                "displayName-count-other": "ευρώ",
                symbol: "€",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "Μάρκο Φινλανδίας",
                "displayName-count-one": "μάρκο Φινλανδίας",
                "displayName-count-other": "μάρκα Φινλανδίας",
                symbol: "FIM"
            },
            FJD: {
                displayName: "Δολάριο Φίτζι",
                "displayName-count-one": "δολάριο Φίτζι",
                "displayName-count-other": "δολάρια Φίτζι",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "Λίρα Νήσων Φόκλαντ",
                "displayName-count-one": "λίρα Νήσων Φόκλαντ",
                "displayName-count-other": "λίρες Νήσων Φόκλαντ",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "Φράγκο Γαλλίας",
                "displayName-count-one": "φράγκο Γαλλίας",
                "displayName-count-other": "φράγκα Γαλλίας",
                symbol: "FRF"
            },
            GBP: {
                displayName: "Λίρα Στερλίνα Βρετανίας",
                "displayName-count-one": "λίρα στερλίνα Βρετανίας",
                "displayName-count-other": "λίρες στερλίνες Βρετανίας",
                symbol: "£",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "Κούπον Λάρι Γεωργίας",
                "displayName-count-one": "κούπον λάρι Γεωργίας",
                "displayName-count-other": "κούπον λάρι Γεωργίας",
                symbol: "GEK"
            },
            GEL: {
                displayName: "Λάρι Γεωργίας",
                "displayName-count-one": "λάρι Γεωργίας",
                "displayName-count-other": "λάρι Γεωργίας",
                symbol: "GEL",
                "symbol-alt-narrow": "₾"
            },
            GHC: {
                displayName: "Σέντι Γκάνας (1979–2007)",
                "displayName-count-one": "σέντι Γκάνας (GHC)",
                "displayName-count-other": "σέντι Γκάνας (GHC)",
                symbol: "GHC"
            },
            GHS: {
                displayName: "Σέντι Γκάνας",
                "displayName-count-one": "σέντι Γκάνας",
                "displayName-count-other": "σέντι Γκάνας",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "Λίρα Γιβραλτάρ",
                "displayName-count-one": "λίρα Γιβραλτάρ",
                "displayName-count-other": "λίρες Γιβραλτάρ",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "Νταλάσι Γκάμπιας",
                "displayName-count-one": "νταλάσι Γκάμπιας",
                "displayName-count-other": "νταλάσι Γκάμπιας",
                symbol: "GMD"
            },
            GNF: {
                displayName: "Φράγκο Γουινέας",
                "displayName-count-one": "φράγκο Γουινέας",
                "displayName-count-other": "φράγκα Γουινέας",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "Συλί Γουινέας",
                "displayName-count-one": "συλί Γουινέας",
                "displayName-count-other": "συλί Γουινέας",
                symbol: "GNS"
            },
            GQE: {
                displayName: "Εκγουέλε Ισημερινής Γουινέας",
                "displayName-count-one": "εκουέλε Ισημερινής Γουινέας",
                "displayName-count-other": "εκουέλε Ισημερινής Γουινέας",
                symbol: "GQE"
            },
            GRD: {
                pattern: "#,##0.00 ¤",
                displayName: "Δραχμή Ελλάδας",
                "displayName-count-one": "δραχμή Ελλάδας",
                "displayName-count-other": "δραχμές Ελλάδας",
                symbol: "Δρχ",
                decimal: ",",
                group: "."
            },
            GTQ: {
                displayName: "Κουετσάλ Γουατεμάλας",
                "displayName-count-one": "κουετσάλ Γουατεμάλας",
                "displayName-count-other": "κουετσάλ Γουατεμάλας",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "Γκινέα Εσκούδο Πορτογαλίας",
                "displayName-count-one": "γκινέα εσκούδο Πορτογαλίας",
                "displayName-count-other": "γκινέα εσκούδο Πορτογαλίας",
                symbol: "GWE"
            },
            GWP: {
                displayName: "Πέσο Γουινέας-Μπισάου",
                "displayName-count-one": "πέσο Γουινέα-Μπισάου",
                "displayName-count-other": "πέσο Γουινέα-Μπισάου",
                symbol: "GWP"
            },
            GYD: {
                displayName: "Δολάριο Γουιάνας",
                "displayName-count-one": "δολάριο Γουιάνας",
                "displayName-count-other": "δολάρια Γουιάνας",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "Δολάριο Χονγκ Κονγκ",
                "displayName-count-one": "δολάριο Χονγκ Κονγκ",
                "displayName-count-other": "δολάρια Χονγκ Κονγκ",
                symbol: "HK$",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "Λεμπίρα Ονδούρας",
                "displayName-count-one": "λεμπίρα Ονδούρας",
                "displayName-count-other": "λεμπίρα Ονδούρας",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "Δηνάριο Κροατίας",
                "displayName-count-one": "δηνάριο Κροατίας",
                "displayName-count-other": "δηνάρια Κροατίας",
                symbol: "HRD"
            },
            HRK: {
                displayName: "Κούνα Κροατίας",
                "displayName-count-one": "κούνα Κροατίας",
                "displayName-count-other": "κούνα Κροατίας",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "Γκουρντ Αϊτής",
                "displayName-count-one": "γκουρντ Αϊτής",
                "displayName-count-other": "γκουρντ Αϊτής",
                symbol: "HTG"
            },
            HUF: {
                displayName: "Φιορίνι Ουγγαρίας",
                "displayName-count-one": "φιορίνι Ουγγαρίας",
                "displayName-count-other": "φιορίνια Ουγγαρίας",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "Ρουπία Ινδονησίας",
                "displayName-count-one": "ρουπία Ινδονησίας",
                "displayName-count-other": "ρουπία Ινδονησίας",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "Λίρα Ιρλανδίας",
                "displayName-count-one": "λίρα Ιρλανδίας",
                "displayName-count-other": "λίρες Ιρλανδίας",
                symbol: "IEP"
            },
            ILP: {
                displayName: "Λίρα Ισραήλ",
                "displayName-count-one": "λίρα Ισραήλ",
                "displayName-count-other": "λίρες Ισραήλ",
                symbol: "ILP"
            },
            ILR: {
                displayName: "παλιό σεκέλ Ισραήλ",
                "displayName-count-one": "παλιό σεκέλ Ισραήλ",
                "displayName-count-other": "παλιά σεκέλ Ισραήλ",
                symbol: "ILR"
            },
            ILS: {
                displayName: "Νέο Σέκελ Ισραήλ",
                "displayName-count-one": "νέο σέκελ Ισραήλ",
                "displayName-count-other": "νέα σέκελ Ισραήλ",
                symbol: "₪",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "Ρουπία Ινδίας",
                "displayName-count-one": "ρουπία Ινδίας",
                "displayName-count-other": "ρουπίες Ινδίας",
                symbol: "₹",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "Δηνάριο Ιράκ",
                "displayName-count-one": "δηνάριο Ιράκ",
                "displayName-count-other": "δηνάρια Ιράκ",
                symbol: "IQD"
            },
            IRR: {
                displayName: "Ριάλ Ιράν",
                "displayName-count-one": "ριάλ Ιράν",
                "displayName-count-other": "ριάλ Ιράν",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "Παλιά κορόνα Ισλανδίας",
                "displayName-count-one": "Παλιά κορόνα Ισλανδίας",
                "displayName-count-other": "παλιές κορόνες Ισλανδίας",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "Κορόνα Ισλανδίας",
                "displayName-count-one": "κορόνα Ισλανδίας",
                "displayName-count-other": "κορόνες Ισλανδίας",
                symbol: "ISK",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "Λιρέτα Ιταλίας",
                "displayName-count-one": "λιρέτα Ιταλίας",
                "displayName-count-other": "λιρέτες Ιταλίας",
                symbol: "ITL"
            },
            JMD: {
                displayName: "Δολάριο Τζαμάικας",
                "displayName-count-one": "δολάριο Τζαμάικας",
                "displayName-count-other": "δολάρια Τζαμάικας",
                symbol: "JMD",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "Δηνάριο Ιορδανίας",
                "displayName-count-one": "δηνάριο Ιορδανίας",
                "displayName-count-other": "δηνάρια Ιορδανίας",
                symbol: "JOD"
            },
            JPY: {
                displayName: "Γιεν Ιαπωνίας",
                "displayName-count-one": "γιεν Ιαπωνίας",
                "displayName-count-other": "γιεν Ιαπωνίας",
                symbol: "JP¥",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "Σελίνι Κένυας",
                "displayName-count-one": "σελίνι Κένυας",
                "displayName-count-other": "σελίνια Κένυας",
                symbol: "KES"
            },
            KGS: {
                displayName: "Σομ Κιργιζίας",
                "displayName-count-one": "σομ Κιργιζίας",
                "displayName-count-other": "σομ Κιργιζίας",
                symbol: "KGS"
            },
            KHR: {
                displayName: "Ρίελ Καμπότζης",
                "displayName-count-one": "ρίελ Καμπότζης",
                "displayName-count-other": "ρίελ Καμπότζης",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "Φράγκο Κομορών",
                "displayName-count-one": "φράγκο Κομορών",
                "displayName-count-other": "φράγκα Κομορών",
                symbol: "KMF",
                "symbol-alt-narrow": "CF"
            },
            KPW: {
                displayName: "Γουόν Βόρειας Κορέας",
                "displayName-count-one": "γουόν Βόρειας Κορέας",
                "displayName-count-other": "γουόν Βόρειας Κορέας",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "KRH",
                symbol: "KRH"
            },
            KRO: {
                displayName: "KRO",
                symbol: "KRO"
            },
            KRW: {
                displayName: "Γουόν Νότιας Κορέας",
                "displayName-count-one": "γουόν Νότιας Κορέας",
                "displayName-count-other": "γουόν Νότιας Κορέας",
                symbol: "₩",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "Δηνάριο Κουβέιτ",
                "displayName-count-one": "δηνάριο Κουβέιτ",
                "displayName-count-other": "δηνάρια Κουβέιτ",
                symbol: "KWD"
            },
            KYD: {
                displayName: "Δολάριο Νήσων Κέιμαν",
                "displayName-count-one": "δολάριο Νήσων Κέιμαν",
                "displayName-count-other": "δολάρια Νήσων Κέιμαν",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "Τένγκε Καζακστάν",
                "displayName-count-one": "τένγκε Καζακστάν",
                "displayName-count-other": "τένγκε Καζακστάν",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "Κιπ Λάος",
                "displayName-count-one": "κιπ Λάος",
                "displayName-count-other": "κιπ Λάος",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "Λίρα Λιβάνου",
                "displayName-count-one": "λίρα Λιβάνου",
                "displayName-count-other": "λίρες Λιβάνου",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "Ρουπία Σρι Λάνκα",
                "displayName-count-one": "ρουπία Σρι Λάνκα",
                "displayName-count-other": "ρουπίες Σρι Λάνκα",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "Δολάριο Λιβερίας",
                "displayName-count-one": "δολάριο Λιβερίας",
                "displayName-count-other": "δολάρια Λιβερίας",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "Λότι Λεσότο",
                "displayName-count-one": "λότι Λεσότο",
                "displayName-count-other": "λότι Λεσότο",
                symbol: "LSL"
            },
            LTL: {
                displayName: "Λίτα Λιθουανίας",
                "displayName-count-one": "λίτα Λιθουανίας",
                "displayName-count-other": "λίτα Λιθουανίας",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "Ταλόνας Λιθουανίας",
                "displayName-count-one": "ταλόνας Λιθουανίας",
                "displayName-count-other": "ταλόνας Λιθουανίας",
                symbol: "LTT"
            },
            LUC: {
                displayName: "Μετατρέψιμο Φράγκο Λουξεμβούργου",
                symbol: "LUC"
            },
            LUF: {
                displayName: "Φράγκο Λουξεμβούργου",
                "displayName-count-one": "φράγκο Λουξεμβούργου",
                "displayName-count-other": "φράγκα Λουξεμβούργου",
                symbol: "LUF"
            },
            LUL: {
                displayName: "Οικονομικό Φράγκο Λουξεμβούργου",
                symbol: "LUL"
            },
            LVL: {
                displayName: "Λατς Λετονίας",
                "displayName-count-one": "λατς Λετονίας",
                "displayName-count-other": "λατς Λετονίας",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "Ρούβλι Λετονίας",
                "displayName-count-one": "ρούβλι Λετονίας",
                "displayName-count-other": "ρούβλια Λετονίας",
                symbol: "LVR"
            },
            LYD: {
                displayName: "Δηνάριο Λιβύης",
                "displayName-count-one": "δηνάριο Λιβύης",
                "displayName-count-other": "δηνάρια Λιβύης",
                symbol: "LYD"
            },
            MAD: {
                displayName: "Ντιράμ Μαρόκου",
                "displayName-count-one": "ντιράμ Μαρόκου",
                "displayName-count-other": "ντιράμ Μαρόκου",
                symbol: "MAD"
            },
            MAF: {
                displayName: "Φράγκο Μαρόκου",
                "displayName-count-one": "φράγκο Μαρόκου",
                "displayName-count-other": "φράγκα Μαρόκου",
                symbol: "MAF"
            },
            MCF: {
                displayName: "MCF",
                symbol: "MCF"
            },
            MDC: {
                displayName: "MDC",
                symbol: "MDC"
            },
            MDL: {
                displayName: "Λέου Μολδαβίας",
                "displayName-count-one": "λέου Μολδαβίας",
                "displayName-count-other": "λέου Μολδαβίας",
                symbol: "MDL"
            },
            MGA: {
                displayName: "Αριάρι Μαδαγασκάρης",
                "displayName-count-one": "αριάρι Μαδαγασκάρης",
                "displayName-count-other": "αριάρι Μαδαγασκάρης",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "Φράγκο Μαδαγασκάρης",
                "displayName-count-one": "φράγκο Μαδαγασκάρης",
                "displayName-count-other": "φράγκα Μαδαγασκάρης",
                symbol: "MGF"
            },
            MKD: {
                displayName: "Δηνάριο ΠΓΔΜ",
                "displayName-count-one": "δηνάριο ΠΓΔΜ",
                "displayName-count-other": "δηνάρια ΠΓΔΜ",
                symbol: "MKD"
            },
            MKN: {
                displayName: "MKN",
                symbol: "MKN"
            },
            MLF: {
                displayName: "Φράγκο Μαλί",
                "displayName-count-one": "φράγκο Μαλί",
                "displayName-count-other": "φράγκα Μαλί",
                symbol: "MLF"
            },
            MMK: {
                displayName: "Κιάτ Μιανμάρ",
                "displayName-count-one": "κιάτ Μιανμάρ",
                "displayName-count-other": "κιάτ Μιανμάρ",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "Τουγκρίκ Μογγολίας",
                "displayName-count-one": "τουγκρίκ Μογγολίας",
                "displayName-count-other": "τουγκρίκ Μογγολίας",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "Πατάκα Μακάο",
                "displayName-count-one": "πατάκα Μακάο",
                "displayName-count-other": "πατάκα Μακάο",
                symbol: "MOP"
            },
            MRO: {
                displayName: "Ουγκίγια Μαυριτανίας (1973–2017)",
                "displayName-count-one": "ουγκίγια Μαυριτανίας (1973–2017)",
                "displayName-count-other": "ουγκίγια Μαυριτανίας (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "Ουγκίγια Μαυριτανίας",
                "displayName-count-one": "ουγκίγια Μαυριτανίας",
                "displayName-count-other": "ουγκίγια Μαυριτανίας",
                symbol: "MRU"
            },
            MTL: {
                displayName: "Λιρέτα Μάλτας",
                "displayName-count-one": "λιρέτα Μάλτας",
                "displayName-count-other": "λιρέτες Μάλτας",
                symbol: "MTL"
            },
            MTP: {
                displayName: "Λίρα Μάλτας",
                "displayName-count-one": "λίρα Μάλτας",
                "displayName-count-other": "λίρες Μάλτας",
                symbol: "MTP"
            },
            MUR: {
                displayName: "Ρουπία Μαυρικίου",
                "displayName-count-one": "ρουπία Μαυρικίου",
                "displayName-count-other": "ρουπίες Μαυρικίου",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "MVP",
                symbol: "MVP"
            },
            MVR: {
                displayName: "Ρουφίγια Μαλδίβων",
                "displayName-count-one": "ρουφίγια Μαλδίβων",
                "displayName-count-other": "ρουφίγιες Μαλδίβων",
                symbol: "MVR"
            },
            MWK: {
                displayName: "Κουάτσα Μαλάουι",
                "displayName-count-one": "κουάτσα Μαλάουι",
                "displayName-count-other": "κουάτσα Μαλάουι",
                symbol: "MWK"
            },
            MXN: {
                displayName: "Πέσο Μεξικού",
                "displayName-count-one": "πέσο Μεξικού",
                "displayName-count-other": "πέσο Μεξικού",
                symbol: "MX$",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "Ασημένιο Πέσο Μεξικού (1861–1992)",
                "displayName-count-one": "ασημένιο πέσο Μεξικού (MXP)",
                "displayName-count-other": "ασημένια πέσο Μεξικού (MXP)",
                symbol: "MXP"
            },
            MXV: {
                displayName: "MXV",
                symbol: "MXV"
            },
            MYR: {
                displayName: "Ρινγκίτ Μαλαισίας",
                "displayName-count-one": "ρινγκίτ Μαλαισίας",
                "displayName-count-other": "ρινγκίτ Μαλαισίας",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "Εσκούδο Μοζαμβίκης",
                "displayName-count-one": "εσκούδο Μοζαμβίκης",
                "displayName-count-other": "εσκούδο Μοζαμβίκης",
                symbol: "MZE"
            },
            MZM: {
                displayName: "Παλαιό Μετικάλ Μοζαμβίκης",
                "displayName-count-one": "παλιό μετικάλ Μοζαμβίκης",
                "displayName-count-other": "παλιά μετικάλ Μοζαμβίκης",
                symbol: "MZM"
            },
            MZN: {
                displayName: "Μετικάλ Μοζαμβίκης",
                "displayName-count-one": "μετικάλ Μοζαμβίκης",
                "displayName-count-other": "μετικάλ Μοζαμβίκης",
                symbol: "MZN"
            },
            NAD: {
                displayName: "Δολάριο Ναμίμπιας",
                "displayName-count-one": "δολάριο Ναμίμπιας",
                "displayName-count-other": "δολάρια Ναμίμπιας",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "Νάιρα Νιγηρίας",
                "displayName-count-one": "νάιρα Νιγηρίας",
                "displayName-count-other": "νάιρα Νιγηρίας",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "Κόρδοβα Νικαράγουας",
                "displayName-count-one": "κόρδοβα Νικαράγουας",
                "displayName-count-other": "κόρδοβα Νικαράγουας",
                symbol: "NIC"
            },
            NIO: {
                displayName: "Χρυσή Κόρδοβα Νικαράγουας",
                "displayName-count-one": "χρυσή κόρδοβα Νικαράγουας",
                "displayName-count-other": "χρυσές κόρδοβα Νικαράγουας",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "Γκίλντα Ολλανδίας",
                "displayName-count-one": "γκίλντα Ολλανδίας",
                "displayName-count-other": "γκίλντα Ολλανδίας",
                symbol: "NLG"
            },
            NOK: {
                displayName: "Κορόνα Νορβηγίας",
                "displayName-count-one": "κορόνα Νορβηγίας",
                "displayName-count-other": "κορόνες Νορβηγίας",
                symbol: "NOK",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "Ρουπία Νεπάλ",
                "displayName-count-one": "ρουπία Νεπάλ",
                "displayName-count-other": "ρουπίες Νεπάλ",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "Δολάριο Νέας Ζηλανδίας",
                "displayName-count-one": "δολάριο Νέας Ζηλανδίας",
                "displayName-count-other": "δολάρια Νέας Ζηλανδίας",
                symbol: "NZ$",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "Ριάλ Ομάν",
                "displayName-count-one": "ριάλ Ομάν",
                "displayName-count-other": "ριάλ Ομάν",
                symbol: "OMR"
            },
            PAB: {
                displayName: "Μπαλμπόα Παναμά",
                "displayName-count-one": "μπαλμπόα Παναμά",
                "displayName-count-other": "μπαλμπόα Παναμά",
                symbol: "PAB"
            },
            PEI: {
                displayName: "Ίντι Περού",
                "displayName-count-one": "ίντι Περού",
                "displayName-count-other": "ίντι Περού",
                symbol: "PEI"
            },
            PEN: {
                displayName: "Σολ Περού",
                "displayName-count-one": "σολ Περού",
                "displayName-count-other": "σολ Περού",
                symbol: "PEN"
            },
            PES: {
                displayName: "Σολ Περού (1863–1965)",
                "displayName-count-one": "σολ Περού (1863–1965)",
                "displayName-count-other": "σολ Περού (1863–1965)",
                symbol: "PES"
            },
            PGK: {
                displayName: "Κίνα Παπούας Νέας Γουινέας",
                "displayName-count-one": "κίνα Παπούας Νέας Γουινέας",
                "displayName-count-other": "κίνα Παπούας Νέας Γουινέας",
                symbol: "PGK"
            },
            PHP: {
                displayName: "Πέσο Φιλιππίνων",
                "displayName-count-one": "πέσο Φιλιππίνων",
                "displayName-count-other": "πέσο Φιλιππίνων",
                symbol: "PHP",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "Ρουπία Πακιστάν",
                "displayName-count-one": "ρουπία Πακιστάν",
                "displayName-count-other": "ρουπίες Πακιστάν",
                symbol: "PKR",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "Ζλότι Πολωνίας",
                "displayName-count-one": "ζλότι Πολωνίας",
                "displayName-count-other": "ζλότι Πολωνίας",
                symbol: "PLN",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "Ζλότυ Πολωνίας (1950–1995)",
                "displayName-count-one": "ζλότυ Πολωνίας (PLZ)",
                "displayName-count-other": "ζλότυ Πολωνίας (PLZ)",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "Εσκούδο Πορτογαλίας",
                "displayName-count-one": "εσκούδο Πορτογαλίας",
                "displayName-count-other": "εσκούδο Πορτογαλίας",
                symbol: "PTE"
            },
            PYG: {
                displayName: "Γκουαρανί Παραγουάης",
                "displayName-count-one": "γκουαρανί Παραγουάης",
                "displayName-count-other": "γκουαρανί Παραγουάης",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "Ριάλ Κατάρ",
                "displayName-count-one": "ριάλ Κατάρ",
                "displayName-count-other": "ριάλ Κατάρ",
                symbol: "QAR"
            },
            RHD: {
                displayName: "Δολάριο Ροδεσίας",
                "displayName-count-one": "δολάριο Ροδεσίας",
                "displayName-count-other": "δολάρια Ροδεσίας",
                symbol: "RHD"
            },
            ROL: {
                displayName: "Λέι Ρουμανίας",
                "displayName-count-one": "παλιό λέι Ρουμανίας",
                "displayName-count-other": "παλιά λέι Ρουμανίας",
                symbol: "ROL"
            },
            RON: {
                displayName: "Λέου Ρουμανίας",
                "displayName-count-one": "λέου Ρουμανίας",
                "displayName-count-other": "λέου Ρουμανίας",
                symbol: "RON",
                "symbol-alt-narrow": "lei"
            },
            RSD: {
                displayName: "Δηνάριο Σερβίας",
                "displayName-count-one": "δηνάριο Σερβίας",
                "displayName-count-other": "δηνάρια Σερβίας",
                symbol: "RSD"
            },
            RUB: {
                displayName: "Ρούβλι Ρωσίας",
                "displayName-count-one": "ρούβλι Ρωσίας",
                "displayName-count-other": "ρούβλια Ρωσίας",
                symbol: "RUB",
                "symbol-alt-narrow": "₽"
            },
            RUR: {
                displayName: "Ρούβλι Ρωσίας (1991–1998)",
                "displayName-count-one": "ρούβλι Ρωσίας (RUR)",
                "displayName-count-other": "ρούβλια Ρωσίας (1991–1998)",
                symbol: "RUR"
            },
            RWF: {
                displayName: "Φράγκο Ρουάντας",
                "displayName-count-one": "φράγκο Ρουάντας",
                "displayName-count-other": "φράγκα Ρουάντας",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "Ριάλ Σαουδικής Αραβίας",
                "displayName-count-one": "ριάλ Σαουδικής Αραβίας",
                "displayName-count-other": "ριάλ Σαουδικής Αραβίας",
                symbol: "SAR"
            },
            SBD: {
                displayName: "Δολάριο Νήσων Σολομώντος",
                "displayName-count-one": "δολάριο Νήσων Σολομώντος",
                "displayName-count-other": "δολάρια Νήσων Σολομώντος",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "Ρουπία Σεϋχελλών",
                "displayName-count-one": "ρουπία Σεϋχελλών",
                "displayName-count-other": "ρουπίες Σεϋχελλών",
                symbol: "SCR"
            },
            SDD: {
                displayName: "Δηνάριο Σουδάν",
                "displayName-count-one": "δηνάριο Σουδάν",
                "displayName-count-other": "δηνάρια Σουδάν",
                symbol: "SDD"
            },
            SDG: {
                displayName: "Λίρα Σουδάν",
                "displayName-count-one": "λίρα Σουδάν",
                "displayName-count-other": "λίρες Σουδάν",
                symbol: "SDG"
            },
            SDP: {
                displayName: "Παλαιά Λίρα Σουδάν",
                "displayName-count-one": "παλιά λίρα Σουδάν",
                "displayName-count-other": "παλαιές λίρες Σουδάν",
                symbol: "SDP"
            },
            SEK: {
                displayName: "Κορόνα Σουηδίας",
                "displayName-count-one": "κορόνα Σουηδίας",
                "displayName-count-other": "κορόνες Σουηδίας",
                symbol: "SEK",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "Δολάριο Σιγκαπούρης",
                "displayName-count-one": "δολάριο Σιγκαπούρης",
                "displayName-count-other": "δολάρια Σιγκαπούρης",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "Λίρα Αγίας Ελένης",
                "displayName-count-one": "λίρα Αγίας Ελένης",
                "displayName-count-other": "λίρες Αγίας Ελένης",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "Τόλαρ Σλοβενίας",
                "displayName-count-one": "τόλαρ Σλοβενίας",
                "displayName-count-other": "τόλαρ Σλοβ",
                symbol: "SIT"
            },
            SKK: {
                displayName: "Κορόνα Σλοβενίας",
                "displayName-count-one": "κορόνα Σλοβενίας",
                "displayName-count-other": "κορόνες Σλοβενίας",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "Λεόνε Σιέρα Λεόνε",
                "displayName-count-one": "λεόνε Σιέρα Λεόνε",
                "displayName-count-other": "λεόνε Σιέρα Λεόνε",
                symbol: "SLL"
            },
            SOS: {
                displayName: "Σελίνι Σομαλίας",
                "displayName-count-one": "σελίνι Σομαλίας",
                "displayName-count-other": "σελίνια Σομαλίας",
                symbol: "SOS"
            },
            SRD: {
                displayName: "Δολάριο Σουρινάμ",
                "displayName-count-one": "δολάριο Σουρινάμ",
                "displayName-count-other": "δολάρια Σουρινάμ",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "Γκίλντα Σουρινάμ",
                "displayName-count-one": "γκίλντα Σουρινάμ",
                "displayName-count-other": "γκίλντα Σουρινάμ",
                symbol: "SRG"
            },
            SSP: {
                displayName: "Λίρα Νότιου Σουδάν",
                "displayName-count-one": "λίρα Νότιου Σουδάν",
                "displayName-count-other": "λίρες Νότιου Σουδάν",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "Ντόμπρα Σάο Τομέ και Πρίνσιπε (1977–2017)",
                "displayName-count-one": "ντόμπρα Σάο Τομέ και Πρίνσιπε (1977–2017)",
                "displayName-count-other": "ντόμπρα Σάο Τομέ και Πρίνσιπε (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "Ντόμπρα Σάο Τομέ και Πρίνσιπε",
                "displayName-count-one": "ντόμπρα Σάο Τομέ και Πρίνσιπε",
                "displayName-count-other": "ντόμπρα Σάο Τομέ και Πρίνσιπε",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "Σοβιετικό Ρούβλι",
                "displayName-count-one": "σοβιετικό ρούβλι",
                "displayName-count-other": "σοβιετικά ρούβλια",
                symbol: "SUR"
            },
            SVC: {
                displayName: "Κολόν Ελ Σαλβαδόρ",
                "displayName-count-one": "κολόν Ελ Σαλβαδόρ",
                "displayName-count-other": "κολόν Ελ Σαλβαδόρ",
                symbol: "SVC"
            },
            SYP: {
                displayName: "Λίρα Συρίας",
                "displayName-count-one": "λίρα Συρίας",
                "displayName-count-other": "λίρες Συρίας",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "Λιλανγκένι Σουαζιλάνδης",
                "displayName-count-one": "λιλανγκένι Σουαζιλάνδης",
                "displayName-count-other": "λιλανγκένι Σουαζιλάνδης",
                symbol: "SZL"
            },
            THB: {
                displayName: "Μπατ Ταϊλάνδης",
                "displayName-count-one": "μπατ Ταϊλάνδης",
                "displayName-count-other": "μπατ Ταϊλάνδης",
                symbol: "฿",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "Ρούβλι Τατζικιστάν",
                "displayName-count-one": "ρούβλι Τατζικιστάν",
                "displayName-count-other": "ρούβλια Τατζικιστάν",
                symbol: "TJR"
            },
            TJS: {
                displayName: "Σομόνι Τατζικιστάν",
                "displayName-count-one": "σομόνι Τατζικιστάν",
                "displayName-count-other": "σομόνι Τατζικιστάν",
                symbol: "TJS"
            },
            TMM: {
                displayName: "Μανάτ Τουρκμενιστάν",
                "displayName-count-one": "μανάτ Τουρκμενιστάν",
                "displayName-count-other": "μανάτ Τουρκμενιστάν",
                symbol: "TMM"
            },
            TMT: {
                displayName: "Μάνατ Τουρκμενιστάν",
                "displayName-count-one": "μάνατ Τουρκμενιστάν",
                "displayName-count-other": "μάνατ Τουρκμενιστάν",
                symbol: "TMT"
            },
            TND: {
                displayName: "Δηνάριο Τυνησίας",
                "displayName-count-one": "δηνάριο Τυνησίας",
                "displayName-count-other": "δηνάρια Τυνησίας",
                symbol: "TND"
            },
            TOP: {
                displayName: "Παάγκα Τόνγκα",
                "displayName-count-one": "παάγκα Τόνγκα",
                "displayName-count-other": "παάγκα Τόνγκα",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "Εσκούδο Τιμόρ",
                "displayName-count-one": "εσκούδο Τιμόρ",
                "displayName-count-other": "εσκούδο Τιμόρ",
                symbol: "TPE"
            },
            TRL: {
                displayName: "Παλιά Λίρα Τουρκίας",
                "displayName-count-one": "παλιά λίρα Τουρκίας",
                "displayName-count-other": "παλιές λίρες Τουρκίας",
                symbol: "TRL"
            },
            TRY: {
                displayName: "Λίρα Τουρκίας",
                "displayName-count-one": "λίρα Τουρκίας",
                "displayName-count-other": "λίρες Τουρκίας",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "Δολάριο Τρινιντάντ και Τομπάγκο",
                "displayName-count-one": "δολάριο Τρινιντάντ και Τομπάγκο",
                "displayName-count-other": "δολάρια Τρινιντάντ και Τομπάγκο",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "Νέο δολάριο Ταϊβάν",
                "displayName-count-one": "νέο δολάριο Ταϊβάν",
                "displayName-count-other": "νέα δολάρια Ταϊβάν",
                symbol: "NT$",
                "symbol-alt-narrow": "$"
            },
            TZS: {
                displayName: "Σελίνι Τανζανίας",
                "displayName-count-one": "σελίνι Τανζανίας",
                "displayName-count-other": "σελίνια Τανζανίας",
                symbol: "TZS"
            },
            UAH: {
                displayName: "Γρίβνα Ουκρανίας",
                "displayName-count-one": "γρίβνα Ουκρανίας",
                "displayName-count-other": "γρίβνα Ουκρανίας",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "Καρμποβανέτς Ουκρανίας",
                "displayName-count-one": "καρμποβανέτς Ουκρανίας",
                "displayName-count-other": "καρμποβανέτς Ουκρανίας",
                symbol: "UAK"
            },
            UGS: {
                displayName: "Σελίνι Ουγκάντας (1966–1987)",
                "displayName-count-one": "σελίνι Ουγκάντας (UGS)",
                "displayName-count-other": "σελίνια Ουγκάντας (UGS)",
                symbol: "UGS"
            },
            UGX: {
                displayName: "Σελίνι Ουγκάντας",
                "displayName-count-one": "σελίνι Ουγκάντας",
                "displayName-count-other": "σελίνια Ουγκάντας",
                symbol: "UGX"
            },
            USD: {
                displayName: "Δολάριο ΗΠΑ",
                "displayName-count-one": "δολάριο ΗΠΑ",
                "displayName-count-other": "δολάρια ΗΠΑ",
                symbol: "$",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "Δολάριο ΗΠΑ (επόμενη ημέρα)",
                "displayName-count-one": "δολάριο Η.Π.Α. (επόμενη ημέρα)",
                "displayName-count-other": "δολάρια Η.Π.Α. (επόμενη ημέρα)",
                symbol: "USN"
            },
            USS: {
                displayName: "Δολάριο ΗΠΑ (ίδια ημέρα)",
                "displayName-count-one": "δολάριο Η.Π.Α. (ίδια ημέρα)",
                "displayName-count-other": "δολάρια Η.Π.Α. (ίδια ημέρα)",
                symbol: "USS"
            },
            UYI: {
                displayName: "UYI",
                symbol: "UYI"
            },
            UYP: {
                displayName: "Πέσο Ουρουγουάης (1975–1993)",
                "displayName-count-one": "πέσο Ουρουγουάης (UYP)",
                "displayName-count-other": "πέσο Ουρουγουάης (UYP)",
                symbol: "UYP"
            },
            UYU: {
                displayName: "Πέσο Ουρουγουάης",
                "displayName-count-one": "πέσο Ουρουγουάης",
                "displayName-count-other": "πέσο Ουρουγουάης",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "UYW",
                symbol: "UYW"
            },
            UZS: {
                displayName: "Σομ Ουζμπεκιστάν",
                "displayName-count-one": "σομ Ουζμπεκιστάν",
                "displayName-count-other": "σομ Ουζμπεκιστάν",
                symbol: "UZS"
            },
            VEB: {
                displayName: "Μπολιβάρ Βενεζουέλας (1871–2008)",
                "displayName-count-one": "μπολιβάρ Βενεζουέλας (1871–2008)",
                "displayName-count-other": "μπολιβάρ Βενεζουέλας (1871–2008)",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "Μπολιβάρ Βενεζουέλας (2008–2018)",
                "displayName-count-one": "μπολιβάρ Βενεζουέλας (2008–2018)",
                "displayName-count-other": "μπολιβάρ Βενεζουέλας (2008–2018)",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs"
            },
            VES: {
                displayName: "Μπολιβάρ Βενεζουέλας",
                "displayName-count-one": "μπολιβάρ Βενεζουέλας",
                "displayName-count-other": "μπολιβάρ Βενεζουέλας",
                symbol: "VES"
            },
            VND: {
                displayName: "Ντονγκ Βιετνάμ",
                "displayName-count-one": "ντονγκ Βιετνάμ",
                "displayName-count-other": "ντονγκ Βιετνάμ",
                symbol: "₫",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "VNN",
                symbol: "VNN"
            },
            VUV: {
                displayName: "Βατού Βανουάτου",
                "displayName-count-one": "βατού Βανουάτου",
                "displayName-count-other": "βατού Βανουάτου",
                symbol: "VUV"
            },
            WST: {
                displayName: "Τάλα Σαμόα",
                "displayName-count-one": "τάλα Σαμόα",
                "displayName-count-other": "τάλα Σαμόα",
                symbol: "WST"
            },
            XAF: {
                displayName: "Φράγκο CFA Κεντρικής Αφρικής",
                "displayName-count-one": "φράγκο CFA Κεντρικής Αφρικής",
                "displayName-count-other": "φράγκα CFA Κεντρικής Αφρικής",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "XAG",
                symbol: "XAG"
            },
            XAU: {
                displayName: "XAU",
                symbol: "XAU"
            },
            XBA: {
                displayName: "Ευρωπαϊκή Σύνθετη Μονάδα",
                "displayName-count-one": "ευρωπαϊκή σύνθετη μονάδα",
                "displayName-count-other": "ευρωπαϊκές σύνθετες μονάδες",
                symbol: "XBA"
            },
            XBB: {
                displayName: "Ευρωπαϊκή Νομισματική Μονάδα",
                "displayName-count-one": "ευρωπαϊκή νομισματική μονάδα",
                "displayName-count-other": "ευρωπαϊκές νομισματικές μονάδες",
                symbol: "XBB"
            },
            XBC: {
                displayName: "Ευρωπαϊκή μονάδα λογαριασμού (XBC)",
                "displayName-count-one": "ευρωπαϊκή μονάδα λογαριασμού (XBC)",
                "displayName-count-other": "ευρωπαϊκές μονάδες λογαριασμού (XBC)",
                symbol: "XBC"
            },
            XBD: {
                displayName: "Ευρωπαϊκή μονάδα λογαριασμού (XBD)",
                "displayName-count-one": "ευρωπαϊκή μονάδα λογαριασμού (XBD)",
                "displayName-count-other": "ευρωπαϊκές μονάδες λογαριασμού (XBD)",
                symbol: "XBD"
            },
            XCD: {
                displayName: "Δολάριο Ανατολικής Καραϊβικής",
                "displayName-count-one": "δολάριο Ανατολικής Καραϊβικής",
                "displayName-count-other": "δολάρια Ανατολικής Καραϊβικής",
                symbol: "EC$",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "Ειδικά Δικαιώματα Ανάληψης",
                "displayName-count-one": "ειδικό δικαίωμα ανάληψης",
                "displayName-count-other": "ειδικά δικαιώματα ανάληψης",
                symbol: "XDR"
            },
            XEU: {
                displayName: "Ευρωπαϊκή Συναλλαγματική Μονάδα",
                "displayName-count-one": "ευρωπαϊκή συναλλαγματική μονάδα",
                "displayName-count-other": "ευρωπαϊκές συναλλαγματικές μονάδες",
                symbol: "XEU"
            },
            XFO: {
                displayName: "Χρυσό Φράγκο Γαλλίας",
                "displayName-count-one": "χρυσό φράγκο Γαλλίας",
                "displayName-count-other": "χρυσά φράγκα Γαλλίας",
                symbol: "XFO"
            },
            XFU: {
                displayName: "UIC-Φράγκο Γαλλίας",
                "displayName-count-one": "UIC-φράγκο Γαλλίας",
                "displayName-count-other": "UIC-φράγκα Γαλλίας",
                symbol: "XFU"
            },
            XOF: {
                displayName: "Φράγκο CFA Δυτικής Αφρικής",
                "displayName-count-one": "φράγκο CFA Δυτικής Αφρικής",
                "displayName-count-other": "φράγκα CFA Δυτικής Αφρικής",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "XPD",
                symbol: "XPD"
            },
            XPF: {
                displayName: "Φράγκο CFP",
                "displayName-count-one": "φράγκο CFP",
                "displayName-count-other": "φράγκα CFP",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "XPT",
                symbol: "XPT"
            },
            XRE: {
                displayName: "XRE",
                symbol: "XRE"
            },
            XSU: {
                displayName: "XSU",
                symbol: "XSU"
            },
            XTS: {
                displayName: "XTS",
                symbol: "XTS"
            },
            XUA: {
                displayName: "XUA",
                symbol: "XUA"
            },
            XXX: {
                displayName: "Άγνωστο νόμισμα",
                "displayName-count-one": "(άγνωστο νόμισμα)",
                "displayName-count-other": "(άγνωστο νόμισμα)",
                symbol: "¤"
            },
            YDD: {
                displayName: "Δηνάριο Υεμένης",
                "displayName-count-one": "δηνάριο Υεμένης",
                "displayName-count-other": "δηνάρια Υεμένης",
                symbol: "YDD"
            },
            YER: {
                displayName: "Ριάλ Υεμένης",
                "displayName-count-one": "ριάλ Υεμένης",
                "displayName-count-other": "ριάλ Υεμένης",
                symbol: "YER"
            },
            YUD: {
                displayName: "Μεταλλικό Δηνάριο Γιουγκοσλαβίας",
                "displayName-count-one": "μεταλλικό δηνάριο Γιουγκοσλαβίας",
                "displayName-count-other": "μεταλλικά δηνάρια Γιουγκοσλαβίας",
                symbol: "YUD"
            },
            YUM: {
                displayName: "Νέο Δηνάριο Γιουγκοσλαβίας",
                "displayName-count-one": "νέο δηνάριο Γιουγκοσλαβίας",
                "displayName-count-other": "νέο δηνάριο Γιουγκοσλαβίας",
                symbol: "YUM"
            },
            YUN: {
                displayName: "Μετατρέψιμο Δηνάριο Γιουγκοσλαβίας",
                "displayName-count-one": "μετατρέψιμο δινάριο Γιουγκοσλαβίας",
                "displayName-count-other": "μετατρέψιμο δηνάριο Γιουγκοσλαβίας",
                symbol: "YUN"
            },
            YUR: {
                displayName: "YUR",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "Ραντ Νότιας Αφρικής (οικονομικό)",
                "displayName-count-one": "ραντ Νότιας Αφρικής (οικονομικό)",
                "displayName-count-other": "ραντ Νότιας Αφρικής (οικονομικό)",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "Ραντ Νότιας Αφρικής",
                "displayName-count-one": "ραντ Νότιας Αφρικής",
                "displayName-count-other": "ραντ Νότιας Αφρικής",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "Κουάνζα Ζαΐρ (1968–2012)",
                "displayName-count-one": "κουάτσα Ζάμπιας (1968–2012)",
                "displayName-count-other": "κουάτσα Ζάμπιας (1968–2012)",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "Κουάτσα Ζάμπιας",
                "displayName-count-one": "κουάτσα Ζάμπιας",
                "displayName-count-other": "κουάτσα Ζάμπιας",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "Νέο Ζαΐρ Ζαΐρ",
                "displayName-count-one": "νέο ζαΐρ Ζαΐρ",
                "displayName-count-other": "νέα ζαΐρ Ζαΐρ",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "Ζαΐρ Ζαΐρ",
                "displayName-count-one": "ζαΐρ Ζαΐρ",
                "displayName-count-other": "ζαΐρ Ζαΐρ",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "Δολάριο Ζιμπάμπουε",
                "displayName-count-one": "δολάριο Ζιμπάμπουε",
                "displayName-count-other": "δολάρια Ζιμπάμπουε",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "Δολάριο Ζιμπάμπουε (2009)",
                "displayName-count-one": "Δολάριο Ζιμπάμπουε (2009)",
                "displayName-count-other": "Δολάριο Ζιμπάμπουε (2009)",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "ZWR",
                symbol: "ZWR"
            }
        },
        localeCurrency: "EUR"
    },
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE d MMMM y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "LLLL y",
            F: "EEEE d MMMM y h:mm:ss a",
            g: "d/M/y h:mm a",
            G: "d/M/y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} - {0}",
            long: "{1} - {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "d/M/y GGGGG",
                GyMMM: "LLL y G",
                GyMMMd: "d MMM y G",
                GyMMMEd: "E d MMM y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E d/M",
                MMM: "MMM",
                MMMd: "d MMM",
                MMMEd: "E d MMM",
                MMMMd: "d MMMM",
                MMMMEd: "E d MMMM",
                "MMMMW-count-one": "εβδομάδα W του MMMM",
                "MMMMW-count-other": "εβδομάδα W του MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E d/M/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E d MMM y",
                yMMMM: "LLLL y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "εβδομάδα w του Y",
                "yw-count-other": "εβδομάδα w του Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "EEEE d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "d/M/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "Κυρ",
                    "Δευ",
                    "Τρί",
                    "Τετ",
                    "Πέμ",
                    "Παρ",
                    "Σάβ"
                ],
                narrow: [
                    "Κ",
                    "Δ",
                    "Τ",
                    "Τ",
                    "Π",
                    "Π",
                    "Σ"
                ],
                short: [
                    "Κυ",
                    "Δε",
                    "Τρ",
                    "Τε",
                    "Πέ",
                    "Πα",
                    "Σά"
                ],
                wide: [
                    "Κυριακή",
                    "Δευτέρα",
                    "Τρίτη",
                    "Τετάρτη",
                    "Πέμπτη",
                    "Παρασκευή",
                    "Σάββατο"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Κυρ",
                    "Δευ",
                    "Τρί",
                    "Τετ",
                    "Πέμ",
                    "Παρ",
                    "Σάβ"
                ],
                narrow: [
                    "Κ",
                    "Δ",
                    "Τ",
                    "Τ",
                    "Π",
                    "Π",
                    "Σ"
                ],
                short: [
                    "Κυ",
                    "Δε",
                    "Τρ",
                    "Τε",
                    "Πέ",
                    "Πα",
                    "Σά"
                ],
                wide: [
                    "Κυριακή",
                    "Δευτέρα",
                    "Τρίτη",
                    "Τετάρτη",
                    "Πέμπτη",
                    "Παρασκευή",
                    "Σάββατο"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Ιαν",
                    "Φεβ",
                    "Μαρ",
                    "Απρ",
                    "Μαΐ",
                    "Ιουν",
                    "Ιουλ",
                    "Αυγ",
                    "Σεπ",
                    "Οκτ",
                    "Νοε",
                    "Δεκ"
                ],
                narrow: [
                    "Ι",
                    "Φ",
                    "Μ",
                    "Α",
                    "Μ",
                    "Ι",
                    "Ι",
                    "Α",
                    "Σ",
                    "Ο",
                    "Ν",
                    "Δ"
                ],
                wide: [
                    "Ιανουαρίου",
                    "Φεβρουαρίου",
                    "Μαρτίου",
                    "Απριλίου",
                    "Μαΐου",
                    "Ιουνίου",
                    "Ιουλίου",
                    "Αυγούστου",
                    "Σεπτεμβρίου",
                    "Οκτωβρίου",
                    "Νοεμβρίου",
                    "Δεκεμβρίου"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Ιαν",
                    "Φεβ",
                    "Μάρ",
                    "Απρ",
                    "Μάι",
                    "Ιούν",
                    "Ιούλ",
                    "Αύγ",
                    "Σεπ",
                    "Οκτ",
                    "Νοέ",
                    "Δεκ"
                ],
                narrow: [
                    "Ι",
                    "Φ",
                    "Μ",
                    "Α",
                    "Μ",
                    "Ι",
                    "Ι",
                    "Α",
                    "Σ",
                    "Ο",
                    "Ν",
                    "Δ"
                ],
                wide: [
                    "Ιανουάριος",
                    "Φεβρουάριος",
                    "Μάρτιος",
                    "Απρίλιος",
                    "Μάιος",
                    "Ιούνιος",
                    "Ιούλιος",
                    "Αύγουστος",
                    "Σεπτέμβριος",
                    "Οκτώβριος",
                    "Νοέμβριος",
                    "Δεκέμβριος"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Τ1",
                    "Τ2",
                    "Τ3",
                    "Τ4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1ο τρίμηνο",
                    "2ο τρίμηνο",
                    "3ο τρίμηνο",
                    "4ο τρίμηνο"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Τ1",
                    "Τ2",
                    "Τ3",
                    "Τ4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1ο τρίμηνο",
                    "2ο τρίμηνο",
                    "3ο τρίμηνο",
                    "4ο τρίμηνο"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "π.μ.",
                    pm: "μ.μ.",
                    morning1: "πρωί",
                    afternoon1: "μεσημ.",
                    evening1: "απόγ.",
                    night1: "βράδυ"
                },
                narrow: {
                    am: "πμ",
                    pm: "μμ",
                    morning1: "πρωί",
                    afternoon1: "μεσημ.",
                    evening1: "απόγ.",
                    night1: "βράδυ"
                },
                wide: {
                    am: "π.μ.",
                    pm: "μ.μ.",
                    morning1: "το πρωί",
                    afternoon1: "το μεσημέρι",
                    evening1: "το απόγευμα",
                    night1: "το βράδυ"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "π.μ.",
                    pm: "μ.μ.",
                    morning1: "πρωί",
                    afternoon1: "μεσημ.",
                    evening1: "απόγ.",
                    night1: "βράδυ"
                },
                narrow: {
                    am: "πμ",
                    pm: "μμ",
                    morning1: "πρωί",
                    afternoon1: "μεσημ.",
                    evening1: "απόγ.",
                    night1: "βράδυ"
                },
                wide: {
                    am: "π.μ.",
                    pm: "μ.μ.",
                    morning1: "πρωί",
                    afternoon1: "μεσημέρι",
                    evening1: "απόγευμα",
                    night1: "βράδυ"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "προ Χριστού",
                    "1": "μετά Χριστόν",
                    "0-alt-variant": "πριν από την Κοινή Χρονολογία",
                    "1-alt-variant": "Κοινή Χρονολογία"
                },
                abbreviated: {
                    "0": "π.Χ.",
                    "1": "μ.Χ.",
                    "0-alt-variant": "π.Κ.Χ.",
                    "1-alt-variant": "ΚΧ"
                },
                narrow: {
                    "0": "π.Χ.",
                    "1": "μ.Χ.",
                    "0-alt-variant": "π.Κ.Χ.",
                    "1-alt-variant": "ΚΧ"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "περίοδος",
                short: "περ.",
                narrow: "περ."
            },
            year: {
                wide: "έτος",
                short: "έτ.",
                narrow: "έτ."
            },
            quarter: {
                wide: "τρίμηνο",
                short: "τρίμ.",
                narrow: "τρίμ."
            },
            month: {
                wide: "μήνας",
                short: "μήν.",
                narrow: "μήν."
            },
            week: {
                wide: "εβδομάδα",
                short: "εβδ.",
                narrow: "εβδ."
            },
            weekOfMonth: {
                wide: "εβδομάδα μήνα",
                short: "εβδ. μήνα",
                narrow: "εβδ. μήνα"
            },
            day: {
                wide: "ημέρα",
                short: "ημ.",
                narrow: "ημ."
            },
            dayOfYear: {
                wide: "ημέρα έτους",
                short: "ημ. έτους",
                narrow: "ημ. έτους"
            },
            weekday: {
                wide: "καθημερινή",
                short: "καθημερ.",
                narrow: "καθημερ."
            },
            weekdayOfMonth: {
                wide: "καθημερινή μήνα",
                short: "καθημερ. μήνα",
                narrow: "καθημερ. μήνα"
            },
            dayperiod: {
                short: "πμ/μμ",
                wide: "π.μ./μ.μ.",
                narrow: "πμ/μμ"
            },
            hour: {
                wide: "ώρα",
                short: "ώ.",
                narrow: "ώ."
            },
            minute: {
                wide: "λεπτό",
                short: "λεπ.",
                narrow: "λ."
            },
            second: {
                wide: "δευτερόλεπτο",
                short: "δευτ.",
                narrow: "δ."
            },
            zone: {
                wide: "ζώνη ώρας",
                short: "ζώνη",
                narrow: "ζώνη"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "χιλιοστό του δευτερολέπτου"
            }
        }
    },
    firstDay: 1,
    weekendRange: {
        start: 6,
        end: 0
    },
    likelySubtags: {
        el: "el-Grek-GR"
    }
});

