/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "et",
    identity: {
        language: "et"
    },
    territory: "EE",
    numbers: {
        symbols: {
            decimal: ",",
            group: " ",
            list: ";",
            percentSign: "%",
            plusSign: "+",
            minusSign: "−",
            approximatelySign: "≈",
            exponential: "×10^",
            superscriptingExponent: "×",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "n%"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-one": "n $",
            "unitPattern-count-other": "n $"
        },
        accounting: {
            patterns: [
                "n $",
                "(n $)"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "Andorra peseeta",
                "displayName-count-one": "Andorra peseeta",
                "displayName-count-other": "Andorra peseetat",
                symbol: "ADP"
            },
            AED: {
                displayName: "Araabia Ühendemiraatide dirhem",
                "displayName-count-one": "Araabia Ühendemiraatide dirhem",
                "displayName-count-other": "Araabia Ühendemiraatide dirhemit",
                symbol: "AED"
            },
            AFA: {
                displayName: "Afganistani afgaani (1927–2002)",
                "displayName-count-one": "Afganistani afgaani (1927–2002)",
                "displayName-count-other": "Afganistani afgaanit (1927–2002)",
                symbol: "AFA"
            },
            AFN: {
                displayName: "Afganistani afgaani",
                "displayName-count-one": "Afganistani afgaani",
                "displayName-count-other": "Afganistani afgaanit",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "Albaania lekk (1946–1965)",
                "displayName-count-one": "Albaania lekk (1946–1965)",
                "displayName-count-other": "Albaania lekki (1946–1965)",
                symbol: "ALK"
            },
            ALL: {
                displayName: "Albaania lekk",
                "displayName-count-one": "Albaania lekk",
                "displayName-count-other": "Albaania lekki",
                symbol: "ALL"
            },
            AMD: {
                displayName: "Armeenia dramm",
                "displayName-count-one": "Armeenia dramm",
                "displayName-count-other": "Armeenia drammi",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "Hollandi Antillide kulden",
                "displayName-count-one": "Hollandi Antillide kulden",
                "displayName-count-other": "Hollandi Antillide kuldnat",
                symbol: "ANG"
            },
            AOA: {
                displayName: "Angola kvanza",
                "displayName-count-one": "Angola kvanza",
                "displayName-count-other": "Angola kvanzat",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "Angola kvanza (1977–1990)",
                "displayName-count-one": "Angola kvanza (1977–1990)",
                "displayName-count-other": "Angola kvanzat (1977–1990)",
                symbol: "AOK"
            },
            AON: {
                displayName: "Angola kvanza (1990–2000)",
                "displayName-count-one": "Angola kvanza (1990–2000)",
                "displayName-count-other": "Angola kvanzat (1990–2000)",
                symbol: "AON"
            },
            AOR: {
                displayName: "Angola reformitud kvanza, 1995–1999",
                symbol: "AOR"
            },
            ARA: {
                displayName: "Argentina austral",
                symbol: "ARA"
            },
            ARL: {
                displayName: "ARL",
                symbol: "ARL"
            },
            ARM: {
                displayName: "Argentina peeso (1881–1970)",
                "displayName-count-one": "Argentina peeso (1881–1970)",
                "displayName-count-other": "Argentina peesot (1881–1970)",
                symbol: "ARM"
            },
            ARP: {
                displayName: "Argentina peeso (1983–1985)",
                "displayName-count-one": "Argentina peeso (1983–1985)",
                "displayName-count-other": "Argentina peesot (1983–1985)",
                symbol: "ARP"
            },
            ARS: {
                displayName: "Argentina peeso",
                "displayName-count-one": "Argentina peeso",
                "displayName-count-other": "Argentina peesot",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "Austria šilling",
                "displayName-count-one": "Austria šilling",
                "displayName-count-other": "Austria šillingit",
                symbol: "ATS"
            },
            AUD: {
                displayName: "Austraalia dollar",
                "displayName-count-one": "Austraalia dollar",
                "displayName-count-other": "Austraalia dollarit",
                symbol: "AU$",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "Aruba kulden",
                "displayName-count-one": "Aruba kulden",
                "displayName-count-other": "Aruba kuldnat",
                symbol: "AWG"
            },
            AZM: {
                displayName: "Aserbaidžaani manat (1993–2006)",
                "displayName-count-one": "Aserbaidžaani manat (1993–2006)",
                "displayName-count-other": "Aserbaidžaani manatit (1993–2006)",
                symbol: "AZM"
            },
            AZN: {
                displayName: "Aserbaidžaani manat",
                "displayName-count-one": "Aserbaidžaani manat",
                "displayName-count-other": "Aserbaidžaani manatit",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "Bosnia ja Hertsegoviina dinaar (1992–1994)",
                "displayName-count-one": "Bosnia ja Hertsegoviina dinaar (1992–1994)",
                "displayName-count-other": "Bosnia ja Hertsegoviina dinaari (1992–1994)",
                symbol: "BAD"
            },
            BAM: {
                displayName: "Bosnia ja Hertsegoviina konverteeritav mark",
                "displayName-count-one": "Bosnia ja Hertsegoviina konverteeritav mark",
                "displayName-count-other": "Bosnia ja Hertsegoviina konverteeritavat marka",
                symbol: "BAM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "Bosnia ja Hertsegoviina uus dinaar (1994–1997)",
                "displayName-count-one": "Bosnia ja Hertsegoviina uus dinaar (1994–1997)",
                "displayName-count-other": "Bosnia ja Hertsegoviina uut dinaari (1994–1997)",
                symbol: "BAN"
            },
            BBD: {
                displayName: "Barbadose dollar",
                "displayName-count-one": "Barbadose dollar",
                "displayName-count-other": "Barbadose dollarit",
                symbol: "BBD",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "Bangladeshi taka",
                "displayName-count-one": "Bangladeshi taka",
                "displayName-count-other": "Bangladeshi takat",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "Belgia konverteeritav frank",
                "displayName-count-one": "Belgia konverteeritav frank",
                "displayName-count-other": "Belgia konverteeritavat franki",
                symbol: "BEC"
            },
            BEF: {
                displayName: "Belgia frank",
                "displayName-count-one": "Belgia frank",
                "displayName-count-other": "Belgia franki",
                symbol: "BEF"
            },
            BEL: {
                displayName: "Belgia arveldusfrank",
                symbol: "BEL"
            },
            BGL: {
                displayName: "Bulgaaria püsiv leev",
                symbol: "BGL"
            },
            BGM: {
                displayName: "BGM",
                symbol: "BGM"
            },
            BGN: {
                displayName: "Bulgaaria leev",
                "displayName-count-one": "Bulgaaria leev",
                "displayName-count-other": "Bulgaaria leevi",
                symbol: "BGN"
            },
            BGO: {
                displayName: "Bulgaaria leev (1879–1952)",
                "displayName-count-one": "Bulgaaria leev (1879–1952)",
                "displayName-count-other": "Bulgaaria leevi (1879–1952)",
                symbol: "BGO"
            },
            BHD: {
                displayName: "Bahreini dinaar",
                "displayName-count-one": "Bahreini dinaar",
                "displayName-count-other": "Bahreini dinaari",
                symbol: "BHD"
            },
            BIF: {
                displayName: "Burundi frank",
                "displayName-count-one": "Burundi frank",
                "displayName-count-other": "Burundi franki",
                symbol: "BIF"
            },
            BMD: {
                displayName: "Bermuda dollar",
                "displayName-count-one": "Bermuda dollar",
                "displayName-count-other": "Bermuda dollarit",
                symbol: "BMD",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "Brunei dollar",
                "displayName-count-one": "Brunei dollar",
                "displayName-count-other": "Brunei dollarit",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "Boliivia boliviaano",
                "displayName-count-one": "Boliivia boliviaano",
                "displayName-count-other": "Boliivia boliviaanot",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "Boliivia boliviaano (1863–1963)",
                "displayName-count-one": "Boliivia boliviaano (1863–1963)",
                "displayName-count-other": "Boliivia boliviaanot (1863–1963)",
                symbol: "BOL"
            },
            BOP: {
                displayName: "Boliivia peeso",
                "displayName-count-one": "Boliivia peeso",
                "displayName-count-other": "Boliivia peesot",
                symbol: "BOP"
            },
            BOV: {
                displayName: "BOV",
                symbol: "BOV"
            },
            BRB: {
                displayName: "Brasiilia uus kruseiro (1967–1986)",
                "displayName-count-one": "Brasiilia uus kruseiro (1967–1986)",
                "displayName-count-other": "Brasiilia uut kruseirot (1967–1986)",
                symbol: "BRB"
            },
            BRC: {
                displayName: "Brasiilia krusado",
                symbol: "BRC"
            },
            BRE: {
                displayName: "Brasiilia kruseiro (1990–1993)",
                "displayName-count-one": "Brasiilia kruseiro (1990–1993)",
                "displayName-count-other": "Brasiilia kruseirot (1990–1993)",
                symbol: "BRE"
            },
            BRL: {
                displayName: "Brasiilia reaal",
                "displayName-count-one": "Brasiilia reaal",
                "displayName-count-other": "Brasiilia reaali",
                symbol: "R$",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "BRN",
                symbol: "BRN"
            },
            BRR: {
                displayName: "Brasiilia kruseiro (1993–1994)",
                "displayName-count-one": "Brasiilia kruseiro (1993–1994)",
                "displayName-count-other": "Brasiilia kruseirot (1993–1994)",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "Brasiilia kruseiro (1942–1967)",
                "displayName-count-one": "Brasiilia kruseiro (1942–1967)",
                "displayName-count-other": "Brasiilia kruseirot (1942–1967)",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "Bahama dollar",
                "displayName-count-one": "Bahama dollar",
                "displayName-count-other": "Bahama dollarit",
                symbol: "BSD",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "Bhutani ngultrum",
                "displayName-count-one": "Bhutani ngultrum",
                "displayName-count-other": "Bhutani ngultrumit",
                symbol: "BTN"
            },
            BUK: {
                displayName: "Birma kjatt",
                "displayName-count-one": "Birma kjatt",
                "displayName-count-other": "Birma kjatti",
                symbol: "BUK"
            },
            BWP: {
                displayName: "Botswana pula",
                "displayName-count-one": "Botswana pula",
                "displayName-count-other": "Botswana pulat",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "Valgevene uus rubla (1994–1999)",
                "displayName-count-one": "Valgevene uus rubla (1994–1999)",
                "displayName-count-other": "Valgevene uut rubla (1994–1999)",
                symbol: "BYB"
            },
            BYN: {
                displayName: "Valgevene rubla",
                "displayName-count-one": "Valgevene rubla",
                "displayName-count-other": "Valgevene rubla",
                symbol: "BYN"
            },
            BYR: {
                displayName: "Valgevene rubla (2000–2016)",
                "displayName-count-one": "Valgevene rubla (2000–2016)",
                "displayName-count-other": "Valgevene rubla (2000–2016)",
                symbol: "BYR"
            },
            BZD: {
                displayName: "Belize’i dollar",
                "displayName-count-one": "Belize’i dollar",
                "displayName-count-other": "Belize’i dollarit",
                symbol: "BZD",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "Kanada dollar",
                "displayName-count-one": "Kanada dollar",
                "displayName-count-other": "Kanada dollarit",
                symbol: "CA$",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "Kongo frank",
                "displayName-count-one": "Kongo frank",
                "displayName-count-other": "Kongo franki",
                symbol: "CDF"
            },
            CHE: {
                displayName: "CHE",
                symbol: "CHE"
            },
            CHF: {
                displayName: "Šveitsi frank",
                "displayName-count-one": "Šveitsi frank",
                "displayName-count-other": "Šveitsi franki",
                symbol: "CHF"
            },
            CHW: {
                displayName: "CHW",
                symbol: "CHW"
            },
            CLE: {
                displayName: "Tšiili eskuudo",
                "displayName-count-one": "Tšiili eskuudo",
                "displayName-count-other": "Tšiili eskuudot",
                symbol: "CLE"
            },
            CLF: {
                displayName: "CLF",
                symbol: "CLF"
            },
            CLP: {
                displayName: "Tšiili peeso",
                "displayName-count-one": "Tšiili peeso",
                "displayName-count-other": "Tšiili peesot",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "Hiina jüaan (välismaine turg)",
                "displayName-count-one": "Hiina jüaan (välismaine turg)",
                "displayName-count-other": "Hiina jüaani (välismaine turg)",
                symbol: "CNH"
            },
            CNX: {
                displayName: "CNX",
                symbol: "CNX"
            },
            CNY: {
                displayName: "Hiina jüaan",
                "displayName-count-one": "Hiina jüaan",
                "displayName-count-other": "Hiina jüaani",
                symbol: "CN¥",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "Colombia peeso",
                "displayName-count-one": "Colombia peeso",
                "displayName-count-other": "Colombia peesot",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "COU",
                symbol: "COU"
            },
            CRC: {
                displayName: "Costa Rica koloon",
                "displayName-count-one": "Costa Rica koloon",
                "displayName-count-other": "Costa Rica kolooni",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "Serbia dinaar (2002–2006)",
                "displayName-count-one": "Serbia dinaar (2002–2006)",
                "displayName-count-other": "Serbia dinaari (2002–2006)",
                symbol: "CSD"
            },
            CSK: {
                displayName: "CSK",
                symbol: "CSK"
            },
            CUC: {
                displayName: "Kuuba konverteeritav peeso",
                "displayName-count-one": "Kuuba konverteeritav peeso",
                "displayName-count-other": "Kuuba konverteeritavat peesot",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "Kuuba peeso",
                "displayName-count-one": "Kuuba peeso",
                "displayName-count-other": "Kuuba peesot",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "Cabo Verde eskuudo",
                "displayName-count-one": "Cabo Verde eskuudo",
                "displayName-count-other": "Cabo Verde eskuudot",
                symbol: "CVE"
            },
            CYP: {
                displayName: "Küprose nael",
                "displayName-count-one": "Küprose nael",
                "displayName-count-other": "Küprose naela",
                symbol: "CYP"
            },
            CZK: {
                displayName: "Tšehhi kroon",
                "displayName-count-one": "Tšehhi kroon",
                "displayName-count-other": "Tšehhi krooni",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "Ida-Saksa mark",
                "displayName-count-one": "Ida-Saksa mark",
                "displayName-count-other": "Ida-Saksa marka",
                symbol: "DDM"
            },
            DEM: {
                displayName: "Saksa mark",
                "displayName-count-one": "Saksa mark",
                "displayName-count-other": "Saksa marka",
                symbol: "DEM"
            },
            DJF: {
                displayName: "Djibouti frank",
                "displayName-count-one": "Djibouti frank",
                "displayName-count-other": "Djibouti franki",
                symbol: "DJF"
            },
            DKK: {
                displayName: "Taani kroon",
                "displayName-count-one": "Taani kroon",
                "displayName-count-other": "Taani krooni",
                symbol: "DKK",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "Dominikaani peeso",
                "displayName-count-one": "Dominikaani peeso",
                "displayName-count-other": "Dominikaani peesot",
                symbol: "DOP",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "Alžeeria dinaar",
                "displayName-count-one": "Alžeeria dinaar",
                "displayName-count-other": "Alžeeria dinaari",
                symbol: "DZD"
            },
            ECS: {
                displayName: "Ecuadori sukre",
                "displayName-count-one": "Ecuadori sukre",
                "displayName-count-other": "Ecuadori sukret",
                symbol: "ECS"
            },
            ECV: {
                displayName: "ECV",
                symbol: "ECV"
            },
            EEK: {
                displayName: "Eesti kroon",
                "displayName-count-one": "Eesti kroon",
                "displayName-count-other": "Eesti krooni",
                symbol: "kr",
                decimal: ".",
                group: " "
            },
            EGP: {
                displayName: "Egiptuse nael",
                "displayName-count-one": "Egiptuse nael",
                "displayName-count-other": "Egiptuse naela",
                symbol: "EGP",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "Eritrea nakfa",
                "displayName-count-one": "Eritrea nakfa",
                "displayName-count-other": "Eritrea nakfat",
                symbol: "ERN"
            },
            ESA: {
                displayName: "ESA",
                symbol: "ESA"
            },
            ESB: {
                displayName: "ESB",
                symbol: "ESB"
            },
            ESP: {
                displayName: "Hispaania peseeta",
                "displayName-count-one": "Hispaania peseeta",
                "displayName-count-other": "Hispaania peseetat",
                symbol: "ESP",
                "symbol-alt-narrow": "₧"
            },
            ETB: {
                displayName: "Etioopia birr",
                "displayName-count-one": "Etioopia birr",
                "displayName-count-other": "Etioopia birri",
                symbol: "ETB"
            },
            EUR: {
                displayName: "euro",
                "displayName-count-one": "euro",
                "displayName-count-other": "eurot",
                symbol: "€",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "Soome mark",
                "displayName-count-one": "Soome mark",
                "displayName-count-other": "Soome marka",
                symbol: "FIM"
            },
            FJD: {
                displayName: "Fidži dollar",
                "displayName-count-one": "Fidži dollar",
                "displayName-count-other": "Fidži dollarit",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "Falklandi saarte nael",
                "displayName-count-one": "Falklandi saarte nael",
                "displayName-count-other": "Falklandi saarte naela",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "Prantsuse frank",
                "displayName-count-one": "Prantsuse frank",
                "displayName-count-other": "Prantsuse franki",
                symbol: "FRF"
            },
            GBP: {
                displayName: "Suurbritannia naelsterling",
                "displayName-count-one": "Suurbritannia naelsterling",
                "displayName-count-other": "Suurbritannia naelsterlingit",
                symbol: "£",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "GEK",
                symbol: "GEK"
            },
            GEL: {
                displayName: "Gruusia lari",
                "displayName-count-one": "Gruusia lari",
                "displayName-count-other": "Gruusia lari",
                symbol: "GEL",
                "symbol-alt-narrow": "₾"
            },
            GHC: {
                displayName: "Ghana sedi (1979–2007)",
                "displayName-count-one": "Ghana sedi (1979–2007)",
                "displayName-count-other": "Ghana sedit (1979–2007)",
                symbol: "GHC"
            },
            GHS: {
                displayName: "Ghana sedi",
                "displayName-count-one": "Ghana sedi",
                "displayName-count-other": "Ghana sedit",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "Gibraltari nael",
                "displayName-count-one": "Gibraltari nael",
                "displayName-count-other": "Gibraltari naela",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "Gambia dalasi",
                "displayName-count-one": "Gambia dalasi",
                "displayName-count-other": "Gambia dalasit",
                symbol: "GMD"
            },
            GNF: {
                displayName: "Guinea frank",
                "displayName-count-one": "Guinea frank",
                "displayName-count-other": "Guinea franki",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "Guinea syli",
                symbol: "GNS"
            },
            GQE: {
                displayName: "GQE",
                symbol: "GQE"
            },
            GRD: {
                displayName: "Kreeka drahm",
                "displayName-count-one": "Kreeka drahm",
                "displayName-count-other": "Kreeka drahmi",
                symbol: "GRD"
            },
            GTQ: {
                displayName: "Guatemala ketsaal",
                "displayName-count-one": "Guatemala ketsaal",
                "displayName-count-other": "Guatemala ketsaali",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "Portugali Guinea eskuudo",
                "displayName-count-one": "Portugali Guinea eskuudo",
                "displayName-count-other": "Portugali Guinea eskuudot",
                symbol: "GWE"
            },
            GWP: {
                displayName: "Guinea-Bissau peeso",
                "displayName-count-one": "Guinea-Bissau peeso",
                "displayName-count-other": "Guinea-Bissau peesot",
                symbol: "GWP"
            },
            GYD: {
                displayName: "Guyana dollar",
                "displayName-count-one": "Guyana dollar",
                "displayName-count-other": "Guyana dollarit",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "Hongkongi dollar",
                "displayName-count-one": "Hongkongi dollar",
                "displayName-count-other": "Hongkongi dollarit",
                symbol: "HK$",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "Hondurase lempiira",
                "displayName-count-one": "Hondurase lempiira",
                "displayName-count-other": "Hondurase lempiirat",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "Horvaatia dinaar",
                "displayName-count-one": "Horvaatia dinaar",
                "displayName-count-other": "Horvaatia dinaari",
                symbol: "HRD"
            },
            HRK: {
                displayName: "Horvaatia kuna",
                "displayName-count-one": "Horvaatia kuna",
                "displayName-count-other": "Horvaatia kuna",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "Haiti gurd",
                "displayName-count-one": "Haiti gurd",
                "displayName-count-other": "Haiti gurdi",
                symbol: "HTG"
            },
            HUF: {
                displayName: "Ungari forint",
                "displayName-count-one": "Ungari forint",
                "displayName-count-other": "Ungari forintit",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "Indoneesia ruupia",
                "displayName-count-one": "Indoneesia ruupia",
                "displayName-count-other": "Indoneesia ruupiat",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "Iiri nael",
                "displayName-count-one": "Iiri nael",
                "displayName-count-other": "Iiri naela",
                symbol: "IEP"
            },
            ILP: {
                displayName: "Iisraeli nael",
                "displayName-count-one": "Iisraeli nael",
                "displayName-count-other": "Iisraeli naela",
                symbol: "ILP"
            },
            ILR: {
                displayName: "Iisraeli seekel (1980–1985)",
                "displayName-count-one": "Iisraeli seekel (1980–1985)",
                "displayName-count-other": "Iisraeli seekelit (1980–1985)",
                symbol: "ILR"
            },
            ILS: {
                displayName: "Iisraeli uus seekel",
                "displayName-count-one": "Iisraeli uus seekel",
                "displayName-count-other": "Iisraeli uut seeklit",
                symbol: "₪",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "India ruupia",
                "displayName-count-one": "India ruupia",
                "displayName-count-other": "India ruupiat",
                symbol: "₹",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "Iraagi dinaar",
                "displayName-count-one": "Iraagi dinaar",
                "displayName-count-other": "Iraagi dinaari",
                symbol: "IQD"
            },
            IRR: {
                displayName: "Iraani riaal",
                "displayName-count-one": "Iraani riaal",
                "displayName-count-other": "Iraani riaali",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "Islandi kroon (1918–1981)",
                "displayName-count-one": "Islandi kroon (1918–1981)",
                "displayName-count-other": "Islandi krooni (1918–1981)",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "Islandi kroon",
                "displayName-count-one": "Islandi kroon",
                "displayName-count-other": "Islandi krooni",
                symbol: "ISK",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "Itaalia liir",
                "displayName-count-one": "Itaalia liir",
                "displayName-count-other": "Itaalia liiri",
                symbol: "ITL"
            },
            JMD: {
                displayName: "Jamaica dollar",
                "displayName-count-one": "Jamaica dollar",
                "displayName-count-other": "Jamaica dollarit",
                symbol: "JMD",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "Jordaania dinaar",
                "displayName-count-one": "Jordaania dinaar",
                "displayName-count-other": "Jordaania dinaari",
                symbol: "JOD"
            },
            JPY: {
                displayName: "Jaapani jeen",
                "displayName-count-one": "Jaapani jeen",
                "displayName-count-other": "Jaapani jeeni",
                symbol: "¥",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "Keenia šilling",
                "displayName-count-one": "Keenia šilling",
                "displayName-count-other": "Keenia šillingit",
                symbol: "KES"
            },
            KGS: {
                displayName: "Kõrgõzstani somm",
                "displayName-count-one": "Kõrgõzstani somm",
                "displayName-count-other": "Kõrgõzstani sommi",
                symbol: "KGS"
            },
            KHR: {
                displayName: "Kambodža riaal",
                "displayName-count-one": "Kambodža riaal",
                "displayName-count-other": "Kambodža riaali",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "Komoori frank",
                "displayName-count-one": "Komoori frank",
                "displayName-count-other": "Komoori franki",
                symbol: "KMF",
                "symbol-alt-narrow": "CF"
            },
            KPW: {
                displayName: "Põhja-Korea vonn",
                "displayName-count-one": "Põhja-Korea vonn",
                "displayName-count-other": "Põhja-Korea vonni",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "KRH",
                symbol: "KRH"
            },
            KRO: {
                displayName: "Lõuna-Korea vonn (1945–1953)",
                "displayName-count-one": "Lõuna-Korea vonn (1945–1953)",
                "displayName-count-other": "Lõuna-Korea vonni (1945–1953)",
                symbol: "KRO"
            },
            KRW: {
                displayName: "Lõuna-Korea vonn",
                "displayName-count-one": "Lõuna-Korea vonn",
                "displayName-count-other": "Lõuna-Korea vonni",
                symbol: "₩",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "Kuveidi dinaar",
                "displayName-count-one": "Kuveidi dinaar",
                "displayName-count-other": "Kuveidi dinaari",
                symbol: "KWD"
            },
            KYD: {
                displayName: "Kaimanisaarte dollar",
                "displayName-count-one": "Kaimanisaarte dollar",
                "displayName-count-other": "Kaimanisaarte dollarit",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "Kasahstani tenge",
                "displayName-count-one": "Kasahstani tenge",
                "displayName-count-other": "Kasahstani tenget",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "Laose kiip",
                "displayName-count-one": "Laose kiip",
                "displayName-count-other": "Laose kiipi",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "Liibanoni nael",
                "displayName-count-one": "Liibanoni nael",
                "displayName-count-other": "Liibanoni naela",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "Sri Lanka ruupia",
                "displayName-count-one": "Sri Lanka ruupia",
                "displayName-count-other": "Sri Lanka ruupiat",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "Libeeria dollar",
                "displayName-count-one": "Libeeria dollar",
                "displayName-count-other": "Libeeria dollarit",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "Lesotho loti",
                "displayName-count-one": "Lesotho loti",
                "displayName-count-other": "Lesotho lotit",
                symbol: "LSL"
            },
            LTL: {
                displayName: "Leedu litt",
                "displayName-count-one": "Leedu litt",
                "displayName-count-other": "Leedu litti",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "LTT",
                symbol: "LTT"
            },
            LUC: {
                displayName: "Luksemburgi konverteeritav frank",
                "displayName-count-one": "Luksemburgi konverteeritav frank",
                "displayName-count-other": "Luksemburgi konverteeritavat franki",
                symbol: "LUC"
            },
            LUF: {
                displayName: "Luksemburgi frank",
                "displayName-count-one": "Luksemburgi frank",
                "displayName-count-other": "Luksemburgi franki",
                symbol: "LUF"
            },
            LUL: {
                displayName: "LUL",
                symbol: "LUL"
            },
            LVL: {
                displayName: "Läti latt",
                "displayName-count-one": "Läti latt",
                "displayName-count-other": "Läti latti",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "Läti rubla",
                "displayName-count-one": "Läti rubla",
                "displayName-count-other": "Läti rubla",
                symbol: "LVR"
            },
            LYD: {
                displayName: "Liibüa dinaar",
                "displayName-count-one": "Liibüa dinaar",
                "displayName-count-other": "Liibüa dinaari",
                symbol: "LYD"
            },
            MAD: {
                displayName: "Maroko dirhem",
                "displayName-count-one": "Maroko dirhem",
                "displayName-count-other": "Maroko dirhemit",
                symbol: "MAD"
            },
            MAF: {
                displayName: "Maroko frank",
                "displayName-count-one": "Maroko frank",
                "displayName-count-other": "Maroko franki",
                symbol: "MAF"
            },
            MCF: {
                displayName: "Monaco frank",
                "displayName-count-one": "Monaco frank",
                "displayName-count-other": "Monaco franki",
                symbol: "MCF"
            },
            MDC: {
                displayName: "MDC",
                symbol: "MDC"
            },
            MDL: {
                displayName: "Moldova leu",
                "displayName-count-one": "Moldova leu",
                "displayName-count-other": "Moldova leud",
                symbol: "MDL"
            },
            MGA: {
                displayName: "Madagaskari ariari",
                "displayName-count-one": "Madagaskari ariari",
                "displayName-count-other": "Madagaskari ariarit",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "Madagaskari frank",
                "displayName-count-one": "Madagaskari frank",
                "displayName-count-other": "Madagaskar franki",
                symbol: "MGF"
            },
            MKD: {
                displayName: "Makedoonia dinaar",
                "displayName-count-one": "Makedoonia dinaar",
                "displayName-count-other": "Makedoonia dinaari",
                symbol: "MKD"
            },
            MKN: {
                displayName: "Makedoonia dinaar (1992–1993)",
                "displayName-count-one": "Makedoonia dinaar (1992–1993)",
                "displayName-count-other": "Makedoonia dinaari (1992–1993)",
                symbol: "MKN"
            },
            MLF: {
                displayName: "Mali frank",
                "displayName-count-one": "Mali frank",
                "displayName-count-other": "Mali franki",
                symbol: "MLF"
            },
            MMK: {
                displayName: "Myanmari kjatt",
                "displayName-count-one": "Myanmari kjatt",
                "displayName-count-other": "Myanmari kjatti",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "Mongoolia tugrik",
                "displayName-count-one": "Mongoolia tugrik",
                "displayName-count-other": "Mongoolia tugrikut",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "Macau pataaka",
                "displayName-count-one": "Macau pataaka",
                "displayName-count-other": "Macau pataakat",
                symbol: "MOP"
            },
            MRO: {
                displayName: "Mauritaania ugia (1973–2017)",
                "displayName-count-one": "Mauritaania ugia (1973–2017)",
                "displayName-count-other": "Mauritaania ugiat (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "Mauritaania ugia",
                "displayName-count-one": "Mauritaania ugia",
                "displayName-count-other": "Mauritaania ugiat",
                symbol: "MRU"
            },
            MTL: {
                displayName: "Malta liir",
                "displayName-count-one": "Malta liir",
                "displayName-count-other": "Malta liiri",
                symbol: "MTL"
            },
            MTP: {
                displayName: "Malta nael",
                "displayName-count-one": "Malta nael",
                "displayName-count-other": "Malta naela",
                symbol: "MTP"
            },
            MUR: {
                displayName: "Mauritiuse ruupia",
                "displayName-count-one": "Mauritiuse ruupia",
                "displayName-count-other": "Mauritiuse ruupiat",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "Maldiivi ruupia (1947–1981)",
                "displayName-count-one": "Maldiivi ruupia (1947–1981)",
                "displayName-count-other": "Maldiivi ruupiat (1947–1981)",
                symbol: "MVP"
            },
            MVR: {
                displayName: "Maldiivi ruupia",
                "displayName-count-one": "Maldiivi ruupia",
                "displayName-count-other": "Maldiivi ruupiat",
                symbol: "MVR"
            },
            MWK: {
                displayName: "Malawi kvatša",
                "displayName-count-one": "Malawi kvatša",
                "displayName-count-other": "Malawi kvatšat",
                symbol: "MWK"
            },
            MXN: {
                displayName: "Mehhiko peeso",
                "displayName-count-one": "Mehhiko peeso",
                "displayName-count-other": "Mehhiko peesot",
                symbol: "MX$",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "Mehhiko peeso (1861–1992)",
                "displayName-count-one": "Mehhiko peeso (1861–1992)",
                "displayName-count-other": "Mehhiko peesot (1861–1992)",
                symbol: "MXP"
            },
            MXV: {
                displayName: "MXV",
                symbol: "MXV"
            },
            MYR: {
                displayName: "Malaisia ringgit",
                "displayName-count-one": "Malaisia ringgit",
                "displayName-count-other": "Malaisia ringgitit",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "Mosambiigi eskuudo",
                "displayName-count-one": "Mosambiigi eskuudo",
                "displayName-count-other": "Mosambiigi eskuudot",
                symbol: "MZE"
            },
            MZM: {
                displayName: "Mosambiigi metikal (1980–2006)",
                "displayName-count-one": "Mosambiigi metikal (1980–2006)",
                "displayName-count-other": "Mosambiigi metikali (1980–2006)",
                symbol: "MZM"
            },
            MZN: {
                displayName: "Mosambiigi metikal",
                "displayName-count-one": "Mosambiigi metikal",
                "displayName-count-other": "Mosambiigi metikali",
                symbol: "MZN"
            },
            NAD: {
                displayName: "Namiibia dollar",
                "displayName-count-one": "Namiibia dollar",
                "displayName-count-other": "Namiibia dollarit",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "Nigeeria naira",
                "displayName-count-one": "Nigeeria naira",
                "displayName-count-other": "Nigeeria nairat",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "Nicaragua kordoba (1988–1991)",
                "displayName-count-one": "Nicaragua kordoba (1988–1991)",
                "displayName-count-other": "Nicaragua kordobat (1988–1991)",
                symbol: "NIC"
            },
            NIO: {
                displayName: "Nicaragua kordoba",
                "displayName-count-one": "Nicaragua kordoba",
                "displayName-count-other": "Nicaragua kordobat",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "Hollandi kulden",
                "displayName-count-one": "Hollandi kulden",
                "displayName-count-other": "Hollandi kuldnat",
                symbol: "NLG"
            },
            NOK: {
                displayName: "Norra kroon",
                "displayName-count-one": "Norra kroon",
                "displayName-count-other": "Norra krooni",
                symbol: "NOK",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "Nepali ruupia",
                "displayName-count-one": "Nepali ruupia",
                "displayName-count-other": "Nepali ruupiat",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "Uus-Meremaa dollar",
                "displayName-count-one": "Uus-Meremaa dollar",
                "displayName-count-other": "Uus-Meremaa dollarit",
                symbol: "NZ$",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "Omaani riaal",
                "displayName-count-one": "Omaani riaal",
                "displayName-count-other": "Omaani riaali",
                symbol: "OMR"
            },
            PAB: {
                displayName: "Panama balboa",
                "displayName-count-one": "Panama balboa",
                "displayName-count-other": "Panama balboad",
                symbol: "PAB"
            },
            PEI: {
                displayName: "Peruu inti",
                symbol: "PEI"
            },
            PEN: {
                displayName: "Peruu soll",
                "displayName-count-one": "Peruu soll",
                "displayName-count-other": "Peruu solli",
                symbol: "PEN"
            },
            PES: {
                displayName: "Peruu soll (1863–1965)",
                "displayName-count-one": "Peruu soll (1863–1965)",
                "displayName-count-other": "Peruu solli (1863–1965)",
                symbol: "PES"
            },
            PGK: {
                displayName: "Paapua Uus-Guinea kina",
                "displayName-count-one": "Paapua Uus-Guinea kina",
                "displayName-count-other": "Paapua Uus-Guinea kinat",
                symbol: "PGK"
            },
            PHP: {
                displayName: "Filipiini peeso",
                "displayName-count-one": "Filipiini peeso",
                "displayName-count-other": "Filipiini peesot",
                symbol: "PHP",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "Pakistani ruupia",
                "displayName-count-one": "Pakistani ruupia",
                "displayName-count-other": "Pakistani ruupiat",
                symbol: "PKR",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "Poola zlott",
                "displayName-count-one": "Poola zlott",
                "displayName-count-other": "Poola zlotti",
                symbol: "PLN",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "Poola zlott (1950–1995)",
                "displayName-count-one": "Poola zlott (1950–1995)",
                "displayName-count-other": "Poola zlotti (1950–1995)",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "Portugali eskuudo",
                "displayName-count-one": "Portugali eskuudo",
                "displayName-count-other": "Portugali eskuudot",
                symbol: "PTE"
            },
            PYG: {
                displayName: "Paraguay guaranii",
                "displayName-count-one": "Paraguay guaranii",
                "displayName-count-other": "Paraguay guaraniid",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "Katari riaal",
                "displayName-count-one": "Katari riaal",
                "displayName-count-other": "Katari riaali",
                symbol: "QAR"
            },
            RHD: {
                displayName: "Rodeesia dollar",
                "displayName-count-one": "Rodeesia dollar",
                "displayName-count-other": "Rodeesia dollarit",
                symbol: "RHD"
            },
            ROL: {
                displayName: "Rumeenia leu (1952–2006)",
                "displayName-count-one": "Rumeenia leu (1952–2006)",
                "displayName-count-other": "Rumeenia leud (1952–2006)",
                symbol: "ROL"
            },
            RON: {
                displayName: "Rumeenia leu",
                "displayName-count-one": "Rumeenia leu",
                "displayName-count-other": "Rumeenia leud",
                symbol: "RON",
                "symbol-alt-narrow": "lei"
            },
            RSD: {
                displayName: "Serbia dinaar",
                "displayName-count-one": "Serbia dinaar",
                "displayName-count-other": "Serbia dinaari",
                symbol: "RSD"
            },
            RUB: {
                displayName: "Venemaa rubla",
                "displayName-count-one": "Venemaa rubla",
                "displayName-count-other": "Venemaa rubla",
                symbol: "RUB",
                "symbol-alt-narrow": "₽"
            },
            RUR: {
                displayName: "Venemaa rubla (1991–1998)",
                symbol: "RUR"
            },
            RWF: {
                displayName: "Rwanda frank",
                "displayName-count-one": "Rwanda frank",
                "displayName-count-other": "Rwanda franki",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "Saudi Araabia riaal",
                "displayName-count-one": "Saudi Araabia riaal",
                "displayName-count-other": "Saudi Araabia riaali",
                symbol: "SAR"
            },
            SBD: {
                displayName: "Saalomoni Saarte dollar",
                "displayName-count-one": "Saalomoni Saarte dollar",
                "displayName-count-other": "Saalomoni Saarte dollarit",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "Seišelli ruupia",
                "displayName-count-one": "Seišelli ruupia",
                "displayName-count-other": "Seišelli ruupiat",
                symbol: "SCR"
            },
            SDD: {
                displayName: "Sudaani dinaar (1992–2007)",
                "displayName-count-one": "Sudaani dinaar (1992–2007)",
                "displayName-count-other": "Sudaani dinaari (1992–2007)",
                symbol: "SDD"
            },
            SDG: {
                displayName: "Sudaani nael",
                "displayName-count-one": "Sudaani nael",
                "displayName-count-other": "Sudaani naela",
                symbol: "SDG"
            },
            SDP: {
                displayName: "Sudaani nael (1957–1998)",
                "displayName-count-one": "Sudaani nael (1957–1998)",
                "displayName-count-other": "Sudaani naela (1957–1998)",
                symbol: "SDP"
            },
            SEK: {
                displayName: "Rootsi kroon",
                "displayName-count-one": "Rootsi kroon",
                "displayName-count-other": "Rootsi krooni",
                symbol: "SEK",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "Singapuri dollar",
                "displayName-count-one": "Singapuri dollar",
                "displayName-count-other": "Singapuri dollarit",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "Saint Helena nael",
                "displayName-count-one": "Saint Helena nael",
                "displayName-count-other": "Saint Helena naela",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "Sloveenia tolar",
                "displayName-count-one": "Sloveenia tolar",
                "displayName-count-other": "Sloveenia tolarit",
                symbol: "SIT"
            },
            SKK: {
                displayName: "Slovaki kroon",
                "displayName-count-one": "Slovaki kroon",
                "displayName-count-other": "Slovaki krooni",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "Sierra Leone leoone",
                "displayName-count-one": "Sierra Leone leoone",
                "displayName-count-other": "Sierra Leone leoonet",
                symbol: "SLL"
            },
            SOS: {
                displayName: "Somaalia šilling",
                "displayName-count-one": "Somaalia šilling",
                "displayName-count-other": "Somaalia šillingit",
                symbol: "SOS"
            },
            SRD: {
                displayName: "Suriname dollar",
                "displayName-count-one": "Suriname dollar",
                "displayName-count-other": "Suriname dollarit",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "Suriname kulden",
                "displayName-count-one": "Suriname kulden",
                "displayName-count-other": "Suriname kuldnat",
                symbol: "SRG"
            },
            SSP: {
                displayName: "Lõuna-Sudaani nael",
                "displayName-count-one": "Lõuna-Sudaani nael",
                "displayName-count-other": "Lõuna-Sudaani naela",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "São Tomé ja Príncipe dobra (1977–2017)",
                "displayName-count-one": "São Tomé ja Príncipe dobra (1977–2017)",
                "displayName-count-other": "São Tomé ja Príncipe dobrat (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "São Tomé ja Príncipe dobra",
                "displayName-count-one": "São Tomé ja Príncipe dobra",
                "displayName-count-other": "São Tomé ja Príncipe dobrat",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "NSVL-i rubla",
                symbol: "SUR"
            },
            SVC: {
                displayName: "El Salvadori koloon",
                "displayName-count-one": "El Salvadori koloon",
                "displayName-count-other": "El Salvadori kolooni",
                symbol: "SVC"
            },
            SYP: {
                displayName: "Süüria nael",
                "displayName-count-one": "Süüria nael",
                "displayName-count-other": "Süüria naela",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "Svaasimaa lilangeni",
                "displayName-count-one": "Svaasimaa lilangeni",
                "displayName-count-other": "Svaasimaa lilangenit",
                symbol: "SZL"
            },
            THB: {
                displayName: "Tai baat",
                "displayName-count-one": "Tai baat",
                "displayName-count-other": "Tai baati",
                symbol: "฿",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "Tadžikistani rubla",
                "displayName-count-one": "Tadžikistani rubla",
                "displayName-count-other": "Tadžikistani rubla",
                symbol: "TJR"
            },
            TJS: {
                displayName: "Tadžikistani somoni",
                "displayName-count-one": "Tadžikistani somoni",
                "displayName-count-other": "Tadžikistani somonit",
                symbol: "TJS"
            },
            TMM: {
                displayName: "Türkmenistani manat (1993–2009)",
                "displayName-count-one": "Türkmenistani manat (1993–2009)",
                "displayName-count-other": "Türkmenistani manatit (1993–2009)",
                symbol: "TMM"
            },
            TMT: {
                displayName: "Türkmenistani manat",
                "displayName-count-one": "Türkmenistani manat",
                "displayName-count-other": "Türkmenistani manatit",
                symbol: "TMT"
            },
            TND: {
                displayName: "Tuneesia dinaar",
                "displayName-count-one": "Tuneesia dinaar",
                "displayName-count-other": "Tuneesia dinaari",
                symbol: "TND"
            },
            TOP: {
                displayName: "Tonga pa’anga",
                "displayName-count-one": "Tonga pa’anga",
                "displayName-count-other": "Tonga pa’angat",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "Timori eskuudo",
                "displayName-count-one": "Timori eskuudo",
                "displayName-count-other": "Timori eskuudot",
                symbol: "TPE"
            },
            TRL: {
                displayName: "Türgi liir (1922–2005)",
                "displayName-count-one": "Türgi liir (1922–2005)",
                "displayName-count-other": "Türgi liiri (1922–2005)",
                symbol: "TRL"
            },
            TRY: {
                displayName: "Türgi liir",
                "displayName-count-one": "Türgi liir",
                "displayName-count-other": "Türgi liiri",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "Trinidadi ja Tobago dollar",
                "displayName-count-one": "Trinidadi ja Tobago dollar",
                "displayName-count-other": "Trinidadi ja Tobago dollarit",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "uus Taiwani dollar",
                "displayName-count-one": "uus Taiwani dollar",
                "displayName-count-other": "uut Taiwani dollarit",
                symbol: "NT$",
                "symbol-alt-narrow": "NT$"
            },
            TZS: {
                displayName: "Tansaania šilling",
                "displayName-count-one": "Tansaania šilling",
                "displayName-count-other": "Tansaania šillingit",
                symbol: "TZS"
            },
            UAH: {
                displayName: "Ukraina grivna",
                "displayName-count-one": "Ukraina grivna",
                "displayName-count-other": "Ukraina grivnat",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "Ukraina karbovanets",
                symbol: "UAK"
            },
            UGS: {
                displayName: "Uganda šilling (1966–1987)",
                "displayName-count-one": "Uganda šilling (1966–1987)",
                "displayName-count-other": "Uganda šillingit (1966–1987)",
                symbol: "UGS"
            },
            UGX: {
                displayName: "Uganda šilling",
                "displayName-count-one": "Uganda šilling",
                "displayName-count-other": "Uganda šillingit",
                symbol: "UGX"
            },
            USD: {
                displayName: "USA dollar",
                "displayName-count-one": "USA dollar",
                "displayName-count-other": "USA dollarit",
                symbol: "$",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "USA järgmise päeva dollar",
                symbol: "USN"
            },
            USS: {
                displayName: "USA sama päeva dollar",
                symbol: "USS"
            },
            UYI: {
                displayName: "UYI",
                symbol: "UYI"
            },
            UYP: {
                displayName: "Uruguay peeso (1975–1993)",
                "displayName-count-one": "Uruguay peeso (1975–1993)",
                "displayName-count-other": "Uruguay peesot (1975–1993)",
                symbol: "UYP"
            },
            UYU: {
                displayName: "Uruguay peeso",
                "displayName-count-one": "Uruguay peeso",
                "displayName-count-other": "Uruguay peesot",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "UYW",
                symbol: "UYW"
            },
            UZS: {
                displayName: "Usbekistani somm",
                "displayName-count-one": "Usbekistani somm",
                "displayName-count-other": "Usbekistani sommi",
                symbol: "UZS"
            },
            VEB: {
                displayName: "Venezuela boliivar (1871–2008)",
                "displayName-count-one": "Venezuela boliivar (1871–2008)",
                "displayName-count-other": "Venezuela boliivarit (1871–2008)",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "Venezuela boliivar (2008–2018)",
                "displayName-count-one": "Venezuela boliivar (2008–2018)",
                "displayName-count-other": "Venezuela boliivarit (2008–2018)",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs"
            },
            VES: {
                displayName: "Venezuela boliivar",
                "displayName-count-one": "Venezuela boliivar",
                "displayName-count-other": "Venezuela boliivarit",
                symbol: "VES"
            },
            VND: {
                displayName: "Vietnami dong",
                "displayName-count-one": "Vietnami dong",
                "displayName-count-other": "Vietnami dongi",
                symbol: "₫",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "Vietnami dong (1978–1985)",
                "displayName-count-one": "Vietnami dong (1978–1985)",
                "displayName-count-other": "Vietnami dongi (1978–1985)",
                symbol: "VNN"
            },
            VUV: {
                displayName: "Vanuatu vatu",
                "displayName-count-one": "Vanuatu vatu",
                "displayName-count-other": "Vanuatu vatut",
                symbol: "VUV"
            },
            WST: {
                displayName: "Samoa taala",
                "displayName-count-one": "Samoa taala",
                "displayName-count-other": "Samoa taalat",
                symbol: "WST"
            },
            XAF: {
                displayName: "Kesk-Aafrika CFA frank",
                "displayName-count-one": "Kesk-Aafrika CFA frank",
                "displayName-count-other": "Kesk-Aafrika CFA franki",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "hõbe",
                "displayName-count-one": "troiunts hõbedat",
                "displayName-count-other": "troiuntsi hõbedat",
                symbol: "XAG"
            },
            XAU: {
                displayName: "kuld",
                "displayName-count-one": "troiunts kulda",
                "displayName-count-other": "troiuntsi kulda",
                symbol: "XAU"
            },
            XBA: {
                displayName: "EURCO",
                symbol: "XBA"
            },
            XBB: {
                displayName: "Euroopa rahaühik",
                symbol: "XBB"
            },
            XBC: {
                displayName: "Euroopa rahaline arvestusühik (XBC)",
                symbol: "XBC"
            },
            XBD: {
                displayName: "Euroopa rahaline arvestusühik (XBD)",
                symbol: "XBD"
            },
            XCD: {
                displayName: "Ida-Kariibi dollar",
                "displayName-count-one": "Ida-Kariibi dollar",
                "displayName-count-other": "Ida-Kariibi dollarit",
                symbol: "EC$",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "Rahvusvahelise Valuutafondi arvestusühik",
                symbol: "XDR"
            },
            XEU: {
                displayName: "eküü",
                "displayName-count-one": "eküü",
                "displayName-count-other": "eküüd",
                symbol: "XEU"
            },
            XFO: {
                displayName: "Prantsuse kuldfrank",
                "displayName-count-one": "Prantsuse kuldfrank",
                "displayName-count-other": "Prantsuse kuldfranki",
                symbol: "XFO"
            },
            XFU: {
                displayName: "Prantsuse UIC-frank",
                symbol: "XFU"
            },
            XOF: {
                displayName: "Lääne-Aafrika CFA frank",
                "displayName-count-one": "Lääne-Aafrika CFA frank",
                "displayName-count-other": "Lääne-Aafrika CFA franki",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "pallaadium",
                "displayName-count-one": "troiunts pallaadiumit",
                "displayName-count-other": "troiuntsi pallaadiumit",
                symbol: "XPD"
            },
            XPF: {
                displayName: "CFP frank",
                "displayName-count-one": "CFP frank",
                "displayName-count-other": "CFP franki",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "plaatina",
                "displayName-count-one": "troiunts plaatinat",
                "displayName-count-other": "troiuntsi plaatinat",
                symbol: "XPT"
            },
            XRE: {
                displayName: "XRE",
                symbol: "XRE"
            },
            XSU: {
                displayName: "XSU",
                symbol: "XSU"
            },
            XTS: {
                displayName: "vääringute testkood",
                symbol: "XTS"
            },
            XUA: {
                displayName: "XUA",
                symbol: "XUA"
            },
            XXX: {
                displayName: "määramata rahaühik",
                "displayName-count-one": "(määramata rahaühik)",
                "displayName-count-other": "(määramata rahaühikut)",
                symbol: "¤"
            },
            YDD: {
                displayName: "Jeemeni dinaar",
                "displayName-count-one": "Jeemeni dinaar",
                "displayName-count-other": "Jeemeni dinaari",
                symbol: "YDD"
            },
            YER: {
                displayName: "Jeemeni riaal",
                "displayName-count-one": "Jeemeni riaal",
                "displayName-count-other": "Jeemeni riaali",
                symbol: "YER"
            },
            YUD: {
                displayName: "YUD",
                symbol: "YUD"
            },
            YUM: {
                displayName: "Jugoslaavia uus dinaar (1994–2002)",
                "displayName-count-one": "Jugoslaavia uus dinaar (1994–2002)",
                "displayName-count-other": "Jugoslaavia uut dinaari (1994–2002)",
                symbol: "YUM"
            },
            YUN: {
                displayName: "Jugoslaavia konverteeritav dinaar (1990–1992)",
                "displayName-count-one": "Jugoslaavia konverteeritav dinaar (1990–1992)",
                "displayName-count-other": "Jugoslaavia konverteeritavat dinaari (1990–1992)",
                symbol: "YUN"
            },
            YUR: {
                displayName: "YUR",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "ZAL",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "Lõuna-Aafrika rand",
                "displayName-count-one": "Lõuna-Aafrika rand",
                "displayName-count-other": "Lõuna-Aafrika randi",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "Sambia kvatša (1968–2012)",
                "displayName-count-one": "Sambia kvatša (1968–2012)",
                "displayName-count-other": "Sambia kvatšat (1968–2012)",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "Sambia kvatša",
                "displayName-count-one": "Sambia kvatša",
                "displayName-count-other": "Sambia kvatšat",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "ZRN",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "Sairi zaire",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "Zimbabwe dollar (1980–2008)",
                "displayName-count-one": "Zimbabwe dollar (1980–2008)",
                "displayName-count-other": "Zimbabwe dollarit (1980–2008)",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "Zimbabwe dollar (2009)",
                "displayName-count-one": "Zimbabwe dollar (2009)",
                "displayName-count-other": "Zimbabwe dollarit (2009)",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "Zimbabwe dollar (2008)",
                "displayName-count-one": "Zimbabwe dollar (2008)",
                "displayName-count-other": "Zimbabwe dollarit (2008)",
                symbol: "ZWR"
            }
        },
        localeCurrency: "EUR"
    },
    calendar: {
        patterns: {
            d: "dd.MM.y",
            D: "EEEE, d. MMMM y",
            m: "d. MMM",
            M: "d. MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d. MMMM y HH:mm:ss",
            g: "d.M.y HH:mm",
            G: "d.M.y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E, d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "d.MM.y GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "d. MMM y G",
                GyMMMEd: "E, d. MMMM y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "M",
                Md: "d.M",
                MEd: "E, d.M",
                MMM: "MMMM",
                MMMd: "d. MMM",
                MMMEd: "E, d. MMM",
                MMMMd: "d. MMMM",
                MMMMEd: "E, d. MMMM",
                "MMMMW-count-one": "MMMM (W. 'nädal')",
                "MMMMW-count-other": "MMMM (W. 'nädal')",
                mmss: "mm:ss",
                ms: "mm:ss",
                y: "y",
                yM: "M.y",
                yMd: "d.M.y",
                yMEd: "E, d.M.y",
                yMMM: "MMM y",
                yMMMd: "d. MMM y",
                yMMMEd: "E, d. MMMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "w. 'nädal' (Y)",
                "yw-count-other": "w. 'nädal' (Y)"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d. MMMM y",
            long: "d. MMMM y",
            medium: "d. MMM y",
            short: "dd.MM.yy"
        },
        days: {
            format: {
                abbreviated: [
                    "P",
                    "E",
                    "T",
                    "K",
                    "N",
                    "R",
                    "L"
                ],
                narrow: [
                    "P",
                    "E",
                    "T",
                    "K",
                    "N",
                    "R",
                    "L"
                ],
                short: [
                    "P",
                    "E",
                    "T",
                    "K",
                    "N",
                    "R",
                    "L"
                ],
                wide: [
                    "Pühapäev",
                    "Esmaspäev",
                    "Teisipäev",
                    "Kolmapäev",
                    "Neljapäev",
                    "Reede",
                    "Laupäev"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "P",
                    "E",
                    "T",
                    "K",
                    "N",
                    "R",
                    "L"
                ],
                narrow: [
                    "P",
                    "E",
                    "T",
                    "K",
                    "N",
                    "R",
                    "L"
                ],
                short: [
                    "P",
                    "E",
                    "T",
                    "K",
                    "N",
                    "R",
                    "L"
                ],
                wide: [
                    "Pühapäev",
                    "Esmaspäev",
                    "Teisipäev",
                    "Kolmapäev",
                    "Neljapäev",
                    "Reede",
                    "Laupäev"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "jaan",
                    "veebr",
                    "märts",
                    "apr",
                    "mai",
                    "juuni",
                    "juuli",
                    "aug",
                    "sept",
                    "okt",
                    "nov",
                    "dets"
                ],
                narrow: [
                    "J",
                    "V",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "jaanuar",
                    "veebruar",
                    "märts",
                    "aprill",
                    "mai",
                    "juuni",
                    "juuli",
                    "august",
                    "september",
                    "oktoober",
                    "november",
                    "detsember"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "jaan",
                    "veebr",
                    "märts",
                    "apr",
                    "mai",
                    "juuni",
                    "juuli",
                    "aug",
                    "sept",
                    "okt",
                    "nov",
                    "dets"
                ],
                narrow: [
                    "J",
                    "V",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "jaanuar",
                    "veebruar",
                    "märts",
                    "aprill",
                    "mai",
                    "juuni",
                    "juuli",
                    "august",
                    "september",
                    "oktoober",
                    "november",
                    "detsember"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. kvartal",
                    "2. kvartal",
                    "3. kvartal",
                    "4. kvartal"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1.",
                    "2.",
                    "3.",
                    "4."
                ],
                wide: [
                    "1. kvartal",
                    "2. kvartal",
                    "3. kvartal",
                    "4. kvartal"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "keskööl",
                    am: "AM",
                    noon: "keskpäeval",
                    pm: "PM",
                    morning1: "hommikul",
                    afternoon1: "pärastlõunal",
                    evening1: "õhtul",
                    night1: "öösel"
                },
                narrow: {
                    midnight: "keskööl",
                    am: "AM",
                    noon: "keskpäeval",
                    pm: "PM",
                    morning1: "hommikul",
                    afternoon1: "pärastlõunal",
                    evening1: "õhtul",
                    night1: "öösel"
                },
                wide: {
                    midnight: "keskööl",
                    am: "AM",
                    noon: "keskpäeval",
                    pm: "PM",
                    morning1: "hommikul",
                    afternoon1: "pärastlõunal",
                    evening1: "õhtul",
                    night1: "öösel"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "kesköö",
                    am: "AM",
                    noon: "keskpäev",
                    pm: "PM",
                    morning1: "hommik",
                    afternoon1: "pärastlõuna",
                    evening1: "õhtu",
                    night1: "öö"
                },
                narrow: {
                    midnight: "kesköö",
                    am: "AM",
                    noon: "keskpäev",
                    pm: "PM",
                    morning1: "hommik",
                    afternoon1: "pärastlõuna",
                    evening1: "õhtu",
                    night1: "öö"
                },
                wide: {
                    midnight: "kesköö",
                    am: "AM",
                    noon: "keskpäev",
                    pm: "PM",
                    morning1: "hommik",
                    afternoon1: "pärastlõuna",
                    evening1: "õhtu",
                    night1: "öö"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "enne Kristust",
                    "1": "pärast Kristust",
                    "0-alt-variant": "enne meie ajaarvamist",
                    "1-alt-variant": "meie ajaarvamise järgi"
                },
                abbreviated: {
                    "0": "eKr",
                    "1": "pKr",
                    "0-alt-variant": "e.m.a",
                    "1-alt-variant": "m.a.j"
                },
                narrow: {
                    "0": "eKr",
                    "1": "pKr",
                    "0-alt-variant": "e.m.a",
                    "1-alt-variant": "m.a.j"
                }
            }
        },
        gmtFormat: "GMT {0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "ajastu",
                short: "ajastu",
                narrow: "ajastu"
            },
            year: {
                wide: "aasta",
                short: "a",
                narrow: "a"
            },
            quarter: {
                wide: "kvartal",
                short: "kv",
                narrow: "kv"
            },
            month: {
                wide: "kuu",
                short: "k",
                narrow: "k"
            },
            week: {
                wide: "nädal",
                short: "näd",
                narrow: "näd"
            },
            weekOfMonth: {
                wide: "kuu nädal",
                short: "kuu näd",
                narrow: "kuu näd"
            },
            day: {
                wide: "päev",
                short: "p",
                narrow: "p"
            },
            dayOfYear: {
                wide: "aasta päev",
                short: "aasta p",
                narrow: "aasta p"
            },
            weekday: {
                wide: "nädalapäev",
                short: "nädalap.",
                narrow: "nädalap."
            },
            weekdayOfMonth: {
                wide: "kuu nädalapäev",
                short: "kuu nädalap.",
                narrow: "kuu nädalap."
            },
            dayperiod: {
                short: "enne/pärast lõunat",
                wide: "enne/pärast lõunat",
                narrow: "enne/pärast lõunat"
            },
            hour: {
                wide: "tund",
                short: "t",
                narrow: "t"
            },
            minute: {
                wide: "minut",
                short: "min",
                narrow: "min"
            },
            second: {
                wide: "sekund",
                short: "sek",
                narrow: "s"
            },
            zone: {
                wide: "ajavöönd",
                short: "vöönd",
                narrow: "vöönd"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "millisekund"
            }
        }
    },
    firstDay: 1,
    weekendRange: {
        start: 6,
        end: 0
    },
    likelySubtags: {
        et: "et-Latn-EE"
    }
});

