/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "et",
    likelySubtags: {
        et: "et-Latn-EE"
    },
    identity: {
        language: "et"
    },
    territory: "EE",
    calendar: {
        patterns: {
            d: "dd.MM.y",
            D: "EEEE, d. MMMM y",
            m: "d. MMM",
            M: "d. MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d. MMMM y HH:mm:ss",
            g: "d.M.y HH:mm",
            G: "d.M.y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E, d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "d.MM.y GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "d. MMM y G",
                GyMMMEd: "E, d. MMMM y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "M",
                Md: "d.M",
                MEd: "E, d.M",
                MMM: "MMMM",
                MMMd: "d. MMM",
                MMMEd: "E, d. MMM",
                MMMMd: "d. MMMM",
                MMMMEd: "E, d. MMMM",
                "MMMMW-count-one": "MMMM (W. 'nädal')",
                "MMMMW-count-other": "MMMM (W. 'nädal')",
                mmss: "mm:ss",
                ms: "mm:ss",
                y: "y",
                yM: "M.y",
                yMd: "d.M.y",
                yMEd: "E, d.M.y",
                yMMM: "MMM y",
                yMMMd: "d. MMM y",
                yMMMEd: "E, d. MMMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "w. 'nädal' (Y)",
                "yw-count-other": "w. 'nädal' (Y)"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d. MMMM y",
            long: "d. MMMM y",
            medium: "d. MMM y",
            short: "dd.MM.yy"
        },
        days: {
            format: {
                abbreviated: [
                    "P",
                    "E",
                    "T",
                    "K",
                    "N",
                    "R",
                    "L"
                ],
                narrow: [
                    "P",
                    "E",
                    "T",
                    "K",
                    "N",
                    "R",
                    "L"
                ],
                short: [
                    "P",
                    "E",
                    "T",
                    "K",
                    "N",
                    "R",
                    "L"
                ],
                wide: [
                    "Pühapäev",
                    "Esmaspäev",
                    "Teisipäev",
                    "Kolmapäev",
                    "Neljapäev",
                    "Reede",
                    "Laupäev"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "P",
                    "E",
                    "T",
                    "K",
                    "N",
                    "R",
                    "L"
                ],
                narrow: [
                    "P",
                    "E",
                    "T",
                    "K",
                    "N",
                    "R",
                    "L"
                ],
                short: [
                    "P",
                    "E",
                    "T",
                    "K",
                    "N",
                    "R",
                    "L"
                ],
                wide: [
                    "Pühapäev",
                    "Esmaspäev",
                    "Teisipäev",
                    "Kolmapäev",
                    "Neljapäev",
                    "Reede",
                    "Laupäev"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "jaan",
                    "veebr",
                    "märts",
                    "apr",
                    "mai",
                    "juuni",
                    "juuli",
                    "aug",
                    "sept",
                    "okt",
                    "nov",
                    "dets"
                ],
                narrow: [
                    "J",
                    "V",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "jaanuar",
                    "veebruar",
                    "märts",
                    "aprill",
                    "mai",
                    "juuni",
                    "juuli",
                    "august",
                    "september",
                    "oktoober",
                    "november",
                    "detsember"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "jaan",
                    "veebr",
                    "märts",
                    "apr",
                    "mai",
                    "juuni",
                    "juuli",
                    "aug",
                    "sept",
                    "okt",
                    "nov",
                    "dets"
                ],
                narrow: [
                    "J",
                    "V",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "jaanuar",
                    "veebruar",
                    "märts",
                    "aprill",
                    "mai",
                    "juuni",
                    "juuli",
                    "august",
                    "september",
                    "oktoober",
                    "november",
                    "detsember"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. kvartal",
                    "2. kvartal",
                    "3. kvartal",
                    "4. kvartal"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1.",
                    "2.",
                    "3.",
                    "4."
                ],
                wide: [
                    "1. kvartal",
                    "2. kvartal",
                    "3. kvartal",
                    "4. kvartal"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "keskööl",
                    am: "AM",
                    noon: "keskpäeval",
                    pm: "PM",
                    morning1: "hommikul",
                    afternoon1: "pärastlõunal",
                    evening1: "õhtul",
                    night1: "öösel"
                },
                narrow: {
                    midnight: "keskööl",
                    am: "AM",
                    noon: "keskpäeval",
                    pm: "PM",
                    morning1: "hommikul",
                    afternoon1: "pärastlõunal",
                    evening1: "õhtul",
                    night1: "öösel"
                },
                wide: {
                    midnight: "keskööl",
                    am: "AM",
                    noon: "keskpäeval",
                    pm: "PM",
                    morning1: "hommikul",
                    afternoon1: "pärastlõunal",
                    evening1: "õhtul",
                    night1: "öösel"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "kesköö",
                    am: "AM",
                    noon: "keskpäev",
                    pm: "PM",
                    morning1: "hommik",
                    afternoon1: "pärastlõuna",
                    evening1: "õhtu",
                    night1: "öö"
                },
                narrow: {
                    midnight: "kesköö",
                    am: "AM",
                    noon: "keskpäev",
                    pm: "PM",
                    morning1: "hommik",
                    afternoon1: "pärastlõuna",
                    evening1: "õhtu",
                    night1: "öö"
                },
                wide: {
                    midnight: "kesköö",
                    am: "AM",
                    noon: "keskpäev",
                    pm: "PM",
                    morning1: "hommik",
                    afternoon1: "pärastlõuna",
                    evening1: "õhtu",
                    night1: "öö"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "enne Kristust",
                    "1": "pärast Kristust",
                    "0-alt-variant": "enne meie ajaarvamist",
                    "1-alt-variant": "meie ajaarvamise järgi"
                },
                abbreviated: {
                    "0": "eKr",
                    "1": "pKr",
                    "0-alt-variant": "e.m.a",
                    "1-alt-variant": "m.a.j"
                },
                narrow: {
                    "0": "eKr",
                    "1": "pKr",
                    "0-alt-variant": "e.m.a",
                    "1-alt-variant": "m.a.j"
                }
            }
        },
        gmtFormat: "GMT {0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "ajastu",
                short: "ajastu",
                narrow: "ajastu"
            },
            year: {
                wide: "aasta",
                short: "a",
                narrow: "a"
            },
            quarter: {
                wide: "kvartal",
                short: "kv",
                narrow: "kv"
            },
            month: {
                wide: "kuu",
                short: "k",
                narrow: "k"
            },
            week: {
                wide: "nädal",
                short: "näd",
                narrow: "näd"
            },
            weekOfMonth: {
                wide: "kuu nädal",
                short: "kuu näd",
                narrow: "kuu näd"
            },
            day: {
                wide: "päev",
                short: "p",
                narrow: "p"
            },
            dayOfYear: {
                wide: "aasta päev",
                short: "aasta p",
                narrow: "aasta p"
            },
            weekday: {
                wide: "nädalapäev",
                short: "nädalap.",
                narrow: "nädalap."
            },
            weekdayOfMonth: {
                wide: "kuu nädalapäev",
                short: "kuu nädalap.",
                narrow: "kuu nädalap."
            },
            dayperiod: {
                short: "enne/pärast lõunat",
                wide: "enne/pärast lõunat",
                narrow: "enne/pärast lõunat"
            },
            hour: {
                wide: "tund",
                short: "t",
                narrow: "t"
            },
            minute: {
                wide: "minut",
                short: "min",
                narrow: "min"
            },
            second: {
                wide: "sekund",
                short: "sek",
                narrow: "s"
            },
            zone: {
                wide: "ajavöönd",
                short: "vöönd",
                narrow: "vöönd"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "millisekund"
            }
        }
    },
    firstDay: 1
});

