/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "eu",
    identity: {
        language: "eu"
    },
    territory: "ES",
    numbers: {
        symbols: {
            decimal: ",",
            group: ".",
            list: ";",
            percentSign: "%",
            plusSign: "+",
            minusSign: "−",
            approximatelySign: "~",
            exponential: "E",
            superscriptingExponent: "×",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "% n"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-one": "n $",
            "unitPattern-count-other": "n $"
        },
        accounting: {
            patterns: [
                "n $",
                "(n $)"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "pezeta andorratarra",
                "displayName-count-one": "pezeta andorratar",
                "displayName-count-other": "pezeta andorratar",
                symbol: "ADP"
            },
            AED: {
                displayName: "Arabiar Emirerri Batuetako dirhama",
                "displayName-count-one": "Arabiar Emirerri Batuetako dirham",
                "displayName-count-other": "Arabiar Emirerri Batuetako dirham",
                symbol: "AED"
            },
            AFA: {
                displayName: "afghani afgandarra (1927–2002)",
                "displayName-count-one": "afghani afgandar (1927–2002)",
                "displayName-count-other": "afghani afgandar (1927–2002)",
                symbol: "AFA"
            },
            AFN: {
                displayName: "afgani afganiarra",
                "displayName-count-one": "afgani afganiar",
                "displayName-count-other": "afgani afganiar",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "lek albaniarra (1946–1965)",
                "displayName-count-one": "lek albaniar (1946–1965)",
                "displayName-count-other": "lek albaniar (1946–1965)",
                symbol: "ALK"
            },
            ALL: {
                displayName: "lek albaniarra",
                "displayName-count-one": "lek albaniar",
                "displayName-count-other": "lek albaniar",
                symbol: "ALL"
            },
            AMD: {
                displayName: "dram armeniarra",
                "displayName-count-one": "dram armeniar",
                "displayName-count-other": "dram armeniar",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "florin antillarra",
                "displayName-count-one": "florin antillar",
                "displayName-count-other": "florin antillar",
                symbol: "ANG"
            },
            AOA: {
                displayName: "kwanza angolarra",
                "displayName-count-one": "kwanza angolar",
                "displayName-count-other": "kwanza angolar",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "kwanza angolarra (1977–1991)",
                "displayName-count-one": "kwanza angolar (1977–1991)",
                "displayName-count-other": "kwanza angolar (1977–1991)",
                symbol: "AOK"
            },
            AON: {
                displayName: "kwanza angolar berria (1990–2000)",
                "displayName-count-one": "kwanza angolar berri (1990–2000)",
                "displayName-count-other": "kwanza angolar berri (1990–2000)",
                symbol: "AON"
            },
            AOR: {
                displayName: "kwanza angolar birdoitua (1995–1999)",
                "displayName-count-one": "kwanza angolar birdoitu (1995–1999)",
                "displayName-count-other": "kwanza angolar birdoitu (1995–1999)",
                symbol: "AOR"
            },
            ARA: {
                displayName: "austral argentinarra",
                "displayName-count-one": "austral argentinar",
                "displayName-count-other": "austral argentinar",
                symbol: "ARA"
            },
            ARL: {
                displayName: "peso ley argentinarra (1970–1983)",
                "displayName-count-one": "peso ley argentinar (1970–1983)",
                "displayName-count-other": "peso ley argentinar (1970–1983)",
                symbol: "ARL"
            },
            ARM: {
                displayName: "peso argentinarra (1981–1970)",
                "displayName-count-one": "peso argentinar (1981–1970)",
                "displayName-count-other": "peso argentinar (1981–1970)",
                symbol: "ARM"
            },
            ARP: {
                displayName: "peso argentinarra (1983–1985)",
                "displayName-count-one": "peso argentinar (1983–1985)",
                "displayName-count-other": "peso argentinar (1983–1985)",
                symbol: "ARP"
            },
            ARS: {
                displayName: "peso argentinarra",
                "displayName-count-one": "peso argentinar",
                "displayName-count-other": "peso argentinar",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "txelin austriarra",
                "displayName-count-one": "txelin austriar",
                "displayName-count-other": "txelin austriar",
                symbol: "ATS"
            },
            AUD: {
                displayName: "dolar australiarra",
                "displayName-count-one": "dolar australiar",
                "displayName-count-other": "dolar australiar",
                symbol: "A$",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "florin arubarra",
                "displayName-count-one": "florin arubar",
                "displayName-count-other": "florin arubar",
                symbol: "AWG"
            },
            AZM: {
                displayName: "manat azerbaijandarra (1993–2006)",
                "displayName-count-one": "manat azerbaijandar (1993–2006)",
                "displayName-count-other": "manat azerbaijandar (1993–2006)",
                symbol: "AZM"
            },
            AZN: {
                displayName: "manat azerbaijandarra",
                "displayName-count-one": "manat azerbaijandar",
                "displayName-count-other": "manat azerbaijandar",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "dinar bosnia-herzegovinarra (1992–1994)",
                "displayName-count-one": "dinar bosnia-herzegovinar (1992–1994)",
                "displayName-count-other": "dinar bosnia-herzegovinar (1992–1994)",
                symbol: "BAD"
            },
            BAM: {
                displayName: "marko bihurgarri bosniarra",
                "displayName-count-one": "marko bihurgarri bosniar",
                "displayName-count-other": "marko bihurgarri bosniar",
                symbol: "BAM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "dinar bosnia-herzegovinar berria (1994–1997)",
                "displayName-count-one": "dinar bosnia-herzegovinar berri (1994–1997)",
                "displayName-count-other": "dinar bosnia-herzegovinar berri (1994–1997)",
                symbol: "BAN"
            },
            BBD: {
                displayName: "dolar barbadostarra",
                "displayName-count-one": "dolar barbadostar",
                "displayName-count-other": "dolar barbadostar",
                symbol: "BBD",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "taka bangladeshtarra",
                "displayName-count-one": "taka bangladeshtar",
                "displayName-count-other": "taka bangladeshtar",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "franko belgikarra (bihurgarria)",
                "displayName-count-one": "franko belgikar (bihurgarria)",
                "displayName-count-other": "franko belgikar (bihurgarria)",
                symbol: "BEC"
            },
            BEF: {
                displayName: "franko belgikarra",
                "displayName-count-one": "franko belgikar",
                "displayName-count-other": "franko belgikar",
                symbol: "BEF"
            },
            BEL: {
                displayName: "franko belgikarra (finantzarioa)",
                "displayName-count-one": "franko belgikar (finantzarioa)",
                "displayName-count-other": "franko belgikar (finantzarioa)",
                symbol: "BEL"
            },
            BGL: {
                displayName: "Lev bulgariar indartsua",
                "displayName-count-one": "Lev bulgariar indartsu",
                "displayName-count-other": "Lev bulgariar indartsu",
                symbol: "BGL"
            },
            BGM: {
                displayName: "Lev bulgariar sozialista",
                "displayName-count-one": "Lev bulgariar sozialista",
                "displayName-count-other": "Lev bulgariar sozialista",
                symbol: "BGM"
            },
            BGN: {
                displayName: "lev bulgariarra",
                "displayName-count-one": "lev bulgariar",
                "displayName-count-other": "lev bulgariar",
                symbol: "BGN"
            },
            BGO: {
                displayName: "Lev bulgariarra (1879–1952)",
                "displayName-count-one": "Lev bulgariar (1879–1952)",
                "displayName-count-other": "Lev bulgariar (1879–1952)",
                symbol: "BGO"
            },
            BHD: {
                displayName: "dinar bahraindarra",
                "displayName-count-one": "dinar bahraindar",
                "displayName-count-other": "dinar bahraindar",
                symbol: "BHD"
            },
            BIF: {
                displayName: "franko burundiarra",
                "displayName-count-one": "franko burundiar",
                "displayName-count-other": "franko burundiar",
                symbol: "BIF"
            },
            BMD: {
                displayName: "dolar bermudarra",
                "displayName-count-one": "dolar bermudar",
                "displayName-count-other": "dolar bermudar",
                symbol: "BMD",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "dolar bruneitarra",
                "displayName-count-one": "dolar bruneitar",
                "displayName-count-other": "dolar bruneitar",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "boliviano boliviarra",
                "displayName-count-one": "boliviano boliviar",
                "displayName-count-other": "boliviano boliviar",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "boliviano boliviarra (1863–1963)",
                "displayName-count-one": "boliviano boliviar (1863–1963)",
                "displayName-count-other": "boliviano boliviar (1863–1963)",
                symbol: "BOL"
            },
            BOP: {
                displayName: "peso boliviarra",
                "displayName-count-one": "peso boliviar",
                "displayName-count-other": "peso boliviar",
                symbol: "BOP"
            },
            BOV: {
                displayName: "mvdol boliviarra",
                "displayName-count-one": "mvdol boliviar",
                "displayName-count-other": "mvdol boliviar",
                symbol: "BOV"
            },
            BRB: {
                displayName: "cruzeiro brasildar berria (1967–1986)",
                "displayName-count-one": "cruzeiro brasildar berri (1967–1986)",
                "displayName-count-other": "cruzeiro brasildar berri (1967–1986)",
                symbol: "BRB"
            },
            BRC: {
                displayName: "cruzado brasildarra (1986–1989)",
                "displayName-count-one": "cruzado brasildar (1986–1989)",
                "displayName-count-other": "cruzado brasildar (1986–1989)",
                symbol: "BRC"
            },
            BRE: {
                displayName: "cruzeiro brasildarra (1990–1993)",
                "displayName-count-one": "cruzeiro brasildar (1990–1993)",
                "displayName-count-other": "cruzeiro brasildar (1990–1993)",
                symbol: "BRE"
            },
            BRL: {
                displayName: "erreal brasildarra",
                "displayName-count-one": "erreal brasildar",
                "displayName-count-other": "erreal brasildar",
                symbol: "R$",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "cruzado brasildar berria (1989–1990)",
                "displayName-count-one": "cruzado brasildar berri (1989–1990)",
                "displayName-count-other": "cruzado brasildar berri (1989–1990)",
                symbol: "BRN"
            },
            BRR: {
                displayName: "cruzeiro brasildar berria (1993–1994)",
                "displayName-count-one": "cruzeiro brasildar berri (1993–1994)",
                "displayName-count-other": "cruzeiro brasildar berri (1993–1994)",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "cruzeiro brasildarra (1942–1967)",
                "displayName-count-one": "cruzeiro brasildar (1942–1967)",
                "displayName-count-other": "cruzeiro brasildar (1942–1967)",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "dolar bahamarra",
                "displayName-count-one": "dolar bahamar",
                "displayName-count-other": "dolar bahamar",
                symbol: "BSD",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "ngultrum bhutandarra",
                "displayName-count-one": "ngultrum bhutandar",
                "displayName-count-other": "ngultrum bhutandar",
                symbol: "BTN"
            },
            BUK: {
                displayName: "kyat birmaniarra",
                "displayName-count-one": "kyat birmaniar",
                "displayName-count-other": "kyat birmaniar",
                symbol: "BUK"
            },
            BWP: {
                displayName: "pula botswanarra",
                "displayName-count-one": "pula botswanar",
                "displayName-count-other": "pula botswanar",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "errublo bielorrusiarra (1994–1999)",
                "displayName-count-one": "errublo bielorrusiar (1994–1999)",
                "displayName-count-other": "errublo bielorrusiar (1994–1999)",
                symbol: "BYB"
            },
            BYN: {
                displayName: "errublo bielorrusiarra",
                "displayName-count-one": "errublo bielorrusiar",
                "displayName-count-other": "errublo bielorrusiar",
                symbol: "BYN",
                "symbol-alt-narrow": "р."
            },
            BYR: {
                displayName: "Bielorrusiako errubloa (2000–2016)",
                "displayName-count-one": "Bielorrusiako errublo (2000–2016)",
                "displayName-count-other": "Bielorrusiako errublo (2000–2016)",
                symbol: "BYR"
            },
            BZD: {
                displayName: "dolar belizetarra",
                "displayName-count-one": "dolar belizetar",
                "displayName-count-other": "dolar belizetar",
                symbol: "BZD",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "dolar kanadarra",
                "displayName-count-one": "dolar kanadar",
                "displayName-count-other": "dolar kanadar",
                symbol: "CA$",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "franko kongoarra",
                "displayName-count-one": "franko kongoar",
                "displayName-count-other": "franko kongoar",
                symbol: "CDF"
            },
            CHE: {
                displayName: "WIR euroa",
                "displayName-count-one": "WIR euro",
                "displayName-count-other": "WIR euro",
                symbol: "CHE"
            },
            CHF: {
                displayName: "franko suitzarra",
                "displayName-count-one": "franko suitzar",
                "displayName-count-other": "franko suitzar",
                symbol: "CHF"
            },
            CHW: {
                displayName: "WIR frankoa",
                "displayName-count-one": "WIR franko",
                "displayName-count-other": "WIR franko",
                symbol: "CHW"
            },
            CLE: {
                displayName: "ezkutu txiletarra",
                "displayName-count-one": "ezkutu txiletar",
                "displayName-count-other": "ezkutu txiletar",
                symbol: "CLE"
            },
            CLF: {
                displayName: "kontu-unitate txiletarra (UF)",
                "displayName-count-one": "kontu-unitate txiletar (UF)",
                "displayName-count-other": "kontu-unitate txiletar (UF)",
                symbol: "CLF"
            },
            CLP: {
                displayName: "peso txiletarra",
                "displayName-count-one": "peso txiletar",
                "displayName-count-other": "peso txiletar",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "yuan txinatarra (itsasoz haraindikoa)",
                "displayName-count-one": "yuan txinatar (itsasoz haraindikoa)",
                "displayName-count-other": "yuan txinatar (itsasoz haraindikoa)",
                symbol: "CNH"
            },
            CNX: {
                displayName: "Txinako Herri Bankuaren dolarra",
                "displayName-count-one": "Txinako Herri Bankuaren dolar",
                "displayName-count-other": "Txinako Herri Bankuaren dolar",
                symbol: "CNX"
            },
            CNY: {
                displayName: "yuan txinatarra",
                "displayName-count-one": "yuan txinatar",
                "displayName-count-other": "yuan txinatar",
                symbol: "CN¥",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "peso kolonbiarra",
                "displayName-count-one": "peso kolonbiar",
                "displayName-count-other": "peso kolonbiar",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "erreal kolonbiarraren balio-unitatea",
                "displayName-count-one": "erreal kolonbiarraren balio-unitate",
                "displayName-count-other": "erreal kolonbiarraren balio-unitate",
                symbol: "COU"
            },
            CRC: {
                displayName: "colon costarricarra",
                "displayName-count-one": "colon costarricar",
                "displayName-count-other": "colon costarricar",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "dinar serbiarra (2002–2006)",
                "displayName-count-one": "dinar serbiar (2002–2006)",
                "displayName-count-other": "dinar serbiar (2002–2006)",
                symbol: "CSD"
            },
            CSK: {
                displayName: "Txekoslovakiako koroa indartsua",
                "displayName-count-one": "Txekoslovakiako koroa indartsu",
                "displayName-count-other": "Txekoslovakiako koroa indartsu",
                symbol: "CSK"
            },
            CUC: {
                displayName: "peso bihurgarri kubatarra",
                "displayName-count-one": "peso bihurgarri kubatar",
                "displayName-count-other": "peso bihurgarri kubatar",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "peso kubatarra",
                "displayName-count-one": "peso kubatar",
                "displayName-count-other": "peso kubatar",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "ezkutu caboverdetarra",
                "displayName-count-one": "ezkutu caboverdetar",
                "displayName-count-other": "ezkutu caboverdetar",
                symbol: "CVE"
            },
            CYP: {
                displayName: "libera zipretarra",
                "displayName-count-one": "libera zipretar",
                "displayName-count-other": "libera zipretar",
                symbol: "CYP"
            },
            CZK: {
                displayName: "koroa txekiarra",
                "displayName-count-one": "koroa txekiar",
                "displayName-count-other": "koroa txekiar",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "Ekialdeko Alemaniako markoa",
                "displayName-count-one": "Ekialdeko Alemaniako marko",
                "displayName-count-other": "Ekialdeko Alemaniako marko",
                symbol: "DDM"
            },
            DEM: {
                displayName: "marko alemana",
                "displayName-count-one": "marko aleman",
                "displayName-count-other": "marko aleman",
                symbol: "DEM"
            },
            DJF: {
                displayName: "franko djibutiarra",
                "displayName-count-one": "franko djibutiar",
                "displayName-count-other": "franko djibutiar",
                symbol: "DJF"
            },
            DKK: {
                displayName: "koroa danimarkarra",
                "displayName-count-one": "koroa danimarkar",
                "displayName-count-other": "koroa danimarkar",
                symbol: "DKK",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "peso dominikarra",
                "displayName-count-one": "peso dominikar",
                "displayName-count-other": "peso dominikar",
                symbol: "DOP",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "dinar aljeriarra",
                "displayName-count-one": "dinar aljeriar",
                "displayName-count-other": "dinar aljeriar",
                symbol: "DZD"
            },
            ECS: {
                displayName: "sukre ekuadortarra",
                "displayName-count-one": "sukre ekuadortar",
                "displayName-count-other": "sukre ekuadortar",
                symbol: "ECS"
            },
            ECV: {
                displayName: "balio-unitate konstante ekuadortarra",
                "displayName-count-one": "balio-unitate konstante ekuadortar",
                "displayName-count-other": "balio-unitate konstante ekuadortar",
                symbol: "ECV"
            },
            EEK: {
                displayName: "kroon estoniarra",
                "displayName-count-one": "kroon estoniar",
                "displayName-count-other": "kroon estoniar",
                symbol: "EEK"
            },
            EGP: {
                displayName: "libera egiptoarra",
                "displayName-count-one": "libera egiptoar",
                "displayName-count-other": "libera egiptoar",
                symbol: "EGP",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "nakfa eritrearra",
                "displayName-count-one": "nakfa eritrear",
                "displayName-count-other": "nakfa eritrear",
                symbol: "ERN"
            },
            ESA: {
                displayName: "pezeta espainiarra (A kontua)",
                "displayName-count-one": "pezeta espainiar (A kontua)",
                "displayName-count-other": "pezeta espainiar (A kontua)",
                symbol: "ESA"
            },
            ESB: {
                displayName: "pezeta espainiarra (kontu bihurgarria)",
                "displayName-count-one": "pezeta espainiar (kontu bihurgarria)",
                "displayName-count-other": "pezeta espainiar (kontu bihurgarria)",
                symbol: "ESB"
            },
            ESP: {
                pattern: "¤ #,##0.00",
                displayName: "pezeta espainiarra",
                "displayName-count-one": "pezeta espainiar",
                "displayName-count-other": "pezeta espainiar",
                symbol: "₧",
                "symbol-alt-narrow": "₧",
                decimal: ",",
                group: "."
            },
            ETB: {
                displayName: "birr etiopiarra",
                "displayName-count-one": "birr etiopiar",
                "displayName-count-other": "birr etiopiar",
                symbol: "ETB"
            },
            EUR: {
                displayName: "euroa",
                "displayName-count-one": "euro",
                "displayName-count-other": "euro",
                symbol: "€",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "markka finlandiarra",
                "displayName-count-one": "markka finlandiar",
                "displayName-count-other": "markka finlandiar",
                symbol: "FIM"
            },
            FJD: {
                displayName: "dolar fijiarra",
                "displayName-count-one": "dolar fijiar",
                "displayName-count-other": "dolar fijiar",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "libera falklandarra",
                "displayName-count-one": "libera falklandar",
                "displayName-count-other": "libera falklandar",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "libera frantsesa",
                "displayName-count-one": "libera frantses",
                "displayName-count-other": "libera frantses",
                symbol: "FRF"
            },
            GBP: {
                displayName: "libera esterlina",
                "displayName-count-one": "libera esterlina",
                "displayName-count-other": "libera esterlina",
                symbol: "£",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "kupon larit georgiarra",
                "displayName-count-one": "kupon larit georgiar",
                "displayName-count-other": "kupon larit georgiar",
                symbol: "GEK"
            },
            GEL: {
                displayName: "lari georgiarra",
                "displayName-count-one": "lari georgiar",
                "displayName-count-other": "lari georgiar",
                symbol: "GEL",
                "symbol-alt-narrow": "₾"
            },
            GHC: {
                displayName: "cedi ghanatarra (1979–2007)",
                "displayName-count-one": "cedi ghanatar (1979–2007)",
                "displayName-count-other": "cedi ghanatar (1979–2007)",
                symbol: "GHC"
            },
            GHS: {
                displayName: "cedi ghanatarra",
                "displayName-count-one": "cedi ghanatar",
                "displayName-count-other": "cedi ghanatar",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "libera gibraltartarra",
                "displayName-count-one": "libera gibraltartar",
                "displayName-count-other": "libera gibraltartar",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "dalasi gambiarra",
                "displayName-count-one": "dalasi gambiar",
                "displayName-count-other": "dalasi gambiar",
                symbol: "GMD"
            },
            GNF: {
                displayName: "franko ginearra",
                "displayName-count-one": "franko ginear",
                "displayName-count-other": "franko ginear",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "syli ginearra",
                "displayName-count-one": "syli ginear",
                "displayName-count-other": "syli ginear",
                symbol: "GNS"
            },
            GQE: {
                displayName: "ekwele ekuatoreginearra",
                "displayName-count-one": "ekwele ekuatoreginear",
                "displayName-count-other": "ekwele ekuatoreginear",
                symbol: "GQE"
            },
            GRD: {
                displayName: "drakma greziarra",
                "displayName-count-one": "drakma greziar",
                "displayName-count-other": "drakma greziar",
                symbol: "GRD"
            },
            GTQ: {
                displayName: "ketzal guatemalarra",
                "displayName-count-one": "ketzal guatemalar",
                "displayName-count-other": "ketzal guatemalar",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "Gineako ezkutu portugesa",
                "displayName-count-one": "Gineako ezkutu portuges",
                "displayName-count-other": "Gineako ezkutu portuges",
                symbol: "GWE"
            },
            GWP: {
                displayName: "peso gineabissautarra",
                "displayName-count-one": "peso gineabissautar",
                "displayName-count-other": "peso gineabissautar",
                symbol: "GWP"
            },
            GYD: {
                displayName: "dolar guyanarra",
                "displayName-count-one": "dolar guyanar",
                "displayName-count-other": "dolar guyanar",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "dolar hongkongtarra",
                "displayName-count-one": "dolar hongkongtar",
                "displayName-count-other": "dolar hongkongtar",
                symbol: "HK$",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "lempira hodurastarra",
                "displayName-count-one": "lempira hodurastar",
                "displayName-count-other": "lempira hodurastar",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "dinar kroaziarra",
                "displayName-count-one": "dinar kroaziar",
                "displayName-count-other": "dinar kroaziar",
                symbol: "HRD"
            },
            HRK: {
                displayName: "kuna kroaziarra",
                "displayName-count-one": "kuna kroaziar",
                "displayName-count-other": "kuna kroaziar",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "gourde haitiarra",
                "displayName-count-one": "gourde haitiar",
                "displayName-count-other": "gourde haitiar",
                symbol: "HTG"
            },
            HUF: {
                displayName: "forint hungariarra",
                "displayName-count-one": "forint hungariar",
                "displayName-count-other": "forint hungariar",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "errupia indonesiarra",
                "displayName-count-one": "errupia indonesiar",
                "displayName-count-other": "errupia indonesiar",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "libera irlandarra",
                "displayName-count-one": "libera irlandar",
                "displayName-count-other": "libera irlandar",
                symbol: "IEP"
            },
            ILP: {
                displayName: "libera israeldarra",
                "displayName-count-one": "libera israeldar",
                "displayName-count-other": "libera israeldar",
                symbol: "ILP"
            },
            ILR: {
                displayName: "shekel israeldarra (1980–1985)",
                "displayName-count-one": "shekel israeldar (1980–1985)",
                "displayName-count-other": "shekel israeldar (1980–1985)",
                symbol: "ILR"
            },
            ILS: {
                displayName: "shekel israeldar berria",
                "displayName-count-one": "shekel israeldar berri",
                "displayName-count-other": "shekel israeldar berri",
                symbol: "₪",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "errupia indiarra",
                "displayName-count-one": "errupia indiar",
                "displayName-count-other": "errupia indiar",
                symbol: "₹",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "dinar irakiarra",
                "displayName-count-one": "dinar irakiar",
                "displayName-count-other": "dinar irakiar",
                symbol: "IQD"
            },
            IRR: {
                displayName: "rial irandarra",
                "displayName-count-one": "rial irandar",
                "displayName-count-other": "rial irandar",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "koroa islandiarra (1918–1981)",
                "displayName-count-one": "koroa islandiar (1918–1981)",
                "displayName-count-other": "koroa islandiar (1918–1981)",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "koroa islandiarra",
                "displayName-count-one": "koroa islandiar",
                "displayName-count-other": "koroa islandiar",
                symbol: "ISK",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "lira italiarra",
                "displayName-count-one": "lira italiar",
                "displayName-count-other": "lira italiar",
                symbol: "ITL"
            },
            JMD: {
                displayName: "dolar jamaikarra",
                "displayName-count-one": "dolar jamaikar",
                "displayName-count-other": "dolar jamaikar",
                symbol: "JMD",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "dinar jordaniarra",
                "displayName-count-one": "dinar jordaniar",
                "displayName-count-other": "dinar jordaniar",
                symbol: "JOD"
            },
            JPY: {
                displayName: "yen japoniarra",
                "displayName-count-one": "yen japoniar",
                "displayName-count-other": "yen japoniar",
                symbol: "JP¥",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "txelin kenyarra",
                "displayName-count-one": "txelin kenyar",
                "displayName-count-other": "txelin kenyar",
                symbol: "KES"
            },
            KGS: {
                displayName: "som kirgizistandarra",
                "displayName-count-one": "som kirgizistandar",
                "displayName-count-other": "som kirgizistandar",
                symbol: "KGS"
            },
            KHR: {
                displayName: "riel kanbodiarra",
                "displayName-count-one": "riel kanbodiar",
                "displayName-count-other": "riel kanbodiar",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "franko komoretarra",
                "displayName-count-one": "franko komoretar",
                "displayName-count-other": "franko komoretar",
                symbol: "KMF",
                "symbol-alt-narrow": "CF"
            },
            KPW: {
                displayName: "won iparkorearra",
                "displayName-count-one": "won iparkorear",
                "displayName-count-other": "won iparkorear",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "hwan hegokorearra (1953–1962)",
                "displayName-count-one": "hwan hegokorear (1953–1962)",
                "displayName-count-other": "hwan hegokorear (1953–1962)",
                symbol: "KRH"
            },
            KRO: {
                displayName: "won hegokorearra (1945–1953)",
                "displayName-count-one": "won hegokorear (1945–1953)",
                "displayName-count-other": "won hegokorear (1945–1953)",
                symbol: "KRO"
            },
            KRW: {
                displayName: "won hegokorearra",
                "displayName-count-one": "won hegokorear",
                "displayName-count-other": "won hegokorear",
                symbol: "₩",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "dinar kuwaitarra",
                "displayName-count-one": "dinar kuwaitar",
                "displayName-count-other": "dinar kuwaitar",
                symbol: "KWD"
            },
            KYD: {
                displayName: "dolar kaimandarra",
                "displayName-count-one": "dolar kaimandar",
                "displayName-count-other": "dolar kaimandar",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "tenge kazakhstandarra",
                "displayName-count-one": "tenge kazakhstandar",
                "displayName-count-other": "tenge kazakhstandar",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "kip laostarra",
                "displayName-count-one": "kip laostar",
                "displayName-count-other": "kip laostar",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "libera libanoarra",
                "displayName-count-one": "libera libanoar",
                "displayName-count-other": "libera libanoar",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "errupia srilankarra",
                "displayName-count-one": "errupia srilankar",
                "displayName-count-other": "errupia srilankar",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "dolar liberiarra",
                "displayName-count-one": "dolar liberiar",
                "displayName-count-other": "dolar liberiar",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "loti lesothoarra",
                "displayName-count-one": "loti lesothoar",
                "displayName-count-other": "loti lesothoar",
                symbol: "LSL"
            },
            LTL: {
                displayName: "Lituaniako litasa",
                "displayName-count-one": "Lituaniako litas",
                "displayName-count-other": "Lituaniako litas",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "Lituaniako talonasa",
                "displayName-count-one": "Lituaniako talonas",
                "displayName-count-other": "Lituaniako talonas",
                symbol: "LTT"
            },
            LUC: {
                displayName: "Luxenburgoko franko bihurgarria",
                "displayName-count-one": "Luxenburgoko franko bihurgarri",
                "displayName-count-other": "Luxenburgoko franko bihurgarri",
                symbol: "LUC"
            },
            LUF: {
                displayName: "Luxenburgoko frankoa",
                "displayName-count-one": "Luxenburgoko franko",
                "displayName-count-other": "Luxenburgoko franko",
                symbol: "LUF"
            },
            LUL: {
                displayName: "Luxenburgoko finantza-frankoa",
                "displayName-count-one": "Luxenburgoko finantza-franko",
                "displayName-count-other": "Luxenburgoko finantza-franko",
                symbol: "LUL"
            },
            LVL: {
                displayName: "Letoniako latsa",
                "displayName-count-one": "Letoniako lats",
                "displayName-count-other": "Letoniako lats",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "Letoniako errubloa",
                "displayName-count-one": "Letoniako errublo",
                "displayName-count-other": "Letoniako errublo",
                symbol: "LVR"
            },
            LYD: {
                displayName: "dinar libiarra",
                "displayName-count-one": "dinar libiar",
                "displayName-count-other": "dinar libiar",
                symbol: "LYD"
            },
            MAD: {
                displayName: "dirham marokoarra",
                "displayName-count-one": "dirham marokoar",
                "displayName-count-other": "dirham marokoar",
                symbol: "MAD"
            },
            MAF: {
                displayName: "franko marokoarra",
                "displayName-count-one": "franko marokoar",
                "displayName-count-other": "franko marokoar",
                symbol: "MAF"
            },
            MCF: {
                displayName: "Monakoko frankoa",
                "displayName-count-one": "Monakoko franko",
                "displayName-count-other": "Monakoko franko",
                symbol: "MCF"
            },
            MDC: {
                displayName: "kupoi moldaviarra",
                "displayName-count-one": "kupoi moldaviar",
                "displayName-count-other": "kupoi moldaviar",
                symbol: "MDC"
            },
            MDL: {
                displayName: "leu moldaviarra",
                "displayName-count-one": "leu moldaviar",
                "displayName-count-other": "leu moldaviar",
                symbol: "MDL"
            },
            MGA: {
                displayName: "ariary madagaskartarra",
                "displayName-count-one": "ariary madagaskartar",
                "displayName-count-other": "ariary madagaskartar",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "franko malagasiarra",
                "displayName-count-one": "franko malagasiar",
                "displayName-count-other": "franko malagasiar",
                symbol: "MGF"
            },
            MKD: {
                displayName: "dinar mazedoniarra",
                "displayName-count-one": "dinar mazedoniar",
                "displayName-count-other": "dinar mazedoniar",
                symbol: "MKD"
            },
            MKN: {
                displayName: "dinar mazedoniarra (1992–1993)",
                "displayName-count-one": "dinar mazedoniar (1992–1993)",
                "displayName-count-other": "dinar mazedoniar (1992–1993)",
                symbol: "MKN"
            },
            MLF: {
                displayName: "franko maliarra",
                "displayName-count-one": "franko maliar",
                "displayName-count-other": "franko maliar",
                symbol: "MLF"
            },
            MMK: {
                displayName: "kyat myanmartarra",
                "displayName-count-one": "kyat myanmartar",
                "displayName-count-other": "kyat myanmartar",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "tugrik mongoliarra",
                "displayName-count-one": "tugrik mongoliar",
                "displayName-count-other": "tugrik mongoliar",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "pataca macauarra",
                "displayName-count-one": "pataca macauar",
                "displayName-count-other": "pataca macauar",
                symbol: "MOP"
            },
            MRO: {
                displayName: "Mauritaniako ouguiya (1973–2017)",
                "displayName-count-one": "Mauritaniako ouguiya (1973–2017)",
                "displayName-count-other": "Mauritaniako ouguiya (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "uguiya mauritaniarra",
                "displayName-count-one": "uguiya mauritaniar",
                "displayName-count-other": "uguiya mauritaniar",
                symbol: "MRU"
            },
            MTL: {
                displayName: "lira maltarra",
                "displayName-count-one": "lira maltar",
                "displayName-count-other": "lira maltar",
                symbol: "MTL"
            },
            MTP: {
                displayName: "libera maltar",
                "displayName-count-one": "libera maltar",
                "displayName-count-other": "libera maltar",
                symbol: "MTP"
            },
            MUR: {
                displayName: "errupia mauriziarra",
                "displayName-count-one": "errupia mauriziar",
                "displayName-count-other": "errupia mauriziar",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "errupia maldivarra (1947–1981)",
                "displayName-count-one": "errupia maldivar (1947–1981)",
                "displayName-count-other": "errupia maldivar (1947–1981)",
                symbol: "MVP"
            },
            MVR: {
                displayName: "rufiyaa maldivarra",
                "displayName-count-one": "rufiyaa maldivar",
                "displayName-count-other": "rufiyaa maldivar",
                symbol: "MVR"
            },
            MWK: {
                displayName: "kwacha malawiarra",
                "displayName-count-one": "kwacha malawiar",
                "displayName-count-other": "kwacha malawiar",
                symbol: "MWK"
            },
            MXN: {
                displayName: "peso mexikarra",
                "displayName-count-one": "peso mexikar",
                "displayName-count-other": "peso mexikar",
                symbol: "MX$",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "Zilar-peso amerikarra (1861–1992)",
                "displayName-count-one": "Zilar-peso amerikar (1861–1992)",
                "displayName-count-other": "Zilar-peso amerikar (1861–1992)",
                symbol: "MXP"
            },
            MXV: {
                displayName: "Inbertsio-unitate mexikarra",
                "displayName-count-one": "Inbertsio-unitate mexikar",
                "displayName-count-other": "Inbertsio-unitate mexikar",
                symbol: "MXV"
            },
            MYR: {
                displayName: "ringgit malaysiarra",
                "displayName-count-one": "ringgit malaysiar",
                "displayName-count-other": "ringgit malaysiar",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "ezkutu mozambiketarra",
                "displayName-count-one": "ezkutu mozambiketar",
                "displayName-count-other": "ezkutu mozambiketar",
                symbol: "MZE"
            },
            MZM: {
                displayName: "metikal mozambiketarra",
                "displayName-count-one": "metikal mozambiketar",
                "displayName-count-other": "metikal mozambiketar",
                symbol: "MZM"
            },
            MZN: {
                displayName: "metical mozambiketarra",
                "displayName-count-one": "metical mozambiketar",
                "displayName-count-other": "metical mozambiketar",
                symbol: "MZN"
            },
            NAD: {
                displayName: "dolar namibiarra",
                "displayName-count-one": "dolar namibiar",
                "displayName-count-other": "dolar namibiar",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "naira nigeriarra",
                "displayName-count-one": "naira nigeriar",
                "displayName-count-other": "naira nigeriar",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "kordoba nikaraguar (1988–1991)",
                "displayName-count-one": "kordoba nikaraguar (1988–1991)",
                "displayName-count-other": "kordoba nikaraguar (1988–1991)",
                symbol: "NIC"
            },
            NIO: {
                displayName: "cordoba nikaraguarra",
                "displayName-count-one": "cordoba nikaraguar",
                "displayName-count-other": "cordoba nikaraguar",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "gilder herbeheretarra",
                "displayName-count-one": "gilder herbeheretar",
                "displayName-count-other": "gilder herbeheretar",
                symbol: "NLG"
            },
            NOK: {
                displayName: "koroa norvegiarra",
                "displayName-count-one": "koroa norvegiar",
                "displayName-count-other": "koroa norvegiar",
                symbol: "NOK",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "errupia nepaldarra",
                "displayName-count-one": "errupia nepaldar",
                "displayName-count-other": "errupia nepaldar",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "dolar zeelandaberritarra",
                "displayName-count-one": "dolar zeelandaberritar",
                "displayName-count-other": "dolar zeelandaberritar",
                symbol: "NZ$",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "rial omandarra",
                "displayName-count-one": "rial omandar",
                "displayName-count-other": "rial omandar",
                symbol: "OMR"
            },
            PAB: {
                displayName: "balboa panamarra",
                "displayName-count-one": "balboa panamar",
                "displayName-count-other": "balboa panamar",
                symbol: "PAB"
            },
            PEI: {
                displayName: "inti perutarra",
                "displayName-count-one": "inti perutar",
                "displayName-count-other": "inti perutar",
                symbol: "PEI"
            },
            PEN: {
                displayName: "sol perutarra",
                "displayName-count-one": "sol perutar",
                "displayName-count-other": "sol perutar",
                symbol: "PEN"
            },
            PES: {
                displayName: "sol perutarra (1863–1965)",
                "displayName-count-one": "sol perutar (1863–1965)",
                "displayName-count-other": "sol perutar (1863–1965)",
                symbol: "PES"
            },
            PGK: {
                displayName: "kina gineaberriarra",
                "displayName-count-one": "kina gineaberriar",
                "displayName-count-other": "kina gineaberriar",
                symbol: "PGK"
            },
            PHP: {
                displayName: "peso filipinarra",
                "displayName-count-one": "peso filipinar",
                "displayName-count-other": "peso filipinar",
                symbol: "PHP",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "errupia pakistandarra",
                "displayName-count-one": "errupia pakistandar",
                "displayName-count-other": "errupia pakistandar",
                symbol: "PKR",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "zloty poloniarra",
                "displayName-count-one": "zloty poloniar",
                "displayName-count-other": "zloty poloniar",
                symbol: "PLN",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "zloty poloniarra (1950–1995)",
                "displayName-count-one": "zloty poloniar (PLZ)",
                "displayName-count-other": "zloty poloniar (PLZ)",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "ezkutu portugesa",
                "displayName-count-one": "ezkutu portuges",
                "displayName-count-other": "ezkutu portuges",
                symbol: "PTE"
            },
            PYG: {
                displayName: "guarani paraguaitarra",
                "displayName-count-one": "guarani paraguaitar",
                "displayName-count-other": "guarani paraguaitar",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "riyal qatartarra",
                "displayName-count-one": "riyal qatartar",
                "displayName-count-other": "riyal qatartar",
                symbol: "QAR"
            },
            RHD: {
                displayName: "dolar rhodesiarra",
                "displayName-count-one": "dolar rhodesiar",
                "displayName-count-other": "dolar rhodesiar",
                symbol: "RHD"
            },
            ROL: {
                displayName: "leu errumaniarra (1952–2006)",
                "displayName-count-one": "leu errumaniar (1952–2006)",
                "displayName-count-other": "leu errumaniar (1952–2006)",
                symbol: "ROL"
            },
            RON: {
                displayName: "leu errumaniarra",
                "displayName-count-one": "leu errumaniar",
                "displayName-count-other": "leu errumaniar",
                symbol: "RON",
                "symbol-alt-narrow": "lei"
            },
            RSD: {
                displayName: "dinar serbiarra",
                "displayName-count-one": "dinar serbiar",
                "displayName-count-other": "dinar serbiar",
                symbol: "RSD"
            },
            RUB: {
                displayName: "errublo errusiarra",
                "displayName-count-one": "errublo errusiar",
                "displayName-count-other": "errublo errusiar",
                symbol: "RUB",
                "symbol-alt-narrow": "₽"
            },
            RUR: {
                displayName: "errublo errusiarra (1991–1998)",
                "displayName-count-one": "errublo errusiar (1991–1998)",
                "displayName-count-other": "errublo errusiar (1991–1998)",
                symbol: "RUR"
            },
            RWF: {
                displayName: "franko ruandarra",
                "displayName-count-one": "franko ruandar",
                "displayName-count-other": "franko ruandar",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "riyal saudiarabiarra",
                "displayName-count-one": "riyal saudiarabiar",
                "displayName-count-other": "riyal saudiarabiar",
                symbol: "SAR"
            },
            SBD: {
                displayName: "dolar salomondarra",
                "displayName-count-one": "dolar salomondar",
                "displayName-count-other": "dolar salomondar",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "errupia seychelletarra",
                "displayName-count-one": "errupia seychelletar",
                "displayName-count-other": "errupia seychelletar",
                symbol: "SCR"
            },
            SDD: {
                displayName: "dinar sudandarra (1992–2007)",
                "displayName-count-one": "dinar sudandar (1992–2007)",
                "displayName-count-other": "dinar sudandar (1992–2007)",
                symbol: "SDD"
            },
            SDG: {
                displayName: "libera sudandarra",
                "displayName-count-one": "libera sudandar",
                "displayName-count-other": "libera sudandar",
                symbol: "SDG"
            },
            SDP: {
                displayName: "libera sudandarra (1957–1998)",
                "displayName-count-one": "libera sudandar (1957–1998)",
                "displayName-count-other": "libera sudandar (1957–1998)",
                symbol: "SDP"
            },
            SEK: {
                displayName: "koroa suediarra",
                "displayName-count-one": "koroa suediar",
                "displayName-count-other": "koroa suediar",
                symbol: "SEK",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "dolar singapurtarra",
                "displayName-count-one": "dolar singapurtar",
                "displayName-count-other": "dolar singapurtar",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "Santa Helenako libera",
                "displayName-count-one": "Santa Helenako libera",
                "displayName-count-other": "Santa Helenako libera",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "tolar esloveniarra",
                "displayName-count-one": "tolar esloveniar",
                "displayName-count-other": "tolar esloveniar",
                symbol: "SIT"
            },
            SKK: {
                displayName: "koroa eslovakiarra",
                "displayName-count-one": "koroa eslovakiar",
                "displayName-count-other": "koroa eslovakiar",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "leone sierraleonarra",
                "displayName-count-one": "leone sierraleonar",
                "displayName-count-other": "leone sierraleonar",
                symbol: "SLL"
            },
            SOS: {
                displayName: "txelin somaliarra",
                "displayName-count-one": "txelin somaliar",
                "displayName-count-other": "txelin somaliar",
                symbol: "SOS"
            },
            SRD: {
                displayName: "dolar surinamdarra",
                "displayName-count-one": "dolar surinamdar",
                "displayName-count-other": "dolar surinamdar",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "gilder surinamdarra",
                "displayName-count-one": "gilder surinamdar",
                "displayName-count-other": "gilder surinamdar",
                symbol: "SRG"
            },
            SSP: {
                displayName: "libera hegosudandarra",
                "displayName-count-one": "libera hegosudandar",
                "displayName-count-other": "libera hegosudandar",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "Sao Tomeko eta Principeko dobra (1977–2017)",
                "displayName-count-one": "Sao Tomeko eta Principeko dobra (1977–2017)",
                "displayName-count-other": "Sao Tomeko eta Principeko dobra (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "dobra saotometarra",
                "displayName-count-one": "dobra saotometar",
                "displayName-count-other": "dobra saotometar",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "errublo sovietarra",
                "displayName-count-one": "errublo sovietar",
                "displayName-count-other": "errublo sovietar",
                symbol: "SUR"
            },
            SVC: {
                displayName: "kolon salvadortarra",
                "displayName-count-one": "kolon salvadortar",
                "displayName-count-other": "kolon salvadortar",
                symbol: "SVC"
            },
            SYP: {
                displayName: "libera siriarra",
                "displayName-count-one": "libera siriar",
                "displayName-count-other": "libera siriar",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "lilangeni swazilandiarra",
                "displayName-count-one": "lilangeni swazilandiar",
                "displayName-count-other": "lilangeni swazilandiar",
                symbol: "SZL"
            },
            THB: {
                displayName: "baht thailandiarra",
                "displayName-count-one": "baht thailandiar",
                "displayName-count-other": "baht thailandiar",
                symbol: "฿",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "errublo tajikistandarra",
                "displayName-count-one": "errublo tajikistandar",
                "displayName-count-other": "errublo tajikistandar",
                symbol: "TJR"
            },
            TJS: {
                displayName: "somoni tajikistandarra",
                "displayName-count-one": "somoni tajikistandar",
                "displayName-count-other": "somoni tajikistandar",
                symbol: "TJS"
            },
            TMM: {
                displayName: "manat turkmenistandarra (1993–2009)",
                "displayName-count-one": "manat turkmenistandar (1993–2009)",
                "displayName-count-other": "manat turkmenistandar (1993–2009)",
                symbol: "TMM"
            },
            TMT: {
                displayName: "manat turkmenistandarra",
                "displayName-count-one": "manat turkmenistandar",
                "displayName-count-other": "manat turkmenistandar",
                symbol: "TMT"
            },
            TND: {
                displayName: "dinar tunisiarra",
                "displayName-count-one": "dinar tunisiar",
                "displayName-count-other": "dinar tunisiar",
                symbol: "TND"
            },
            TOP: {
                displayName: "paʻanga tongatarra",
                "displayName-count-one": "paʻanga tongatar",
                "displayName-count-other": "paʻanga tongatar",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "ezkutu timortarra",
                "displayName-count-one": "ezkutu timortar",
                "displayName-count-other": "ezkutu timortar",
                symbol: "TPE"
            },
            TRL: {
                displayName: "lira turkiarra (1922–2005)",
                "displayName-count-one": "lira turkiar (1922–2005)",
                "displayName-count-other": "lira turkiar (1922–2005)",
                symbol: "TRL"
            },
            TRY: {
                displayName: "lira turkiarra",
                "displayName-count-one": "lira turkiar",
                "displayName-count-other": "lira turkiar",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "dolar trinitatearra",
                "displayName-count-one": "dolar trinitatear",
                "displayName-count-other": "dolar trinitatear",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "dolar taiwandar berria",
                "displayName-count-one": "dolar taiwandar berri",
                "displayName-count-other": "dolar taiwandar berri",
                symbol: "NT$",
                "symbol-alt-narrow": "NT$"
            },
            TZS: {
                displayName: "txelin tanzaniarra",
                "displayName-count-one": "txelin tanzaniar",
                "displayName-count-other": "txelin tanzaniar",
                symbol: "TZS"
            },
            UAH: {
                displayName: "hryvnia ukrainarra",
                "displayName-count-one": "hryvnia ukrainar",
                "displayName-count-other": "hryvnia ukrainar",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "karbovanets ukrainarra",
                "displayName-count-one": "karbovanets ukrainar",
                "displayName-count-other": "karbovanets ukrainar",
                symbol: "UAK"
            },
            UGS: {
                displayName: "txelin ugandarra (1966–1987)",
                "displayName-count-one": "txelin ugandar (1966–1987)",
                "displayName-count-other": "txelin ugandar (1966–1987)",
                symbol: "UGS"
            },
            UGX: {
                displayName: "txelin ugandarra",
                "displayName-count-one": "txelin ugandar",
                "displayName-count-other": "txelin ugandar",
                symbol: "UGX"
            },
            USD: {
                displayName: "dolar estatubatuarra",
                "displayName-count-one": "dolar estatubatuar",
                "displayName-count-other": "dolar estatubatuar",
                symbol: "US$",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "dolar estatubatuar (Hurrengo eguna)",
                "displayName-count-one": "dolar estatubatuar (hurrengo eguna)",
                "displayName-count-other": "dolar estatubatuar (hurrengo eguna)",
                symbol: "USN"
            },
            USS: {
                displayName: "dolar estatubatuar (Egun berean)",
                "displayName-count-one": "dolar estatubatuar (egun berean)",
                "displayName-count-other": "dolar estatubatuar (egun berean)",
                symbol: "USS"
            },
            UYI: {
                displayName: "peso uruguaitarra (unitate indexatuak)",
                "displayName-count-one": "peso uruguaitar (unitate indexatuak)",
                "displayName-count-other": "peso uruguaitar (unitate indexatuak)",
                symbol: "UYI"
            },
            UYP: {
                displayName: "peso uruguaitarra (1975–1993)",
                "displayName-count-one": "peso uruguaitar (1975–1993)",
                "displayName-count-other": "peso uruguaitar (1975–1993)",
                symbol: "UYP"
            },
            UYU: {
                displayName: "peso uruguaitarra",
                "displayName-count-one": "peso uruguaitar",
                "displayName-count-other": "peso uruguaitar",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "soldata nominalaren indize-unitate uruguaitarra",
                "displayName-count-one": "soldata nominalaren indize-unitate uruguaitar",
                "displayName-count-other": "soldata nominalaren indize-unitate uruguaitar",
                symbol: "UYW"
            },
            UZS: {
                displayName: "sum uzbekistandarra",
                "displayName-count-one": "sum uzbekistandar",
                "displayName-count-other": "sum uzbekistandar",
                symbol: "UZS"
            },
            VEB: {
                displayName: "Venezuelako bolivarra (1871–2008)",
                "displayName-count-one": "Venezuelako bolivar (1871–2008)",
                "displayName-count-other": "Venezuelako bolivar (1871–2008)",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "Venezuelako bolivarra (2008–2018)",
                "displayName-count-one": "Venezuelako bolivar (2008–2018)",
                "displayName-count-other": "Venezuelako bolivar (2008–2018)",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs"
            },
            VES: {
                displayName: "bolivar venezuelarra",
                "displayName-count-one": "bolivar venezuelar",
                "displayName-count-other": "bolivar venezuelar",
                symbol: "VES"
            },
            VND: {
                displayName: "dong vietnamdarra",
                "displayName-count-one": "dong vietnamdar",
                "displayName-count-other": "dong vietnamdar",
                symbol: "₫",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "dong vietnamdar (1978–1985)",
                "displayName-count-one": "dong vietnamdar (1978–1985)",
                "displayName-count-other": "dong vietnamdar (1978–1985)",
                symbol: "VNN"
            },
            VUV: {
                displayName: "vatu vanuatuarra",
                "displayName-count-one": "vatu vanuatuar",
                "displayName-count-other": "vatu vanuatuar",
                symbol: "VUV"
            },
            WST: {
                displayName: "tala samoarra",
                "displayName-count-one": "tala samoar",
                "displayName-count-other": "tala samoar",
                symbol: "WST"
            },
            XAF: {
                displayName: "Afrika erdialdeko CFA frankoa",
                "displayName-count-one": "Afrika erdialdeko CFA franko",
                "displayName-count-other": "Afrika erdialdeko CFA franko",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "zilarra",
                "displayName-count-one": "zilarrezko troy ontza",
                "displayName-count-other": "zilarrezko troy ontza",
                symbol: "XAG"
            },
            XAU: {
                displayName: "urrea",
                "displayName-count-one": "urrezko troy ontza",
                "displayName-count-other": "urrezko troy ontza",
                symbol: "XAU"
            },
            XBA: {
                displayName: "Europako unitate konposatua",
                "displayName-count-one": "Europako unitate konposatu",
                "displayName-count-other": "Europako unitate konposatu",
                symbol: "XBA"
            },
            XBB: {
                displayName: "Europako moneta-unitatea",
                "displayName-count-one": "Europako moneta-unitate",
                "displayName-count-other": "Europako moneta-unitate",
                symbol: "XBB"
            },
            XBC: {
                displayName: "Europako kontu-unitatea (XBC)",
                "displayName-count-one": "Europako kontu-unitate (XBC)",
                "displayName-count-other": "Europako kontu-unitate (XBC)",
                symbol: "XBC"
            },
            XBD: {
                displayName: "Europako kontu-unitatea (XBD)",
                "displayName-count-one": "Europako kontu-unitate (XBD)",
                "displayName-count-other": "Europako kontu-unitate (XBD)",
                symbol: "XBD"
            },
            XCD: {
                displayName: "dolar ekikaribearra",
                "displayName-count-one": "dolar ekikaribear",
                "displayName-count-other": "dolar ekikaribear",
                symbol: "EC$",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "igorpen-eskubide berezia",
                "displayName-count-one": "igorpen-eskubide berezi",
                "displayName-count-other": "igorpen-eskubide berezi",
                symbol: "XDR"
            },
            XEU: {
                displayName: "Europako dibisa-unitatea",
                "displayName-count-one": "Europako dibisa-unitate",
                "displayName-count-other": "Europako dibisa-unitate",
                symbol: "XEU"
            },
            XFO: {
                displayName: "urrezko libera frantsesa",
                "displayName-count-one": "urrezko libera frantses",
                "displayName-count-other": "urrezko libera frantses",
                symbol: "XFO"
            },
            XFU: {
                displayName: "UIC libera frantsesa",
                "displayName-count-one": "UIC libera frantses",
                "displayName-count-other": "UIC libera frantses",
                symbol: "XFU"
            },
            XOF: {
                displayName: "Afrika mendebaldeko CFA frankoa",
                "displayName-count-one": "Afrika mendebaldeko CFA franko",
                "displayName-count-other": "Afrika mendebaldeko CFA franko",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "paladioa",
                "displayName-count-one": "paladiozko troy ontza",
                "displayName-count-other": "paladiozko troy ontza",
                symbol: "XPD"
            },
            XPF: {
                displayName: "CFP frankoa",
                "displayName-count-one": "CFP franko",
                "displayName-count-other": "CFP franko",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "platinozko troy ontza",
                "displayName-count-one": "platinozko troy ontza",
                "displayName-count-other": "platinozko troy ontza",
                symbol: "XPT"
            },
            XRE: {
                displayName: "RINET funtsak",
                "displayName-count-one": "RINET funtsen unitate",
                "displayName-count-other": "RINET funtsen unitate",
                symbol: "XRE"
            },
            XSU: {
                displayName: "sucrea",
                "displayName-count-one": "sucre",
                "displayName-count-other": "sucre",
                symbol: "XSU"
            },
            XTS: {
                displayName: "aztertzeko dibisa-unitatea",
                "displayName-count-one": "aztertzeko dibisa-unitate",
                "displayName-count-other": "aztertzeko dibisa-unitate",
                symbol: "XTS"
            },
            XUA: {
                displayName: "ADB kontu-unitatea",
                "displayName-count-one": "ADB kontu-unitate",
                "displayName-count-other": "ADB kontu-unitate",
                symbol: "XUA"
            },
            XXX: {
                displayName: "moneta ezezaguna",
                "displayName-count-one": "(moneta ezezaguna)",
                "displayName-count-other": "(moneta ezezaguna)",
                symbol: "¤"
            },
            YDD: {
                displayName: "dinar yemendarra",
                "displayName-count-one": "dinar yemendar",
                "displayName-count-other": "dinar yemendar",
                symbol: "YDD"
            },
            YER: {
                displayName: "rial yemendarra",
                "displayName-count-one": "rial yemendar",
                "displayName-count-other": "rial yemendar",
                symbol: "YER"
            },
            YUD: {
                displayName: "dinar yugoslaviar indartsua (1966–1990)",
                "displayName-count-one": "dinar yugoslaviar indartsu (1966–1990)",
                "displayName-count-other": "dinar yugoslaviar indartsu (1966–1990)",
                symbol: "YUD"
            },
            YUM: {
                displayName: "dinar yugoslaviar berria (1994–2002)",
                "displayName-count-one": "dinar yugoslaviar berri (1994–2002)",
                "displayName-count-other": "dinar yugoslaviar berri (1994–2002)",
                symbol: "YUM"
            },
            YUN: {
                displayName: "dinar yugoslaviar bihurgarria (1990–1992)",
                "displayName-count-one": "dinar yugoslaviar bihurgarri (1990–1992)",
                "displayName-count-other": "dinar yugoslaviar bihurgarri (1990–1992)",
                symbol: "YUN"
            },
            YUR: {
                displayName: "dinar yugoslaviar erreformatua (1992–1993)",
                "displayName-count-one": "dinar yugoslaviar erreformatu (1992–1993)",
                "displayName-count-other": "dinar yugoslaviar erreformatu (1992–1993)",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "rand hegoafrikarra (finantzarioa)",
                "displayName-count-one": "rand hegoafrikar (finantzarioa)",
                "displayName-count-other": "rand hegoafrikar (finantzarioa)",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "rand hegoafrikarra",
                "displayName-count-one": "rand hegoafrikar",
                "displayName-count-other": "rand hegoafrikar",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "Zambiako kwacha (1968–2012)",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "kwacha zambiarra",
                "displayName-count-one": "kwacha zambiar",
                "displayName-count-other": "kwacha zambiar",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "zaire berri zairetarra (1993–1998)",
                "displayName-count-one": "zaire berri zairetar (1993–1998)",
                "displayName-count-other": "zaire berri zairetar (1993–1998)",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "zaire zairetarra (1971–1993)",
                "displayName-count-one": "zaire zairetar (1971–1993)",
                "displayName-count-other": "zaire zairetar (1971–1993)",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "dolar zimbabwetarra (1980–2008)",
                "displayName-count-one": "dolar zimbabwetar (1980–2008)",
                "displayName-count-other": "dolar zimbabwetar (1980–2008)",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "dolar zimbabwetarra (2009)",
                "displayName-count-one": "dolar zimbabwetar (2009)",
                "displayName-count-other": "dolar zimbabwetar (2009)",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "dolar zimbabwetarra (2008)",
                "displayName-count-one": "dolar zimbabwetar (2008)",
                "displayName-count-other": "dolar zimbabwetar (2008)",
                symbol: "ZWR"
            }
        },
        localeCurrency: "EUR"
    },
    calendar: {
        patterns: {
            d: "y/M/d",
            D: "y('e')'ko' MMMM'ren' d('a'), EEEE",
            m: "MMM d",
            M: "MMMM d",
            y: "y MMM",
            Y: "y('e')'ko' MMMM",
            F: "y('e')'ko' MMMM'ren' d('a'), EEEE HH:mm:ss",
            g: "y/M/d HH:mm",
            G: "y/M/d HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "B h",
                Bhm: "B h:mm",
                Bhms: "B h:mm:ss",
                d: "d",
                E: "ccc",
                EBhm: "E B h:mm",
                EBhms: "E B h:mm:ss",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y. 'urteko' MMM",
                GyMMMd: "G y. 'urteko' MMM d",
                GyMMMEd: "G y. 'urteko' MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "M/d",
                MEd: "M/d, E",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "MMM d, E",
                MMMMd: "MMMM d",
                "MMMMW-count-one": "MMMM W. 'astea'",
                "MMMMW-count-other": "MMMM W. 'astea'",
                ms: "mm:ss",
                y: "y",
                yM: "y/M",
                yMd: "y/M/d",
                yMEd: "y/M/d, E",
                yMMM: "y MMM",
                yMMMd: "y MMM d",
                yMMMEd: "y MMM d, E",
                yMMMM: "y('e')'ko' MMMM",
                yMMMMd: "y('e')'ko' MMMM'ren' d",
                yMMMMEd: "y('e')'ko' MMMM'k' d, E",
                yQQQ: "y('e')'ko' QQQ",
                yQQQQ: "y('e')'ko' QQQQ",
                "yw-count-one": "Y. 'urteko' w. 'astea'",
                "yw-count-other": "Y. 'urteko' w. 'astea'"
            }
        },
        timeFormats: {
            full: "HH:mm:ss (zzzz)",
            long: "HH:mm:ss (z)",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "y('e')'ko' MMMM'ren' d('a'), EEEE",
            long: "y('e')'ko' MMMM'ren' d('a')",
            medium: "y('e')'ko' MMM d('a')",
            short: "yy/M/d"
        },
        days: {
            format: {
                abbreviated: [
                    "ig.",
                    "al.",
                    "ar.",
                    "az.",
                    "og.",
                    "or.",
                    "lr."
                ],
                narrow: [
                    "I",
                    "A",
                    "A",
                    "A",
                    "O",
                    "O",
                    "L"
                ],
                short: [
                    "ig.",
                    "al.",
                    "ar.",
                    "az.",
                    "og.",
                    "or.",
                    "lr."
                ],
                wide: [
                    "igandea",
                    "astelehena",
                    "asteartea",
                    "asteazkena",
                    "osteguna",
                    "ostirala",
                    "larunbata"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ig.",
                    "al.",
                    "ar.",
                    "az.",
                    "og.",
                    "or.",
                    "lr."
                ],
                narrow: [
                    "I",
                    "A",
                    "A",
                    "A",
                    "O",
                    "O",
                    "L"
                ],
                short: [
                    "ig.",
                    "al.",
                    "ar.",
                    "az.",
                    "og.",
                    "or.",
                    "lr."
                ],
                wide: [
                    "igandea",
                    "astelehena",
                    "asteartea",
                    "asteazkena",
                    "osteguna",
                    "ostirala",
                    "larunbata"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "urt.",
                    "ots.",
                    "mar.",
                    "api.",
                    "mai.",
                    "eka.",
                    "uzt.",
                    "abu.",
                    "ira.",
                    "urr.",
                    "aza.",
                    "abe."
                ],
                narrow: [
                    "U",
                    "O",
                    "M",
                    "A",
                    "M",
                    "E",
                    "U",
                    "A",
                    "I",
                    "U",
                    "A",
                    "A"
                ],
                wide: [
                    "urtarrilak",
                    "otsailak",
                    "martxoak",
                    "apirilak",
                    "maiatzak",
                    "ekainak",
                    "uztailak",
                    "abuztuak",
                    "irailak",
                    "urriak",
                    "azaroak",
                    "abenduak"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "urt.",
                    "ots.",
                    "mar.",
                    "api.",
                    "mai.",
                    "eka.",
                    "uzt.",
                    "abu.",
                    "ira.",
                    "urr.",
                    "aza.",
                    "abe."
                ],
                narrow: [
                    "U",
                    "O",
                    "M",
                    "A",
                    "M",
                    "E",
                    "U",
                    "A",
                    "I",
                    "U",
                    "A",
                    "A"
                ],
                wide: [
                    "urtarrila",
                    "otsaila",
                    "martxoa",
                    "apirila",
                    "maiatza",
                    "ekaina",
                    "uztaila",
                    "abuztua",
                    "iraila",
                    "urria",
                    "azaroa",
                    "abendua"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1Hh",
                    "2Hh",
                    "3Hh",
                    "4Hh"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. hiruhilekoa",
                    "2. hiruhilekoa",
                    "3. hiruhilekoa",
                    "4. hiruhilekoa"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1Hh",
                    "2Hh",
                    "3Hh",
                    "4Hh"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. hiruhilekoa",
                    "2. hiruhilekoa",
                    "3. hiruhilekoa",
                    "4. hiruhilekoa"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "gauerdia",
                    am: "AM",
                    pm: "PM",
                    morning1: "goizald.",
                    morning2: "goizeko",
                    afternoon1: "eguerd.",
                    afternoon2: "arrats.",
                    evening1: "iluntz.",
                    night1: "gaueko"
                },
                narrow: {
                    midnight: "gauerdia",
                    am: "g",
                    pm: "a",
                    morning1: "goizald.",
                    morning2: "goizeko",
                    afternoon1: "eguerd.",
                    afternoon2: "arrats.",
                    evening1: "iluntz.",
                    night1: "gaueko"
                },
                wide: {
                    midnight: "gauerdia",
                    am: "AM",
                    pm: "PM",
                    morning1: "goizaldeko",
                    morning2: "goizeko",
                    afternoon1: "eguerdiko",
                    afternoon2: "arratsaldeko",
                    evening1: "iluntzeko",
                    night1: "gaueko"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "gauerdia",
                    am: "AM",
                    pm: "PM",
                    morning1: "goiz.",
                    morning2: "goiza",
                    afternoon1: "eguerd.",
                    afternoon2: "arrats.",
                    evening1: "iluntz.",
                    night1: "gaua"
                },
                narrow: {
                    midnight: "gauerdia",
                    am: "AM",
                    pm: "PM",
                    morning1: "goizald.",
                    morning2: "goiza",
                    afternoon1: "eguerd.",
                    afternoon2: "arrats.",
                    evening1: "iluntz.",
                    night1: "gaua"
                },
                wide: {
                    midnight: "gauerdia",
                    am: "AM",
                    pm: "PM",
                    morning1: "goizaldea",
                    morning2: "goiza",
                    afternoon1: "eguerdia",
                    afternoon2: "arratsaldea",
                    evening1: "iluntzea",
                    night1: "gaua"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "K.a.",
                    "1": "Kristo ondoren",
                    "0-alt-variant": "Gure aroaren aurretik",
                    "1-alt-variant": "Gure aroa"
                },
                abbreviated: {
                    "0": "K.a.",
                    "1": "K.o.",
                    "0-alt-variant": "G.a.a.",
                    "1-alt-variant": "G.a."
                },
                narrow: {
                    "0": "a",
                    "1": "o",
                    "0-alt-variant": "G.a.a.",
                    "1-alt-variant": "G.a."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "aroa",
                short: "aroa",
                narrow: "aroa"
            },
            year: {
                wide: "urtea",
                short: "urtea",
                narrow: "urtea"
            },
            quarter: {
                wide: "hiruhilekoa",
                short: "hiruhil.",
                narrow: "hiruhil."
            },
            month: {
                wide: "hilabetea",
                short: "hil.",
                narrow: "hil."
            },
            week: {
                wide: "astea",
                short: "ast.",
                narrow: "ast."
            },
            weekOfMonth: {
                wide: "hileko #. astea",
                short: "hileko #. astea",
                narrow: "hileko #. astea"
            },
            day: {
                wide: "eguna",
                short: "eg.",
                narrow: "eg."
            },
            dayOfYear: {
                wide: "urteko #. eguna",
                short: "urteko #. eguna",
                narrow: "urteko #. eguna"
            },
            weekday: {
                wide: "asteguna",
                short: "asteguna",
                narrow: "asteguna"
            },
            weekdayOfMonth: {
                wide: "hileko #. asteguna",
                short: "hileko #. asteguna",
                narrow: "hileko #. asteguna"
            },
            dayperiod: {
                short: "AM/PM",
                wide: "AM/PM",
                narrow: "AM/PM"
            },
            hour: {
                wide: "ordua",
                short: "h",
                narrow: "h"
            },
            minute: {
                wide: "minutua",
                short: "min",
                narrow: "min"
            },
            second: {
                wide: "segundoa",
                short: "s",
                narrow: "s"
            },
            zone: {
                wide: "ordu-zona",
                short: "ordu-zona",
                narrow: "ordu-zona"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "milisegundo"
            }
        }
    },
    firstDay: 1,
    weekendRange: {
        start: 6,
        end: 0
    },
    likelySubtags: {
        eu: "eu-Latn-ES"
    }
});

