/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ewo",
    likelySubtags: {
        ewo: "ewo-Latn-CM"
    },
    identity: {
        language: "ewo"
    },
    territory: "CM",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE d MMMM y",
            m: "d MMM",
            M: "MMMM d",
            y: "MMM y",
            Y: "y MMMM",
            F: "EEEE d MMMM y HH:mm:ss",
            g: "d/M/y HH:mm",
            G: "d/M/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E d/M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E d MMM",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "m:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E d/M/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E d MMM y",
                yMMMM: "y MMMM",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "d/M/y"
        },
        days: {
            format: {
                abbreviated: [
                    "sɔ́n",
                    "mɔ́n",
                    "smb",
                    "sml",
                    "smn",
                    "fúl",
                    "sér"
                ],
                narrow: [
                    "s",
                    "m",
                    "s",
                    "s",
                    "s",
                    "f",
                    "s"
                ],
                short: [
                    "sɔ́n",
                    "mɔ́n",
                    "smb",
                    "sml",
                    "smn",
                    "fúl",
                    "sér"
                ],
                wide: [
                    "sɔ́ndɔ",
                    "mɔ́ndi",
                    "sɔ́ndɔ məlú mə́bɛ̌",
                    "sɔ́ndɔ məlú mə́lɛ́",
                    "sɔ́ndɔ məlú mə́nyi",
                    "fúladé",
                    "séradé"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "sɔ́n",
                    "mɔ́n",
                    "smb",
                    "sml",
                    "smn",
                    "fúl",
                    "sér"
                ],
                narrow: [
                    "s",
                    "m",
                    "s",
                    "s",
                    "s",
                    "f",
                    "s"
                ],
                short: [
                    "sɔ́n",
                    "mɔ́n",
                    "smb",
                    "sml",
                    "smn",
                    "fúl",
                    "sér"
                ],
                wide: [
                    "sɔ́ndɔ",
                    "mɔ́ndi",
                    "sɔ́ndɔ məlú mə́bɛ̌",
                    "sɔ́ndɔ məlú mə́lɛ́",
                    "sɔ́ndɔ məlú mə́nyi",
                    "fúladé",
                    "séradé"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "ngo",
                    "ngb",
                    "ngl",
                    "ngn",
                    "ngt",
                    "ngs",
                    "ngz",
                    "ngm",
                    "nge",
                    "nga",
                    "ngad",
                    "ngab"
                ],
                narrow: [
                    "o",
                    "b",
                    "l",
                    "n",
                    "t",
                    "s",
                    "z",
                    "m",
                    "e",
                    "a",
                    "d",
                    "b"
                ],
                wide: [
                    "ngɔn osú",
                    "ngɔn bɛ̌",
                    "ngɔn lála",
                    "ngɔn nyina",
                    "ngɔn tána",
                    "ngɔn saməna",
                    "ngɔn zamgbála",
                    "ngɔn mwom",
                    "ngɔn ebulú",
                    "ngɔn awóm",
                    "ngɔn awóm ai dziá",
                    "ngɔn awóm ai bɛ̌"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ngo",
                    "ngb",
                    "ngl",
                    "ngn",
                    "ngt",
                    "ngs",
                    "ngz",
                    "ngm",
                    "nge",
                    "nga",
                    "ngad",
                    "ngab"
                ],
                narrow: [
                    "o",
                    "b",
                    "l",
                    "n",
                    "t",
                    "s",
                    "z",
                    "m",
                    "e",
                    "a",
                    "d",
                    "b"
                ],
                wide: [
                    "ngɔn osú",
                    "ngɔn bɛ̌",
                    "ngɔn lála",
                    "ngɔn nyina",
                    "ngɔn tána",
                    "ngɔn saməna",
                    "ngɔn zamgbála",
                    "ngɔn mwom",
                    "ngɔn ebulú",
                    "ngɔn awóm",
                    "ngɔn awóm ai dziá",
                    "ngɔn awóm ai bɛ̌"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "nno",
                    "nnb",
                    "nnl",
                    "nnny"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "nsámbá ngɔn asú",
                    "nsámbá ngɔn bɛ̌",
                    "nsámbá ngɔn lála",
                    "nsámbá ngɔn nyina"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "nno",
                    "nnb",
                    "nnl",
                    "nnny"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "nsámbá ngɔn asú",
                    "nsámbá ngɔn bɛ̌",
                    "nsámbá ngɔn lála",
                    "nsámbá ngɔn nyina"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "kíkíríg",
                    pm: "ngəgógəle"
                },
                narrow: {
                    am: "kíkíríg",
                    pm: "ngəgógəle"
                },
                wide: {
                    am: "kíkíríg",
                    pm: "ngəgógəle"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "kíkíríg",
                    pm: "ngəgógəle"
                },
                narrow: {
                    am: "kíkíríg",
                    pm: "ngəgógəle"
                },
                wide: {
                    am: "kíkíríg",
                    pm: "ngəgógəle"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "osúsúa Yésus kiri",
                    "1": "ámvus Yésus Kirís",
                    "0-alt-variant": "oyk",
                    "1-alt-variant": "ayk"
                },
                abbreviated: {
                    "0": "oyk",
                    "1": "ayk",
                    "0-alt-variant": "oyk",
                    "1-alt-variant": "ayk"
                },
                narrow: {
                    "0": "oyk",
                    "1": "ayk",
                    "0-alt-variant": "oyk",
                    "1-alt-variant": "ayk"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Abǒg",
                short: "Abǒg",
                narrow: "Abǒg"
            },
            year: {
                wide: "M̀bú",
                short: "M̀bú",
                narrow: "M̀bú"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Ngɔn",
                short: "Ngɔn",
                narrow: "Ngɔn"
            },
            week: {
                wide: "Sɔ́ndɔ",
                short: "Sɔ́ndɔ",
                narrow: "Sɔ́ndɔ"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Amǒs",
                short: "Amǒs",
                narrow: "Amǒs"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Amǒs yá sɔ́ndɔ",
                short: "Amǒs yá sɔ́ndɔ",
                narrow: "Amǒs yá sɔ́ndɔ"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Kírí / Ngəgógəle",
                wide: "Kírí / Ngəgógəle",
                narrow: "Kírí / Ngəgógəle"
            },
            hour: {
                wide: "Awola",
                short: "Awola",
                narrow: "Awola"
            },
            minute: {
                wide: "Enútɛn",
                short: "Enútɛn",
                narrow: "Enútɛn"
            },
            second: {
                wide: "Akábəga",
                short: "Akábəga",
                narrow: "Akábəga"
            },
            zone: {
                wide: "Nkɔŋ Awola",
                short: "Nkɔŋ Awola",
                narrow: "Nkɔŋ Awola"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

