/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "gl",
    identity: {
        language: "gl"
    },
    territory: "ES",
    numbers: {
        symbols: {
            decimal: ",",
            group: ".",
            list: ";",
            percentSign: "%",
            plusSign: "+",
            minusSign: "-",
            approximatelySign: "~",
            exponential: "E",
            superscriptingExponent: "×",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "n %"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-one": "n $",
            "unitPattern-count-other": "n $"
        },
        accounting: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "peseta andorrana",
                "displayName-count-one": "peseta andorrana",
                "displayName-count-other": "pesetas andorranas",
                symbol: "ADP"
            },
            AED: {
                displayName: "dirham dos Emiratos Árabes Unidos",
                "displayName-count-one": "dirham dos Emiratos Árabes Unidos",
                "displayName-count-other": "dirhams dos Emiratos Árabes Unidos",
                symbol: "AED"
            },
            AFA: {
                displayName: "AFA",
                symbol: "AFA"
            },
            AFN: {
                displayName: "afgani afgán",
                "displayName-count-one": "afgani afgán",
                "displayName-count-other": "afganis afgáns",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "ALK",
                symbol: "ALK"
            },
            ALL: {
                displayName: "lek albanés",
                "displayName-count-one": "lek albanés",
                "displayName-count-other": "lekë albaneses",
                symbol: "ALL"
            },
            AMD: {
                displayName: "dram armenio",
                "displayName-count-one": "dram armenio",
                "displayName-count-other": "drams armenios",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "florín das Antillas Neerlandesas",
                "displayName-count-one": "florín das Antillas Neerlandesas",
                "displayName-count-other": "floríns das Antillas Neerlandesas",
                symbol: "ANG"
            },
            AOA: {
                displayName: "kwanza angolano",
                "displayName-count-one": "kwanza angolano",
                "displayName-count-other": "kwanzas angolanos",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "AOK",
                symbol: "AOK"
            },
            AON: {
                displayName: "AON",
                symbol: "AON"
            },
            AOR: {
                displayName: "AOR",
                symbol: "AOR"
            },
            ARA: {
                displayName: "ARA",
                symbol: "ARA"
            },
            ARL: {
                displayName: "ARL",
                symbol: "ARL"
            },
            ARM: {
                displayName: "ARM",
                symbol: "ARM"
            },
            ARP: {
                displayName: "Peso arxentino (1983–1985)",
                "displayName-count-one": "peso arxentino (ARP)",
                "displayName-count-other": "pesos arxentinos (ARP)",
                symbol: "ARP"
            },
            ARS: {
                displayName: "peso arxentino",
                "displayName-count-one": "peso arxentino",
                "displayName-count-other": "pesos arxentinos",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "ATS",
                symbol: "ATS"
            },
            AUD: {
                displayName: "dólar australiano",
                "displayName-count-one": "dólar australiano",
                "displayName-count-other": "dólares australianos",
                symbol: "A$",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "florín de Aruba",
                "displayName-count-one": "florín de Aruba",
                "displayName-count-other": "floríns de Aruba",
                symbol: "AWG"
            },
            AZM: {
                displayName: "AZM",
                symbol: "AZM"
            },
            AZN: {
                displayName: "manat acerbaixano",
                "displayName-count-one": "manat acerbaixano",
                "displayName-count-other": "manats acerbaixanos",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "BAD",
                symbol: "BAD"
            },
            BAM: {
                displayName: "marco convertible de Bosnia e Hercegovina",
                "displayName-count-one": "marco convertible de Bosnia e Hercegovina",
                "displayName-count-other": "marcos convertibles de Bosnia e Hercegovina",
                symbol: "BAM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "BAN",
                symbol: "BAN"
            },
            BBD: {
                displayName: "dólar de Barbados",
                "displayName-count-one": "dólar de Barbados",
                "displayName-count-other": "dólares de Barbados",
                symbol: "BBD",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "taka de Bangladesh",
                "displayName-count-one": "taka de Bangladesh",
                "displayName-count-other": "takas de Bangladesh",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "Franco belga (convertible)",
                "displayName-count-one": "franco belga (convertible)",
                "displayName-count-other": "francos belgas (convertibles)",
                symbol: "BEC"
            },
            BEF: {
                displayName: "Franco belga",
                "displayName-count-one": "franco belga",
                "displayName-count-other": "francos belgas",
                symbol: "BEF"
            },
            BEL: {
                displayName: "Franco belga (financeiro)",
                "displayName-count-one": "franco belga (financeiro)",
                "displayName-count-other": "francos belgas (financeiros)",
                symbol: "BEL"
            },
            BGL: {
                displayName: "BGL",
                symbol: "BGL"
            },
            BGM: {
                displayName: "BGM",
                symbol: "BGM"
            },
            BGN: {
                displayName: "lev búlgaro",
                "displayName-count-one": "lev búlgaro",
                "displayName-count-other": "leva búlgaros",
                symbol: "BGN"
            },
            BGO: {
                displayName: "BGO",
                symbol: "BGO"
            },
            BHD: {
                displayName: "dinar de Bahrain",
                "displayName-count-one": "dinar de Bahrain",
                "displayName-count-other": "dinares de Bahrain",
                symbol: "BHD"
            },
            BIF: {
                displayName: "franco burundiano",
                "displayName-count-one": "franco burundiano",
                "displayName-count-other": "francos burundianos",
                symbol: "BIF"
            },
            BMD: {
                displayName: "dólar bermudano",
                "displayName-count-one": "dólar bermudano",
                "displayName-count-other": "dólares bermudanos",
                symbol: "BMD",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "dólar de Brunei",
                "displayName-count-one": "dólar de Brunei",
                "displayName-count-other": "dólares de Brunei",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "boliviano",
                "displayName-count-one": "boliviano",
                "displayName-count-other": "bolivianos",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "BOL",
                symbol: "BOL"
            },
            BOP: {
                displayName: "Peso boliviano",
                "displayName-count-one": "peso boliviano",
                "displayName-count-other": "pesos bolivianos",
                symbol: "BOP"
            },
            BOV: {
                displayName: "MVDOL boliviano",
                symbol: "BOV"
            },
            BRB: {
                displayName: "Cruzeiro novo brasileiro (1967–1986)",
                "displayName-count-one": "cruzeiro novo brasileiro",
                "displayName-count-other": "cruzeiros novos brasileiros",
                symbol: "BRB"
            },
            BRC: {
                displayName: "Cruzado brasileiro",
                "displayName-count-one": "cruzado brasileiro",
                "displayName-count-other": "cruzados brasileiros",
                symbol: "BRC"
            },
            BRE: {
                displayName: "Cruzeiro brasileiro (1990–1993)",
                "displayName-count-one": "cruzeiro brasileiro (BRE)",
                "displayName-count-other": "cruzeiros brasileiros (BRE)",
                symbol: "BRE"
            },
            BRL: {
                displayName: "real brasileiro",
                "displayName-count-one": "real brasileiro",
                "displayName-count-other": "reais brasileiros",
                symbol: "R$",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "Cruzado novo brasileiro",
                "displayName-count-one": "cruzado novo brasileiro",
                "displayName-count-other": "cruzados novos brasileiros",
                symbol: "BRN"
            },
            BRR: {
                displayName: "Cruzeiro brasileiro",
                "displayName-count-one": "cruzeiro brasileiro",
                "displayName-count-other": "cruzeiros brasileiros",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "BRZ",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "dólar bahamés",
                "displayName-count-one": "dólar bahamés",
                "displayName-count-other": "dólares bahameses",
                symbol: "BSD",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "ngultrum butanés",
                "displayName-count-one": "ngultrum butanés",
                "displayName-count-other": "ngultrums butaneses",
                symbol: "BTN"
            },
            BUK: {
                displayName: "BUK",
                symbol: "BUK"
            },
            BWP: {
                displayName: "pula botswaniano",
                "displayName-count-one": "pula botswaniano",
                "displayName-count-other": "pulas botswanianos",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "BYB",
                symbol: "BYB"
            },
            BYN: {
                displayName: "rublo belaruso",
                "displayName-count-one": "rublo belaruso",
                "displayName-count-other": "rublos belarusos",
                symbol: "BYN",
                "symbol-alt-narrow": "Br"
            },
            BYR: {
                displayName: "Rublo bielorruso (2000–2016)",
                "displayName-count-one": "rublo bielorruso (2000–2016)",
                "displayName-count-other": "rublos bielorrusos (2000–2016)",
                symbol: "BYR"
            },
            BZD: {
                displayName: "dólar belizense",
                "displayName-count-one": "dólar belizense",
                "displayName-count-other": "dólares belizenses",
                symbol: "BZD",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "dólar canadense",
                "displayName-count-one": "dólar canadense",
                "displayName-count-other": "dólares canadenses",
                symbol: "CA$",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "franco congolés",
                "displayName-count-one": "franco congolés",
                "displayName-count-other": "francos congoleses",
                symbol: "CDF"
            },
            CHE: {
                displayName: "CHE",
                symbol: "CHE"
            },
            CHF: {
                displayName: "franco suízo",
                "displayName-count-one": "franco suízo",
                "displayName-count-other": "francos suízos",
                symbol: "CHF"
            },
            CHW: {
                displayName: "CHW",
                symbol: "CHW"
            },
            CLE: {
                displayName: "CLE",
                symbol: "CLE"
            },
            CLF: {
                displayName: "Unidades de fomento chilenas",
                "displayName-count-one": "unidade de fomento chilena",
                "displayName-count-other": "unidades de fomento chilenas",
                symbol: "CLF"
            },
            CLP: {
                displayName: "peso chileno",
                "displayName-count-one": "peso chileno",
                "displayName-count-other": "pesos chilenos",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "iuán chinés (extracontinental)",
                "displayName-count-one": "iuán chinés (extracontinental)",
                "displayName-count-other": "iuáns chineses (extracontinentais)",
                symbol: "CNH"
            },
            CNX: {
                displayName: "CNX",
                symbol: "CNX"
            },
            CNY: {
                displayName: "iuán chinés",
                "displayName-count-one": "iuán chinés",
                "displayName-count-other": "iuáns chineses",
                symbol: "CN¥",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "peso colombiano",
                "displayName-count-one": "peso colombiano",
                "displayName-count-other": "pesos colombianos",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "COU",
                symbol: "COU"
            },
            CRC: {
                displayName: "colón costarriqueño",
                "displayName-count-one": "colón costarriqueño",
                "displayName-count-other": "colóns costarriqueños",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "CSD",
                symbol: "CSD"
            },
            CSK: {
                displayName: "CSK",
                symbol: "CSK"
            },
            CUC: {
                displayName: "peso cubano convertible",
                "displayName-count-one": "peso cubano convertible",
                "displayName-count-other": "pesos cubanos convertibles",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "peso cubano",
                "displayName-count-one": "peso cubano",
                "displayName-count-other": "pesos cubanos",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "escudo caboverdiano",
                "displayName-count-one": "escudo caboverdiano",
                "displayName-count-other": "escudos caboverdianos",
                symbol: "CVE"
            },
            CYP: {
                displayName: "CYP",
                symbol: "CYP"
            },
            CZK: {
                displayName: "coroa checa",
                "displayName-count-one": "coroa checa",
                "displayName-count-other": "coroas checas",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "DDM",
                symbol: "DDM"
            },
            DEM: {
                displayName: "Marco alemán",
                "displayName-count-one": "marco alemán",
                "displayName-count-other": "marcos alemáns",
                symbol: "DEM"
            },
            DJF: {
                displayName: "franco djibutiano",
                "displayName-count-one": "franco djibutiano",
                "displayName-count-other": "francos djibutianos",
                symbol: "DJF"
            },
            DKK: {
                displayName: "coroa dinamarquesa",
                "displayName-count-one": "coroa dinamarquesa",
                "displayName-count-other": "coroas dinamarquesas",
                symbol: "DKK",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "peso dominicano",
                "displayName-count-one": "peso dominicano",
                "displayName-count-other": "pesos dominicanos",
                symbol: "DOP",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "dinar alxeriano",
                "displayName-count-one": "dinar alxeriano",
                "displayName-count-other": "dinares alxerianos",
                symbol: "DZD"
            },
            ECS: {
                displayName: "Sucre ecuatoriano",
                "displayName-count-one": "sucre ecuatoriano",
                "displayName-count-other": "sucres ecuatorianos",
                symbol: "ECS"
            },
            ECV: {
                displayName: "Unidade de valor constante ecuatoriana",
                symbol: "ECV"
            },
            EEK: {
                displayName: "EEK",
                symbol: "EEK"
            },
            EGP: {
                displayName: "libra exipcia",
                "displayName-count-one": "libra exipcia",
                "displayName-count-other": "libras exipcias",
                symbol: "EGP",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "nakfa eritreo",
                "displayName-count-one": "nakfa eritreo",
                "displayName-count-other": "nakfas eritreos",
                symbol: "ERN"
            },
            ESA: {
                displayName: "Peseta española (conta A)",
                symbol: "ESA"
            },
            ESB: {
                displayName: "Peseta española (conta convertible)",
                symbol: "ESB"
            },
            ESP: {
                pattern: "#,##0.00 ¤",
                displayName: "Peseta española",
                "displayName-count-one": "peseta",
                "displayName-count-other": "pesetas",
                symbol: "₧",
                "symbol-alt-narrow": "₧",
                decimal: ",",
                group: "."
            },
            ETB: {
                displayName: "birr etíope",
                "displayName-count-one": "birr etíope",
                "displayName-count-other": "birres etíopes",
                symbol: "ETB"
            },
            EUR: {
                displayName: "euro",
                "displayName-count-one": "euro",
                "displayName-count-other": "euros",
                symbol: "€",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "FIM",
                symbol: "FIM"
            },
            FJD: {
                displayName: "dólar fixiano",
                "displayName-count-one": "dólar fixiano",
                "displayName-count-other": "dólares fixianos",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "libra das Illas Malvinas",
                "displayName-count-one": "libra das Illas Malvinas",
                "displayName-count-other": "libras das Illas Malvinas",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "Franco francés",
                "displayName-count-one": "franco francés",
                "displayName-count-other": "francos franceses",
                symbol: "FRF"
            },
            GBP: {
                displayName: "libra esterlina",
                "displayName-count-one": "libra esterlina",
                "displayName-count-other": "libras esterlinas",
                symbol: "£",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "GEK",
                symbol: "GEK"
            },
            GEL: {
                displayName: "lari xeorxiano",
                "displayName-count-one": "lari xeorxiano",
                "displayName-count-other": "laris xeorxianos",
                symbol: "GEL",
                "symbol-alt-narrow": "₾"
            },
            GHC: {
                displayName: "GHC",
                symbol: "GHC"
            },
            GHS: {
                displayName: "cedi ghanés",
                "displayName-count-one": "cedi ghanés",
                "displayName-count-other": "cedis ghaneses",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "libra xibraltareña",
                "displayName-count-one": "libra xibraltareña",
                "displayName-count-other": "libras xibraltareñas",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "dalasi gambiano",
                "displayName-count-one": "dalasi gambiano",
                "displayName-count-other": "dalasis gambianos",
                symbol: "GMD"
            },
            GNF: {
                displayName: "franco guineano",
                "displayName-count-one": "franco guineano",
                "displayName-count-other": "francos guineanos",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "Syli guineano",
                symbol: "GNS"
            },
            GQE: {
                displayName: "Ekwele guineana",
                symbol: "GQE"
            },
            GRD: {
                displayName: "Dracma grego",
                symbol: "GRD"
            },
            GTQ: {
                displayName: "quetzal guatemalteco",
                "displayName-count-one": "quetzal guatemalteco",
                "displayName-count-other": "quetzais guatemaltecos",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "GWE",
                symbol: "GWE"
            },
            GWP: {
                displayName: "GWP",
                symbol: "GWP"
            },
            GYD: {
                displayName: "dólar güianés",
                "displayName-count-one": "dólar güianés",
                "displayName-count-other": "dólares güianeses",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "dólar de Hong Kong",
                "displayName-count-one": "dólar de Hong Kong",
                "displayName-count-other": "dólares de Hong Kong",
                symbol: "HK$",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "lempira hondureño",
                "displayName-count-one": "lempira hondureño",
                "displayName-count-other": "lempiras hondureños",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "HRD",
                symbol: "HRD"
            },
            HRK: {
                displayName: "kuna croata",
                "displayName-count-one": "kuna croata",
                "displayName-count-other": "kunas croatas",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "gourde haitiana",
                "displayName-count-one": "gourde haitiana",
                "displayName-count-other": "gourdes haitianas",
                symbol: "HTG"
            },
            HUF: {
                displayName: "florín húngaro",
                "displayName-count-one": "florín húngaro",
                "displayName-count-other": "floríns húngaros",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "rupia indonesia",
                "displayName-count-one": "rupia indonesia",
                "displayName-count-other": "rupias indonesias",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "Libra irlandesa",
                "displayName-count-one": "libra irlandesa",
                "displayName-count-other": "libras irlandesas",
                symbol: "IEP"
            },
            ILP: {
                displayName: "ILP",
                symbol: "ILP"
            },
            ILR: {
                displayName: "ILR",
                symbol: "ILR"
            },
            ILS: {
                displayName: "novo shequel israelí",
                "displayName-count-one": "novo shequel israelí",
                "displayName-count-other": "novos shequeis israelís",
                symbol: "₪",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "rupia india",
                "displayName-count-one": "rupia india",
                "displayName-count-other": "rupias indias",
                symbol: "₹",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "dinar iraquí",
                "displayName-count-one": "dinar iraquí",
                "displayName-count-other": "dinares iraquíes",
                symbol: "IQD"
            },
            IRR: {
                displayName: "rial iraniano",
                "displayName-count-one": "rial iraniano",
                "displayName-count-other": "riales iranianos",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "ISJ",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "coroa islandesa",
                "displayName-count-one": "coroa islandesa",
                "displayName-count-other": "coroas islandesas",
                symbol: "ISK",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "Lira italiana",
                symbol: "ITL"
            },
            JMD: {
                displayName: "dólar xamaicano",
                "displayName-count-one": "dólar xamaicano",
                "displayName-count-other": "dólares xamaicanos",
                symbol: "JMD",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "dinar xordano",
                "displayName-count-one": "dinar xordano",
                "displayName-count-other": "dinares xordanos",
                symbol: "JOD"
            },
            JPY: {
                displayName: "ien xaponés",
                "displayName-count-one": "ien xaponés",
                "displayName-count-other": "iens xaponeses",
                symbol: "JP¥",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "xilin kenyano",
                "displayName-count-one": "xilin kenyano",
                "displayName-count-other": "xilins kenyanos",
                symbol: "KES"
            },
            KGS: {
                displayName: "som kirguiz",
                "displayName-count-one": "som kirguiz",
                "displayName-count-other": "soms kirguiz",
                symbol: "KGS"
            },
            KHR: {
                displayName: "riel camboxano",
                "displayName-count-one": "riel camboxano",
                "displayName-count-other": "rieis camboxanos",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "franco comoriano",
                "displayName-count-one": "franco comoriano",
                "displayName-count-other": "francos comorianos",
                symbol: "KMF",
                "symbol-alt-narrow": "FC"
            },
            KPW: {
                displayName: "won norcoreano",
                "displayName-count-one": "won norcoreano",
                "displayName-count-other": "wons norcoreanos",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "KRH",
                symbol: "KRH"
            },
            KRO: {
                displayName: "KRO",
                symbol: "KRO"
            },
            KRW: {
                displayName: "won surcoreano",
                "displayName-count-one": "won surcoreano",
                "displayName-count-other": "wons surcoreanos",
                symbol: "₩",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "dinar kuwaití",
                "displayName-count-one": "dinar kuwaití",
                "displayName-count-other": "dinares kuwaitís",
                symbol: "KWD"
            },
            KYD: {
                displayName: "dólar das Illas Caimán",
                "displayName-count-one": "dólar das Illas Caimán",
                "displayName-count-other": "dólares das Illas Caimán",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "tenge kazako",
                "displayName-count-one": "tenge kazako",
                "displayName-count-other": "tenges kazakos",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "kip laosiano",
                "displayName-count-one": "kip laosiano",
                "displayName-count-other": "kips laosianos",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "libra libanesa",
                "displayName-count-one": "libra libanesa",
                "displayName-count-other": "libras libanesas",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "rupia srilankesa",
                "displayName-count-one": "rupia srilankesa",
                "displayName-count-other": "rupias srilankesas",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "dólar liberiano",
                "displayName-count-one": "dólar liberiano",
                "displayName-count-other": "dólares liberianos",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "loti de Lesoto",
                "displayName-count-one": "loti de Lesoto",
                "displayName-count-other": "lotis de Lesoto",
                symbol: "LSL"
            },
            LTL: {
                displayName: "Litas lituana",
                "displayName-count-one": "litas lituana",
                "displayName-count-other": "litas lituanas",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "LTT",
                symbol: "LTT"
            },
            LUC: {
                displayName: "Franco convertible luxemburgués",
                symbol: "LUC"
            },
            LUF: {
                displayName: "Franco luxemburgués",
                symbol: "LUF"
            },
            LUL: {
                displayName: "Franco financeiro luxemburgués",
                symbol: "LUL"
            },
            LVL: {
                displayName: "Lats letón",
                "displayName-count-one": "lats letón",
                "displayName-count-other": "lats letóns",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "LVR",
                symbol: "LVR"
            },
            LYD: {
                displayName: "dinar libio",
                "displayName-count-one": "dinar libio",
                "displayName-count-other": "dinares libios",
                symbol: "LYD"
            },
            MAD: {
                displayName: "dirham marroquí",
                "displayName-count-one": "dirham marroquí",
                "displayName-count-other": "dirhams marroquís",
                symbol: "MAD"
            },
            MAF: {
                displayName: "Franco marroquí",
                symbol: "MAF"
            },
            MCF: {
                displayName: "MCF",
                symbol: "MCF"
            },
            MDC: {
                displayName: "MDC",
                symbol: "MDC"
            },
            MDL: {
                displayName: "leu moldavo",
                "displayName-count-one": "leu moldavo",
                "displayName-count-other": "lei moldavos",
                symbol: "MDL"
            },
            MGA: {
                displayName: "ariary malgaxe",
                "displayName-count-one": "ariary malgaxe",
                "displayName-count-other": "ariarys malgaxes",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "MGF",
                symbol: "MGF"
            },
            MKD: {
                displayName: "dinar macedonio",
                "displayName-count-one": "dinar macedonio",
                "displayName-count-other": "dinares macedonios",
                symbol: "MKD"
            },
            MKN: {
                displayName: "MKN",
                symbol: "MKN"
            },
            MLF: {
                displayName: "MLF",
                symbol: "MLF"
            },
            MMK: {
                displayName: "kyat birmano",
                "displayName-count-one": "kyat birmano",
                "displayName-count-other": "kyats birmanos",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "tugrik mongol",
                "displayName-count-one": "tugrik mongol",
                "displayName-count-other": "tugriks mongois",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "pataca macaense",
                "displayName-count-one": "pataca macaense",
                "displayName-count-other": "patacas macaenses",
                symbol: "MOP"
            },
            MRO: {
                displayName: "Ouguiya mauritano (1973–2017)",
                "displayName-count-one": "ouguiya mauritano (1973–2017)",
                "displayName-count-other": "ouguiyas mauritanos (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "ouguiya mauritano",
                "displayName-count-one": "ouguiya mauritano",
                "displayName-count-other": "ouguiyas mauritanos",
                symbol: "MRU"
            },
            MTL: {
                displayName: "MTL",
                symbol: "MTL"
            },
            MTP: {
                displayName: "MTP",
                symbol: "MTP"
            },
            MUR: {
                displayName: "rupia mauriciana",
                "displayName-count-one": "rupia mauriciana",
                "displayName-count-other": "rupias mauricianas",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "MVP",
                symbol: "MVP"
            },
            MVR: {
                displayName: "rupia maldivana",
                "displayName-count-one": "rupia maldivana",
                "displayName-count-other": "rupias maldivanas",
                symbol: "MVR"
            },
            MWK: {
                displayName: "kwacha de Malawi",
                "displayName-count-one": "kwacha de Malawi",
                "displayName-count-other": "kwachas de Malawi",
                symbol: "MWK"
            },
            MXN: {
                displayName: "peso mexicano",
                "displayName-count-one": "peso mexicano",
                "displayName-count-other": "pesos mexicanos",
                symbol: "$MX",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "Peso de prata mexicano (1861–1992)",
                symbol: "MXP"
            },
            MXV: {
                displayName: "Unidade de inversión mexicana",
                symbol: "MXV"
            },
            MYR: {
                displayName: "ringgit malaio",
                "displayName-count-one": "ringgit malaio",
                "displayName-count-other": "ringgits malaios",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "MZE",
                symbol: "MZE"
            },
            MZM: {
                displayName: "MZM",
                symbol: "MZM"
            },
            MZN: {
                displayName: "metical mozambicano",
                "displayName-count-one": "metical mozambicano",
                "displayName-count-other": "meticais mozambicanos",
                symbol: "MZN"
            },
            NAD: {
                displayName: "dólar namibio",
                "displayName-count-one": "dólar namibio",
                "displayName-count-other": "dólares namibios",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "naira nixeriano",
                "displayName-count-one": "naira nixeriano",
                "displayName-count-other": "nairas nixerianos",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "Córdoba nicaragüense",
                symbol: "NIC"
            },
            NIO: {
                displayName: "córdoba nicaraguano",
                "displayName-count-one": "córdoba nicaraguano",
                "displayName-count-other": "córdobas nicaraguanos",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "Florín holandés",
                symbol: "NLG"
            },
            NOK: {
                displayName: "coroa norueguesa",
                "displayName-count-one": "coroa norueguesa",
                "displayName-count-other": "coroas norueguesas",
                symbol: "NOK",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "rupia nepalesa",
                "displayName-count-one": "rupia nepalesa",
                "displayName-count-other": "rupias nepalesas",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "dólar neozelandés",
                "displayName-count-one": "dólar neozelandés",
                "displayName-count-other": "dólares neozelandeses",
                symbol: "NZ$",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "rial omaní",
                "displayName-count-one": "rial omaní",
                "displayName-count-other": "riais omanís",
                symbol: "OMR"
            },
            PAB: {
                displayName: "balboa panameño",
                "displayName-count-one": "balboa panameño",
                "displayName-count-other": "balboas panameños",
                symbol: "PAB"
            },
            PEI: {
                displayName: "Inti peruano",
                symbol: "PEI"
            },
            PEN: {
                displayName: "sol peruano",
                "displayName-count-one": "sol peruano",
                "displayName-count-other": "soles peruanos",
                symbol: "PEN"
            },
            PES: {
                displayName: "Sol peruano (1863–1965)",
                "displayName-count-one": "sol peruano (1863–1965)",
                "displayName-count-other": "soles peruanos (1863–1965)",
                symbol: "PES"
            },
            PGK: {
                displayName: "kina de Papúa-Nova Guinea",
                "displayName-count-one": "kina de Papúa-Nova Guinea",
                "displayName-count-other": "kinas de Papúa-Nova Guinea",
                symbol: "PGK"
            },
            PHP: {
                displayName: "peso filipino",
                "displayName-count-one": "peso filipino",
                "displayName-count-other": "pesos filipinos",
                symbol: "PHP",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "rupia paquistaní",
                "displayName-count-one": "rupia paquistaní",
                "displayName-count-other": "rupias paquistanís",
                symbol: "PKR",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "zloty polaco",
                "displayName-count-one": "zloty polaco",
                "displayName-count-other": "zlotys polacos",
                symbol: "PLN",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "PLZ",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "Escudo portugués",
                "displayName-count-one": "escudo portugués",
                "displayName-count-other": "escudos portugueses",
                symbol: "PTE"
            },
            PYG: {
                displayName: "guaraní paraguaio",
                "displayName-count-one": "guaraní paraguaio",
                "displayName-count-other": "guaranís paraguaios",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "rial qatarí",
                "displayName-count-one": "rial qatarí",
                "displayName-count-other": "riais qatarís",
                symbol: "QAR"
            },
            RHD: {
                displayName: "RHD",
                symbol: "RHD"
            },
            ROL: {
                displayName: "ROL",
                symbol: "ROL"
            },
            RON: {
                displayName: "leu romanés",
                "displayName-count-one": "leu romanés",
                "displayName-count-other": "lei romaneses",
                symbol: "RON",
                "symbol-alt-narrow": "lei"
            },
            RSD: {
                displayName: "dinar serbio",
                "displayName-count-one": "dinar serbio",
                "displayName-count-other": "dinares serbios",
                symbol: "RSD"
            },
            RUB: {
                displayName: "rublo ruso",
                "displayName-count-one": "rublo ruso",
                "displayName-count-other": "rublos rusos",
                symbol: "RUB",
                "symbol-alt-narrow": "руб"
            },
            RUR: {
                displayName: "Rublo ruso (1991–1998)",
                symbol: "RUR"
            },
            RWF: {
                displayName: "franco ruandés",
                "displayName-count-one": "franco ruandés",
                "displayName-count-other": "francos ruandeses",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "rial saudita",
                "displayName-count-one": "rial saudita",
                "displayName-count-other": "riais sauditas",
                symbol: "SAR"
            },
            SBD: {
                displayName: "dólar das Illas Salomón",
                "displayName-count-one": "dólar das Illas Salomón",
                "displayName-count-other": "dólares das Illas Salomón",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "rupia de Seychelles",
                "displayName-count-one": "rupia de Seychelles",
                "displayName-count-other": "rupias de Seychelles",
                symbol: "SCR"
            },
            SDD: {
                displayName: "SDD",
                symbol: "SDD"
            },
            SDG: {
                displayName: "libra sudanesa",
                "displayName-count-one": "libra sudanesa",
                "displayName-count-other": "libras sudanesas",
                symbol: "SDG"
            },
            SDP: {
                displayName: "SDP",
                symbol: "SDP"
            },
            SEK: {
                displayName: "coroa sueca",
                "displayName-count-one": "coroa sueca",
                "displayName-count-other": "coroas suecas",
                symbol: "SEK",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "dólar de Singapur",
                "displayName-count-one": "dólar de Singapur",
                "displayName-count-other": "dólares de Singapur",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "libra de Santa Helena",
                "displayName-count-one": "libra de Santa Helena",
                "displayName-count-other": "libras de Santa Helena",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "SIT",
                symbol: "SIT"
            },
            SKK: {
                displayName: "SKK",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "leone de Serra Leoa",
                "displayName-count-one": "leone de Serra Leoa",
                "displayName-count-other": "leones de Serra Leoa",
                symbol: "SLL"
            },
            SOS: {
                displayName: "xilin somalí",
                "displayName-count-one": "xilin somalí",
                "displayName-count-other": "xilins somalís",
                symbol: "SOS"
            },
            SRD: {
                displayName: "dólar surinamés",
                "displayName-count-one": "dólar surinamés",
                "displayName-count-other": "dólares surinamés",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "SRG",
                symbol: "SRG"
            },
            SSP: {
                displayName: "libra sursudanesa",
                "displayName-count-one": "libra sursudanesa",
                "displayName-count-other": "libras sursudanesa",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "Dobra de São Tomé e Príncipe (1977–2017)",
                "displayName-count-one": "dobra de São Tomé e Príncipe (1977–2017)",
                "displayName-count-other": "dobras de São Tomé e Príncipe (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "dobra de San Tomé e Príncipe",
                "displayName-count-one": "dobra de San Tomé e Príncipe",
                "displayName-count-other": "dobras de San Tomé e Príncipe",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "Rublo soviético",
                "displayName-count-one": "rublo soviético",
                "displayName-count-other": "rublos soviéticos",
                symbol: "SUR"
            },
            SVC: {
                displayName: "Colón salvadoreño",
                "displayName-count-one": "colón salvadoreño",
                "displayName-count-other": "colóns salvadoreños",
                symbol: "SVC"
            },
            SYP: {
                displayName: "libra siria",
                "displayName-count-one": "libra siria",
                "displayName-count-other": "libras sirias",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "lilangeni de Swazilandia",
                "displayName-count-one": "lilangeni de Swazilandia",
                "displayName-count-other": "lilangenis de Swazilandia",
                symbol: "SZL"
            },
            THB: {
                displayName: "baht tailandés",
                "displayName-count-one": "baht tailandés",
                "displayName-count-other": "bahts tailandeses",
                symbol: "฿",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "TJR",
                symbol: "TJR"
            },
            TJS: {
                displayName: "somoni taxiquistano",
                "displayName-count-one": "somoni taxiquistano",
                "displayName-count-other": "somonis taxiquistanos",
                symbol: "TJS"
            },
            TMM: {
                displayName: "TMM",
                symbol: "TMM"
            },
            TMT: {
                displayName: "manat turkmeno",
                "displayName-count-one": "manat turkmeno",
                "displayName-count-other": "manats turkmenos",
                symbol: "TMT"
            },
            TND: {
                displayName: "dinar tunisiano",
                "displayName-count-one": "dinar tunisiano",
                "displayName-count-other": "dinares tunisianos",
                symbol: "TND"
            },
            TOP: {
                displayName: "paʻanga tongano",
                "displayName-count-one": "paʻanga tongano",
                "displayName-count-other": "pa’angas tonganos",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "TPE",
                symbol: "TPE"
            },
            TRL: {
                displayName: "TRL",
                symbol: "TRL"
            },
            TRY: {
                displayName: "lira turca",
                "displayName-count-one": "lira turca",
                "displayName-count-other": "liras turcas",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "dólar trinitense",
                "displayName-count-one": "dólar trinitense",
                "displayName-count-other": "dólares trinitenses",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "novo dólar taiwanés",
                "displayName-count-one": "novo dólar taiwanés",
                "displayName-count-other": "novos dólares taiwaneses",
                symbol: "NT$",
                "symbol-alt-narrow": "NT$"
            },
            TZS: {
                displayName: "xilin tanzano",
                "displayName-count-one": "xilin tanzano",
                "displayName-count-other": "xilins tanzanos",
                symbol: "TZS"
            },
            UAH: {
                displayName: "hrivna ucraína",
                "displayName-count-one": "hrivna ucraína",
                "displayName-count-other": "hrivnas ucraínas",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "UAK",
                symbol: "UAK"
            },
            UGS: {
                displayName: "UGS",
                symbol: "UGS"
            },
            UGX: {
                displayName: "xilin ugandés",
                "displayName-count-one": "xilin ugandés",
                "displayName-count-other": "xilins ugandeses",
                symbol: "UGX"
            },
            USD: {
                displayName: "dólar estadounidense",
                "displayName-count-one": "dólar estadounidense",
                "displayName-count-other": "dólares estadounidenses",
                symbol: "$",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "USN",
                symbol: "USN"
            },
            USS: {
                displayName: "USS",
                symbol: "USS"
            },
            UYI: {
                displayName: "Peso en unidades indexadas uruguaio",
                symbol: "UYI"
            },
            UYP: {
                displayName: "Peso uruguaio (1975–1993)",
                symbol: "UYP"
            },
            UYU: {
                displayName: "peso uruguaio",
                "displayName-count-one": "peso uruguaio",
                "displayName-count-other": "pesos uruguaios",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "UYW",
                symbol: "UYW"
            },
            UZS: {
                displayName: "som uzbeko",
                "displayName-count-one": "som uzbeko",
                "displayName-count-other": "soms uzbekos",
                symbol: "UZS"
            },
            VEB: {
                displayName: "Bolívar venezolano (1871–2008)",
                "displayName-count-one": "bolívar venezolano (1871–2008)",
                "displayName-count-other": "bolívares venezolanos (1871–2008)",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "Bolívar venezolano (2008–2018)",
                "displayName-count-one": "bolívar venezolano (2008–2018)",
                "displayName-count-other": "bolívares venezolanos (2008–2018)",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs"
            },
            VES: {
                displayName: "bolívar venezolano",
                "displayName-count-one": "bolívar venezolano",
                "displayName-count-other": "bolívares venezolanos",
                symbol: "VES"
            },
            VND: {
                displayName: "dong vietnamita",
                "displayName-count-one": "dong vietnamita",
                "displayName-count-other": "dongs vietnamitas",
                symbol: "₫",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "VNN",
                symbol: "VNN"
            },
            VUV: {
                displayName: "vatu vanuatiano",
                "displayName-count-one": "vatu vanuatiano",
                "displayName-count-other": "vatus vanuatianos",
                symbol: "VUV"
            },
            WST: {
                displayName: "tala samoano",
                "displayName-count-one": "tala samoano",
                "displayName-count-other": "talas samoanos",
                symbol: "WST"
            },
            XAF: {
                displayName: "franco CFA (BEAC)",
                "displayName-count-one": "franco CFA (BEAC)",
                "displayName-count-other": "francos CFA (BEAC)",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "Prata",
                symbol: "XAG"
            },
            XAU: {
                displayName: "Ouro",
                symbol: "XAU"
            },
            XBA: {
                displayName: "XBA",
                symbol: "XBA"
            },
            XBB: {
                displayName: "XBB",
                symbol: "XBB"
            },
            XBC: {
                displayName: "XBC",
                symbol: "XBC"
            },
            XBD: {
                displayName: "XBD",
                symbol: "XBD"
            },
            XCD: {
                displayName: "dólar do Caribe Oriental",
                "displayName-count-one": "dólar do Caribe Oriental",
                "displayName-count-other": "dólares do Caribe Oriental",
                symbol: "XCD",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "XDR",
                symbol: "XDR"
            },
            XEU: {
                displayName: "XEU",
                symbol: "XEU"
            },
            XFO: {
                displayName: "XFO",
                symbol: "XFO"
            },
            XFU: {
                displayName: "XFU",
                symbol: "XFU"
            },
            XOF: {
                displayName: "franco CFA (BCEAO)",
                "displayName-count-one": "franco CFA (BCEAO)",
                "displayName-count-other": "francos CFA (BCEAO)",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "Paladio",
                symbol: "XPD"
            },
            XPF: {
                displayName: "franco CFP",
                "displayName-count-one": "franco CFP",
                "displayName-count-other": "francos CFP",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "Platino",
                symbol: "XPT"
            },
            XRE: {
                displayName: "XRE",
                symbol: "XRE"
            },
            XSU: {
                displayName: "XSU",
                symbol: "XSU"
            },
            XTS: {
                displayName: "XTS",
                symbol: "XTS"
            },
            XUA: {
                displayName: "XUA",
                symbol: "XUA"
            },
            XXX: {
                displayName: "moeda descoñecida",
                "displayName-count-one": "(moeda descoñecida)",
                "displayName-count-other": "(moedas descoñecidas)",
                symbol: "¤"
            },
            YDD: {
                displayName: "YDD",
                symbol: "YDD"
            },
            YER: {
                displayName: "rial iemení",
                "displayName-count-one": "rial iemení",
                "displayName-count-other": "riais iemenís",
                symbol: "YER"
            },
            YUD: {
                displayName: "YUD",
                symbol: "YUD"
            },
            YUM: {
                displayName: "YUM",
                symbol: "YUM"
            },
            YUN: {
                displayName: "YUN",
                symbol: "YUN"
            },
            YUR: {
                displayName: "YUR",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "ZAL",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "rand surafricano",
                "displayName-count-one": "rand surafricano",
                "displayName-count-other": "rands surafricanos",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "Kwacha zambiano (1968–2012)",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "kwacha zambiano",
                "displayName-count-one": "kwacha zambiano",
                "displayName-count-other": "kwachas zambianos",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "ZRN",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "ZRZ",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "ZWD",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "ZWL",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "ZWR",
                symbol: "ZWR"
            }
        },
        localeCurrency: "EUR"
    },
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, d 'de' MMMM 'de' y",
            m: "d 'de' MMM",
            M: "d 'de' MMMM",
            y: "MMM 'de' y",
            Y: "MMMM 'de' y",
            F: "EEEE, d 'de' MMMM 'de' y HH:mm:ss",
            g: "d/M/y HH:mm",
            G: "d/M/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{0} 'do' {1}",
            long: "{0} 'do' {1}",
            medium: "{0}, {1}",
            short: "{0}, {1}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E, h:mm B",
                EBhms: "E, h:mm:ss B",
                Ed: "E d",
                Ehm: "E, h:mm a",
                EHm: "E, HH:mm",
                Ehms: "E, h:mm:ss a",
                EHms: "E, HH:mm:ss",
                Gy: "y G",
                GyMd: "d/M/y GGGGG",
                GyMMM: "MMM 'de' y G",
                GyMMMd: "d 'de' MMM 'de' y G",
                GyMMMEd: "E, d 'de' MMM 'de' y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E, d/M",
                MMdd: "dd/MM",
                MMM: "LLL",
                MMMd: "d 'de' MMM",
                MMMEd: "E, d 'de' MMM",
                MMMMd: "d 'de' MMMM",
                MMMMEd: "E, d 'de' MMMM",
                "MMMMW-count-one": "W.'ª' 'semana' 'de' MMMM",
                "MMMMW-count-other": "W.'ª' 'semana' 'de' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E, d/M/y",
                yMM: "MM/y",
                yMMM: "MMM 'de' y",
                yMMMd: "d 'de' MMM 'de' y",
                yMMMEd: "E, d 'de' MMM 'de' y",
                yMMMM: "MMMM 'de' y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ 'de' y",
                "yw-count-one": "w.'ª' 'semana' 'de' Y",
                "yw-count-other": "w.'ª' 'semana' 'de' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d 'de' MMMM 'de' y",
            long: "d 'de' MMMM 'de' y",
            medium: "d 'de' MMM 'de' y",
            short: "dd/MM/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "dom.",
                    "luns",
                    "mar.",
                    "mér.",
                    "xov.",
                    "ven.",
                    "sáb."
                ],
                narrow: [
                    "d.",
                    "l.",
                    "m.",
                    "m.",
                    "x.",
                    "v.",
                    "s."
                ],
                short: [
                    "do.",
                    "lu.",
                    "ma.",
                    "mé.",
                    "xo.",
                    "ve.",
                    "sá."
                ],
                wide: [
                    "domingo",
                    "luns",
                    "martes",
                    "mércores",
                    "xoves",
                    "venres",
                    "sábado"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Dom.",
                    "Luns",
                    "Mar.",
                    "Mér.",
                    "Xov.",
                    "Ven.",
                    "Sáb."
                ],
                narrow: [
                    "D",
                    "L",
                    "M",
                    "M",
                    "X",
                    "V",
                    "S"
                ],
                short: [
                    "Do",
                    "Lu",
                    "Ma",
                    "Mé",
                    "Xo",
                    "Ve",
                    "Sá"
                ],
                wide: [
                    "Domingo",
                    "Luns",
                    "Martes",
                    "Mércores",
                    "Xoves",
                    "Venres",
                    "Sábado"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "xan.",
                    "feb.",
                    "mar.",
                    "abr.",
                    "maio",
                    "xuño",
                    "xul.",
                    "ago.",
                    "set.",
                    "out.",
                    "nov.",
                    "dec."
                ],
                narrow: [
                    "x.",
                    "f.",
                    "m.",
                    "a.",
                    "m.",
                    "x.",
                    "x.",
                    "a.",
                    "s.",
                    "o.",
                    "n.",
                    "d."
                ],
                wide: [
                    "xaneiro",
                    "febreiro",
                    "marzo",
                    "abril",
                    "maio",
                    "xuño",
                    "xullo",
                    "agosto",
                    "setembro",
                    "outubro",
                    "novembro",
                    "decembro"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Xan.",
                    "Feb.",
                    "Mar.",
                    "Abr.",
                    "Maio",
                    "Xuño",
                    "Xul.",
                    "Ago.",
                    "Set.",
                    "Out.",
                    "Nov.",
                    "Dec."
                ],
                narrow: [
                    "X",
                    "F",
                    "M",
                    "A",
                    "M",
                    "X",
                    "X",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Xaneiro",
                    "Febreiro",
                    "Marzo",
                    "Abril",
                    "Maio",
                    "Xuño",
                    "Xullo",
                    "Agosto",
                    "Setembro",
                    "Outubro",
                    "Novembro",
                    "Decembro"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "T1",
                    "T2",
                    "T3",
                    "T4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1.º trimestre",
                    "2.º trimestre",
                    "3.º trimestre",
                    "4.º trimestre"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "T1",
                    "T2",
                    "T3",
                    "T4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1.º trimestre",
                    "2.º trimestre",
                    "3.º trimestre",
                    "4.º trimestre"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "da noite",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "da madrugada",
                    morning2: "da mañá",
                    afternoon1: "do mediodía",
                    evening1: "da tarde",
                    night1: "da noite"
                },
                narrow: {
                    midnight: "da noite",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "da madrugada",
                    morning2: "da mañá",
                    afternoon1: "do mediodía",
                    evening1: "da tarde",
                    night1: "da noite"
                },
                wide: {
                    midnight: "da noite",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "da madrugada",
                    morning2: "da mañá",
                    afternoon1: "do mediodía",
                    evening1: "da tarde",
                    night1: "da noite"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "medianoite",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "madrugada",
                    morning2: "mañá",
                    afternoon1: "mediodía",
                    evening1: "tarde",
                    night1: "noite"
                },
                narrow: {
                    midnight: "medianoite",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "madrugada",
                    morning2: "mañá",
                    afternoon1: "mediodía",
                    evening1: "tarde",
                    night1: "noite"
                },
                wide: {
                    midnight: "medianoite",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "madrugada",
                    morning2: "mañá",
                    afternoon1: "mediodía",
                    evening1: "tarde",
                    night1: "noite"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "antes de Cristo",
                    "1": "despois de Cristo",
                    "0-alt-variant": "antes da era común",
                    "1-alt-variant": "da era común"
                },
                abbreviated: {
                    "0": "a.C.",
                    "1": "d.C.",
                    "0-alt-variant": "a.e.c.",
                    "1-alt-variant": "e.c."
                },
                narrow: {
                    "0": "a.C.",
                    "1": "d.C.",
                    "0-alt-variant": "a.e.c.",
                    "1-alt-variant": "e.c."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "era",
                short: "era",
                narrow: "era"
            },
            year: {
                wide: "ano",
                short: "ano",
                narrow: "ano"
            },
            quarter: {
                wide: "trimestre",
                short: "trim.",
                narrow: "trim."
            },
            month: {
                wide: "mes",
                short: "mes",
                narrow: "mes"
            },
            week: {
                wide: "semana",
                short: "sem.",
                narrow: "sem."
            },
            weekOfMonth: {
                wide: "semana do mes",
                short: "sem. do mes",
                narrow: "sem. do mes"
            },
            day: {
                wide: "día",
                short: "día",
                narrow: "día"
            },
            dayOfYear: {
                wide: "día do ano",
                short: "día do ano",
                narrow: "día do ano"
            },
            weekday: {
                wide: "día da semana",
                short: "día da sem.",
                narrow: "día da sem."
            },
            weekdayOfMonth: {
                wide: "semana do mes",
                short: "sem. do mes",
                narrow: "sem. do mes"
            },
            dayperiod: {
                short: "a.m./p.m.",
                wide: "a.m./p.m.",
                narrow: "a.m./p.m."
            },
            hour: {
                wide: "hora",
                short: "h",
                narrow: "h"
            },
            minute: {
                wide: "minuto",
                short: "min",
                narrow: "min"
            },
            second: {
                wide: "segundo",
                short: "s",
                narrow: "s"
            },
            zone: {
                wide: "fuso horario",
                short: "fuso",
                narrow: "fuso"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "milisegundo"
            }
        }
    },
    firstDay: 1,
    weekendRange: {
        start: 6,
        end: 0
    },
    likelySubtags: {
        gl: "gl-Latn-ES"
    }
});

