/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "gl",
    likelySubtags: {
        gl: "gl-Latn-ES"
    },
    identity: {
        language: "gl"
    },
    territory: "ES",
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, d 'de' MMMM 'de' y",
            m: "d 'de' MMM",
            M: "d 'de' MMMM",
            y: "MMM 'de' y",
            Y: "MMMM 'de' y",
            F: "EEEE, d 'de' MMMM 'de' y HH:mm:ss",
            g: "d/M/y HH:mm",
            G: "d/M/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{0} 'do' {1}",
            long: "{0} 'do' {1}",
            medium: "{0}, {1}",
            short: "{0}, {1}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E, h:mm B",
                EBhms: "E, h:mm:ss B",
                Ed: "E d",
                Ehm: "E, h:mm a",
                EHm: "E, HH:mm",
                Ehms: "E, h:mm:ss a",
                EHms: "E, HH:mm:ss",
                Gy: "y G",
                GyMd: "d/M/y GGGGG",
                GyMMM: "MMM 'de' y G",
                GyMMMd: "d 'de' MMM 'de' y G",
                GyMMMEd: "E, d 'de' MMM 'de' y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E, d/M",
                MMdd: "dd/MM",
                MMM: "LLL",
                MMMd: "d 'de' MMM",
                MMMEd: "E, d 'de' MMM",
                MMMMd: "d 'de' MMMM",
                MMMMEd: "E, d 'de' MMMM",
                "MMMMW-count-one": "W.'ª' 'semana' 'de' MMMM",
                "MMMMW-count-other": "W.'ª' 'semana' 'de' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E, d/M/y",
                yMM: "MM/y",
                yMMM: "MMM 'de' y",
                yMMMd: "d 'de' MMM 'de' y",
                yMMMEd: "E, d 'de' MMM 'de' y",
                yMMMM: "MMMM 'de' y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ 'de' y",
                "yw-count-one": "w.'ª' 'semana' 'de' Y",
                "yw-count-other": "w.'ª' 'semana' 'de' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d 'de' MMMM 'de' y",
            long: "d 'de' MMMM 'de' y",
            medium: "d 'de' MMM 'de' y",
            short: "dd/MM/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "dom.",
                    "luns",
                    "mar.",
                    "mér.",
                    "xov.",
                    "ven.",
                    "sáb."
                ],
                narrow: [
                    "d.",
                    "l.",
                    "m.",
                    "m.",
                    "x.",
                    "v.",
                    "s."
                ],
                short: [
                    "do.",
                    "lu.",
                    "ma.",
                    "mé.",
                    "xo.",
                    "ve.",
                    "sá."
                ],
                wide: [
                    "domingo",
                    "luns",
                    "martes",
                    "mércores",
                    "xoves",
                    "venres",
                    "sábado"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Dom.",
                    "Luns",
                    "Mar.",
                    "Mér.",
                    "Xov.",
                    "Ven.",
                    "Sáb."
                ],
                narrow: [
                    "D",
                    "L",
                    "M",
                    "M",
                    "X",
                    "V",
                    "S"
                ],
                short: [
                    "Do",
                    "Lu",
                    "Ma",
                    "Mé",
                    "Xo",
                    "Ve",
                    "Sá"
                ],
                wide: [
                    "Domingo",
                    "Luns",
                    "Martes",
                    "Mércores",
                    "Xoves",
                    "Venres",
                    "Sábado"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "xan.",
                    "feb.",
                    "mar.",
                    "abr.",
                    "maio",
                    "xuño",
                    "xul.",
                    "ago.",
                    "set.",
                    "out.",
                    "nov.",
                    "dec."
                ],
                narrow: [
                    "x.",
                    "f.",
                    "m.",
                    "a.",
                    "m.",
                    "x.",
                    "x.",
                    "a.",
                    "s.",
                    "o.",
                    "n.",
                    "d."
                ],
                wide: [
                    "xaneiro",
                    "febreiro",
                    "marzo",
                    "abril",
                    "maio",
                    "xuño",
                    "xullo",
                    "agosto",
                    "setembro",
                    "outubro",
                    "novembro",
                    "decembro"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Xan.",
                    "Feb.",
                    "Mar.",
                    "Abr.",
                    "Maio",
                    "Xuño",
                    "Xul.",
                    "Ago.",
                    "Set.",
                    "Out.",
                    "Nov.",
                    "Dec."
                ],
                narrow: [
                    "X",
                    "F",
                    "M",
                    "A",
                    "M",
                    "X",
                    "X",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Xaneiro",
                    "Febreiro",
                    "Marzo",
                    "Abril",
                    "Maio",
                    "Xuño",
                    "Xullo",
                    "Agosto",
                    "Setembro",
                    "Outubro",
                    "Novembro",
                    "Decembro"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "T1",
                    "T2",
                    "T3",
                    "T4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1.º trimestre",
                    "2.º trimestre",
                    "3.º trimestre",
                    "4.º trimestre"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "T1",
                    "T2",
                    "T3",
                    "T4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1.º trimestre",
                    "2.º trimestre",
                    "3.º trimestre",
                    "4.º trimestre"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "da noite",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "da madrugada",
                    morning2: "da mañá",
                    afternoon1: "do mediodía",
                    evening1: "da tarde",
                    night1: "da noite"
                },
                narrow: {
                    midnight: "da noite",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "da madrugada",
                    morning2: "da mañá",
                    afternoon1: "do mediodía",
                    evening1: "da tarde",
                    night1: "da noite"
                },
                wide: {
                    midnight: "da noite",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "da madrugada",
                    morning2: "da mañá",
                    afternoon1: "do mediodía",
                    evening1: "da tarde",
                    night1: "da noite"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "medianoite",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "madrugada",
                    morning2: "mañá",
                    afternoon1: "mediodía",
                    evening1: "tarde",
                    night1: "noite"
                },
                narrow: {
                    midnight: "medianoite",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "madrugada",
                    morning2: "mañá",
                    afternoon1: "mediodía",
                    evening1: "tarde",
                    night1: "noite"
                },
                wide: {
                    midnight: "medianoite",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "madrugada",
                    morning2: "mañá",
                    afternoon1: "mediodía",
                    evening1: "tarde",
                    night1: "noite"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "antes de Cristo",
                    "1": "despois de Cristo",
                    "0-alt-variant": "antes da era común",
                    "1-alt-variant": "da era común"
                },
                abbreviated: {
                    "0": "a.C.",
                    "1": "d.C.",
                    "0-alt-variant": "a.e.c.",
                    "1-alt-variant": "e.c."
                },
                narrow: {
                    "0": "a.C.",
                    "1": "d.C.",
                    "0-alt-variant": "a.e.c.",
                    "1-alt-variant": "e.c."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "era",
                short: "era",
                narrow: "era"
            },
            year: {
                wide: "ano",
                short: "ano",
                narrow: "ano"
            },
            quarter: {
                wide: "trimestre",
                short: "trim.",
                narrow: "trim."
            },
            month: {
                wide: "mes",
                short: "mes",
                narrow: "mes"
            },
            week: {
                wide: "semana",
                short: "sem.",
                narrow: "sem."
            },
            weekOfMonth: {
                wide: "semana do mes",
                short: "sem. do mes",
                narrow: "sem. do mes"
            },
            day: {
                wide: "día",
                short: "día",
                narrow: "día"
            },
            dayOfYear: {
                wide: "día do ano",
                short: "día do ano",
                narrow: "día do ano"
            },
            weekday: {
                wide: "día da semana",
                short: "día da sem.",
                narrow: "día da sem."
            },
            weekdayOfMonth: {
                wide: "semana do mes",
                short: "sem. do mes",
                narrow: "sem. do mes"
            },
            dayperiod: {
                short: "a.m./p.m.",
                wide: "a.m./p.m.",
                narrow: "a.m./p.m."
            },
            hour: {
                wide: "hora",
                short: "h",
                narrow: "h"
            },
            minute: {
                wide: "minuto",
                short: "min",
                narrow: "min"
            },
            second: {
                wide: "segundo",
                short: "s",
                narrow: "s"
            },
            zone: {
                wide: "fuso horario",
                short: "fuso",
                narrow: "fuso"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "milisegundo"
            }
        }
    },
    firstDay: 1
});

