/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "he",
    identity: {
        language: "he"
    },
    territory: "IL",
    numbers: {
        symbols: {
            decimal: ".",
            group: ",",
            list: ";",
            percentSign: "%",
            plusSign: "‎+",
            minusSign: "‎-",
            approximatelySign: "~",
            exponential: "E",
            superscriptingExponent: "×",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "n%"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "‏n $",
                "‏-n $"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-one": "n $",
            "unitPattern-count-two": "n $",
            "unitPattern-count-many": "n $",
            "unitPattern-count-other": "n $"
        },
        accounting: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "פזטה אנדורית",
                symbol: "ADP"
            },
            AED: {
                displayName: "דירהם של איחוד הנסיכויות הערביות",
                "displayName-count-one": "דירהם של איחוד הנסיכויות הערביות",
                "displayName-count-two": "דירהם של איחוד הנסיכויות הערביות",
                "displayName-count-many": "דירהם של איחוד הנסיכויות הערביות",
                "displayName-count-other": "דירהם של איחוד הנסיכויות הערביות",
                symbol: "AED"
            },
            AFA: {
                displayName: "AFA",
                symbol: "AFA"
            },
            AFN: {
                displayName: "אפגני אפגני",
                "displayName-count-one": "אפגני אפגני",
                "displayName-count-two": "אפגני אפגני",
                "displayName-count-many": "אפגני אפגני",
                "displayName-count-other": "אפגני אפגני",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "ALK",
                symbol: "ALK"
            },
            ALL: {
                displayName: "לק אלבני",
                "displayName-count-one": "לק אלבני",
                "displayName-count-two": "לק אלבני",
                "displayName-count-many": "לק אלבני",
                "displayName-count-other": "לק אלבני",
                symbol: "ALL"
            },
            AMD: {
                displayName: "דראם ארמני",
                "displayName-count-one": "דראם ארמני",
                "displayName-count-two": "דראם ארמני",
                "displayName-count-many": "דראם ארמני",
                "displayName-count-other": "דראם ארמני",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "גילדר של האנטילים ההולנדיים",
                "displayName-count-one": "גילדר של האנטילים ההולנדיים",
                "displayName-count-two": "גילדר של האנטילים ההולנדיים",
                "displayName-count-many": "גילדר של האנטילים ההולנדיים",
                "displayName-count-other": "גילדר של האנטילים ההולנדיים",
                symbol: "ANG"
            },
            AOA: {
                displayName: "קואנזה אנגולי",
                "displayName-count-one": "קואנזה אנגולי",
                "displayName-count-two": "קואנזה אנגולי",
                "displayName-count-many": "קואנזה אנגולי",
                "displayName-count-other": "קואנזה אנגולי",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "AOK",
                symbol: "AOK"
            },
            AON: {
                displayName: "קואנזה חדש אנגולי (1990–2000)",
                symbol: "AON"
            },
            AOR: {
                displayName: "קואנזה רג׳וסטדו אנגולי (1995–1999)",
                symbol: "AOR"
            },
            ARA: {
                displayName: "ARA",
                symbol: "ARA"
            },
            ARL: {
                displayName: "ARL",
                symbol: "ARL"
            },
            ARM: {
                displayName: "ARM",
                symbol: "ARM"
            },
            ARP: {
                displayName: "פזו ארגנטינאי (1983–1985)",
                symbol: "ARP"
            },
            ARS: {
                displayName: "פסו ארגנטינאי",
                "displayName-count-one": "פסו ארגנטינאי",
                "displayName-count-two": "פסו ארגנטינאי",
                "displayName-count-many": "פסו ארגנטינאי",
                "displayName-count-other": "פסו ארגנטינאי",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "שילינג אוסטרי",
                symbol: "ATS"
            },
            AUD: {
                displayName: "דולר אוסטרלי",
                "displayName-count-one": "דולר אוסטרלי",
                "displayName-count-two": "דולר אוסטרלי",
                "displayName-count-many": "דולר אוסטרלי",
                "displayName-count-other": "דולר אוסטרלי",
                symbol: "A$",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "פלורין של ארובה",
                "displayName-count-one": "פלורין של ארובה",
                "displayName-count-two": "פלורין של ארובה",
                "displayName-count-many": "פלורין של ארובה",
                "displayName-count-other": "פלורין של ארובה",
                symbol: "AWG"
            },
            AZM: {
                displayName: "מנאט אזרביג׳אני (1993–2006)",
                symbol: "AZM"
            },
            AZN: {
                displayName: "מאנאט אזרבייג׳ני",
                "displayName-count-one": "מאנאט אזרבייג׳ני",
                "displayName-count-two": "מאנאט אזרבייג׳ני",
                "displayName-count-many": "מאנאט אזרבייג׳ני",
                "displayName-count-other": "מאנאט אזרבייג׳ני",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "דינר של בוסניה־הרצגובינה",
                symbol: "BAD"
            },
            BAM: {
                displayName: "מארק סחיר של בוסניה והרצגובינה",
                "displayName-count-one": "מארק סחיר של בוסניה והרצגובינה",
                "displayName-count-two": "מארק סחיר של בוסניה והרצגובינה",
                "displayName-count-many": "מארק סחיר של בוסניה והרצגובינה",
                "displayName-count-other": "מארק סחיר של בוסניה והרצגובינה",
                symbol: "BAM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "BAN",
                symbol: "BAN"
            },
            BBD: {
                displayName: "דולר ברבדיאני",
                "displayName-count-one": "דולר ברבדיאני",
                "displayName-count-two": "דולר ברבדיאני",
                "displayName-count-many": "דולר ברבדיאני",
                "displayName-count-other": "דולר ברבדיאני",
                symbol: "BBD",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "טאקה בנגלדשי",
                "displayName-count-one": "טאקה בנגלדשי",
                "displayName-count-two": "טאקה בנגלדשי",
                "displayName-count-many": "טאקה בנגלדשי",
                "displayName-count-other": "טאקה בנגלדשי",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "פרנק בלגי (בר המרה)",
                symbol: "BEC"
            },
            BEF: {
                displayName: "פרנק בלגי",
                symbol: "BEF"
            },
            BEL: {
                displayName: "BEL",
                symbol: "BEL"
            },
            BGL: {
                displayName: "לב בולגרי ישן",
                symbol: "BGL"
            },
            BGM: {
                displayName: "BGM",
                symbol: "BGM"
            },
            BGN: {
                displayName: "לב בולגרי",
                "displayName-count-one": "לב בולגרי",
                "displayName-count-two": "לב בולגרי",
                "displayName-count-many": "לב בולגרי",
                "displayName-count-other": "לב בולגרי",
                symbol: "BGN"
            },
            BGO: {
                displayName: "BGO",
                symbol: "BGO"
            },
            BHD: {
                displayName: "דינר בחרייני",
                "displayName-count-one": "דינר בחרייני",
                "displayName-count-two": "דינר בחרייני",
                "displayName-count-many": "דינר בחרייני",
                "displayName-count-other": "דינר בחרייני",
                symbol: "BHD"
            },
            BIF: {
                displayName: "פרנק בורונדי",
                "displayName-count-one": "פרנק בורונדי",
                "displayName-count-two": "פרנק בורונדי",
                "displayName-count-many": "פרנק בורונדי",
                "displayName-count-other": "פרנק בורונדי",
                symbol: "BIF"
            },
            BMD: {
                displayName: "דולר ברמודה",
                "displayName-count-one": "דולר ברמודה",
                "displayName-count-two": "דולר ברמודה",
                "displayName-count-many": "דולר ברמודה",
                "displayName-count-other": "דולר ברמודה",
                symbol: "BMD",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "דולר ברוניי",
                "displayName-count-one": "דולר ברוניי",
                "displayName-count-two": "דולר ברוניי",
                "displayName-count-many": "דולר ברוניי",
                "displayName-count-other": "דולר ברוניי",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "בוליביאנו",
                "displayName-count-one": "בוליביאנו",
                "displayName-count-two": "בוליביאנו",
                "displayName-count-many": "בוליביאנו",
                "displayName-count-other": "בוליביאנו",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "BOL",
                symbol: "BOL"
            },
            BOP: {
                displayName: "פזו בוליבי",
                symbol: "BOP"
            },
            BOV: {
                displayName: "BOV",
                symbol: "BOV"
            },
            BRB: {
                displayName: "קרוזיארו חדש ברזילאי (1967–1986)",
                symbol: "BRB"
            },
            BRC: {
                displayName: "קרוזדו ברזילאי",
                symbol: "BRC"
            },
            BRE: {
                displayName: "BRE",
                symbol: "BRE"
            },
            BRL: {
                displayName: "ריאל ברזילאי",
                "displayName-count-one": "ריאל ברזילאי",
                "displayName-count-two": "ריאל ברזילאי",
                "displayName-count-many": "ריאל ברזילאי",
                "displayName-count-other": "ריאל ברזילאי",
                symbol: "R$",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "BRN",
                symbol: "BRN"
            },
            BRR: {
                displayName: "BRR",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "BRZ",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "דולר בהאמי",
                "displayName-count-one": "דולר בהאמי",
                "displayName-count-two": "דולר בהאמי",
                "displayName-count-many": "דולר בהאמי",
                "displayName-count-other": "דולר בהאמי",
                symbol: "BSD",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "נגולטרום בהוטני",
                "displayName-count-one": "נגולטרום בהוטני",
                "displayName-count-two": "נגולטרום בהוטני",
                "displayName-count-many": "נגולטרום בהוטני",
                "displayName-count-other": "נגולטרום בהוטני",
                symbol: "BTN"
            },
            BUK: {
                displayName: "BUK",
                symbol: "BUK"
            },
            BWP: {
                displayName: "פולה בוטסואני",
                "displayName-count-one": "פולה בוטסואני",
                "displayName-count-two": "פולה בוטסואני",
                "displayName-count-many": "פולה בוטסואני",
                "displayName-count-other": "פולה בוטסואני",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "BYB",
                symbol: "BYB"
            },
            BYN: {
                displayName: "רובל בלרוסי",
                "displayName-count-one": "רובל בלרוסי",
                "displayName-count-two": "רובל בלרוסי",
                "displayName-count-many": "רובל בלרוסי",
                "displayName-count-other": "רובל בלרוסי",
                symbol: "BYN",
                "symbol-alt-narrow": "р"
            },
            BYR: {
                displayName: "רובל בלרוסי (2000–2016)",
                "displayName-count-one": "רובל בלרוסי (2000–2016)",
                "displayName-count-two": "רובל בלרוסי (2000–2016)",
                "displayName-count-many": "רובל בלרוסי (2000–2016)",
                "displayName-count-other": "רובל בלרוסי (2000–2016)",
                symbol: "BYR"
            },
            BZD: {
                displayName: "דולר בליזי",
                "displayName-count-one": "דולר בליזי",
                "displayName-count-two": "דולר בליזי",
                "displayName-count-many": "דולר בליזי",
                "displayName-count-other": "דולר בליזי",
                symbol: "BZD",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "דולר קנדי",
                "displayName-count-one": "דולר קנדי",
                "displayName-count-two": "דולר קנדי",
                "displayName-count-many": "דולר קנדי",
                "displayName-count-other": "דולר קנדי",
                symbol: "CA$",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "פרנק קונגולזי",
                "displayName-count-one": "פרנק קונגולזי",
                "displayName-count-two": "פרנק קונגולזי",
                "displayName-count-many": "פרנק קונגולזי",
                "displayName-count-other": "פרנק קונגולזי",
                symbol: "CDF"
            },
            CHE: {
                displayName: "CHE",
                symbol: "CHE"
            },
            CHF: {
                displayName: "פרנק שוויצרי",
                "displayName-count-one": "פרנק שוויצרי",
                "displayName-count-two": "פרנק שוויצרי",
                "displayName-count-many": "פרנק שוויצרי",
                "displayName-count-other": "פרנק שוויצרי",
                symbol: "CHF"
            },
            CHW: {
                displayName: "CHW",
                symbol: "CHW"
            },
            CLE: {
                displayName: "CLE",
                symbol: "CLE"
            },
            CLF: {
                displayName: "CLF",
                symbol: "CLF"
            },
            CLP: {
                displayName: "פסו צ׳ילאני",
                "displayName-count-one": "פסו צ׳ילאני",
                "displayName-count-two": "פסו צ׳ילאני",
                "displayName-count-many": "פסו צ׳ילאני",
                "displayName-count-other": "פסו צ׳ילאני",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "יואן סיני (CNH)",
                "displayName-count-one": "יואן סיני (CNH)",
                "displayName-count-two": "יואן סיני (CNH)",
                "displayName-count-many": "יואן סיני (CNH)",
                "displayName-count-other": "יואן סיני (CNH)",
                symbol: "CNH"
            },
            CNX: {
                displayName: "CNX",
                symbol: "CNX"
            },
            CNY: {
                displayName: "יואן סיני",
                "displayName-count-one": "יואן סיני",
                "displayName-count-two": "יואן סיני",
                "displayName-count-many": "יואן סיני",
                "displayName-count-other": "יואן סיני",
                symbol: "‎CN¥‎",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "פסו קולומביאני",
                "displayName-count-one": "פסו קולומביאני",
                "displayName-count-two": "פסו קולומביאני",
                "displayName-count-many": "פסו קולומביאני",
                "displayName-count-other": "פסו קולומביאני",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "COU",
                symbol: "COU"
            },
            CRC: {
                displayName: "קולון קוסטה־ריקני",
                "displayName-count-one": "קולון קוסטה־ריקני",
                "displayName-count-two": "קולון קוסטה־ריקני",
                "displayName-count-many": "קולון קוסטה־ריקני",
                "displayName-count-other": "קולון קוסטה־ריקני",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "דינר סרבי ישן",
                symbol: "CSD"
            },
            CSK: {
                displayName: "CSK",
                symbol: "CSK"
            },
            CUC: {
                displayName: "פסו קובני להמרה",
                "displayName-count-one": "פסו קובני להמרה",
                "displayName-count-two": "פסו קובני להמרה",
                "displayName-count-many": "פסו קובני להמרה",
                "displayName-count-other": "פסו קובני להמרה",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "פסו קובני",
                "displayName-count-one": "פסו קובני",
                "displayName-count-two": "פסו קובני",
                "displayName-count-many": "פסו קובני",
                "displayName-count-other": "פסו קובני",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "אסקודו כף ורדה",
                "displayName-count-one": "אסקודו כף ורדה",
                "displayName-count-two": "אסקודו כף ורדה",
                "displayName-count-many": "אסקודו כף ורדה",
                "displayName-count-other": "אסקודו כף ורדה",
                symbol: "CVE"
            },
            CYP: {
                displayName: "לירה קפריסאית",
                symbol: "CYP"
            },
            CZK: {
                displayName: "קורונה צ׳כית",
                "displayName-count-one": "קורונה צ׳כית",
                "displayName-count-two": "קורונה צ׳כית",
                "displayName-count-many": "קורונה צ׳כית",
                "displayName-count-other": "קורונה צ׳כית",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "מרק מזרח גרמני",
                symbol: "DDM"
            },
            DEM: {
                displayName: "מרק גרמני",
                symbol: "DEM"
            },
            DJF: {
                displayName: "פרנק ג׳יבוטי",
                "displayName-count-one": "פרנק ג׳יבוטי",
                "displayName-count-two": "פרנק ג׳יבוטי",
                "displayName-count-many": "פרנק ג׳יבוטי",
                "displayName-count-other": "פרנק ג׳יבוטי",
                symbol: "DJF"
            },
            DKK: {
                displayName: "כתר דני",
                "displayName-count-one": "כתר דני",
                "displayName-count-two": "כתר דני",
                "displayName-count-many": "כתר דני",
                "displayName-count-other": "כתר דני",
                symbol: "DKK",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "פסו דומיניקני",
                "displayName-count-one": "פסו דומיניקני",
                "displayName-count-two": "פסו דומיניקני",
                "displayName-count-many": "פסו דומיניקני",
                "displayName-count-other": "פסו דומיניקני",
                symbol: "DOP",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "דינר אלג׳ירי",
                "displayName-count-one": "דינר אלג׳ירי",
                "displayName-count-two": "דינר אלג׳ירי",
                "displayName-count-many": "דינר אלג׳ירי",
                "displayName-count-other": "דינר אלג׳ירי",
                symbol: "DZD"
            },
            ECS: {
                displayName: "סוקר אקואדורי",
                symbol: "ECS"
            },
            ECV: {
                displayName: "ECV",
                symbol: "ECV"
            },
            EEK: {
                displayName: "קרון אסטוני",
                symbol: "EEK"
            },
            EGP: {
                displayName: "לירה מצרית",
                "displayName-count-one": "לירה מצרית",
                "displayName-count-two": "לירה מצרית",
                "displayName-count-many": "לירה מצרית",
                "displayName-count-other": "לירה מצרית",
                symbol: "EGP",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "נאקפה אריתראי",
                "displayName-count-one": "נאקפה אריתראי",
                "displayName-count-two": "נאקפה אריתראי",
                "displayName-count-many": "נאקפה אריתראי",
                "displayName-count-other": "נאקפה אריתראי",
                symbol: "ERN"
            },
            ESA: {
                displayName: "ESA",
                symbol: "ESA"
            },
            ESB: {
                displayName: "ESB",
                symbol: "ESB"
            },
            ESP: {
                displayName: "פסטה ספרדי",
                symbol: "ESP",
                "symbol-alt-narrow": "₧"
            },
            ETB: {
                displayName: "ביר אתיופי",
                "displayName-count-one": "ביר אתיופי",
                "displayName-count-two": "ביר אתיופי",
                "displayName-count-many": "ביר אתיופי",
                "displayName-count-other": "ביר אתיופי",
                symbol: "ETB"
            },
            EUR: {
                displayName: "אירו",
                "displayName-count-one": "אירו",
                "displayName-count-two": "אירו",
                "displayName-count-many": "אירו",
                "displayName-count-other": "אירו",
                symbol: "€",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "מרק פיני",
                symbol: "FIM"
            },
            FJD: {
                displayName: "דולר פיג׳י",
                "displayName-count-one": "דולר פיג׳י",
                "displayName-count-two": "דולר פיג׳י",
                "displayName-count-many": "דולר פיג׳י",
                "displayName-count-other": "דולר פיג׳י",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "לירה של איי פוקלנד",
                "displayName-count-one": "לירה של איי פוקלנד",
                "displayName-count-two": "לירה של איי פוקלנד",
                "displayName-count-many": "לירה של איי פוקלנד",
                "displayName-count-other": "לירה של איי פוקלנד",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "פרנק צרפתי",
                symbol: "FRF"
            },
            GBP: {
                displayName: "לירה שטרלינג",
                "displayName-count-one": "לירה שטרלינג",
                "displayName-count-two": "לירה שטרלינג",
                "displayName-count-many": "לירה שטרלינג",
                "displayName-count-other": "לירה שטרלינג",
                symbol: "£",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "GEK",
                symbol: "GEK"
            },
            GEL: {
                displayName: "לארי גאורגי",
                "displayName-count-one": "לארי גאורגי",
                "displayName-count-two": "לארי גאורגי",
                "displayName-count-many": "לארי גאורגי",
                "displayName-count-other": "לארי גאורגי",
                symbol: "GEL",
                "symbol-alt-narrow": "₾"
            },
            GHC: {
                displayName: "GHC",
                symbol: "GHC"
            },
            GHS: {
                displayName: "סדי גאני",
                "displayName-count-one": "סדי גאני",
                "displayName-count-two": "סדי גאני",
                "displayName-count-many": "סדי גאני",
                "displayName-count-other": "סדי גאני",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "פאונד גיברלטר",
                "displayName-count-one": "פאונד גיברלטר",
                "displayName-count-two": "פאונד גיברלטר",
                "displayName-count-many": "פאונד גיברלטר",
                "displayName-count-other": "פאונד גיברלטר",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "דלסי גמבי",
                "displayName-count-one": "דלסי גמבי",
                "displayName-count-two": "דלסי גמבי",
                "displayName-count-many": "דלסי גמבי",
                "displayName-count-other": "דלסי גמבי",
                symbol: "GMD"
            },
            GNF: {
                displayName: "פרנק גינאי",
                "displayName-count-one": "פרנק גינאי",
                "displayName-count-two": "פרנק גינאי",
                "displayName-count-many": "פרנק גינאי",
                "displayName-count-other": "פרנק גינאי",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "GNS",
                symbol: "GNS"
            },
            GQE: {
                displayName: "GQE",
                symbol: "GQE"
            },
            GRD: {
                displayName: "דרכמה",
                symbol: "GRD"
            },
            GTQ: {
                displayName: "קצאל גואטמלי",
                "displayName-count-one": "קצאל גואטמלי",
                "displayName-count-two": "קצאל גואטמלי",
                "displayName-count-many": "קצאל גואטמלי",
                "displayName-count-other": "קצאל גואטמלי",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "GWE",
                symbol: "GWE"
            },
            GWP: {
                displayName: "פזו גינאי",
                symbol: "GWP"
            },
            GYD: {
                displayName: "דולר גיאני",
                "displayName-count-one": "דולר גיאני",
                "displayName-count-two": "דולר גיאני",
                "displayName-count-many": "דולר גיאני",
                "displayName-count-other": "דולר גיאני",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "דולר הונג קונגי",
                "displayName-count-one": "דולר הונג קונגי",
                "displayName-count-two": "דולר הונג קונגי",
                "displayName-count-many": "דולר הונג קונגי",
                "displayName-count-other": "דולר הונג קונגי",
                symbol: "HK$",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "למפירה הונדורי",
                "displayName-count-one": "למפירה הונדורי",
                "displayName-count-two": "למפירה הונדורי",
                "displayName-count-many": "למפירה הונדורי",
                "displayName-count-other": "למפירה הונדורי",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "HRD",
                symbol: "HRD"
            },
            HRK: {
                displayName: "קונה קרואטי",
                "displayName-count-one": "קונה קרואטי",
                "displayName-count-two": "קונה קרואטי",
                "displayName-count-many": "קונה קרואטי",
                "displayName-count-other": "קונה קרואטי",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "גורד האיטי",
                "displayName-count-one": "גורד האיטי",
                "displayName-count-two": "גורד האיטי",
                "displayName-count-many": "גורד האיטי",
                "displayName-count-other": "גורד האיטי",
                symbol: "HTG"
            },
            HUF: {
                displayName: "פורינט הונגרי",
                "displayName-count-one": "פורינט הונגרי",
                "displayName-count-two": "פורינט הונגרי",
                "displayName-count-many": "פורינט הונגרי",
                "displayName-count-other": "פורינט הונגרי",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "רופיה אינדונזית",
                "displayName-count-one": "רופיה אינדונזית",
                "displayName-count-two": "רופיה אינדונזית",
                "displayName-count-many": "רופיה אינדונזית",
                "displayName-count-other": "רופיה אינדונזית",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "לירה אירית",
                symbol: "IEP"
            },
            ILP: {
                displayName: "לירה ישראלית",
                symbol: "ל״י"
            },
            ILR: {
                displayName: "ILR",
                symbol: "ILR"
            },
            ILS: {
                displayName: "שקל חדש",
                "displayName-count-one": "שקל חדש",
                "displayName-count-two": "שקלים חדשים",
                "displayName-count-many": "שקלים חדשים",
                "displayName-count-other": "שקלים חדשים",
                symbol: "₪",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "רופי הודי",
                "displayName-count-one": "רופי הודי",
                "displayName-count-two": "רופי הודי",
                "displayName-count-many": "רופי הודי",
                "displayName-count-other": "רופי הודי",
                symbol: "₹",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "דינר עיראקי",
                "displayName-count-one": "דינר עיראקי",
                "displayName-count-two": "דינר עיראקי",
                "displayName-count-many": "דינר עיראקי",
                "displayName-count-other": "דינר עיראקי",
                symbol: "IQD"
            },
            IRR: {
                displayName: "ריאל איראני",
                "displayName-count-one": "ריאל איראני",
                "displayName-count-two": "ריאל איראני",
                "displayName-count-many": "ריאל איראני",
                "displayName-count-other": "ריאל איראני",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "ISJ",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "כתר איסלנדי",
                "displayName-count-one": "כתר איסלנדי",
                "displayName-count-two": "כתר איסלנדי",
                "displayName-count-many": "כתר איסלנדי",
                "displayName-count-other": "כתר איסלנדי",
                symbol: "ISK",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "לירה איטלקית",
                symbol: "ITL"
            },
            JMD: {
                displayName: "דולר ג׳מייקני",
                "displayName-count-one": "דולר ג׳מייקני",
                "displayName-count-two": "דולר ג׳מייקני",
                "displayName-count-many": "דולר ג׳מייקני",
                "displayName-count-other": "דולר ג׳מייקני",
                symbol: "JMD",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "דינר ירדני",
                "displayName-count-one": "דינר ירדני",
                "displayName-count-two": "דינר ירדני",
                "displayName-count-many": "דינר ירדני",
                "displayName-count-other": "דינר ירדני",
                symbol: "JOD"
            },
            JPY: {
                displayName: "ין יפני",
                "displayName-count-one": "ין יפני",
                "displayName-count-two": "ין יפני",
                "displayName-count-many": "ין יפני",
                "displayName-count-other": "ין יפני",
                symbol: "¥",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "שילינג קנייתי",
                "displayName-count-one": "שילינג קנייתי",
                "displayName-count-two": "שילינג קנייתי",
                "displayName-count-many": "שילינג קנייתי",
                "displayName-count-other": "שילינג קנייתי",
                symbol: "KES"
            },
            KGS: {
                displayName: "סום קירגיזי",
                "displayName-count-one": "סום קירגיזי",
                "displayName-count-two": "סום קירגיזי",
                "displayName-count-many": "סום קירגיזי",
                "displayName-count-other": "סום קירגיזי",
                symbol: "KGS"
            },
            KHR: {
                displayName: "ריל קמבודי",
                "displayName-count-one": "ריל קמבודי",
                "displayName-count-two": "ריל קמבודי",
                "displayName-count-many": "ריל קמבודי",
                "displayName-count-other": "ריל קמבודי",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "פרנק קומורואי",
                "displayName-count-one": "פרנק קומורואי",
                "displayName-count-two": "פרנק קומורואי",
                "displayName-count-many": "פרנק קומורואי",
                "displayName-count-other": "פרנק קומורואי",
                symbol: "KMF",
                "symbol-alt-narrow": "CF"
            },
            KPW: {
                displayName: "וון צפון קוריאני",
                "displayName-count-one": "וון צפון קוריאני",
                "displayName-count-two": "וון צפון קוריאני",
                "displayName-count-many": "וון צפון קוריאני",
                "displayName-count-other": "וון צפון קוריאני",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "KRH",
                symbol: "KRH"
            },
            KRO: {
                displayName: "KRO",
                symbol: "KRO"
            },
            KRW: {
                displayName: "וון דרום קוריאני",
                "displayName-count-one": "וון דרום קוריאני",
                "displayName-count-two": "וון דרום קוריאני",
                "displayName-count-many": "וון דרום קוריאני",
                "displayName-count-other": "וון דרום קוריאני",
                symbol: "₩",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "דינר כוויתי",
                "displayName-count-one": "דינר כוויתי",
                "displayName-count-two": "דינר כוויתי",
                "displayName-count-many": "דינר כוויתי",
                "displayName-count-other": "דינר כוויתי",
                symbol: "KWD"
            },
            KYD: {
                displayName: "דולר קיימני",
                "displayName-count-one": "דולר קיימני",
                "displayName-count-two": "דולר קיימני",
                "displayName-count-many": "דולר קיימני",
                "displayName-count-other": "דולר קיימני",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "טנגה קזחסטני",
                "displayName-count-one": "טנגה קזחסטני",
                "displayName-count-two": "טנגה קזחסטני",
                "displayName-count-many": "טנגה קזחסטני",
                "displayName-count-other": "טנגה קזחסטני",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "קיפ לאי",
                "displayName-count-one": "קיפ לאי",
                "displayName-count-two": "קיפ לאי",
                "displayName-count-many": "קיפ לאי",
                "displayName-count-other": "קיפ לאי",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "לירה לבנונית",
                "displayName-count-one": "לירה לבנונית",
                "displayName-count-two": "לירה לבנונית",
                "displayName-count-many": "לירה לבנונית",
                "displayName-count-other": "לירה לבנונית",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "רופי סרי לנקי",
                "displayName-count-one": "רופי סרי לנקי",
                "displayName-count-two": "רופי סרי לנקי",
                "displayName-count-many": "רופי סרי לנקי",
                "displayName-count-other": "רופי סרי לנקי",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "דולר ליברי",
                "displayName-count-one": "דולר ליברי",
                "displayName-count-two": "דולר ליברי",
                "displayName-count-many": "דולר ליברי",
                "displayName-count-other": "דולר ליברי",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "לוטי לסותי",
                symbol: "LSL"
            },
            LTL: {
                displayName: "ליטא ליטאי",
                "displayName-count-one": "ליטא ליטאי",
                "displayName-count-two": "ליטא ליטאי",
                "displayName-count-many": "ליטא ליטאי",
                "displayName-count-other": "ליטא ליטאי",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "LTT",
                symbol: "LTT"
            },
            LUC: {
                displayName: "LUC",
                symbol: "LUC"
            },
            LUF: {
                displayName: "פרנק לוקסמבורגי",
                symbol: "LUF"
            },
            LUL: {
                displayName: "LUL",
                symbol: "LUL"
            },
            LVL: {
                displayName: "לט לטבי",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "LVR",
                symbol: "LVR"
            },
            LYD: {
                displayName: "דינר לובי",
                "displayName-count-one": "דינר לובי",
                "displayName-count-two": "דינר לובי",
                "displayName-count-many": "דינר לובי",
                "displayName-count-other": "דינר לובי",
                symbol: "LYD"
            },
            MAD: {
                displayName: "דירהם מרוקאי",
                "displayName-count-one": "דירהם מרוקאי",
                "displayName-count-two": "דירהם מרוקאי",
                "displayName-count-many": "דירהם מרוקאי",
                "displayName-count-other": "דירהם מרוקאי",
                symbol: "MAD"
            },
            MAF: {
                displayName: "פרנק מרוקאי",
                symbol: "MAF"
            },
            MCF: {
                displayName: "MCF",
                symbol: "MCF"
            },
            MDC: {
                displayName: "MDC",
                symbol: "MDC"
            },
            MDL: {
                displayName: "לאו מולדובני",
                "displayName-count-one": "לאו מולדובני",
                "displayName-count-two": "לאו מולדובני",
                "displayName-count-many": "לאו מולדובני",
                "displayName-count-other": "לאו מולדובני",
                symbol: "MDL"
            },
            MGA: {
                displayName: "אריארי מלגשי",
                "displayName-count-one": "אריארי מלגשי",
                "displayName-count-two": "אריארי מלגשי",
                "displayName-count-many": "אריארי מלגשי",
                "displayName-count-other": "אריארי מלגשי",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "פרנק מדגסקארי",
                symbol: "MGF"
            },
            MKD: {
                displayName: "דינר מקדוני",
                "displayName-count-one": "דינר מקדוני",
                "displayName-count-two": "דינר מקדוני",
                "displayName-count-many": "דינר מקדוני",
                "displayName-count-other": "דינר מקדוני",
                symbol: "MKD"
            },
            MKN: {
                displayName: "MKN",
                symbol: "MKN"
            },
            MLF: {
                displayName: "MLF",
                symbol: "MLF"
            },
            MMK: {
                displayName: "קיאט מיאנמרי",
                "displayName-count-one": "קיאט מיאנמרי",
                "displayName-count-two": "קיאט מיאנמרי",
                "displayName-count-many": "קיאט מיאנמרי",
                "displayName-count-other": "קיאט מיאנמרי",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "טוגרוג מונגולי",
                "displayName-count-one": "טוגרוג מונגולי",
                "displayName-count-two": "טוגרוג מונגולי",
                "displayName-count-many": "טוגרוג מונגולי",
                "displayName-count-other": "טוגרוג מונגולי",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "פטקה של מקאו",
                "displayName-count-one": "פטקה של מקאו",
                "displayName-count-two": "פטקה של מקאו",
                "displayName-count-many": "פטקה של מקאו",
                "displayName-count-other": "פטקה של מקאו",
                symbol: "MOP"
            },
            MRO: {
                displayName: "אואוגויה מאוריטני (1973–2017)",
                "displayName-count-one": "אואוגויה מאוריטני (1973–2017)",
                "displayName-count-two": "אואוגויה מאוריטני (1973–2017)",
                "displayName-count-many": "אואוגויה מאוריטני (1973–2017)",
                "displayName-count-other": "אואוגויה מאוריטני (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "אואוגויה מאוריטני",
                "displayName-count-one": "אואוגויה מאוריטני",
                "displayName-count-two": "אואוגויה מאוריטני",
                "displayName-count-many": "אואוגויה מאוריטני",
                "displayName-count-other": "אואוגויה מאוריטני",
                symbol: "MRU"
            },
            MTL: {
                displayName: "לירה מלטית",
                symbol: "MTL"
            },
            MTP: {
                displayName: "MTP",
                symbol: "MTP"
            },
            MUR: {
                displayName: "רופי מאוריציני",
                "displayName-count-one": "רופי מאוריציני",
                "displayName-count-two": "רופי מאוריציני",
                "displayName-count-many": "רופי מאוריציני",
                "displayName-count-other": "רופי מאוריציני",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "MVP",
                symbol: "MVP"
            },
            MVR: {
                displayName: "רופיה מלדיבית",
                "displayName-count-one": "רופיה מלדיבית",
                "displayName-count-two": "רופיה מלדיבית",
                "displayName-count-many": "רופיה מלדיבית",
                "displayName-count-other": "רופיה מלדיבית",
                symbol: "MVR"
            },
            MWK: {
                displayName: "קואצ׳ה מלאווי",
                "displayName-count-one": "קואצ׳ה מלאווי",
                "displayName-count-two": "קואצ׳ה מלאווי",
                "displayName-count-many": "קואצ׳ה מלאווי",
                "displayName-count-other": "קואצ׳ה מלאווי",
                symbol: "MWK"
            },
            MXN: {
                displayName: "פסו מקסיקני",
                "displayName-count-one": "פסו מקסיקני",
                "displayName-count-two": "פסו מקסיקני",
                "displayName-count-many": "פסו מקסיקני",
                "displayName-count-other": "פסו מקסיקני",
                symbol: "MX$",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "פזו מקסיקני (1861 – 1992)",
                "displayName-count-one": "פסו מקסיקני (1861 – 1992)",
                "displayName-count-two": "פסו מקסיקני (1861 – 1992)",
                "displayName-count-many": "פסו מקסיקני (1861 – 1992)",
                "displayName-count-other": "פסו מקסיקני (1861 – 1992)",
                symbol: "MXP"
            },
            MXV: {
                displayName: "יחידת השקעות מקסיקנית",
                "displayName-count-one": "יחידת השקעות מקסיקנית",
                "displayName-count-two": "יחידות השקעות מקסיקניות",
                "displayName-count-many": "יחידות השקעות מקסיקניות",
                "displayName-count-other": "יחידות השקעות מקסיקניות",
                symbol: "MXV"
            },
            MYR: {
                displayName: "רינגיט מלזי",
                "displayName-count-one": "רינגיט מלזי",
                "displayName-count-two": "רינגיט מלזי",
                "displayName-count-many": "רינגיט מלזי",
                "displayName-count-other": "רינגיט מלזי",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "אסקודו מוזמביקי",
                "displayName-count-one": "אסקודו מוזמביקי",
                "displayName-count-two": "אסקודואים מוזמביקיים",
                "displayName-count-many": "אסקודו מוזמביקי",
                "displayName-count-other": "אסקודואים מוזמביקיים",
                symbol: "MZE"
            },
            MZM: {
                displayName: "מטיקל",
                symbol: "MZM"
            },
            MZN: {
                displayName: "מטיקל מוזמביני",
                "displayName-count-one": "מטיקל מוזמביני",
                "displayName-count-two": "מטיקל מוזמביני",
                "displayName-count-many": "מטיקל מוזמביני",
                "displayName-count-other": "מטיקל מוזמביני",
                symbol: "MZN"
            },
            NAD: {
                displayName: "דולר נמיבי",
                "displayName-count-one": "דולר נמיבי",
                "displayName-count-two": "דולר נמיבי",
                "displayName-count-many": "דולר נמיבי",
                "displayName-count-other": "דולר נמיבי",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "נאירה ניגרי",
                "displayName-count-one": "נאירה ניגרי",
                "displayName-count-two": "נאירה ניגרי",
                "displayName-count-many": "נאירה ניגרי",
                "displayName-count-other": "נאירה ניגרי",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "קורדובה (1988–1991)",
                "displayName-count-one": "קורדובה (1988–1991)",
                "displayName-count-two": "קורדובות (1988–1991)",
                "displayName-count-many": "קורדובות (1988–1991)",
                "displayName-count-other": "קורדובות (1988–1991)",
                symbol: "NIC"
            },
            NIO: {
                displayName: "קורדובה ניקרגואה",
                "displayName-count-one": "קורדובה ניקרגואה",
                "displayName-count-two": "קורדובה ניקרגואה",
                "displayName-count-many": "קורדובה ניקרגואה",
                "displayName-count-other": "קורדובה ניקרגואה",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "גילדן הולנדי",
                symbol: "NLG"
            },
            NOK: {
                displayName: "כתר נורווגי",
                "displayName-count-one": "כתר נורווגי",
                "displayName-count-two": "כתר נורווגי",
                "displayName-count-many": "כתר נורווגי",
                "displayName-count-other": "כתר נורווגי",
                symbol: "NOK",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "רופי נפאלי",
                "displayName-count-one": "רופי נפאלי",
                "displayName-count-two": "רופי נפאלי",
                "displayName-count-many": "רופי נפאלי",
                "displayName-count-other": "רופי נפאלי",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "דולר ניו זילנדי",
                "displayName-count-one": "דולר ניו זילנדי",
                "displayName-count-two": "דולר ניו זילנדי",
                "displayName-count-many": "דולר ניו זילנדי",
                "displayName-count-other": "דולר ניו זילנדי",
                symbol: "NZ$",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "ריאל עומאני",
                "displayName-count-one": "ריאל עומאני",
                "displayName-count-two": "ריאל עומאני",
                "displayName-count-many": "ריאל עומאני",
                "displayName-count-other": "ריאל עומאני",
                symbol: "OMR"
            },
            PAB: {
                displayName: "בלבואה פנמי",
                "displayName-count-one": "בלבואה פנמי",
                "displayName-count-two": "בלבואה פנמי",
                "displayName-count-many": "בלבואה פנמי",
                "displayName-count-other": "בלבואה פנמי",
                symbol: "PAB"
            },
            PEI: {
                displayName: "PEI",
                symbol: "PEI"
            },
            PEN: {
                displayName: "סול פרואני",
                "displayName-count-one": "סול פרואני",
                "displayName-count-two": "סול פרואני",
                "displayName-count-many": "סול פרואני",
                "displayName-count-other": "סול פרואני",
                symbol: "PEN"
            },
            PES: {
                displayName: "PES",
                symbol: "PES"
            },
            PGK: {
                displayName: "קינה של פפואה גינאה החדשה",
                "displayName-count-one": "קינה של פפואה גינאה החדשה",
                "displayName-count-two": "קינה של פפואה גינאה החדשה",
                "displayName-count-many": "קינה של פפואה גינאה החדשה",
                "displayName-count-other": "קינה של פפואה גינאה החדשה",
                symbol: "PGK"
            },
            PHP: {
                displayName: "פזו פיליפיני",
                "displayName-count-one": "פזו פיליפיני",
                "displayName-count-two": "פזו פיליפיני",
                "displayName-count-many": "פזו פיליפיני",
                "displayName-count-other": "פזו פיליפיני",
                symbol: "PHP",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "רופי פקיסטני",
                "displayName-count-one": "רופי פקיסטני",
                "displayName-count-two": "רופי פקיסטני",
                "displayName-count-many": "רופי פקיסטני",
                "displayName-count-other": "רופי פקיסטני",
                symbol: "PKR",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "זלוטי פולני",
                "displayName-count-one": "זלוטי פולני",
                "displayName-count-two": "זלוטי פולני",
                "displayName-count-many": "זלוטי פולני",
                "displayName-count-other": "זלוטי פולני",
                symbol: "PLN",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "PLZ",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "אסקודו פורטוגלי",
                symbol: "PTE"
            },
            PYG: {
                displayName: "גוארני פרגוואי",
                "displayName-count-one": "גוארני פרגוואי",
                "displayName-count-two": "גוארני פרגוואי",
                "displayName-count-many": "גוארני פרגוואי",
                "displayName-count-other": "גוארני פרגוואי",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "ריאל קטארי",
                "displayName-count-one": "ריאל קטארי",
                "displayName-count-two": "ריאל קטארי",
                "displayName-count-many": "ריאל קטארי",
                "displayName-count-other": "ריאל קטארי",
                symbol: "QAR"
            },
            RHD: {
                displayName: "RHD",
                symbol: "RHD"
            },
            ROL: {
                displayName: "לאו רומני ישן",
                symbol: "ROL"
            },
            RON: {
                displayName: "לאו רומני",
                "displayName-count-one": "לאו רומני",
                "displayName-count-two": "לאו רומני",
                "displayName-count-many": "לאו רומני",
                "displayName-count-other": "לאו רומני",
                symbol: "RON",
                "symbol-alt-narrow": "lei"
            },
            RSD: {
                displayName: "דינר סרבי",
                "displayName-count-one": "דינר סרבי",
                "displayName-count-two": "דינר סרבי",
                "displayName-count-many": "דינר סרבי",
                "displayName-count-other": "דינר סרבי",
                symbol: "RSD"
            },
            RUB: {
                displayName: "רובל רוסי",
                "displayName-count-one": "רובל רוסי",
                "displayName-count-two": "רובל רוסי",
                "displayName-count-many": "רובל רוסי",
                "displayName-count-other": "רובל רוסי",
                symbol: "RUB",
                "symbol-alt-narrow": "₽",
                "symbol-alt-variant": "₽"
            },
            RUR: {
                displayName: "רובל רוסי (1991 – 1998)",
                symbol: "RUR"
            },
            RWF: {
                displayName: "פרנק רואנדי",
                "displayName-count-one": "פרנק רואנדי",
                "displayName-count-two": "פרנק רואנדי",
                "displayName-count-many": "פרנק רואנדי",
                "displayName-count-other": "פרנק רואנדי",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "ריאל סעודי",
                "displayName-count-one": "ריאל סעודי",
                "displayName-count-two": "ריאל סעודי",
                "displayName-count-many": "ריאל סעודי",
                "displayName-count-other": "ריאל סעודי",
                symbol: "SAR"
            },
            SBD: {
                displayName: "דולר איי שלמה",
                "displayName-count-one": "דולר איי שלמה",
                "displayName-count-two": "דולר איי שלמה",
                "displayName-count-many": "דולר איי שלמה",
                "displayName-count-other": "דולר איי שלמה",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "רופי סיישלי",
                "displayName-count-one": "רופי סיישלי",
                "displayName-count-two": "רופי סיישלי",
                "displayName-count-many": "רופי סיישלי",
                "displayName-count-other": "רופי סיישלי",
                symbol: "SCR"
            },
            SDD: {
                displayName: "דינר סודני",
                symbol: "SDD"
            },
            SDG: {
                displayName: "לירה סודנית",
                "displayName-count-one": "לירה סודנית",
                "displayName-count-two": "לירה סודנית",
                "displayName-count-many": "לירה סודנית",
                "displayName-count-other": "לירה סודנית",
                symbol: "SDG"
            },
            SDP: {
                displayName: "לירה סודנית (1957–1998)",
                symbol: "SDP"
            },
            SEK: {
                displayName: "כתר שוודי",
                "displayName-count-one": "כתר שוודי",
                "displayName-count-two": "כתר שוודי",
                "displayName-count-many": "כתר שוודי",
                "displayName-count-other": "כתר שוודי",
                symbol: "SEK",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "דולר סינגפורי",
                "displayName-count-one": "דולר סינגפורי",
                "displayName-count-two": "דולר סינגפורי",
                "displayName-count-many": "דולר סינגפורי",
                "displayName-count-other": "דולר סינגפורי",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "פאונד סנט הלני",
                "displayName-count-one": "פאונד סנט הלני",
                "displayName-count-two": "פאונד סנט הלני",
                "displayName-count-many": "פאונד סנט הלני",
                "displayName-count-other": "פאונד סנט הלני",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "טולאר סלובני",
                symbol: "SIT"
            },
            SKK: {
                displayName: "קורונה סלובקי",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "ליאון סיירה לאוני",
                "displayName-count-one": "ליאון סיירה לאוני",
                "displayName-count-two": "ליאון סיירה לאוני",
                "displayName-count-many": "ליאון סיירה לאוני",
                "displayName-count-other": "ליאון סיירה לאוני",
                symbol: "SLL"
            },
            SOS: {
                displayName: "שילינג סומלי",
                "displayName-count-one": "שילינג סומלי",
                "displayName-count-two": "שילינג סומלי",
                "displayName-count-many": "שילינג סומלי",
                "displayName-count-other": "שילינג סומלי",
                symbol: "SOS"
            },
            SRD: {
                displayName: "דולר סורינאמי",
                "displayName-count-one": "דולר סורינאמי",
                "displayName-count-two": "דולר סורינאמי",
                "displayName-count-many": "דולר סורינאמי",
                "displayName-count-other": "דולר סורינאמי",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "גילדר סורינאמי",
                symbol: "SRG"
            },
            SSP: {
                displayName: "לירה דרום-סודנית",
                "displayName-count-one": "לירה דרום-סודנית",
                "displayName-count-two": "לירה דרום-סודנית",
                "displayName-count-many": "לירה דרום-סודנית",
                "displayName-count-other": "לירה דרום-סודנית",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "דוברה של סן טומה ופרינסיפה (1977–2017)",
                "displayName-count-one": "דוברה של סן טומה ופרינסיפה (1977–2017)",
                "displayName-count-two": "דוברה של סן טומה ופרינסיפה (1977–2017)",
                "displayName-count-many": "דוברה של סן טומה ופרינסיפה (1977–2017)",
                "displayName-count-other": "דוברה של סן טומה ופרינסיפה (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "דוברה של סאו טומה ופרינסיפה",
                "displayName-count-one": "דוברה של סאו טומה ופרינסיפה",
                "displayName-count-two": "דוברה של סאו טומה ופרינסיפה",
                "displayName-count-many": "דוברה של סאו טומה ופרינסיפה",
                "displayName-count-other": "דוברה של סאו טומה ופרינסיפה",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "רובל סובייטי",
                symbol: "SUR"
            },
            SVC: {
                displayName: "קולון סלבדורי",
                "displayName-count-one": "קולון סלבדורי",
                "displayName-count-two": "קולונים סלבדוריים",
                "displayName-count-many": "קולון סלבדורי",
                "displayName-count-other": "קולונים סלבדוריים",
                symbol: "SVC"
            },
            SYP: {
                displayName: "לירה סורית",
                "displayName-count-one": "לירה סורית",
                "displayName-count-two": "לירה סורית",
                "displayName-count-many": "לירה סורית",
                "displayName-count-other": "לירה סורית",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "לילנגני סווזילנדי",
                "displayName-count-one": "לילנגני סווזילנדי",
                "displayName-count-two": "לילנגני סווזילנדי",
                "displayName-count-many": "לילנגני סווזילנדי",
                "displayName-count-other": "לילנגני סווזילנדי",
                symbol: "SZL"
            },
            THB: {
                displayName: "בהט תאילנדי",
                "displayName-count-one": "בהט תאילנדי",
                "displayName-count-two": "בהט תאילנדי",
                "displayName-count-many": "בהט תאילנדי",
                "displayName-count-other": "בהט תאילנדי",
                symbol: "฿",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "TJR",
                symbol: "TJR"
            },
            TJS: {
                displayName: "סומוני טג׳קיסטני",
                "displayName-count-one": "סומוני טג׳קיסטני",
                "displayName-count-two": "סומוני טג׳קיסטני",
                "displayName-count-many": "סומוני טג׳קיסטני",
                "displayName-count-other": "סומוני טג׳קיסטני",
                symbol: "TJS"
            },
            TMM: {
                displayName: "מנאט טורקמאני",
                symbol: "TMM"
            },
            TMT: {
                displayName: "מאנאט טורקמני",
                "displayName-count-one": "מאנאט טורקמני",
                "displayName-count-two": "מאנאט טורקמני",
                "displayName-count-many": "מאנאט טורקמני",
                "displayName-count-other": "מאנאט טורקמני",
                symbol: "TMT"
            },
            TND: {
                displayName: "דינר טוניסאי",
                "displayName-count-one": "דינר טוניסאי",
                "displayName-count-two": "דינר טוניסאי",
                "displayName-count-many": "דינר טוניסאי",
                "displayName-count-other": "דינר טוניסאי",
                symbol: "TND"
            },
            TOP: {
                displayName: "פאנגה טונגי",
                "displayName-count-one": "פאנגה טונגי",
                "displayName-count-two": "פאנגה טונגי",
                "displayName-count-many": "פאנגה טונגי",
                "displayName-count-other": "פאנגה טונגי",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "אסקודו טימוראי",
                symbol: "TPE"
            },
            TRL: {
                displayName: "לירה טורקית",
                symbol: "TRL"
            },
            TRY: {
                displayName: "לירה טורקית חדשה",
                "displayName-count-one": "לירה טורקית חדשה",
                "displayName-count-two": "לירה טורקית חדשה",
                "displayName-count-many": "לירה טורקית חדשה",
                "displayName-count-other": "לירה טורקית חדשה",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "דולר טרינידדי",
                "displayName-count-one": "דולר טרינידדי",
                "displayName-count-two": "דולר טרינידדי",
                "displayName-count-many": "דולר טרינידדי",
                "displayName-count-other": "דולר טרינידדי",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "דולר טייוואני חדש",
                "displayName-count-one": "דולר טייוואני חדש",
                "displayName-count-two": "דולר טייוואני חדש",
                "displayName-count-many": "דולר טייוואני חדש",
                "displayName-count-other": "דולר טייוואני חדש",
                symbol: "NT$",
                "symbol-alt-narrow": "NT$"
            },
            TZS: {
                displayName: "שילינג טנזני",
                "displayName-count-one": "שילינג טנזני",
                "displayName-count-two": "שילינג טנזני",
                "displayName-count-many": "שילינג טנזני",
                "displayName-count-other": "שילינג טנזני",
                symbol: "TZS"
            },
            UAH: {
                displayName: "הריבנה אוקראיני",
                "displayName-count-one": "הריבנה אוקראיני",
                "displayName-count-two": "הריבנה אוקראיני",
                "displayName-count-many": "הריבנה אוקראיני",
                "displayName-count-other": "הריבנה אוקראיני",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "UAK",
                symbol: "UAK"
            },
            UGS: {
                displayName: "שילינג אוגנדי (1966 – 1987)",
                symbol: "UGS"
            },
            UGX: {
                displayName: "שילינג אוגנדי",
                "displayName-count-one": "שילינג אוגנדי",
                "displayName-count-two": "שילינג אוגנדי",
                "displayName-count-many": "שילינג אוגנדי",
                "displayName-count-other": "שילינג אוגנדי",
                symbol: "UGX"
            },
            USD: {
                displayName: "דולר אמריקאי",
                "displayName-count-one": "דולר אמריקאי",
                "displayName-count-two": "דולר אמריקאי",
                "displayName-count-many": "דולר אמריקאי",
                "displayName-count-other": "דולר אמריקאי",
                symbol: "$",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "דולר אמריקאי (היום הבא)",
                symbol: "USN"
            },
            USS: {
                displayName: "דולר אמריקאי (היום הזה)",
                symbol: "USS"
            },
            UYI: {
                displayName: "UYI",
                symbol: "UYI"
            },
            UYP: {
                displayName: "UYP",
                symbol: "UYP"
            },
            UYU: {
                displayName: "פסו אורוגוואי",
                "displayName-count-one": "פסו אורוגוואי",
                "displayName-count-two": "פסו אורוגוואי",
                "displayName-count-many": "פסו אורוגוואי",
                "displayName-count-other": "פסו אורוגוואי",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "UYW",
                symbol: "UYW"
            },
            UZS: {
                displayName: "סום אוזבקי",
                "displayName-count-one": "סום אוזבקי",
                "displayName-count-two": "סום אוזבקי",
                "displayName-count-many": "סום אוזבקי",
                "displayName-count-other": "סום אוזבקי",
                symbol: "UZS"
            },
            VEB: {
                displayName: "בוליבר ונצואלי (1871–2008)",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "בוליבר ונצואלי (2008–2018)",
                "displayName-count-one": "בוליבר ונצואלי (2008–2018)",
                "displayName-count-two": "בוליבר ונצואלי (2008–2018)",
                "displayName-count-many": "בוליבר ונצואלי (2008–2018)",
                "displayName-count-other": "בוליבר ונצואלי (2008–2018)",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs"
            },
            VES: {
                displayName: "בוליבר ונצואלי",
                "displayName-count-one": "בוליבר ונצואלי",
                "displayName-count-two": "בוליבר ונצואלי",
                "displayName-count-many": "בוליבר ונצואלי",
                "displayName-count-other": "בוליבר ונצואלי",
                symbol: "VES"
            },
            VND: {
                displayName: "דונג וייטנאמי",
                "displayName-count-one": "דונג וייטנאמי",
                "displayName-count-two": "דונג וייטנאמי",
                "displayName-count-many": "דונג וייטנאמי",
                "displayName-count-other": "דונג וייטנאמי",
                symbol: "₫",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "VNN",
                symbol: "VNN"
            },
            VUV: {
                displayName: "ואטו של ונואטו",
                "displayName-count-one": "ואטו של ונואטו",
                "displayName-count-two": "ואטו של ונואטו",
                "displayName-count-many": "ואטו של ונואטו",
                "displayName-count-other": "ואטו של ונואטו",
                symbol: "VUV"
            },
            WST: {
                displayName: "טאלה סמואי",
                "displayName-count-one": "טאלה סמואי",
                "displayName-count-two": "טאלה סמואי",
                "displayName-count-many": "טאלה סמואי",
                "displayName-count-other": "טאלה סמואי",
                symbol: "WST"
            },
            XAF: {
                displayName: "פרנק CFA מרכז אפריקני",
                "displayName-count-one": "פרנק CFA מרכז אפריקני",
                "displayName-count-two": "פרנק CFA מרכז אפריקני",
                "displayName-count-many": "פרנק CFA מרכז אפריקני",
                "displayName-count-other": "פרנק CFA מרכז אפריקני",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "כסף",
                symbol: "XAG"
            },
            XAU: {
                displayName: "זהב",
                symbol: "XAU"
            },
            XBA: {
                displayName: "XBA",
                symbol: "XBA"
            },
            XBB: {
                displayName: "XBB",
                symbol: "XBB"
            },
            XBC: {
                displayName: "XBC",
                symbol: "XBC"
            },
            XBD: {
                displayName: "XBD",
                symbol: "XBD"
            },
            XCD: {
                displayName: "דולר מזרח קריבי",
                "displayName-count-one": "דולר מזרח קריבי",
                "displayName-count-two": "דולר מזרח קריבי",
                "displayName-count-many": "דולר מזרח קריבי",
                "displayName-count-other": "דולר מזרח קריבי",
                symbol: "EC$",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "זכויות משיכה מיוחדות",
                symbol: "XDR"
            },
            XEU: {
                displayName: "XEU",
                symbol: "XEU"
            },
            XFO: {
                displayName: "פרנק זהב",
                symbol: "XFO"
            },
            XFU: {
                displayName: "XFU",
                symbol: "XFU"
            },
            XOF: {
                displayName: "פרנק CFA מערב אפריקני",
                "displayName-count-one": "פרנק CFA מערב אפריקני",
                "displayName-count-two": "פרנק CFA מערב אפריקני",
                "displayName-count-many": "פרנק CFA מערב אפריקני",
                "displayName-count-other": "פרנק CFA מערב אפריקני",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "פלדיום",
                symbol: "XPD"
            },
            XPF: {
                displayName: "פרנק פולינזיה הצרפתית",
                "displayName-count-one": "פרנק פולינזיה הצרפתית",
                "displayName-count-two": "פרנק פולינזיה הצרפתית",
                "displayName-count-many": "פרנק פולינזיה הצרפתית",
                "displayName-count-other": "פרנק פולינזיה הצרפתית",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "פלטינה",
                symbol: "XPT"
            },
            XRE: {
                displayName: "XRE",
                symbol: "XRE"
            },
            XSU: {
                displayName: "XSU",
                symbol: "XSU"
            },
            XTS: {
                displayName: "סימון למטרות בדיקה",
                symbol: "XTS"
            },
            XUA: {
                displayName: "XUA",
                symbol: "XUA"
            },
            XXX: {
                displayName: "מטבע שאינו ידוע",
                "displayName-count-one": "(מטבע שאינו ידוע)",
                "displayName-count-two": "(מטבע שאינו ידוע)",
                "displayName-count-many": "(מטבע שאינו ידוע)",
                "displayName-count-other": "(מטבע שאינו ידוע)",
                symbol: "¤"
            },
            YDD: {
                displayName: "דינר תימני",
                symbol: "YDD"
            },
            YER: {
                displayName: "ריאל תימני",
                "displayName-count-one": "ריאל תימני",
                "displayName-count-two": "ריאל תימני",
                "displayName-count-many": "ריאל תימני",
                "displayName-count-other": "ריאל תימני",
                symbol: "YER"
            },
            YUD: {
                displayName: "YUD",
                symbol: "YUD"
            },
            YUM: {
                displayName: "YUM",
                symbol: "YUM"
            },
            YUN: {
                displayName: "YUN",
                symbol: "YUN"
            },
            YUR: {
                displayName: "YUR",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "ראנד דרום אפריקאי (כספי)",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "ראנד דרום אפריקאי",
                "displayName-count-one": "ראנד דרום אפריקאי",
                "displayName-count-two": "ראנד דרום אפריקאי",
                "displayName-count-many": "ראנד דרום אפריקאי",
                "displayName-count-other": "ראנד דרום אפריקאי",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "קוואצ׳ה זמבית (1968–2012)",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "קוואצ׳ה זמבי",
                "displayName-count-one": "קוואצ׳ה זמבי",
                "displayName-count-two": "קוואצ׳ה זמבי",
                "displayName-count-many": "קוואצ׳ה זמבי",
                "displayName-count-other": "קוואצ׳ה זמבי",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "זאיר חדש",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "ZRZ",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "דולר זימבבואי",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "ZWL",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "ZWR",
                symbol: "ZWR"
            }
        },
        localeCurrency: "ILS"
    },
    calendar: {
        patterns: {
            d: "d.M.y",
            D: "EEEE, d בMMMM y",
            m: "d בMMM",
            M: "d בMMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d בMMMM y H:mm:ss",
            g: "d.M.y H:mm",
            G: "d.M.y H:mm:ss",
            t: "H:mm",
            T: "H:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} בשעה {0}",
            long: "{1} בשעה {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E ה-d",
                Ehm: "E h:mm a",
                EHm: "E H:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E H:mm:ss",
                Gy: "y G",
                GyMd: "d/M/y GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "d בMMM y G",
                GyMMMEd: "E, d בMMM y G",
                h: "‏h a",
                H: "H",
                hm: "h:mm a",
                Hm: "H:mm",
                hms: "h:mm:ss a",
                Hms: "H:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d.M",
                MEd: "E, d.M",
                MMM: "LLL",
                MMMd: "d בMMM",
                MMMEd: "E, d בMMM",
                MMMMd: "d בMMMM",
                "MMMMW-count-one": "שבוע W בMMMM",
                "MMMMW-count-two": "שבוע W בMMMM",
                "MMMMW-count-many": "שבוע W בMMMM",
                "MMMMW-count-other": "שבוע W בMMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M.y",
                yMd: "d.M.y",
                yMEd: "E, d.M.y",
                yMM: "M.y",
                yMMM: "MMM y",
                yMMMd: "d בMMM y",
                yMMMEd: "E, d בMMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "שבוע w בשנת Y",
                "yw-count-two": "שבוע w בשנת Y",
                "yw-count-many": "שבוע w בשנת Y",
                "yw-count-other": "שבוע w בשנת Y"
            }
        },
        timeFormats: {
            full: "H:mm:ss zzzz",
            long: "H:mm:ss z",
            medium: "H:mm:ss",
            short: "H:mm"
        },
        dateFormats: {
            full: "EEEE, d בMMMM y",
            long: "d בMMMM y",
            medium: "d בMMM y",
            short: "d.M.y"
        },
        days: {
            format: {
                abbreviated: [
                    "יום א׳",
                    "יום ב׳",
                    "יום ג׳",
                    "יום ד׳",
                    "יום ה׳",
                    "יום ו׳",
                    "שבת"
                ],
                narrow: [
                    "א׳",
                    "ב׳",
                    "ג׳",
                    "ד׳",
                    "ה׳",
                    "ו׳",
                    "ש׳"
                ],
                short: [
                    "א׳",
                    "ב׳",
                    "ג׳",
                    "ד׳",
                    "ה׳",
                    "ו׳",
                    "ש׳"
                ],
                wide: [
                    "יום ראשון",
                    "יום שני",
                    "יום שלישי",
                    "יום רביעי",
                    "יום חמישי",
                    "יום שישי",
                    "יום שבת"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "יום א׳",
                    "יום ב׳",
                    "יום ג׳",
                    "יום ד׳",
                    "יום ה׳",
                    "יום ו׳",
                    "שבת"
                ],
                narrow: [
                    "א׳",
                    "ב׳",
                    "ג׳",
                    "ד׳",
                    "ה׳",
                    "ו׳",
                    "ש׳"
                ],
                short: [
                    "א׳",
                    "ב׳",
                    "ג׳",
                    "ד׳",
                    "ה׳",
                    "ו׳",
                    "ש׳"
                ],
                wide: [
                    "יום ראשון",
                    "יום שני",
                    "יום שלישי",
                    "יום רביעי",
                    "יום חמישי",
                    "יום שישי",
                    "יום שבת"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "ינו׳",
                    "פבר׳",
                    "מרץ",
                    "אפר׳",
                    "מאי",
                    "יוני",
                    "יולי",
                    "אוג׳",
                    "ספט׳",
                    "אוק׳",
                    "נוב׳",
                    "דצמ׳"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "ינואר",
                    "פברואר",
                    "מרץ",
                    "אפריל",
                    "מאי",
                    "יוני",
                    "יולי",
                    "אוגוסט",
                    "ספטמבר",
                    "אוקטובר",
                    "נובמבר",
                    "דצמבר"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ינו׳",
                    "פבר׳",
                    "מרץ",
                    "אפר׳",
                    "מאי",
                    "יוני",
                    "יולי",
                    "אוג׳",
                    "ספט׳",
                    "אוק׳",
                    "נוב׳",
                    "דצמ׳"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "ינואר",
                    "פברואר",
                    "מרץ",
                    "אפריל",
                    "מאי",
                    "יוני",
                    "יולי",
                    "אוגוסט",
                    "ספטמבר",
                    "אוקטובר",
                    "נובמבר",
                    "דצמבר"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "רבעון 1",
                    "רבעון 2",
                    "רבעון 3",
                    "רבעון 4"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "רבעון 1",
                    "רבעון 2",
                    "רבעון 3",
                    "רבעון 4"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "חצות",
                    am: "לפנה״צ",
                    pm: "אחה״צ",
                    morning1: "בוקר",
                    afternoon1: "צהריים",
                    afternoon2: "אחר הצהריים",
                    evening1: "ערב",
                    night1: "לילה",
                    night2: "לפנות בוקר"
                },
                narrow: {
                    midnight: "חצות",
                    am: "לפנה״צ",
                    pm: "אחה״צ",
                    morning1: "בבוקר",
                    afternoon1: "בצהריים",
                    afternoon2: "אחה״צ",
                    evening1: "בערב",
                    night1: "בלילה",
                    night2: "לפנות בוקר"
                },
                wide: {
                    midnight: "חצות",
                    am: "לפנה״צ",
                    pm: "אחה״צ",
                    morning1: "בבוקר",
                    afternoon1: "בצהריים",
                    afternoon2: "אחר הצהריים",
                    evening1: "בערב",
                    night1: "בלילה",
                    night2: "לפנות בוקר"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "חצות",
                    am: "AM",
                    pm: "PM",
                    morning1: "בוקר",
                    afternoon1: "צהריים",
                    afternoon2: "אחה״צ",
                    evening1: "ערב",
                    night1: "לילה",
                    night2: "לפנות בוקר"
                },
                narrow: {
                    midnight: "חצות",
                    am: "לפנה״צ",
                    pm: "אחה״צ",
                    morning1: "בוקר",
                    afternoon1: "צהריים",
                    afternoon2: "אחה״צ",
                    evening1: "ערב",
                    night1: "לילה",
                    night2: "לפנות בוקר"
                },
                wide: {
                    midnight: "חצות",
                    am: "AM",
                    pm: "PM",
                    morning1: "בוקר",
                    afternoon1: "צהריים",
                    afternoon2: "אחר הצהריים",
                    evening1: "ערב",
                    night1: "לילה",
                    night2: "לפנות בוקר"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "לפני הספירה",
                    "1": "לספירה",
                    "0-alt-variant": "לפנה״ס",
                    "1-alt-variant": "CE"
                },
                abbreviated: {
                    "0": "לפנה״ס",
                    "1": "לספירה",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                narrow: {
                    "0": "לפני",
                    "1": "אחריי",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                }
            }
        },
        gmtFormat: "GMT{0}‎",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "תקופה",
                short: "תקופה",
                narrow: "תקופה"
            },
            year: {
                wide: "שנה",
                short: "שנ׳",
                narrow: "שנ׳"
            },
            quarter: {
                wide: "רבעון",
                short: "רבע׳",
                narrow: "רבע׳"
            },
            month: {
                wide: "חודש",
                short: "חו׳",
                narrow: "חו׳"
            },
            week: {
                wide: "שבוע",
                short: "שב׳",
                narrow: "שב׳"
            },
            weekOfMonth: {
                wide: "השבוע בחודש",
                short: "השבוע בחודש",
                narrow: "השבוע בחודש"
            },
            day: {
                wide: "יום",
                short: "יום",
                narrow: "יום"
            },
            dayOfYear: {
                wide: "יום בשנה",
                short: "יום בשנה",
                narrow: "יום בשנה"
            },
            weekday: {
                wide: "יום בשבוע",
                short: "יום בשבוע",
                narrow: "יום בשבוע"
            },
            weekdayOfMonth: {
                wide: "יום חול בחודש",
                short: "יום בחודש",
                narrow: "יום בחודש"
            },
            dayperiod: {
                short: "AM/PM",
                wide: "לפנה״צ/אחה״צ",
                narrow: "AM/PM"
            },
            hour: {
                wide: "שעה",
                short: "שעה",
                narrow: "שע׳"
            },
            minute: {
                wide: "דקה",
                short: "דק׳",
                narrow: "דק׳"
            },
            second: {
                wide: "שנייה",
                short: "שנ׳",
                narrow: "שנ׳"
            },
            zone: {
                wide: "אזור זמן",
                short: "אזור",
                narrow: "אזור"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "אלפית שנייה "
            }
        }
    },
    firstDay: 0,
    weekendRange: {
        start: 5,
        end: 6
    },
    likelySubtags: {
        he: "he-Hebr-IL"
    }
});

