/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "hr",
    likelySubtags: {
        hr: "hr-Latn-HR"
    },
    identity: {
        language: "hr"
    },
    territory: "HR",
    calendar: {
        patterns: {
            d: "dd. MM. y.",
            D: "EEEE, d. MMMM y.",
            m: "d. MMM",
            M: "d. MMMM",
            y: "LLL y.",
            Y: "LLLL y.",
            F: "EEEE, d. MMMM y. HH:mm:ss",
            g: "dd. MM. y. HH:mm",
            G: "dd. MM. y. HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} 'u' {0}",
            long: "{1} 'u' {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d.",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E, d.",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y. G",
                GyMd: "d. M. y. GGGGG",
                GyMMM: "LLL y. G",
                GyMMMd: "d. MMM y. G",
                GyMMMEd: "E, d. MMM y. G",
                h: "h a",
                H: "HH",
                hm: "hh:mm a",
                Hm: "HH:mm",
                hms: "hh:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L.",
                Md: "dd. MM.",
                MEd: "E, dd. MM.",
                MMdd: "dd. MM.",
                MMM: "LLL",
                MMMd: "d. MMM",
                MMMEd: "E, d. MMM",
                MMMMd: "d. MMMM",
                MMMMEd: "E, d. MMMM",
                "MMMMW-count-one": "W. 'tjedan' MMMM",
                "MMMMW-count-few": "W. 'tjedan' MMMM",
                "MMMMW-count-other": "W. 'tjedan' MMMM",
                ms: "mm:ss",
                y: "y.",
                yM: "MM. y.",
                yMd: "dd. MM. y.",
                yMEd: "E, dd. MM. y.",
                yMM: "MM. y.",
                yMMM: "LLL y.",
                yMMMd: "d. MMM y.",
                yMMMEd: "E, d. MMM y.",
                yMMMM: "LLLL y.",
                yQQQ: "QQQ y.",
                yQQQQ: "QQQQ y.",
                "yw-count-one": "w. 'tjedan' 'u' Y.",
                "yw-count-few": "w. 'tjedan' 'u' Y.",
                "yw-count-other": "w. 'tjedan' 'u' Y."
            }
        },
        timeFormats: {
            full: "HH:mm:ss (zzzz)",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d. MMMM y.",
            long: "d. MMMM y.",
            medium: "d. MMM y.",
            short: "dd. MM. y."
        },
        days: {
            format: {
                abbreviated: [
                    "ned",
                    "pon",
                    "uto",
                    "sri",
                    "čet",
                    "pet",
                    "sub"
                ],
                narrow: [
                    "N",
                    "P",
                    "U",
                    "S",
                    "Č",
                    "P",
                    "S"
                ],
                short: [
                    "ned",
                    "pon",
                    "uto",
                    "sri",
                    "čet",
                    "pet",
                    "sub"
                ],
                wide: [
                    "nedjelja",
                    "ponedjeljak",
                    "utorak",
                    "srijeda",
                    "četvrtak",
                    "petak",
                    "subota"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ned",
                    "pon",
                    "uto",
                    "sri",
                    "čet",
                    "pet",
                    "sub"
                ],
                narrow: [
                    "n",
                    "p",
                    "u",
                    "s",
                    "č",
                    "p",
                    "s"
                ],
                short: [
                    "ned",
                    "pon",
                    "uto",
                    "sri",
                    "čet",
                    "pet",
                    "sub"
                ],
                wide: [
                    "nedjelja",
                    "ponedjeljak",
                    "utorak",
                    "srijeda",
                    "četvrtak",
                    "petak",
                    "subota"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "sij",
                    "velj",
                    "ožu",
                    "tra",
                    "svi",
                    "lip",
                    "srp",
                    "kol",
                    "ruj",
                    "lis",
                    "stu",
                    "pro"
                ],
                narrow: [
                    "1.",
                    "2.",
                    "3.",
                    "4.",
                    "5.",
                    "6.",
                    "7.",
                    "8.",
                    "9.",
                    "10.",
                    "11.",
                    "12."
                ],
                wide: [
                    "siječnja",
                    "veljače",
                    "ožujka",
                    "travnja",
                    "svibnja",
                    "lipnja",
                    "srpnja",
                    "kolovoza",
                    "rujna",
                    "listopada",
                    "studenoga",
                    "prosinca"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "sij",
                    "velj",
                    "ožu",
                    "tra",
                    "svi",
                    "lip",
                    "srp",
                    "kol",
                    "ruj",
                    "lis",
                    "stu",
                    "pro"
                ],
                narrow: [
                    "1.",
                    "2.",
                    "3.",
                    "4.",
                    "5.",
                    "6.",
                    "7.",
                    "8.",
                    "9.",
                    "10.",
                    "11.",
                    "12."
                ],
                wide: [
                    "siječanj",
                    "veljača",
                    "ožujak",
                    "travanj",
                    "svibanj",
                    "lipanj",
                    "srpanj",
                    "kolovoz",
                    "rujan",
                    "listopad",
                    "studeni",
                    "prosinac"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1kv",
                    "2kv",
                    "3kv",
                    "4kv"
                ],
                narrow: [
                    "1.",
                    "2.",
                    "3.",
                    "4."
                ],
                wide: [
                    "1. kvartal",
                    "2. kvartal",
                    "3. kvartal",
                    "4. kvartal"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1. kv.",
                    "2. kv.",
                    "3. kv.",
                    "4. kv."
                ],
                narrow: [
                    "1.",
                    "2.",
                    "3.",
                    "4."
                ],
                wide: [
                    "1. kvartal",
                    "2. kvartal",
                    "3. kvartal",
                    "4. kvartal"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "ponoć",
                    am: "AM",
                    noon: "podne",
                    pm: "PM",
                    morning1: "ujutro",
                    afternoon1: "popodne",
                    evening1: "navečer",
                    night1: "noću"
                },
                narrow: {
                    midnight: "ponoć",
                    am: "AM",
                    noon: "podne",
                    pm: "PM",
                    morning1: "ujutro",
                    afternoon1: "popodne",
                    evening1: "navečer",
                    night1: "noću"
                },
                wide: {
                    midnight: "ponoć",
                    am: "AM",
                    noon: "podne",
                    pm: "PM",
                    morning1: "ujutro",
                    afternoon1: "poslije podne",
                    evening1: "navečer",
                    night1: "noću"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "ponoć",
                    am: "AM",
                    noon: "podne",
                    pm: "PM",
                    morning1: "ujutro",
                    afternoon1: "popodne",
                    evening1: "navečer",
                    night1: "noću"
                },
                narrow: {
                    midnight: "ponoć",
                    am: "AM",
                    noon: "podne",
                    pm: "PM",
                    morning1: "ujutro",
                    afternoon1: "popodne",
                    evening1: "navečer",
                    night1: "noću"
                },
                wide: {
                    midnight: "ponoć",
                    am: "AM",
                    noon: "podne",
                    pm: "PM",
                    morning1: "ujutro",
                    afternoon1: "popodne",
                    evening1: "navečer",
                    night1: "noću"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "prije Krista",
                    "1": "poslije Krista",
                    "0-alt-variant": "prije nove ere",
                    "1-alt-variant": "nove ere"
                },
                abbreviated: {
                    "0": "pr. Kr.",
                    "1": "po. Kr.",
                    "0-alt-variant": "pr. n. e.",
                    "1-alt-variant": "n. e."
                },
                narrow: {
                    "0": "pr.n.e.",
                    "1": "AD",
                    "0-alt-variant": "pr. n. e.",
                    "1-alt-variant": "n. e."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "era",
                short: "era",
                narrow: "era"
            },
            year: {
                wide: "godina",
                short: "g.",
                narrow: "g."
            },
            quarter: {
                wide: "kvartal",
                short: "kv.",
                narrow: "kv."
            },
            month: {
                wide: "mjesec",
                short: "mj.",
                narrow: "m."
            },
            week: {
                wide: "tjedan",
                short: "tj.",
                narrow: "tj."
            },
            weekOfMonth: {
                wide: "tjedan u mjesecu",
                short: "tj. u mj.",
                narrow: "tj. u mjesecu"
            },
            day: {
                wide: "dan",
                short: "d.",
                narrow: "d."
            },
            dayOfYear: {
                wide: "dan u godini",
                short: "dan u god.",
                narrow: "dan u g."
            },
            weekday: {
                wide: "dan u tjednu",
                short: "dan u tjed.",
                narrow: "dan u tj."
            },
            weekdayOfMonth: {
                wide: "radni dan u mjesecu",
                short: "radni dan u mj.",
                narrow: "r. dan u mj."
            },
            dayperiod: {
                short: "AM/PM",
                wide: "AM/PM",
                narrow: "AM/PM"
            },
            hour: {
                wide: "sat",
                short: "h",
                narrow: "h"
            },
            minute: {
                wide: "minuta",
                short: "min",
                narrow: "min"
            },
            second: {
                wide: "sekunda",
                short: "s",
                narrow: "s"
            },
            zone: {
                wide: "vremenska zona",
                short: "zona",
                narrow: "zona"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "milisekunda"
            }
        }
    },
    firstDay: 1
});

