/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "hsb",
    identity: {
        language: "hsb"
    },
    territory: "DE",
    numbers: {
        symbols: {
            decimal: ",",
            group: ".",
            list: ";",
            percentSign: "%",
            plusSign: "+",
            minusSign: "-",
            approximatelySign: "≈",
            exponential: "E",
            superscriptingExponent: "·",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "n %"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-one": "n $",
            "unitPattern-count-two": "n $",
            "unitPattern-count-few": "n $",
            "unitPattern-count-other": "n $"
        },
        accounting: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "andorraska peseta",
                "displayName-count-one": "andorraska peseta",
                "displayName-count-two": "andorraskej peseće",
                "displayName-count-few": "andorraske pesety",
                "displayName-count-other": "andorraskich pesetow",
                symbol: "ADP"
            },
            AED: {
                displayName: "ZAE dirham",
                "displayName-count-one": "ZAE dirham",
                "displayName-count-two": "ZAE dirhamaj",
                "displayName-count-few": "SAE dirhamy",
                "displayName-count-other": "SAE dirhamow",
                symbol: "AED"
            },
            AFA: {
                displayName: "AFA",
                symbol: "AFA"
            },
            AFN: {
                displayName: "afghaniski afghani",
                "displayName-count-one": "afghaniski afghani",
                "displayName-count-two": "afghaniskej afghanijej",
                "displayName-count-few": "afghaniske afghanije",
                "displayName-count-other": "afghaniskich afghanijow",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "ALK",
                symbol: "ALK"
            },
            ALL: {
                displayName: "albanski lek",
                "displayName-count-one": "albanski lek",
                "displayName-count-two": "albanskej lekaj",
                "displayName-count-few": "albanske leki",
                "displayName-count-other": "albanskich lekow",
                symbol: "ALL"
            },
            AMD: {
                displayName: "armenski dram",
                "displayName-count-one": "armenski dram",
                "displayName-count-two": "armenskej dramaj",
                "displayName-count-few": "armenske dramy",
                "displayName-count-other": "armenskich dramow",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "nižozemsko-antilski gulden",
                "displayName-count-one": "nižozemsko-antilski gulden",
                "displayName-count-two": "nižozemsko-antilskej guldenaj",
                "displayName-count-few": "nižozemsko-antilske guldeny",
                "displayName-count-other": "nižozemsko-antilskich guldenow",
                symbol: "ANG"
            },
            AOA: {
                displayName: "angolska kwanza",
                "displayName-count-one": "angolska kwanza",
                "displayName-count-two": "angolskej kwanzy",
                "displayName-count-few": "angolske kwanzy",
                "displayName-count-other": "angolskich kwanzow",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "angolska kwanza (1977–1990)",
                "displayName-count-one": "angolska kwanza (1977–1990)",
                "displayName-count-two": "angolskej kwanzy (1977–1990)",
                "displayName-count-few": "angolske kwanzy (1977–1990)",
                "displayName-count-other": "angolskich kwanzow (1977–1990)",
                symbol: "AOK"
            },
            AON: {
                displayName: "angolska nowa kwanza (1990–2000)",
                "displayName-count-one": "angolska nowa kwanza (1990–2000)",
                "displayName-count-two": "angolskej nowej kwanzy (1990–2000)",
                "displayName-count-few": "angolske nowe kwanzy (1990–2000)",
                "displayName-count-other": "angolskich nowych kwanzow (1990–2000)",
                symbol: "AON"
            },
            AOR: {
                displayName: "angolska kwanza reajustado (1995–1999)",
                "displayName-count-one": "angolska kwanza reajustado (1995–1999)",
                "displayName-count-two": "angolskej kwanzy reajustado (1995–1999)",
                "displayName-count-few": "angolske kwanzy reajustado (1995–1999)",
                "displayName-count-other": "angolskich kwanzow reajustado (1995–1999)",
                symbol: "AOR"
            },
            ARA: {
                displayName: "argentinski austral",
                "displayName-count-one": "argentinski austral",
                "displayName-count-two": "argentinskej australej",
                "displayName-count-few": "argentinske australe",
                "displayName-count-other": "argentinskich australow",
                symbol: "ARA"
            },
            ARL: {
                displayName: "ARL",
                symbol: "ARL"
            },
            ARM: {
                displayName: "ARM",
                symbol: "ARM"
            },
            ARP: {
                displayName: "argentinski peso (1983–1985)",
                "displayName-count-one": "argentinski peso (1983–1985)",
                "displayName-count-two": "argentinskej pesaj (1983–1985)",
                "displayName-count-few": "argentinske pesa (1983–1985)",
                "displayName-count-other": "argentinskich pesow (1983–1985)",
                symbol: "ARP"
            },
            ARS: {
                displayName: "argentinski peso",
                "displayName-count-one": "argentinski peso",
                "displayName-count-two": "argentinskej pesaj",
                "displayName-count-few": "argentinske pesa",
                "displayName-count-other": "argentinskich pesow",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "awstriski šiling",
                "displayName-count-one": "awstriski šiling",
                "displayName-count-two": "awstriskej šilingaj",
                "displayName-count-few": "awstriske šilingi",
                "displayName-count-other": "awstriskich šilingow",
                symbol: "ATS"
            },
            AUD: {
                displayName: "awstralski dolar",
                "displayName-count-one": "awstralski dolar",
                "displayName-count-two": "awstralskej dolaraj",
                "displayName-count-few": "awstralske dolary",
                "displayName-count-other": "awstralskich dolarow",
                symbol: "AUD",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "aruba-florin",
                "displayName-count-one": "aruba-florin",
                "displayName-count-two": "aruba-florinaj",
                "displayName-count-few": "aruba-floriny",
                "displayName-count-other": "aruba-florinow",
                symbol: "AWG"
            },
            AZM: {
                displayName: "azerbajdźanski manat (1993–2006)",
                "displayName-count-one": "azerbajdźanski manat (1993–2006)",
                "displayName-count-two": "azerbajdźanski manataj (1993–2006)",
                "displayName-count-few": "azerbajdźanski manaty (1993–2006)",
                "displayName-count-other": "azerbajdźanski manatow (1993–2006)",
                symbol: "AZM"
            },
            AZN: {
                displayName: "azerbajdźanski manat",
                "displayName-count-one": "azerbajdźanski manat",
                "displayName-count-two": "azerbajdźanski manataj",
                "displayName-count-few": "azerbajdźanski manaty",
                "displayName-count-other": "azerbajdźanski manatow",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "bosniski dinar",
                "displayName-count-one": "bosniski dinar",
                "displayName-count-two": "bosniskej dinaraj",
                "displayName-count-few": "bosniske dinary",
                "displayName-count-other": "bosniskich dinarow",
                symbol: "BAD"
            },
            BAM: {
                displayName: "bosniska konwertibelna hriwna",
                "displayName-count-one": "bosniska konwertibelna hriwna",
                "displayName-count-two": "bosniskej konwertibelnej hriwnje",
                "displayName-count-few": "bosniske konwertibelne hriwny",
                "displayName-count-other": "bosniskich konwertibelnych hriwnow",
                symbol: "BAM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "BAN",
                symbol: "BAN"
            },
            BBD: {
                displayName: "barbadoski dolar",
                "displayName-count-one": "barbadoski dolar",
                "displayName-count-two": "barbadoskej dolaraj",
                "displayName-count-few": "barbadoske dolary",
                "displayName-count-other": "barbadoskich dolarow",
                symbol: "BBD",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "bangladešska taka",
                "displayName-count-one": "bangladešska taka",
                "displayName-count-two": "bangladešskej tace",
                "displayName-count-few": "bangladešske taki",
                "displayName-count-other": "bangladešskich takow",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "belgiski frank (konwertibelny)",
                "displayName-count-one": "belgiski frank (konwertibelny)",
                "displayName-count-two": "belgiskej frankaj (konwertibelnej)",
                "displayName-count-few": "belgiske franki (konwertibelne)",
                "displayName-count-other": "belgiskich frankow (konwertibelnych)",
                symbol: "BEC"
            },
            BEF: {
                displayName: "belgiski frank",
                "displayName-count-one": "belgiski frank",
                "displayName-count-two": "belgiskej frankaj",
                "displayName-count-few": "belgiske franki",
                "displayName-count-other": "belgiskich frankow",
                symbol: "BEF"
            },
            BEL: {
                displayName: "belgiski finančny frank",
                "displayName-count-one": "belgiski finančny frank",
                "displayName-count-two": "belgiskej finančnej frankaj",
                "displayName-count-few": "belgiske finančne franki",
                "displayName-count-other": "belgiskich finančnych frankow",
                symbol: "BEL"
            },
            BGL: {
                displayName: "bołharski lew (1962–1999)",
                "displayName-count-one": "bołharski lew (1962–1999)",
                "displayName-count-two": "bołharskej lewaj (1962–1999)",
                "displayName-count-few": "bołharske lewy (1962–1999)",
                "displayName-count-other": "bołharskich lewow (1962–1999)",
                symbol: "BGL"
            },
            BGM: {
                displayName: "BGM",
                symbol: "BGM"
            },
            BGN: {
                displayName: "bołharski lew",
                "displayName-count-one": "bołharski lew",
                "displayName-count-two": "bołharskej lewaj",
                "displayName-count-few": "bołharske lewy",
                "displayName-count-other": "bołharskich lewow",
                symbol: "BGN"
            },
            BGO: {
                displayName: "BGO",
                symbol: "BGO"
            },
            BHD: {
                displayName: "bahrainski dinar",
                "displayName-count-one": "bahrainski dinar",
                "displayName-count-two": "bahrainskej dinaraj",
                "displayName-count-few": "bahrainske dinary",
                "displayName-count-other": "bahrainskich dinarow",
                symbol: "BHD"
            },
            BIF: {
                displayName: "burundiski frank",
                "displayName-count-one": "burundiski frank",
                "displayName-count-two": "burundiskej frankaj",
                "displayName-count-few": "burundiske franki",
                "displayName-count-other": "burundiskich frankow",
                symbol: "BIF"
            },
            BMD: {
                displayName: "bermudaski dolar",
                "displayName-count-one": "bermudaski dolar",
                "displayName-count-two": "bermudaskej dolaraj",
                "displayName-count-few": "bermudaske dolary",
                "displayName-count-other": "bermudaskich dolarow",
                symbol: "BMD",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "bruneiski dolar",
                "displayName-count-one": "bruneiski dolar",
                "displayName-count-two": "bruneiskej dolaraj",
                "displayName-count-few": "bruneiske dolary",
                "displayName-count-other": "bruneiskich dolarow",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "boliwiski boliviano",
                "displayName-count-one": "boliwiski boliviano",
                "displayName-count-two": "boliwiskej bolivianaj",
                "displayName-count-few": "boliwiske boliviany",
                "displayName-count-other": "boliwiskich bolivianow",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "BOL",
                symbol: "BOL"
            },
            BOP: {
                displayName: "boliwiski peso",
                "displayName-count-one": "boliwiski peso",
                "displayName-count-two": "boliwiskej pesaj",
                "displayName-count-few": "boliwiske pesa",
                "displayName-count-other": "boliwiskich pesow",
                symbol: "BOP"
            },
            BOV: {
                displayName: "boliwiski mvdol",
                "displayName-count-one": "boliwiski mvdol",
                "displayName-count-two": "boliwiskej mvdolej",
                "displayName-count-few": "boliwiske mvdole",
                "displayName-count-other": "boliwiskich mvdolow",
                symbol: "BOV"
            },
            BRB: {
                displayName: "brazilski nowy cruzeiro (1967–1986)",
                "displayName-count-one": "brazilski nowy cruzeiro (1967–1986)",
                "displayName-count-two": "brazilskej nowej cruzeiraj (1967–1986)",
                "displayName-count-few": "brazilske nowe cruzeiry (1967–1986)",
                "displayName-count-other": "brazilskich nowych cruzeirow (1967–1986)",
                symbol: "BRB"
            },
            BRC: {
                displayName: "brazilski cruzado (1986–1989)",
                "displayName-count-one": "brazilski cruzado (1986–1989)",
                "displayName-count-two": "brazilskej cruzadaj (1986–1989)",
                "displayName-count-few": "brazilske cruzady (1986–1989)",
                "displayName-count-other": "brazilskich cruzadow (1986–1989)",
                symbol: "BRC"
            },
            BRE: {
                displayName: "brazilski cruzeiro (1990–1993)",
                "displayName-count-one": "brazilski cruzeiro (1990–1993)",
                "displayName-count-two": "brazilskej cruzeiraj (1990–1993)",
                "displayName-count-few": "brazilske cruzeiry (1990–1993)",
                "displayName-count-other": "brazilskich cruzeirow (1990–1993)",
                symbol: "BRE"
            },
            BRL: {
                displayName: "brazilski real",
                "displayName-count-one": "brazilski real",
                "displayName-count-two": "brazilskej realej",
                "displayName-count-few": "brazilske reale",
                "displayName-count-other": "brazilskich realow",
                symbol: "R$",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "brazilski nowy cruzado (1989–1990)",
                "displayName-count-one": "brazilski nowy cruzado (1989–1990)",
                "displayName-count-two": "brazilskej nowej cruzadaj (1989–1990)",
                "displayName-count-few": "brazilske nowe cruzady",
                "displayName-count-other": "brazilskich nowych cruzadow",
                symbol: "BRN"
            },
            BRR: {
                displayName: "brazilski cruzeiro (1993–1994)",
                "displayName-count-one": "brazilski cruzeiro (1993–1994)",
                "displayName-count-two": "brazilskej cruzeiraj (1993–1994)",
                "displayName-count-few": "brazilske cruzeiry (1993–1994)",
                "displayName-count-other": "brazilskich cruzeirow (1993–1994)",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "BRZ",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "bahamaski dolar",
                "displayName-count-one": "bahamaski dolar",
                "displayName-count-two": "bahamaskej dolaraj",
                "displayName-count-few": "bahamaske dolary",
                "displayName-count-other": "bahamaskich dolarow",
                symbol: "BSD",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "bhutanski ngultrum",
                "displayName-count-one": "bhutanski ngultrum",
                "displayName-count-two": "bhutanskej ngultrumaj",
                "displayName-count-few": "bhutanske ngultrumy",
                "displayName-count-other": "bhutanskich ngultrumow",
                symbol: "BTN"
            },
            BUK: {
                displayName: "burmaski kyat",
                "displayName-count-one": "burmaski kyat",
                "displayName-count-two": "burmaskej kyataj",
                "displayName-count-few": "burmaske kyaty",
                "displayName-count-other": "burmaskich kyatow",
                symbol: "BUK"
            },
            BWP: {
                displayName: "botswanska pula",
                "displayName-count-one": "botswanska pula",
                "displayName-count-two": "botswanskej puli",
                "displayName-count-few": "botswanske pule",
                "displayName-count-other": "botswanskich pulow",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "běłoruski rubl (1994–1999)",
                "displayName-count-one": "běłoruski rubl (1994–1999)",
                "displayName-count-two": "běłoruskej rublej (1994–1999)",
                "displayName-count-few": "běłoruske ruble (1994–1999)",
                "displayName-count-other": "běłoruskich rublow (1994–1999)",
                symbol: "BYB"
            },
            BYN: {
                displayName: "běłoruski rubl",
                "displayName-count-one": "běłoruski rubl",
                "displayName-count-two": "běłoruskej rublej",
                "displayName-count-few": "běłoruske ruble",
                "displayName-count-other": "běłoruskich rublow",
                symbol: "BYN"
            },
            BYR: {
                displayName: "běłoruski rubl (2000–2016)",
                "displayName-count-one": "běłoruski rubl (2000–2016)",
                "displayName-count-two": "běłoruskej rublej (2000–2016)",
                "displayName-count-few": "běłoruske ruble (2000–2016)",
                "displayName-count-other": "běłoruskich rublow (2000–2016)",
                symbol: "BYR"
            },
            BZD: {
                displayName: "belizeski dolar",
                "displayName-count-one": "belizeski dolar",
                "displayName-count-two": "belizeskej dolaraj",
                "displayName-count-few": "belizeske dolary",
                "displayName-count-other": "belizeskich dolarow",
                symbol: "BZD",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "kanadiski dolar",
                "displayName-count-one": "kanadiski dolar",
                "displayName-count-two": "kanadiskej dolaraj",
                "displayName-count-few": "kanadiske dolary",
                "displayName-count-other": "kanadiskich dolarow",
                symbol: "CA$",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "kongoski frank",
                "displayName-count-one": "kongoski frank",
                "displayName-count-two": "kongoskej frankaj",
                "displayName-count-few": "kongoske franki",
                "displayName-count-other": "kongoskich frankow",
                symbol: "CDF"
            },
            CHE: {
                displayName: "CHE",
                symbol: "CHE"
            },
            CHF: {
                displayName: "šwicarski frank",
                "displayName-count-one": "šwicarski frank",
                "displayName-count-two": "šwicarskej frankaj",
                "displayName-count-few": "šwicarske franki",
                "displayName-count-other": "šwicarskich frankow",
                symbol: "CHF"
            },
            CHW: {
                displayName: "CHW",
                symbol: "CHW"
            },
            CLE: {
                displayName: "CLE",
                symbol: "CLE"
            },
            CLF: {
                displayName: "CLF",
                symbol: "CLF"
            },
            CLP: {
                displayName: "chilski peso",
                "displayName-count-one": "chilski peso",
                "displayName-count-two": "chilskej pesaj",
                "displayName-count-few": "chilske pesa",
                "displayName-count-other": "chilskich pesow",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "chinski yuan (offshore)",
                "displayName-count-one": "chinski yuan (offshore)",
                "displayName-count-two": "chinskej yuanaj (offshore)",
                "displayName-count-few": "chinske yuany (offshore)",
                "displayName-count-other": "chinskich yuanow (offshore)",
                symbol: "CNH"
            },
            CNX: {
                displayName: "CNX",
                symbol: "CNX"
            },
            CNY: {
                displayName: "chinski yuan",
                "displayName-count-one": "chinski yuan",
                "displayName-count-two": "chinskej yuanaj",
                "displayName-count-few": "chinske yuany",
                "displayName-count-other": "chinskich yuanow",
                symbol: "CN¥",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "kolumbiski peso",
                "displayName-count-one": "kolumbiski peso",
                "displayName-count-two": "kolumbiskej pesaj",
                "displayName-count-few": "kolumbiske pesa",
                "displayName-count-other": "kolumbiskich pesow",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "COU",
                symbol: "COU"
            },
            CRC: {
                displayName: "kosta-rikaski colón",
                "displayName-count-one": "kosta-rikaski colón",
                "displayName-count-two": "kosta-rikaskej colónaj",
                "displayName-count-few": "kosta-rikaske colóny",
                "displayName-count-other": "kosta-rikaskich colónow",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "CSD",
                symbol: "CSD"
            },
            CSK: {
                displayName: "CSK",
                symbol: "CSK"
            },
            CUC: {
                displayName: "kubaski konwertibelny peso",
                "displayName-count-one": "kubaski konwertibelny peso",
                "displayName-count-two": "kubaskej konwertibelnej pesaj",
                "displayName-count-few": "kubaske konwertibelne pesa",
                "displayName-count-other": "kubaskich konwertibelnych pesow",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "kubaski peso",
                "displayName-count-one": "kubaski peso",
                "displayName-count-two": "kubaskej pesaj",
                "displayName-count-few": "kubaske pesa",
                "displayName-count-other": "kubaskich pesow",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "kapverdski escudo",
                "displayName-count-one": "kapverdski escudo",
                "displayName-count-two": "kapverdskej escudaj",
                "displayName-count-few": "kapverdske escuda",
                "displayName-count-other": "kapverdskich escudow",
                symbol: "CVE"
            },
            CYP: {
                displayName: "CYP",
                symbol: "CYP"
            },
            CZK: {
                displayName: "čěska króna",
                "displayName-count-one": "čěska króna",
                "displayName-count-two": "čěskej krónje",
                "displayName-count-few": "čěske króny",
                "displayName-count-other": "čěskich krónow",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "DDM",
                symbol: "DDM"
            },
            DEM: {
                displayName: "DEM",
                symbol: "DEM"
            },
            DJF: {
                displayName: "dźibutiski frank",
                "displayName-count-one": "dźibutiski frank",
                "displayName-count-two": "dźibutiskej frankaj",
                "displayName-count-few": "dźibutiske franki",
                "displayName-count-other": "dźibutiskich frankow",
                symbol: "DJF"
            },
            DKK: {
                displayName: "danska króna",
                "displayName-count-one": "danska króna",
                "displayName-count-two": "danskej krónje",
                "displayName-count-few": "danske króny",
                "displayName-count-other": "danskich krónow",
                symbol: "DKK",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "dominikanski peso",
                "displayName-count-one": "dominikanski peso",
                "displayName-count-two": "dominikanskej pesaj",
                "displayName-count-few": "dominikanske pesa",
                "displayName-count-other": "dominikanskich pesow",
                symbol: "DOP",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "algeriski dinar",
                "displayName-count-one": "algeriski dinar",
                "displayName-count-two": "algeriskej dinaraj",
                "displayName-count-few": "algeriske dinary",
                "displayName-count-other": "algeriskich dinarow",
                symbol: "DZD"
            },
            ECS: {
                displayName: "ECS",
                symbol: "ECS"
            },
            ECV: {
                displayName: "ECV",
                symbol: "ECV"
            },
            EEK: {
                displayName: "EEK",
                symbol: "EEK"
            },
            EGP: {
                displayName: "egyptowski punt",
                "displayName-count-one": "egyptowski punt",
                "displayName-count-two": "egyptowskej puntaj",
                "displayName-count-few": "egyptowske punty",
                "displayName-count-other": "egyptowskich puntow",
                symbol: "EGP",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "eritrejska nakfa",
                "displayName-count-one": "eritrejska nakfa",
                "displayName-count-two": "eritrejskej nakfje",
                "displayName-count-few": "eritrejske nakfy",
                "displayName-count-other": "eritrejskich nakfow",
                symbol: "ERN"
            },
            ESA: {
                displayName: "ESA",
                symbol: "ESA"
            },
            ESB: {
                displayName: "ESB",
                symbol: "ESB"
            },
            ESP: {
                displayName: "ESP",
                symbol: "ESP",
                "symbol-alt-narrow": "₧"
            },
            ETB: {
                displayName: "etiopiski birr",
                "displayName-count-one": "etiopiski birr",
                "displayName-count-two": "etiopiskej birraj",
                "displayName-count-few": "etiopiske birra",
                "displayName-count-other": "etiopiskich birrow",
                symbol: "ETB"
            },
            EUR: {
                displayName: "euro",
                "displayName-count-one": "euro",
                "displayName-count-two": "euraj",
                "displayName-count-few": "eura",
                "displayName-count-other": "eurow",
                symbol: "€",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "FIM",
                symbol: "FIM"
            },
            FJD: {
                displayName: "fidźiski dolar",
                "displayName-count-one": "fidźiski dolar",
                "displayName-count-two": "fidźiskej dolaraj",
                "displayName-count-few": "fidźiske dolary",
                "displayName-count-other": "fidźiskich dolarow",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "falklandski punt",
                "displayName-count-one": "falklandski punt",
                "displayName-count-two": "falklandskej puntaj",
                "displayName-count-few": "falklandske punty",
                "displayName-count-other": "falklandskich puntow",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "FRF",
                symbol: "FRF"
            },
            GBP: {
                displayName: "britiski punt",
                "displayName-count-one": "britiski punt",
                "displayName-count-two": "britiskej puntaj",
                "displayName-count-few": "britiske punty",
                "displayName-count-other": "britiskich puntow",
                symbol: "£",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "GEK",
                symbol: "GEK"
            },
            GEL: {
                displayName: "georgiski lari",
                "displayName-count-one": "georgiski lari",
                "displayName-count-two": "georgiskej larijej",
                "displayName-count-few": "georgiske larije",
                "displayName-count-other": "georgiskich larijow",
                symbol: "GEL",
                "symbol-alt-narrow": "₾"
            },
            GHC: {
                displayName: "GHC",
                symbol: "GHC"
            },
            GHS: {
                displayName: "ghanaski cedi",
                "displayName-count-one": "ghanaski cedi",
                "displayName-count-two": "ghanaskej cedaj",
                "displayName-count-few": "ghanaske cedije",
                "displayName-count-other": "ghanaskich cedijow",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "gibraltarski punt",
                "displayName-count-one": "gibraltarski punt",
                "displayName-count-two": "gibraltarskej puntaj",
                "displayName-count-few": "gibraltarske punty",
                "displayName-count-other": "gibraltarskich puntow",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "gambiski dalasi",
                "displayName-count-one": "gambiski dalasi",
                "displayName-count-two": "gambiskej dalasijej",
                "displayName-count-few": "gambiske dalasije",
                "displayName-count-other": "gambiskich dalasijow",
                symbol: "GMD"
            },
            GNF: {
                displayName: "ginejski frank",
                "displayName-count-one": "ginejski frank",
                "displayName-count-two": "ginejskej frankaj",
                "displayName-count-few": "ginejske franki",
                "displayName-count-other": "ginejskich frankow",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "GNS",
                symbol: "GNS"
            },
            GQE: {
                displayName: "GQE",
                symbol: "GQE"
            },
            GRD: {
                displayName: "GRD",
                symbol: "GRD"
            },
            GTQ: {
                displayName: "guatemalski quetzal",
                "displayName-count-one": "guatemalski quetzal",
                "displayName-count-two": "guatemalskej quetzalej",
                "displayName-count-few": "guatemalske quetzale",
                "displayName-count-other": "guatemalskich quetzalow",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "GWE",
                symbol: "GWE"
            },
            GWP: {
                displayName: "ginejsko-bissauski peso",
                "displayName-count-one": "ginejsko-bissauski peso",
                "displayName-count-two": "ginejsko-bissauskej pesaj",
                "displayName-count-few": "ginejsko-bissauske pesa",
                "displayName-count-other": "ginejsko-bissauskich pesow",
                symbol: "GWP"
            },
            GYD: {
                displayName: "guyanski dolar",
                "displayName-count-one": "guyanski dolar",
                "displayName-count-two": "guyanskej dolaraj",
                "displayName-count-few": "guyanske dolary",
                "displayName-count-other": "guyanskich dolarow",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "hongkongski dolar",
                "displayName-count-one": "hongkongski dolar",
                "displayName-count-two": "hongkongskej dolaraj",
                "displayName-count-few": "hongkongske dolary",
                "displayName-count-other": "hongkongskich dolarow",
                symbol: "HK$",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "honduraska lempira",
                "displayName-count-one": "honduraska lempira",
                "displayName-count-two": "honduraskej lempirje",
                "displayName-count-few": "honduraske lempiry",
                "displayName-count-other": "honduraskich lempirow",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "HRD",
                symbol: "HRD"
            },
            HRK: {
                displayName: "chorwatska kuna",
                "displayName-count-one": "chorwatska kuna",
                "displayName-count-two": "chorwatskej kunje",
                "displayName-count-few": "chorwatske kuny",
                "displayName-count-other": "chorwatskich kunow",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "haitiska gourda",
                "displayName-count-one": "haitiska gourda",
                "displayName-count-two": "haitiskej gourdźe",
                "displayName-count-few": "haitiske gourdy",
                "displayName-count-other": "haitiskich gourdow",
                symbol: "HTG"
            },
            HUF: {
                displayName: "madźarski forint",
                "displayName-count-one": "madźarski forint",
                "displayName-count-two": "madźarskej forintaj",
                "displayName-count-few": "madźarske forinty",
                "displayName-count-other": "madźarskich forintow",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "indoneska rupija",
                "displayName-count-one": "indoneska rupija",
                "displayName-count-two": "indoneskej rupiji",
                "displayName-count-few": "indoneske rupije",
                "displayName-count-other": "indoneskich rupijow",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "IEP",
                symbol: "IEP"
            },
            ILP: {
                displayName: "ILP",
                symbol: "ILP"
            },
            ILR: {
                displayName: "ILR",
                symbol: "ILR"
            },
            ILS: {
                displayName: "israelski nowy šekel",
                "displayName-count-one": "israelski nowy šekel",
                "displayName-count-two": "israelskej nowej šekelej",
                "displayName-count-few": "israelske nowe šekele",
                "displayName-count-other": "israelskich nowych šekelow",
                symbol: "₪",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "indiska rupija",
                "displayName-count-one": "indiska rupija",
                "displayName-count-two": "indiskej rupiji",
                "displayName-count-few": "indiske rupije",
                "displayName-count-other": "indiskich rupijow",
                symbol: "₹",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "irakski dinar",
                "displayName-count-one": "irakski dinar",
                "displayName-count-two": "irakskej dinaraj",
                "displayName-count-few": "irakske dinary",
                "displayName-count-other": "irakskich dinarow",
                symbol: "IQD"
            },
            IRR: {
                displayName: "iranski rial",
                "displayName-count-one": "iranski rial",
                "displayName-count-two": "iranskej rialej",
                "displayName-count-few": "iranske riale",
                "displayName-count-other": "iranskich rialow",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "ISJ",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "islandska króna",
                "displayName-count-one": "islandska króna",
                "displayName-count-two": "islandskej krónje",
                "displayName-count-few": "islandske króny",
                "displayName-count-other": "islandskich krónow",
                symbol: "ISK",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "ITL",
                symbol: "ITL"
            },
            JMD: {
                displayName: "jamaiski dolar",
                "displayName-count-one": "jamaiski dolar",
                "displayName-count-two": "jamaiskej dolaraj",
                "displayName-count-few": "jamaiske dolary",
                "displayName-count-other": "jamaiskich dolarow",
                symbol: "JMD",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "jordaniski dinar",
                "displayName-count-one": "jordaniski dinar",
                "displayName-count-two": "jordaniskej dinaraj",
                "displayName-count-few": "jordaniske dinary",
                "displayName-count-other": "jordaniskich dinarow",
                symbol: "JOD"
            },
            JPY: {
                displayName: "japanski yen",
                "displayName-count-one": "japanski yen",
                "displayName-count-two": "japanskej yenaj",
                "displayName-count-few": "japanske yeny",
                "displayName-count-other": "japanskich yenow",
                symbol: "¥",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "keniaski šiling",
                "displayName-count-one": "keniaski šiling",
                "displayName-count-two": "keniaskej šilingaj",
                "displayName-count-few": "keniaske šilingi",
                "displayName-count-other": "keniaskich šilingow",
                symbol: "KES"
            },
            KGS: {
                displayName: "kirgiski som",
                "displayName-count-one": "kirgiski som",
                "displayName-count-two": "kirgiskej somaj",
                "displayName-count-few": "kirgiske somy",
                "displayName-count-other": "kirgiskich somow",
                symbol: "KGS"
            },
            KHR: {
                displayName: "kambodźaski riel",
                "displayName-count-one": "kambodźaski riel",
                "displayName-count-two": "kambodźaskej rielej",
                "displayName-count-few": "kambodźaske riele",
                "displayName-count-other": "kambodźaskich rielow",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "komorski frank",
                "displayName-count-one": "komorski frank",
                "displayName-count-two": "komorskej frankaj",
                "displayName-count-few": "komorske franki",
                "displayName-count-other": "komorskich frankow",
                symbol: "KMF",
                "symbol-alt-narrow": "CF"
            },
            KPW: {
                displayName: "sewjernokorejski won",
                "displayName-count-one": "sewjernokorejski won",
                "displayName-count-two": "sewjernokorejskej wonaj",
                "displayName-count-few": "sewjernokorejske wony",
                "displayName-count-other": "sewjernokorejskich wonow",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "KRH",
                symbol: "KRH"
            },
            KRO: {
                displayName: "KRO",
                symbol: "KRO"
            },
            KRW: {
                displayName: "južnokorejski won",
                "displayName-count-one": "južnokorejski won",
                "displayName-count-two": "južnokorejskej wonaj",
                "displayName-count-few": "južnokorejske wony",
                "displayName-count-other": "južnokorejskich wonow",
                symbol: "₩",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "kuwaitski dinar",
                "displayName-count-one": "kuwaitski dinar",
                "displayName-count-two": "kuwaitskej dinaraj",
                "displayName-count-few": "kuwaitske dinary",
                "displayName-count-other": "kuwaitskich dinarow",
                symbol: "KWD"
            },
            KYD: {
                displayName: "kajmanski dolar",
                "displayName-count-one": "kajmanski dolar",
                "displayName-count-two": "kajmanskej dolaraj",
                "displayName-count-few": "kajmanske dolary",
                "displayName-count-other": "kajmanskich dolarow",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "kazachski tenge",
                "displayName-count-one": "kazachski tenge",
                "displayName-count-two": "kazachskej tengaj",
                "displayName-count-few": "kazachske tengi",
                "displayName-count-other": "kazachskich tengow",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "laoski kip",
                "displayName-count-one": "laoski kip",
                "displayName-count-two": "laoskej kipaj",
                "displayName-count-few": "laoske kipy",
                "displayName-count-other": "laoskich kipow",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "libanonski punt",
                "displayName-count-one": "libanonski punt",
                "displayName-count-two": "libanonskej puntaj",
                "displayName-count-few": "libanonske punty",
                "displayName-count-other": "libanonskich puntow",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "sri-lankaska rupija",
                "displayName-count-one": "sri-lankaska rupija",
                "displayName-count-two": "sri-lankaskej rupiji",
                "displayName-count-few": "sri-lankaske rupije",
                "displayName-count-other": "sri-lankaskich rupijow",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "liberiski dolar",
                "displayName-count-one": "liberiski dolar",
                "displayName-count-two": "liberiskej dolaraj",
                "displayName-count-few": "liberiske dolary",
                "displayName-count-other": "liberiskich dolarow",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "lesothiski loti",
                "displayName-count-one": "lesothiski loti",
                "displayName-count-two": "lesothiskej lotijej",
                "displayName-count-few": "lesothiske lotije",
                "displayName-count-other": "lesothiskich lotijow",
                symbol: "LSL"
            },
            LTL: {
                displayName: "litawski litas",
                "displayName-count-one": "litawski litas",
                "displayName-count-two": "litawskej litasaj",
                "displayName-count-few": "litawske litasy",
                "displayName-count-other": "litawskich litasow",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "LTT",
                symbol: "LTT"
            },
            LUC: {
                displayName: "LUC",
                symbol: "LUC"
            },
            LUF: {
                displayName: "LUF",
                symbol: "LUF"
            },
            LUL: {
                displayName: "LUL",
                symbol: "LUL"
            },
            LVL: {
                displayName: "letiski lat",
                "displayName-count-one": "letiski lat",
                "displayName-count-two": "letiskej lataj",
                "displayName-count-few": "letiske laty",
                "displayName-count-other": "letiskich latow",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "LVR",
                symbol: "LVR"
            },
            LYD: {
                displayName: "libyski dinar",
                "displayName-count-one": "libyski dinar",
                "displayName-count-two": "libyskej dinaraj",
                "displayName-count-few": "libyske dinary",
                "displayName-count-other": "libyskich dinarow",
                symbol: "LYD"
            },
            MAD: {
                displayName: "marokkoski dirham",
                "displayName-count-one": "marokkoski dirham",
                "displayName-count-two": "marokkoskej dirhamaj",
                "displayName-count-few": "marokkoske dirhamy",
                "displayName-count-other": "marokkoskich dirhamow",
                symbol: "MAD"
            },
            MAF: {
                displayName: "MAF",
                symbol: "MAF"
            },
            MCF: {
                displayName: "MCF",
                symbol: "MCF"
            },
            MDC: {
                displayName: "MDC",
                symbol: "MDC"
            },
            MDL: {
                displayName: "moldawski leu",
                "displayName-count-one": "moldawski leu",
                "displayName-count-two": "moldawskej leuwaj",
                "displayName-count-few": "moldawske leuwy",
                "displayName-count-other": "moldawskich leuwow",
                symbol: "MDL"
            },
            MGA: {
                displayName: "madagaskarski ariary",
                "displayName-count-one": "madagaskarski ariary",
                "displayName-count-two": "madagaskarskej ariaryjej",
                "displayName-count-few": "madagaskarske ariaryje",
                "displayName-count-other": "madagaskarskich ariaryjow",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "MGF",
                symbol: "MGF"
            },
            MKD: {
                displayName: "makedonski denar",
                "displayName-count-one": "makedonski denar",
                "displayName-count-two": "makedonskej denaraj",
                "displayName-count-few": "makedonske denary",
                "displayName-count-other": "makedonskich denarow",
                symbol: "MKD"
            },
            MKN: {
                displayName: "MKN",
                symbol: "MKN"
            },
            MLF: {
                displayName: "MLF",
                symbol: "MLF"
            },
            MMK: {
                displayName: "myanmarski kyat",
                "displayName-count-one": "myanmarski kyat",
                "displayName-count-two": "myanmarskej kyataj",
                "displayName-count-few": "myanmarske kyaty",
                "displayName-count-other": "myanmarskich kyatow",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "mongolski tugrik",
                "displayName-count-one": "mongolski tugrik",
                "displayName-count-two": "mongolskej tugrikaj",
                "displayName-count-few": "mongolske tugriki",
                "displayName-count-other": "mongolskich tugrikow",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "macaoska pataka",
                "displayName-count-one": "macaoska pataka",
                "displayName-count-two": "macaoskej patace",
                "displayName-count-few": "macaoske pataki",
                "displayName-count-other": "macaoskich patakow",
                symbol: "MOP"
            },
            MRO: {
                displayName: "mawretanska ouguiya (1973–2017)",
                "displayName-count-one": "mawretanska ouguiya (1973–2017)",
                "displayName-count-two": "mawretanskej ouguiji (1973–2017)",
                "displayName-count-few": "mawretanske ouguije (1973–2017)",
                "displayName-count-other": "mawretanskich ouguijow (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "mawretanska ouguiya",
                "displayName-count-one": "mawretanska ouguiya",
                "displayName-count-two": "mawretanskej ouguiji",
                "displayName-count-few": "mawretanske ouguije",
                "displayName-count-other": "mawretanskich ouguijow",
                symbol: "MRU"
            },
            MTL: {
                displayName: "MTL",
                symbol: "MTL"
            },
            MTP: {
                displayName: "MTP",
                symbol: "MTP"
            },
            MUR: {
                displayName: "mauritiuska rupija",
                "displayName-count-one": "mauritiuska rupija",
                "displayName-count-two": "mauritiuskej rupiji",
                "displayName-count-few": "mauritiuske rupije",
                "displayName-count-other": "mauritiuskich rupijow",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "MVP",
                symbol: "MVP"
            },
            MVR: {
                displayName: "malediwiska rupija",
                "displayName-count-one": "malediwiska rupija",
                "displayName-count-two": "malediwiskej rupiji",
                "displayName-count-few": "malediwiske rupije",
                "displayName-count-other": "malediwiskich rupijow",
                symbol: "MVR"
            },
            MWK: {
                displayName: "malawiski kwacha",
                "displayName-count-one": "malawiski kwacha",
                "displayName-count-two": "malawiskej kwachaj",
                "displayName-count-few": "malawiske kwachi",
                "displayName-count-other": "malawiskich kwachow",
                symbol: "MWK"
            },
            MXN: {
                displayName: "mexiski peso",
                "displayName-count-one": "mexiski peso",
                "displayName-count-two": "mexiskej pesaj",
                "displayName-count-few": "mexiske pesa",
                "displayName-count-other": "mexiskich pesow",
                symbol: "MX$",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "MXP",
                symbol: "MXP"
            },
            MXV: {
                displayName: "MXV",
                symbol: "MXV"
            },
            MYR: {
                displayName: "malajziski ringgit",
                "displayName-count-one": "malajziski ringgit",
                "displayName-count-two": "malajziskej ringgitaj",
                "displayName-count-few": "malajziske ringgity",
                "displayName-count-other": "malajziskich ringgitow",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "mosambikski escudo",
                "displayName-count-one": "mosambikski escudo",
                "displayName-count-two": "mosambikskej escudaj",
                "displayName-count-few": "mosambikske escuda",
                "displayName-count-other": "mosambikskich escudow",
                symbol: "MZE"
            },
            MZM: {
                displayName: "mosambikski metical (1980–2006)",
                "displayName-count-one": "mosambikski metical (1980–2006)",
                "displayName-count-two": "mosambikskej meticalej (1980–2006)",
                "displayName-count-few": "mosambikske meticale (1980–2006)",
                "displayName-count-other": "mosambikskich meticalow (1980–2006)",
                symbol: "MZM"
            },
            MZN: {
                displayName: "mosambikski metical",
                "displayName-count-one": "mosambikski metical",
                "displayName-count-two": "mosambikskej meticalej",
                "displayName-count-few": "mosambikske meticale",
                "displayName-count-other": "mosambikskich meticalow",
                symbol: "MZN"
            },
            NAD: {
                displayName: "namibiski dolar",
                "displayName-count-one": "namibiski dolar",
                "displayName-count-two": "namibiskej dolaraj",
                "displayName-count-few": "namibiske dolary",
                "displayName-count-other": "namibiskich dolarow",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "nigeriski naira",
                "displayName-count-one": "nigeriski naira",
                "displayName-count-two": "nigeriskej nairaj",
                "displayName-count-few": "nigeriske nairy",
                "displayName-count-other": "nigeriskich nairow",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "NIC",
                symbol: "NIC"
            },
            NIO: {
                displayName: "nikaraguaski cordoba",
                "displayName-count-one": "nikaraguaski cordoba",
                "displayName-count-two": "nikaraguaskej cordobaj",
                "displayName-count-few": "nikaraguaske cordoby",
                "displayName-count-other": "nikaraguaskich cordobow",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "NLG",
                symbol: "NLG"
            },
            NOK: {
                displayName: "norwegska króna",
                "displayName-count-one": "norwegska króna",
                "displayName-count-two": "norwegskej krónje",
                "displayName-count-few": "norwegske króny",
                "displayName-count-other": "norwegskich krónow",
                symbol: "NOK",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "nepalska rupija",
                "displayName-count-one": "nepalska rupija",
                "displayName-count-two": "nepalskej rupiji",
                "displayName-count-few": "nepalske rupije",
                "displayName-count-other": "nepalskich rupijow",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "nowoseelandski dolar",
                "displayName-count-one": "nowoseelandski dolar",
                "displayName-count-two": "nowoseelandskej dolaraj",
                "displayName-count-few": "nowoseelandske dolary",
                "displayName-count-other": "nowoseelandskich dolarow",
                symbol: "NZ$",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "omanski rial",
                "displayName-count-one": "omanski rial",
                "displayName-count-two": "omanskej rialej",
                "displayName-count-few": "omanske riale",
                "displayName-count-other": "omanskich rialow",
                symbol: "OMR"
            },
            PAB: {
                displayName: "panamaski balboa",
                "displayName-count-one": "panamaski balboa",
                "displayName-count-two": "panamaskej balbowaj",
                "displayName-count-few": "panamaske balbowy",
                "displayName-count-other": "panamaskich balbowow",
                symbol: "PAB"
            },
            PEI: {
                displayName: "PEI",
                symbol: "PEI"
            },
            PEN: {
                displayName: "peruski sol",
                "displayName-count-one": "peruski sol",
                "displayName-count-two": "peruskej solej",
                "displayName-count-few": "peruske sole",
                "displayName-count-other": "peruskich solow",
                symbol: "PEN"
            },
            PES: {
                displayName: "PES",
                symbol: "PES"
            },
            PGK: {
                displayName: "papua-nowoginejski kina",
                "displayName-count-one": "papua-nowoginejski kina",
                "displayName-count-two": "papua-nowoginejskej kinaj",
                "displayName-count-few": "papua-nowoginejske kiny",
                "displayName-count-other": "papua-nowoginejskich kinow",
                symbol: "PGK"
            },
            PHP: {
                displayName: "filipinski peso",
                "displayName-count-one": "filipinski peso",
                "displayName-count-two": "filipinskej pesaj",
                "displayName-count-few": "filipinske pesa",
                "displayName-count-other": "filipinskich pesow",
                symbol: "₱",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "pakistanska rupija",
                "displayName-count-one": "pakistanska rupija",
                "displayName-count-two": "pakistanskej rupiji",
                "displayName-count-few": "pakistanske rupije",
                "displayName-count-other": "pakistanskich rupijow",
                symbol: "PKR",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "pólski złoty",
                "displayName-count-one": "pólski złoty",
                "displayName-count-two": "pólskej złotej",
                "displayName-count-few": "pólske złote",
                "displayName-count-other": "pólskich złotych",
                symbol: "zł",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "PLZ",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "PTE",
                symbol: "PTE"
            },
            PYG: {
                displayName: "paraguayski guarani",
                "displayName-count-one": "paraguayski guarani",
                "displayName-count-two": "paraguayskej guaranijej",
                "displayName-count-few": "paraguayske guaranije",
                "displayName-count-other": "paraguayskich guaranijow",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "katarski rial",
                "displayName-count-one": "katarski rial",
                "displayName-count-two": "katarskej rialej",
                "displayName-count-few": "katarske riale",
                "displayName-count-other": "katarskich rialow",
                symbol: "QAR"
            },
            RHD: {
                displayName: "RHD",
                symbol: "RHD"
            },
            ROL: {
                displayName: "ROL",
                symbol: "ROL"
            },
            RON: {
                displayName: "rumunski leu",
                "displayName-count-one": "rumunski leu",
                "displayName-count-two": "rumunskej leuwaj",
                "displayName-count-few": "rumunske leuwy",
                "displayName-count-other": "rumunskich leuwow",
                symbol: "RON",
                "symbol-alt-narrow": "lei"
            },
            RSD: {
                displayName: "serbiski dinar",
                "displayName-count-one": "serbiski dinar",
                "displayName-count-two": "serbiskej dinaraj",
                "displayName-count-few": "serbiske dinary",
                "displayName-count-other": "serbiskich dinarow",
                symbol: "RSD"
            },
            RUB: {
                displayName: "ruski rubl",
                "displayName-count-one": "ruski rubl",
                "displayName-count-two": "ruskej rublej",
                "displayName-count-few": "ruske ruble",
                "displayName-count-other": "ruskich rublow",
                symbol: "RUB",
                "symbol-alt-narrow": "₽"
            },
            RUR: {
                displayName: "RUR",
                symbol: "RUR"
            },
            RWF: {
                displayName: "ruandiski frank",
                "displayName-count-one": "ruandiski frank",
                "displayName-count-two": "ruandiskej frankaj",
                "displayName-count-few": "ruandiske franki",
                "displayName-count-other": "ruandiskich frankow",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "saudi-arabski rial",
                "displayName-count-one": "saudi-arabski rial",
                "displayName-count-two": "saudi-arabskej rialej",
                "displayName-count-few": "saudi-arabske riale",
                "displayName-count-other": "saudi-arabskich rialow",
                symbol: "SAR"
            },
            SBD: {
                displayName: "salomonski dolar",
                "displayName-count-one": "salomonski dolar",
                "displayName-count-two": "salomonskej dolaraj",
                "displayName-count-few": "salomonske dolary",
                "displayName-count-other": "salomonskich dolarow",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "seychellska rupija",
                "displayName-count-one": "seychellska rupija",
                "displayName-count-two": "seychellskej rupiji",
                "displayName-count-few": "seychellske rupije",
                "displayName-count-other": "seychellskich rupijow",
                symbol: "SCR"
            },
            SDD: {
                displayName: "SDD",
                symbol: "SDD"
            },
            SDG: {
                displayName: "sudanski punt",
                "displayName-count-one": "sudanski punt",
                "displayName-count-two": "sudanskej puntaj",
                "displayName-count-few": "sudanske punty",
                "displayName-count-other": "sudanskich puntow",
                symbol: "SDG"
            },
            SDP: {
                displayName: "SDP",
                symbol: "SDP"
            },
            SEK: {
                displayName: "šwedska króna",
                "displayName-count-one": "šwedska króna",
                "displayName-count-two": "šwedskej krónje",
                "displayName-count-few": "šwedske króny",
                "displayName-count-other": "šwedskich krónow",
                symbol: "SEK",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "singapurski dolar",
                "displayName-count-one": "singapurski dolar",
                "displayName-count-two": "singapurskej dolaraj",
                "displayName-count-few": "singapurske dolary",
                "displayName-count-other": "singapurskich dolarow",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "St. Helenski punt",
                "displayName-count-one": "St. Helenski punt",
                "displayName-count-two": "St. Helenskej puntaj",
                "displayName-count-few": "St. Helenske punty",
                "displayName-count-other": "St. Helenskich puntow",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "SIT",
                symbol: "SIT"
            },
            SKK: {
                displayName: "SKK",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "sierra-leoneski leone",
                "displayName-count-one": "sierra-leoneski leone",
                "displayName-count-two": "sierra-leoneskej leonaj",
                "displayName-count-few": "sierra-leoneske leony",
                "displayName-count-other": "sierra-leoneskich leonow",
                symbol: "SLL"
            },
            SOS: {
                displayName: "somaliski šiling",
                "displayName-count-one": "somaliski šiling",
                "displayName-count-two": "somaliskej šilingaj",
                "displayName-count-few": "somaliske šilingi",
                "displayName-count-other": "somaliskich šilingow",
                symbol: "SOS"
            },
            SRD: {
                displayName: "surinamski dolar",
                "displayName-count-one": "surinamski dolar",
                "displayName-count-two": "surinamskej dolaraj",
                "displayName-count-few": "surinamske dolary",
                "displayName-count-other": "surinamskich dolarow",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "SRG",
                symbol: "SRG"
            },
            SSP: {
                displayName: "južnosudanski punt",
                "displayName-count-one": "južnosudanski punt",
                "displayName-count-two": "južnosudanskej puntaj",
                "displayName-count-few": "južnosudanske punty",
                "displayName-count-other": "južnosudanskich puntow",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "são tomeski dobra (1977–2017)",
                "displayName-count-one": "são tomeski dobra (1977–2017)",
                "displayName-count-two": "são tomeskej dobraj (1977–2017)",
                "displayName-count-few": "são tomeske dobry (1977–2017)",
                "displayName-count-other": "são tomeskich dobrow (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "são tomeski dobra",
                "displayName-count-one": "são tomeski dobra",
                "displayName-count-two": "são tomeskej dobraj",
                "displayName-count-few": "são tomeske dobry",
                "displayName-count-other": "são tomeskich dobrow",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "SUR",
                symbol: "SUR"
            },
            SVC: {
                displayName: "el salvadorski colón",
                "displayName-count-one": "el salvadorski colón",
                "displayName-count-two": "el salvadorskej colónaj",
                "displayName-count-few": "el salvadorske colóny",
                "displayName-count-other": "el salvadorskich colónow",
                symbol: "SVC"
            },
            SYP: {
                displayName: "syriski punt",
                "displayName-count-one": "syriski punt",
                "displayName-count-two": "syriskej puntaj",
                "displayName-count-few": "syriske punty",
                "displayName-count-other": "syriskich puntow",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "swasiski lilangeni",
                "displayName-count-one": "swasiski lilangeni",
                "displayName-count-two": "swasiskej lilangenijej",
                "displayName-count-few": "swasiske lilangenije",
                "displayName-count-other": "swasiskich lilangenijow",
                symbol: "SZL"
            },
            THB: {
                displayName: "thaiski baht",
                "displayName-count-one": "thaiski baht",
                "displayName-count-two": "thaiskej bahtaj",
                "displayName-count-few": "thaiske bahty",
                "displayName-count-other": "thaiskich bahtow",
                symbol: "฿",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "TJR",
                symbol: "TJR"
            },
            TJS: {
                displayName: "tadźikski somoni",
                "displayName-count-one": "tadźikski somoni",
                "displayName-count-two": "tadźikskej somonijej",
                "displayName-count-few": "tadźikske somonije",
                "displayName-count-other": "tadźikskich somonijow",
                symbol: "TJS"
            },
            TMM: {
                displayName: "TMM",
                symbol: "TMM"
            },
            TMT: {
                displayName: "turkmenski manat",
                "displayName-count-one": "turkmenski manat",
                "displayName-count-two": "turkmenskej manataj",
                "displayName-count-few": "turkmenske manaty",
                "displayName-count-other": "turkmenskich manatow",
                symbol: "TMT"
            },
            TND: {
                displayName: "tuneziski dinar",
                "displayName-count-one": "tuneziski dinar",
                "displayName-count-two": "tuneziskej dinaraj",
                "displayName-count-few": "tuneziske dinary",
                "displayName-count-other": "tuneziskich dinarow",
                symbol: "TND"
            },
            TOP: {
                displayName: "tongaski paʻanga",
                "displayName-count-one": "tongaski pa’anga",
                "displayName-count-two": "tongaskej pa’angaj",
                "displayName-count-few": "tongaske pa’angi",
                "displayName-count-other": "tongaskich pa’angow",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "TPE",
                symbol: "TPE"
            },
            TRL: {
                displayName: "TRL",
                symbol: "TRL"
            },
            TRY: {
                displayName: "turkowska lira",
                "displayName-count-one": "turkowska lira",
                "displayName-count-two": "turkowskej lirje",
                "displayName-count-few": "turkowske liry",
                "displayName-count-other": "turkowskich lirow",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "trinidad-tobagoski dolar",
                "displayName-count-one": "trinidad-tobagoski dolar",
                "displayName-count-two": "trinidad-tobagoskej dolaraj",
                "displayName-count-few": "trinidad-tobagoske dolary",
                "displayName-count-other": "trinidad-tobagoskich dolarow",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "nowy taiwanski dolar",
                "displayName-count-one": "nowy taiwanski dolar",
                "displayName-count-two": "nowej taiwanskej dolaraj",
                "displayName-count-few": "nowe taiwanske dolary",
                "displayName-count-other": "nowych taiwanskich dolarow",
                symbol: "NT$",
                "symbol-alt-narrow": "$"
            },
            TZS: {
                displayName: "tansaniski šiling",
                "displayName-count-one": "tansaniski šiling",
                "displayName-count-two": "tansaniskej šilingaj",
                "displayName-count-few": "tansaniske šilingi",
                "displayName-count-other": "tansaniskich šilingow",
                symbol: "TZS"
            },
            UAH: {
                displayName: "ukrainska hriwna",
                "displayName-count-one": "ukrainska hriwna",
                "displayName-count-two": "ukrainskej hriwnje",
                "displayName-count-few": "ukrainske hriwny",
                "displayName-count-other": "ukrainskich hriwnow",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "UAK",
                symbol: "UAK"
            },
            UGS: {
                displayName: "UGS",
                symbol: "UGS"
            },
            UGX: {
                displayName: "ugandaski šiling",
                "displayName-count-one": "ugandaski šiling",
                "displayName-count-two": "ugandaskej šilingaj",
                "displayName-count-few": "ugandaske šilingi",
                "displayName-count-other": "ugandaskich šilingow",
                symbol: "UGX"
            },
            USD: {
                displayName: "ameriski dolar",
                "displayName-count-one": "ameriski dolar",
                "displayName-count-two": "ameriskej dolaraj",
                "displayName-count-few": "ameriske dolary",
                "displayName-count-other": "ameriskich dolarow",
                symbol: "$",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "USN",
                symbol: "USN"
            },
            USS: {
                displayName: "USS",
                symbol: "USS"
            },
            UYI: {
                displayName: "UYI",
                symbol: "UYI"
            },
            UYP: {
                displayName: "UYP",
                symbol: "UYP"
            },
            UYU: {
                displayName: "uruguayski peso",
                "displayName-count-one": "uruguayski peso",
                "displayName-count-two": "uruguayskej pesaj",
                "displayName-count-few": "uruguayske pesa",
                "displayName-count-other": "uruguayskich pesow",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "UYW",
                symbol: "UYW"
            },
            UZS: {
                displayName: "uzbekski sum",
                "displayName-count-one": "uzbekski sum",
                "displayName-count-two": "uzbekskej sumaj",
                "displayName-count-few": "uzbekske sumy",
                "displayName-count-other": "uzbekskich sumow",
                symbol: "UZS"
            },
            VEB: {
                displayName: "VEB",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "venezuelski bolívar (2008–2018)",
                "displayName-count-one": "venezuelski bolívar (2008–2018)",
                "displayName-count-two": "venezuelskej bolívaraj (2008–2018)",
                "displayName-count-few": "venezuelske bolívary (2008–2018)",
                "displayName-count-other": "venezuelskich bolívarow (2008–2018)",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs"
            },
            VES: {
                displayName: "venezuelski bolívar",
                "displayName-count-one": "venezuelski bolívar",
                "displayName-count-two": "venezuelskej bolívaraj",
                "displayName-count-few": "venezuelske bolívary",
                "displayName-count-other": "venezuelskich bolívarow",
                symbol: "VES"
            },
            VND: {
                displayName: "vietnamski dong",
                "displayName-count-one": "vietnamski dong",
                "displayName-count-two": "vietnamskej dongaj",
                "displayName-count-few": "vietnamske dongi",
                "displayName-count-other": "vietnamskich dongow",
                symbol: "₫",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "VNN",
                symbol: "VNN"
            },
            VUV: {
                displayName: "vanuatuski vatu",
                "displayName-count-one": "vanuatuski vatu",
                "displayName-count-two": "vanuatuskej vatuwaj",
                "displayName-count-few": "vanuatuske vatuwy",
                "displayName-count-other": "vanuatuskich vatuwow",
                symbol: "VUV"
            },
            WST: {
                displayName: "samoaski tala",
                "displayName-count-one": "samoaski tala",
                "displayName-count-two": "samoaskej talej",
                "displayName-count-few": "samoaske tale",
                "displayName-count-other": "samoaskich talow",
                symbol: "WST"
            },
            XAF: {
                displayName: "CFA-frank (BEAC)",
                "displayName-count-one": "CFA-frank (BEAC)",
                "displayName-count-two": "CFA-frankaj (BEAC)",
                "displayName-count-few": "CFA-franki (BEAC)",
                "displayName-count-other": "CFA-frankow (BEAC)",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "XAG",
                symbol: "XAG"
            },
            XAU: {
                displayName: "XAU",
                symbol: "XAU"
            },
            XBA: {
                displayName: "XBA",
                symbol: "XBA"
            },
            XBB: {
                displayName: "XBB",
                symbol: "XBB"
            },
            XBC: {
                displayName: "XBC",
                symbol: "XBC"
            },
            XBD: {
                displayName: "XBD",
                symbol: "XBD"
            },
            XCD: {
                displayName: "wuchodnokaribiski dolar",
                "displayName-count-one": "wuchodnokaribiski dolar",
                "displayName-count-two": "wuchodnokaribiskej dolaraj",
                "displayName-count-few": "wuchodnokaribiske dolary",
                "displayName-count-other": "wuchodnokaribiskich dolarow",
                symbol: "EC$",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "XDR",
                symbol: "XDR"
            },
            XEU: {
                displayName: "XEU",
                symbol: "XEU"
            },
            XFO: {
                displayName: "XFO",
                symbol: "XFO"
            },
            XFU: {
                displayName: "XFU",
                symbol: "XFU"
            },
            XOF: {
                displayName: "CFA-frank (BCEAO)",
                "displayName-count-one": "CFA-frank (BCEAO)",
                "displayName-count-two": "CFA-frankaj (BCEAO)",
                "displayName-count-few": "CFA-franki (BCEAO)",
                "displayName-count-other": "CFA-frankow (BCEAO)",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "XPD",
                symbol: "XPD"
            },
            XPF: {
                displayName: "CFP-frank",
                "displayName-count-one": "CFP-frank",
                "displayName-count-two": "CFP-frankaj",
                "displayName-count-few": "CFP-franki",
                "displayName-count-other": "CFP-frankow",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "XPT",
                symbol: "XPT"
            },
            XRE: {
                displayName: "XRE",
                symbol: "XRE"
            },
            XSU: {
                displayName: "XSU",
                symbol: "XSU"
            },
            XTS: {
                displayName: "XTS",
                symbol: "XTS"
            },
            XUA: {
                displayName: "XUA",
                symbol: "XUA"
            },
            XXX: {
                displayName: "njeznata měna",
                "displayName-count-one": "njeznata měna",
                "displayName-count-two": "njeznatej měnje",
                "displayName-count-few": "njeznate měny",
                "displayName-count-other": "njeznatych měnow",
                symbol: "¤"
            },
            YDD: {
                displayName: "YDD",
                symbol: "YDD"
            },
            YER: {
                displayName: "jemenski rial",
                "displayName-count-one": "jemenski rial",
                "displayName-count-two": "jemenskej rialej",
                "displayName-count-few": "jemenske riale",
                "displayName-count-other": "jemenskich rialow",
                symbol: "YER"
            },
            YUD: {
                displayName: "YUD",
                symbol: "YUD"
            },
            YUM: {
                displayName: "YUM",
                symbol: "YUM"
            },
            YUN: {
                displayName: "YUN",
                symbol: "YUN"
            },
            YUR: {
                displayName: "YUR",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "ZAL",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "južnoafriski rand",
                "displayName-count-one": "južnoafriski rand",
                "displayName-count-two": "južnoafriskej randaj",
                "displayName-count-few": "južnoafriske randy",
                "displayName-count-other": "južnoafriskich randow",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "ZMK",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "sambiski kwacha",
                "displayName-count-one": "sambiski kwacha",
                "displayName-count-two": "sambiskej kwachaj",
                "displayName-count-few": "sambiske kwachi",
                "displayName-count-other": "sambiskich kwachow",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "ZRN",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "ZRZ",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "ZWD",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "ZWL",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "ZWR",
                symbol: "ZWR"
            }
        },
        localeCurrency: "EUR"
    },
    calendar: {
        patterns: {
            d: "d.M.y",
            D: "EEEE, d. MMMM y",
            m: "d. MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "LLLL y",
            F: "EEEE, d. MMMM y H:mm:ss",
            g: "d.M.y H:mm 'hodź'.",
            G: "d.M.y H:mm:ss",
            t: "H:mm 'hodź'.",
            T: "H:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E, d.",
                Ehm: "E, h:mm a",
                EHm: "E, H:mm 'hodź'.",
                Ehms: "E, h:mm:ss a",
                EHms: "E, HH:mm:ss",
                Gy: "y G",
                GyMd: "d.M.y GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "d. MMM y G",
                GyMMMEd: "E, d. MMM y G",
                h: "h a",
                H: "H 'hodź'.",
                hm: "h:mm a",
                Hm: "H:mm 'hodź'.",
                hms: "h:mm:ss a",
                Hms: "H:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "H:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "H:mm v",
                M: "L",
                Md: "d.M.",
                MEd: "E, d.M.",
                MMM: "LLL",
                MMMd: "d. MMM",
                MMMEd: "E, d. MMM",
                MMMMd: "d MMMM",
                "MMMMW-count-one": "'tydźeń' W MMMM",
                "MMMMW-count-two": "'tydźeń' W MMMM",
                "MMMMW-count-few": "'tydźeń' W MMMM",
                "MMMMW-count-other": "'tydźeń' W MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M.y",
                yMd: "d.M.y",
                yMEd: "E, d.M.y",
                yMMM: "MMM y",
                yMMMd: "d. MMM y",
                yMMMEd: "E, d. MMM y",
                yMMMM: "LLLL y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "'tydźeń' w 'lěta' Y",
                "yw-count-two": "'tydźeń' w 'lěta' Y",
                "yw-count-few": "'tydźeń' w 'lěta' Y",
                "yw-count-other": "'tydźeń' w 'lěta' Y"
            }
        },
        timeFormats: {
            full: "H:mm:ss zzzz",
            long: "H:mm:ss z",
            medium: "H:mm:ss",
            short: "H:mm 'hodź'."
        },
        dateFormats: {
            full: "EEEE, d. MMMM y",
            long: "d. MMMM y",
            medium: "d.M.y",
            short: "d.M.yy"
        },
        days: {
            format: {
                abbreviated: [
                    "nje",
                    "pón",
                    "wut",
                    "srj",
                    "štw",
                    "pja",
                    "sob"
                ],
                narrow: [
                    "n",
                    "p",
                    "w",
                    "s",
                    "š",
                    "p",
                    "s"
                ],
                short: [
                    "nj",
                    "pó",
                    "wu",
                    "sr",
                    "št",
                    "pj",
                    "so"
                ],
                wide: [
                    "njedźela",
                    "póndźela",
                    "wutora",
                    "srjeda",
                    "štwórtk",
                    "pjatk",
                    "sobota"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "nje",
                    "pón",
                    "wut",
                    "srj",
                    "štw",
                    "pja",
                    "sob"
                ],
                narrow: [
                    "n",
                    "p",
                    "w",
                    "s",
                    "š",
                    "p",
                    "s"
                ],
                short: [
                    "nj",
                    "pó",
                    "wu",
                    "sr",
                    "št",
                    "pj",
                    "so"
                ],
                wide: [
                    "njedźela",
                    "póndźela",
                    "wutora",
                    "srjeda",
                    "štwórtk",
                    "pjatk",
                    "sobota"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "jan.",
                    "feb.",
                    "měr.",
                    "apr.",
                    "mej.",
                    "jun.",
                    "jul.",
                    "awg.",
                    "sep.",
                    "okt.",
                    "now.",
                    "dec."
                ],
                narrow: [
                    "j",
                    "f",
                    "m",
                    "a",
                    "m",
                    "j",
                    "j",
                    "a",
                    "s",
                    "o",
                    "n",
                    "d"
                ],
                wide: [
                    "januara",
                    "februara",
                    "měrca",
                    "apryla",
                    "meje",
                    "junija",
                    "julija",
                    "awgusta",
                    "septembra",
                    "oktobra",
                    "nowembra",
                    "decembra"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "jan",
                    "feb",
                    "měr",
                    "apr",
                    "mej",
                    "jun",
                    "jul",
                    "awg",
                    "sep",
                    "okt",
                    "now",
                    "dec"
                ],
                narrow: [
                    "j",
                    "f",
                    "m",
                    "a",
                    "m",
                    "j",
                    "j",
                    "a",
                    "s",
                    "o",
                    "n",
                    "d"
                ],
                wide: [
                    "januar",
                    "februar",
                    "měrc",
                    "apryl",
                    "meja",
                    "junij",
                    "julij",
                    "awgust",
                    "september",
                    "oktober",
                    "nowember",
                    "december"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. kwartal",
                    "2. kwartal",
                    "3. kwartal",
                    "4. kwartal"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. kwartal",
                    "2. kwartal",
                    "3. kwartal",
                    "4. kwartal"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "dopołdnja",
                    pm: "popołdnju"
                },
                narrow: {
                    am: "dop.",
                    pm: "pop."
                },
                wide: {
                    am: "dopołdnja",
                    pm: "popołdnju"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "am",
                    pm: "pm"
                },
                narrow: {
                    am: "am",
                    pm: "pm"
                },
                wide: {
                    am: "dopołdnja",
                    pm: "popołdnju"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "před Chrystowym narodźenjom",
                    "1": "po Chrystowym narodźenju",
                    "0-alt-variant": "před našim ličenjom časa",
                    "1-alt-variant": "našeho ličenja časa"
                },
                abbreviated: {
                    "0": "př.Chr.n.",
                    "1": "po Chr.n.",
                    "0-alt-variant": "př.n.l.č.",
                    "1-alt-variant": "n.l.č."
                },
                narrow: {
                    "0": "př.Chr.n.",
                    "1": "po Chr.n.",
                    "0-alt-variant": "př.n.l.č.",
                    "1-alt-variant": "n.l.č."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "doba",
                short: "doba",
                narrow: "doba"
            },
            year: {
                wide: "lěto",
                short: "l.",
                narrow: "l."
            },
            quarter: {
                wide: "kwartal",
                short: "kwart.",
                narrow: "kw."
            },
            month: {
                wide: "měsac",
                short: "měs.",
                narrow: "měs."
            },
            week: {
                wide: "tydźeń",
                short: "tydź.",
                narrow: "tydź."
            },
            weekOfMonth: {
                wide: "tydźeń měsaca",
                short: "tydź. měs.",
                narrow: "t. měs."
            },
            day: {
                wide: "dźeń",
                short: "dźeń",
                narrow: "d"
            },
            dayOfYear: {
                wide: "dźeń lěta",
                short: "dźeń l.",
                narrow: "dźeń l."
            },
            weekday: {
                wide: "dźeń tydźenja",
                short: "dźeń tydźenja",
                narrow: "dź. tydźenja"
            },
            weekdayOfMonth: {
                wide: "dźeń tydźenja w měsacu",
                short: "dn. tydź. w měs.",
                narrow: "d. t. w měs."
            },
            dayperiod: {
                short: "połojca dnja",
                wide: "połojca dnja",
                narrow: "poł. dnja"
            },
            hour: {
                wide: "hodźina",
                short: "hodź.",
                narrow: "h"
            },
            minute: {
                wide: "minuta",
                short: "min.",
                narrow: "m"
            },
            second: {
                wide: "sekunda",
                short: "sek.",
                narrow: "s"
            },
            zone: {
                wide: "časowe pasmo",
                short: "časowe pasmo",
                narrow: "čas. pasmo"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "milisekunda"
            }
        }
    },
    firstDay: 1,
    weekendRange: {
        start: 6,
        end: 0
    },
    likelySubtags: {
        hsb: "hsb-Latn-DE"
    }
});

