/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "is",
    identity: {
        language: "is"
    },
    territory: "IS",
    numbers: {
        symbols: {
            decimal: ",",
            group: ".",
            list: ";",
            percentSign: "%",
            plusSign: "+",
            minusSign: "-",
            approximatelySign: "~",
            exponential: "E",
            superscriptingExponent: "×",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "n%"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-one": "n $",
            "unitPattern-count-other": "n $"
        },
        accounting: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "Andorrskur peseti",
                symbol: "ADP"
            },
            AED: {
                displayName: "arabískt dírham",
                "displayName-count-one": "arabískt dírham",
                "displayName-count-other": "arabísk dírhöm",
                symbol: "AED"
            },
            AFA: {
                displayName: "AFA",
                symbol: "AFA"
            },
            AFN: {
                displayName: "afgani",
                "displayName-count-one": "afgani",
                "displayName-count-other": "afganar",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "ALK",
                symbol: "ALK"
            },
            ALL: {
                displayName: "albanskt lek",
                "displayName-count-one": "albanskt lek",
                "displayName-count-other": "albönsk lek",
                symbol: "ALL"
            },
            AMD: {
                displayName: "armenskt dramm",
                "displayName-count-one": "armenskt dramm",
                "displayName-count-other": "armensk drömm",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "hollenskt Antillugyllini",
                "displayName-count-one": "hollenskt Antillugyllini",
                "displayName-count-other": "hollensk Antillugyllini",
                symbol: "ANG"
            },
            AOA: {
                displayName: "angólsk kvansa",
                "displayName-count-one": "angólsk kvansa",
                "displayName-count-other": "angólskar kvönsur",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "AOK",
                symbol: "AOK"
            },
            AON: {
                displayName: "AON",
                symbol: "AON"
            },
            AOR: {
                displayName: "AOR",
                symbol: "AOR"
            },
            ARA: {
                displayName: "Argentine Austral",
                symbol: "ARA"
            },
            ARL: {
                displayName: "ARL",
                symbol: "ARL"
            },
            ARM: {
                displayName: "ARM",
                symbol: "ARM"
            },
            ARP: {
                displayName: "Argentískur pesi (1983–1985)",
                symbol: "ARP"
            },
            ARS: {
                displayName: "argentínskur pesi",
                "displayName-count-one": "argentínskur pesi",
                "displayName-count-other": "argentínskir pesar",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "Austurrískur skildingur",
                symbol: "ATS"
            },
            AUD: {
                displayName: "ástralskur dalur",
                "displayName-count-one": "ástralskur dalur",
                "displayName-count-other": "ástralskir dalir",
                symbol: "AUD",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "arúbönsk flórína",
                "displayName-count-one": "arúbönsk flórína",
                "displayName-count-other": "arúbanskar flórínur",
                symbol: "AWG"
            },
            AZM: {
                displayName: "AZM",
                symbol: "AZM"
            },
            AZN: {
                displayName: "aserskt manat",
                "displayName-count-one": "aserskt manat",
                "displayName-count-other": "asersk manöt",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "BAD",
                symbol: "BAD"
            },
            BAM: {
                displayName: "skiptanlegt Bosníu og Hersegóvínu-mark",
                "displayName-count-one": "skiptanlegt Bosníu og Hersegóvínu-mark",
                "displayName-count-other": "skiptanleg Bosníu og Hersegóvínu-mörk",
                symbol: "BAM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "BAN",
                symbol: "BAN"
            },
            BBD: {
                displayName: "barbadoskur dalur",
                "displayName-count-one": "barbadoskur dalur",
                "displayName-count-other": "barbadoskir dalir",
                symbol: "BBD",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "bangladessk taka",
                "displayName-count-one": "bangladessk taka",
                "displayName-count-other": "bangladesskar tökur",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "BEC",
                symbol: "BEC"
            },
            BEF: {
                displayName: "Belgískur franki",
                symbol: "BEF"
            },
            BEL: {
                displayName: "BEL",
                symbol: "BEL"
            },
            BGL: {
                displayName: "Lef",
                symbol: "BGL"
            },
            BGM: {
                displayName: "BGM",
                symbol: "BGM"
            },
            BGN: {
                displayName: "búlgarskt lef",
                "displayName-count-one": "búlgarskt lef",
                "displayName-count-other": "búlgörsk lef",
                symbol: "BGN"
            },
            BGO: {
                displayName: "BGO",
                symbol: "BGO"
            },
            BHD: {
                displayName: "bareinskur denari",
                "displayName-count-one": "bareinskur denari",
                "displayName-count-other": "bareinskir denarar",
                symbol: "BHD"
            },
            BIF: {
                displayName: "búrúndískur franki",
                "displayName-count-one": "búrúndískur franki",
                "displayName-count-other": "búrúndískir frankar",
                symbol: "BIF"
            },
            BMD: {
                displayName: "Bermúdadalur",
                "displayName-count-one": "Bermúdadalur",
                "displayName-count-other": "Bermúdadalir",
                symbol: "BMD",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "brúneiskur dalur",
                "displayName-count-one": "brúneiskur dalur",
                "displayName-count-other": "brúneiskir dalir",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "bólivíani",
                "displayName-count-one": "bólivíani",
                "displayName-count-other": "bólivíanar",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "BOL",
                symbol: "BOL"
            },
            BOP: {
                displayName: "Bólivískur pesi",
                symbol: "BOP"
            },
            BOV: {
                displayName: "Bolivian Mvdol",
                symbol: "BOV"
            },
            BRB: {
                displayName: "BRB",
                symbol: "BRB"
            },
            BRC: {
                displayName: "BRC",
                symbol: "BRC"
            },
            BRE: {
                displayName: "BRE",
                symbol: "BRE"
            },
            BRL: {
                displayName: "brasilískt ríal",
                "displayName-count-one": "brasilískt ríal",
                "displayName-count-other": "brasilísk ríöl",
                symbol: "BRL",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "BRN",
                symbol: "BRN"
            },
            BRR: {
                displayName: "BRR",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "BRZ",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "Bahamadalur",
                "displayName-count-one": "Bahamadalur",
                "displayName-count-other": "Bahamadalir",
                symbol: "BSD",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "bútanskt núltrum",
                "displayName-count-one": "bútanskt núltrum",
                "displayName-count-other": "bútönsk núltrum",
                symbol: "BTN"
            },
            BUK: {
                displayName: "Búrmverskt kjat",
                symbol: "BUK"
            },
            BWP: {
                displayName: "botsvönsk púla",
                "displayName-count-one": "botsvönsk púla",
                "displayName-count-other": "botsvanskar púlur",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "BYB",
                symbol: "BYB"
            },
            BYN: {
                displayName: "hvítrússnesk rúbla",
                "displayName-count-one": "hvítrússnesk rúbla",
                "displayName-count-other": "hvítrússneskar rúblur",
                symbol: "BYN"
            },
            BYR: {
                displayName: "hvítrússnesk rúbla (2000–2016)",
                "displayName-count-one": "hvítrússnesk rúbla (2000–2016)",
                "displayName-count-other": "hvítrússneskar rúblur (2000–2016)",
                symbol: "BYR"
            },
            BZD: {
                displayName: "belískur dalur",
                "displayName-count-one": "belískur dalur",
                "displayName-count-other": "belískir dalir",
                symbol: "BZD",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "Kanadadalur",
                "displayName-count-one": "Kanadadalur",
                "displayName-count-other": "Kanadadalir",
                symbol: "CAD",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "kongóskur franki",
                "displayName-count-one": "kongóskur franki",
                "displayName-count-other": "kongóskir frankar",
                symbol: "CDF"
            },
            CHE: {
                displayName: "CHE",
                symbol: "CHE"
            },
            CHF: {
                displayName: "svissneskur franki",
                "displayName-count-one": "svissneskur franki",
                "displayName-count-other": "svissneskir frankar",
                symbol: "CHF"
            },
            CHW: {
                displayName: "CHW",
                symbol: "CHW"
            },
            CLE: {
                displayName: "CLE",
                symbol: "CLE"
            },
            CLF: {
                displayName: "Chilean Unidades de Fomento",
                symbol: "CLF"
            },
            CLP: {
                displayName: "síleskur pesi",
                "displayName-count-one": "síleskur pesi",
                "displayName-count-other": "síleskir pesar",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "kínverskt júan (utan heimalands)",
                "displayName-count-one": "kínverskt júan (utan heimalands)",
                "displayName-count-other": "kínverskt júan (utan heimalands)",
                symbol: "CNH"
            },
            CNX: {
                displayName: "CNX",
                symbol: "CNX"
            },
            CNY: {
                displayName: "kínverskt júan",
                "displayName-count-one": "kínverskt júan",
                "displayName-count-other": "kínversk júön",
                symbol: "CN¥",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "kólumbískur pesi",
                "displayName-count-one": "kólumbískur pesi",
                "displayName-count-other": "kólumbískir pesar",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "COU",
                symbol: "COU"
            },
            CRC: {
                displayName: "kostarískt kólon",
                "displayName-count-one": "kostarískt kólon",
                "displayName-count-other": "kostarísk kólon",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "CSD",
                symbol: "CSD"
            },
            CSK: {
                displayName: "Tékknesk króna, eldri",
                symbol: "CSK"
            },
            CUC: {
                displayName: "kúbverskur skiptanlegur pesi",
                "displayName-count-one": "kúbverskur skiptanlegur pesi",
                "displayName-count-other": "kúbverskir skiptanlegir pesar",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "kúbverskur pesi",
                "displayName-count-one": "kúbverskur pesi",
                "displayName-count-other": "kúbverskir pesar",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "grænhöfðeyskur skúti",
                "displayName-count-one": "grænhöfðeyskur skúti",
                "displayName-count-other": "grænhöfðeyskir skútar",
                symbol: "CVE"
            },
            CYP: {
                displayName: "Kýpverskt pund",
                symbol: "CYP"
            },
            CZK: {
                displayName: "tékknesk króna",
                "displayName-count-one": "tékknesk króna",
                "displayName-count-other": "tékkneskar krónur",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "Austurþýskt mark",
                symbol: "DDM"
            },
            DEM: {
                displayName: "Þýskt mark",
                symbol: "DEM"
            },
            DJF: {
                displayName: "djíbútískur franki",
                "displayName-count-one": "djíbútískur franki",
                "displayName-count-other": "djíbútískir frankar",
                symbol: "DJF"
            },
            DKK: {
                displayName: "dönsk króna",
                "displayName-count-one": "dönsk króna",
                "displayName-count-other": "danskar krónur",
                symbol: "DKK",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "dóminískur pesi",
                "displayName-count-one": "dóminískur pesi",
                "displayName-count-other": "dóminískir pesar",
                symbol: "DOP",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "alsírskur denari",
                "displayName-count-one": "alsírskur denari",
                "displayName-count-other": "alsírskir denarar",
                symbol: "DZD"
            },
            ECS: {
                displayName: "Ecuador Sucre",
                symbol: "ECS"
            },
            ECV: {
                displayName: "ECV",
                symbol: "ECV"
            },
            EEK: {
                displayName: "Eistnesk króna",
                "displayName-count-one": "eistnesk króna",
                "displayName-count-other": "eistneskar krónur",
                symbol: "EEK"
            },
            EGP: {
                displayName: "egypskt pund",
                "displayName-count-one": "egypskt pund",
                "displayName-count-other": "egypsk pund",
                symbol: "EGP",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "erítresk nakfa",
                "displayName-count-one": "erítresk nakfa",
                "displayName-count-other": "erítreskar nökfur",
                symbol: "ERN"
            },
            ESA: {
                displayName: "ESA",
                symbol: "ESA"
            },
            ESB: {
                displayName: "ESB",
                symbol: "ESB"
            },
            ESP: {
                displayName: "Spænskur peseti",
                symbol: "ESP",
                "symbol-alt-narrow": "₧"
            },
            ETB: {
                displayName: "eþíópískt birr",
                "displayName-count-one": "eþíópískt birr",
                "displayName-count-other": "eþíópísk birr",
                symbol: "ETB"
            },
            EUR: {
                displayName: "evra",
                "displayName-count-one": "evra",
                "displayName-count-other": "evrur",
                symbol: "EUR",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "Finnskt mark",
                symbol: "FIM"
            },
            FJD: {
                displayName: "fidjeyskur dalur",
                "displayName-count-one": "fidjeyskur dalur",
                "displayName-count-other": "fidjeyskir dalir",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "falklenskt pund",
                "displayName-count-one": "falklenskt pund",
                "displayName-count-other": "falklensk pund",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "Franskur franki",
                symbol: "FRF"
            },
            GBP: {
                displayName: "sterlingspund",
                "displayName-count-one": "sterlingspund",
                "displayName-count-other": "sterlingspund",
                symbol: "GBP",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "GEK",
                symbol: "GEK"
            },
            GEL: {
                displayName: "georgískur lari",
                "displayName-count-one": "georgískur lari",
                "displayName-count-other": "georgískir larar",
                symbol: "GEL",
                "symbol-alt-narrow": "₾"
            },
            GHC: {
                displayName: "GHC",
                symbol: "GHC"
            },
            GHS: {
                displayName: "ganverskur sedi",
                "displayName-count-one": "ganverskur sedi",
                "displayName-count-other": "ganverskir sedar",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "Gíbraltarspund",
                "displayName-count-one": "Gíbraltarspund",
                "displayName-count-other": "Gíbraltarspund",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "gambískur dalasi",
                "displayName-count-one": "gambískur dalasi",
                "displayName-count-other": "gambískir dalasar",
                symbol: "GMD"
            },
            GNF: {
                displayName: "Gíneufranki",
                "displayName-count-one": "Gíneufranki",
                "displayName-count-other": "Gíneufrankar",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "GNS",
                symbol: "GNS"
            },
            GQE: {
                displayName: "GQE",
                symbol: "GQE"
            },
            GRD: {
                displayName: "Drakma",
                symbol: "GRD"
            },
            GTQ: {
                displayName: "gvatemalskt kvesal",
                "displayName-count-one": "gvatemalskt kvesal",
                "displayName-count-other": "gvatemölsk kvesöl",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "Portúgalskur, gíneskur skúti",
                symbol: "GWE"
            },
            GWP: {
                displayName: "GWP",
                symbol: "GWP"
            },
            GYD: {
                displayName: "gvæjanskur dalur",
                "displayName-count-one": "gvæjanskur dalur",
                "displayName-count-other": "gvæjanskir dalir",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "Hong Kong-dalur",
                "displayName-count-one": "Hong Kong-dalur",
                "displayName-count-other": "Hong Kong-dalir",
                symbol: "HK$",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "hondúrsk lempíra",
                "displayName-count-one": "hondúrsk lempíra",
                "displayName-count-other": "hondúrskar lempírur",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "HRD",
                symbol: "HRD"
            },
            HRK: {
                displayName: "króatísk kúna",
                "displayName-count-one": "króatísk kúna",
                "displayName-count-other": "króatískar kúnur",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "haítískur gúrdi",
                "displayName-count-one": "haítískur gúrdi",
                "displayName-count-other": "haítískir gúrdar",
                symbol: "HTG"
            },
            HUF: {
                displayName: "ungversk fórinta",
                "displayName-count-one": "ungversk fórinta",
                "displayName-count-other": "ungverskar fórintur",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "indónesísk rúpía",
                "displayName-count-one": "indónesísk rúpía",
                "displayName-count-other": "indónesískar rúpíur",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "Írskt pund",
                symbol: "IEP"
            },
            ILP: {
                displayName: "Ísraelskt pund",
                symbol: "ILP"
            },
            ILR: {
                displayName: "ILR",
                symbol: "ILR"
            },
            ILS: {
                displayName: "nýr ísraelskur sikill",
                "displayName-count-one": "nýr ísraelskur sikill",
                "displayName-count-other": "nýir ísraelskir siklar",
                symbol: "₪",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "indversk rúpía",
                "displayName-count-one": "indversk rúpía",
                "displayName-count-other": "indverskar rúpíur",
                symbol: "INR",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "írakskur denari",
                "displayName-count-one": "írakskur denari",
                "displayName-count-other": "írakskir denarar",
                symbol: "IQD"
            },
            IRR: {
                displayName: "íranskt ríal",
                "displayName-count-one": "íranskt ríal",
                "displayName-count-other": "írönsk ríöl",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "ISJ",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "íslensk króna",
                "displayName-count-one": "íslensk króna",
                "displayName-count-other": "íslenskar krónur",
                symbol: "ISK",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "Ítölsk líra",
                symbol: "ITL"
            },
            JMD: {
                displayName: "jamaískur dalur",
                "displayName-count-one": "jamaískur dalur",
                "displayName-count-other": "jamaískir dalir",
                symbol: "JMD",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "jórdanskur denari",
                "displayName-count-one": "jórdanskur denari",
                "displayName-count-other": "jórdanskir denarar",
                symbol: "JOD"
            },
            JPY: {
                displayName: "japanskt jen",
                "displayName-count-one": "japanskt jen",
                "displayName-count-other": "japönsk jen",
                symbol: "JP¥",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "kenískur skildingur",
                "displayName-count-one": "kenískur skildingur",
                "displayName-count-other": "kenískir skildingar",
                symbol: "KES"
            },
            KGS: {
                displayName: "kirgiskt som",
                "displayName-count-one": "kirgiskt som",
                "displayName-count-other": "kirgisk som",
                symbol: "KGS"
            },
            KHR: {
                displayName: "kambódískt ríal",
                "displayName-count-one": "kambódískt ríal",
                "displayName-count-other": "kambódísk ríöl",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "kómoreyskur franki",
                "displayName-count-one": "kómoreyskur franki",
                "displayName-count-other": "kómoreyskir frankar",
                symbol: "KMF",
                "symbol-alt-narrow": "CF"
            },
            KPW: {
                displayName: "norðurkóreskt vonn",
                "displayName-count-one": "norðurkóreskt vonn",
                "displayName-count-other": "norðurkóresk vonn",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "KRH",
                symbol: "KRH"
            },
            KRO: {
                displayName: "KRO",
                symbol: "KRO"
            },
            KRW: {
                displayName: "suðurkóreskt vonn",
                "displayName-count-one": "suðurkóreskt vonn",
                "displayName-count-other": "suðurkóresk vonn",
                symbol: "KRW",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "kúveiskur denari",
                "displayName-count-one": "kúveiskur denari",
                "displayName-count-other": "kúveiskir denarar",
                symbol: "KWD"
            },
            KYD: {
                displayName: "caymaneyskur dalur",
                "displayName-count-one": "caymaneyskur dalur",
                "displayName-count-other": "caymaneyskir dalir",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "kasakst tengi",
                "displayName-count-one": "kasakst tengi",
                "displayName-count-other": "kasöksk tengi",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "laoskt kip",
                "displayName-count-one": "laoskt kip",
                "displayName-count-other": "laosk kip",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "líbanskt pund",
                "displayName-count-one": "líbanskt pund",
                "displayName-count-other": "líbönsk pund",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "srílönsk rúpía",
                "displayName-count-one": "srílönsk rúpía",
                "displayName-count-other": "srílanskar rúpíur",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "líberískur dalur",
                "displayName-count-one": "líberískur dalur",
                "displayName-count-other": "líberískir dalir",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "lesótóskur lóti",
                "displayName-count-one": "lesótóskur lóti",
                "displayName-count-other": "lesótóskir lótar",
                symbol: "LSL"
            },
            LTL: {
                displayName: "Litháískt lít",
                "displayName-count-one": "litháískt lít",
                "displayName-count-other": "litháísk lít",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "Lithuanian Talonas",
                symbol: "LTT"
            },
            LUC: {
                displayName: "LUC",
                symbol: "LUC"
            },
            LUF: {
                displayName: "Lúxemborgarfranki",
                symbol: "LUF"
            },
            LUL: {
                displayName: "LUL",
                symbol: "LUL"
            },
            LVL: {
                displayName: "Lettneskt lat",
                "displayName-count-one": "lettneskt lat",
                "displayName-count-other": "lettnesk löt",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "Lettnesk rúbla",
                symbol: "LVR"
            },
            LYD: {
                displayName: "líbískur denari",
                "displayName-count-one": "líbískur denari",
                "displayName-count-other": "líbískir denarar",
                symbol: "LYD"
            },
            MAD: {
                displayName: "marokkóskt dírham",
                "displayName-count-one": "marokkóskt dírham",
                "displayName-count-other": "marokkósk dírhöm",
                symbol: "MAD"
            },
            MAF: {
                displayName: "Marokkóskur franki",
                symbol: "MAF"
            },
            MCF: {
                displayName: "MCF",
                symbol: "MCF"
            },
            MDC: {
                displayName: "MDC",
                symbol: "MDC"
            },
            MDL: {
                displayName: "moldavískt lei",
                "displayName-count-one": "moldavískt lei",
                "displayName-count-other": "moldavísk lei",
                symbol: "MDL"
            },
            MGA: {
                displayName: "Madagaskararjari",
                "displayName-count-one": "Madagaskararjari",
                "displayName-count-other": "Madagaskararjarar",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "Madagaskur franki",
                symbol: "MGF"
            },
            MKD: {
                displayName: "makedónskur denari",
                "displayName-count-one": "makedónskur denari",
                "displayName-count-other": "makedónskir denarar",
                symbol: "MKD"
            },
            MKN: {
                displayName: "MKN",
                symbol: "MKN"
            },
            MLF: {
                displayName: "Malískur franki",
                symbol: "MLF"
            },
            MMK: {
                displayName: "mjanmarskt kjat",
                "displayName-count-one": "mjanmarskt kjat",
                "displayName-count-other": "mjanmörsk kjöt",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "mongólskur túríkur",
                "displayName-count-one": "mongólskur túríkur",
                "displayName-count-other": "mongólskir túríkar",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "makaósk pataka",
                "displayName-count-one": "makaósk pataka",
                "displayName-count-other": "makaóskar patökur",
                symbol: "MOP"
            },
            MRO: {
                displayName: "márítönsk úgía (1973–2017)",
                "displayName-count-one": "máritönsk úgía (1973–2017)",
                "displayName-count-other": "máritanskar úgíur (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "márítönsk úgía",
                "displayName-count-one": "máritönsk úgía",
                "displayName-count-other": "máritanskar úgíur",
                symbol: "MRU"
            },
            MTL: {
                displayName: "Meltnesk líra",
                symbol: "MTL"
            },
            MTP: {
                displayName: "Maltneskt pund",
                symbol: "MTP"
            },
            MUR: {
                displayName: "máritísk rúpía",
                "displayName-count-one": "máritísk rúpía",
                "displayName-count-other": "máritískar rúpíur",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "MVP",
                symbol: "MVP"
            },
            MVR: {
                displayName: "maldíveysk rúpía",
                "displayName-count-one": "maldíveysk rúpía",
                "displayName-count-other": "maldíveyskar rúpíur",
                symbol: "MVR"
            },
            MWK: {
                displayName: "malavísk kvaka",
                "displayName-count-one": "malavísk kvaka",
                "displayName-count-other": "malavískar kvökur",
                symbol: "MWK"
            },
            MXN: {
                displayName: "mexíkóskur pesi",
                "displayName-count-one": "mexíkóskur pesi",
                "displayName-count-other": "mexíkóskir pesar",
                symbol: "MXN",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "Mexíkóskur silfurpesi (1861–1992)",
                symbol: "MXP"
            },
            MXV: {
                displayName: "Mexíkóskur pesi, UDI",
                symbol: "MXV"
            },
            MYR: {
                displayName: "malasískt ringit",
                "displayName-count-one": "malasískt ringit",
                "displayName-count-other": "malasísk ringit",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "Mósambískur skúti",
                symbol: "MZE"
            },
            MZM: {
                displayName: "MZM",
                symbol: "MZM"
            },
            MZN: {
                displayName: "mósambískt metikal",
                "displayName-count-one": "mósambískt metikal",
                "displayName-count-other": "mósambísk metiköl",
                symbol: "MZN"
            },
            NAD: {
                displayName: "namibískur dalur",
                "displayName-count-one": "namibískur dalur",
                "displayName-count-other": "namibískir dalir",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "nígerísk næra",
                "displayName-count-one": "nígerísk næra",
                "displayName-count-other": "nígerískar nærur",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "Níkarögsk kordóva (1988–1991)",
                "displayName-count-one": "Níkarögsk kordóva (1988–1991)",
                "displayName-count-other": "Níkaragskar kordóvur (1988–1991)",
                symbol: "NIC"
            },
            NIO: {
                displayName: "níkarögsk kordóva",
                "displayName-count-one": "níkarögsk kordóva",
                "displayName-count-other": "níkaragskar kordóvur",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "Hollenskt gyllini",
                symbol: "NLG"
            },
            NOK: {
                displayName: "norsk króna",
                "displayName-count-one": "norsk króna",
                "displayName-count-other": "norskar krónur",
                symbol: "NOK",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "nepölsk rúpía",
                "displayName-count-one": "nepölsk rúpía",
                "displayName-count-other": "nepalskar rúpíur",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "nýsjálenskur dalur",
                "displayName-count-one": "nýsjálenskur dalur",
                "displayName-count-other": "nýsjálenskir dalir",
                symbol: "NZD",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "ómanskt ríal",
                "displayName-count-one": "ómanskt ríal",
                "displayName-count-other": "ómönsk ríöl",
                symbol: "OMR"
            },
            PAB: {
                displayName: "balbói",
                "displayName-count-one": "balbói",
                "displayName-count-other": "balbóar",
                symbol: "PAB"
            },
            PEI: {
                displayName: "PEI",
                symbol: "PEI"
            },
            PEN: {
                displayName: "perúskt sól",
                "displayName-count-one": "perúskt sól",
                "displayName-count-other": "perúsk sól",
                symbol: "PEN"
            },
            PES: {
                displayName: "PES",
                symbol: "PES"
            },
            PGK: {
                displayName: "papúsk kína",
                "displayName-count-one": "papúsk kína",
                "displayName-count-other": "papúskar kínur",
                symbol: "PGK"
            },
            PHP: {
                displayName: "filippseyskur pesi",
                "displayName-count-one": "filippseyskur pesi",
                "displayName-count-other": "filippseyskir pesar",
                symbol: "PHP",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "pakistönsk rúpía",
                "displayName-count-one": "pakistönsk rúpía",
                "displayName-count-other": "pakistanskar rúpíur",
                symbol: "PKR",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "pólskt slot",
                "displayName-count-one": "pólskt slot",
                "displayName-count-other": "pólsk slot",
                symbol: "PLN",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "Slot",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "Portúgalskur skúti",
                symbol: "PTE"
            },
            PYG: {
                displayName: "paragvæskt gvaraní",
                "displayName-count-one": "paragvæskt gvaraní",
                "displayName-count-other": "paragvæsk gvaraní",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "katarskt ríal",
                "displayName-count-one": "katarskt ríal",
                "displayName-count-other": "katörsk ríöl",
                symbol: "QAR"
            },
            RHD: {
                displayName: "RHD",
                symbol: "RHD"
            },
            ROL: {
                displayName: "Rúmenskt lei (1952–2006)",
                "displayName-count-one": "Rúmenskt lei (1952–2006)",
                "displayName-count-other": "Rúmenskt lei (1952–2006)",
                symbol: "ROL"
            },
            RON: {
                displayName: "rúmenskt lei",
                "displayName-count-one": "rúmenskt lei",
                "displayName-count-other": "rúmensk lei",
                symbol: "RON",
                "symbol-alt-narrow": "lei"
            },
            RSD: {
                displayName: "serbneskur denari",
                "displayName-count-one": "serbneskur denari",
                "displayName-count-other": "serbneskir denarar",
                symbol: "RSD"
            },
            RUB: {
                displayName: "rússnesk rúbla",
                "displayName-count-one": "rússnesk rúbla",
                "displayName-count-other": "rússneskar rúblur",
                symbol: "RUB",
                "symbol-alt-narrow": "₽"
            },
            RUR: {
                displayName: "Rússnesk rúbla (1991–1998)",
                symbol: "RUR"
            },
            RWF: {
                displayName: "rúandskur franki",
                "displayName-count-one": "rúandskur franki",
                "displayName-count-other": "rúandskir frankar",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "sádíarabískt ríal",
                "displayName-count-one": "sádiarabískt ríal",
                "displayName-count-other": "sádiarabísk ríöl",
                symbol: "SAR"
            },
            SBD: {
                displayName: "salómonseyskur dalur",
                "displayName-count-one": "salómonseyskur dalur",
                "displayName-count-other": "salómonseyskir dalir",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "Seychellesrúpía",
                "displayName-count-one": "Seychellesrúpía",
                "displayName-count-other": "Seychellesrúpíur",
                symbol: "SCR"
            },
            SDD: {
                displayName: "Súdanskur denari",
                symbol: "SDD"
            },
            SDG: {
                displayName: "súdanskt pund",
                "displayName-count-one": "súdanskt pund",
                "displayName-count-other": "súdönsk pund",
                symbol: "SDG"
            },
            SDP: {
                displayName: "Súdanskt pund (1957–1998)",
                symbol: "SDP"
            },
            SEK: {
                displayName: "sænsk króna",
                "displayName-count-one": "sænsk króna",
                "displayName-count-other": "sænskar krónur",
                symbol: "SEK",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "singapúrskur dalur",
                "displayName-count-one": "singapúrskur dalur",
                "displayName-count-other": "singapúrskir dalir",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "helenskt pund",
                "displayName-count-one": "helenskt pund",
                "displayName-count-other": "helensk pund",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "Slóvenskur dalur",
                symbol: "SIT"
            },
            SKK: {
                displayName: "Slóvakísk króna",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "síerraleónsk ljóna",
                "displayName-count-one": "síerraleónsk ljóna",
                "displayName-count-other": "síerraleónskar ljónur",
                symbol: "SLL"
            },
            SOS: {
                displayName: "sómalískur skildingur",
                "displayName-count-one": "sómalískur skildingur",
                "displayName-count-other": "sómalískir skildingar",
                symbol: "SOS"
            },
            SRD: {
                displayName: "Súrínamdalur",
                "displayName-count-one": "Súrínamdalur",
                "displayName-count-other": "Súrínamdalir",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "Suriname Guilder",
                symbol: "SRG"
            },
            SSP: {
                displayName: "suðursúdanskt pund",
                "displayName-count-one": "suðursúdanskt pund",
                "displayName-count-other": "suðursúdönsk pund",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "Saó Tóme og Prinsípe-dóbra (1977–2017)",
                "displayName-count-one": "Saó Tóme og Prinsípe-dóbra (1977–2017)",
                "displayName-count-other": "Saó Tóme og Prinsípe-dóbrur (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "Saó Tóme og Prinsípe-dóbra",
                "displayName-count-one": "Saó Tóme og Prinsípe-dóbra",
                "displayName-count-other": "Saó Tóme og Prinsípe-dóbrur",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "Soviet Rouble",
                symbol: "SUR"
            },
            SVC: {
                displayName: "El Salvador Colon",
                "displayName-count-one": "El Salvador Colon",
                "displayName-count-other": "El Salvador Colon",
                symbol: "SVC"
            },
            SYP: {
                displayName: "sýrlenskt pund",
                "displayName-count-one": "sýrlenskt pund",
                "displayName-count-other": "sýrlensk pund",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "svasílenskur lílangeni",
                "displayName-count-one": "svasílenskur lílangeni",
                "displayName-count-other": "svasílenskir lílangenar",
                symbol: "SZL"
            },
            THB: {
                displayName: "taílenskt bat",
                "displayName-count-one": "taílenskt bat",
                "displayName-count-other": "taílensk böt",
                symbol: "THB",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "Tadsjiksk rúbla",
                symbol: "TJR"
            },
            TJS: {
                displayName: "tadsjikskur sómóni",
                "displayName-count-one": "tadsjikskur sómóni",
                "displayName-count-other": "tadsjikskir sómónar",
                symbol: "TJS"
            },
            TMM: {
                displayName: "Túrkmenskt manat (1993–2009)",
                "displayName-count-one": "Túrkmenskt manat (1993–2009)",
                "displayName-count-other": "Túrkmenskt manat (1993–2009)",
                symbol: "TMM"
            },
            TMT: {
                displayName: "túrkmenskt manat",
                "displayName-count-one": "túrkmenskt manat",
                "displayName-count-other": "túrkmensk manöt",
                symbol: "TMT"
            },
            TND: {
                displayName: "túnískur denari",
                "displayName-count-one": "túniskur denari",
                "displayName-count-other": "túniskir denarar",
                symbol: "TND"
            },
            TOP: {
                displayName: "Tongapanga",
                "displayName-count-one": "Tongapanga",
                "displayName-count-other": "Tongapöngur",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "Tímorskur skúti",
                symbol: "TPE"
            },
            TRL: {
                displayName: "Tyrknesk líra (1922–2005)",
                symbol: "TRL"
            },
            TRY: {
                displayName: "tyrknesk líra",
                "displayName-count-one": "tyrknesk líra",
                "displayName-count-other": "tyrkneskar lírur",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "Trínidad og Tóbagó-dalur",
                "displayName-count-one": "Trínidad og Tóbagó-dalur",
                "displayName-count-other": "Trínidad og Tóbagó-dalir",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "taívanskur dalur",
                "displayName-count-one": "taívanskur dalur",
                "displayName-count-other": "taívanskir dalir",
                symbol: "TWD",
                "symbol-alt-narrow": "NT$"
            },
            TZS: {
                displayName: "tansanískur skildingur",
                "displayName-count-one": "tansanískur skildingur",
                "displayName-count-other": "tansanískir skildingar",
                symbol: "TZS"
            },
            UAH: {
                displayName: "úkraínsk hrinja",
                "displayName-count-one": "úkraínsk hrinja",
                "displayName-count-other": "úkraínskar hrinjur",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "Ukrainian Karbovanetz",
                symbol: "UAK"
            },
            UGS: {
                displayName: "UGS",
                symbol: "UGS"
            },
            UGX: {
                displayName: "úgandskur skildingur",
                "displayName-count-one": "úgandskur skildingur",
                "displayName-count-other": "úgandskir skildingar",
                symbol: "UGX"
            },
            USD: {
                displayName: "Bandaríkjadalur",
                "displayName-count-one": "Bandaríkjadalur",
                "displayName-count-other": "Bandaríkjadalir",
                symbol: "USD",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "Bandaríkjadalur (næsta dag)",
                symbol: "USN"
            },
            USS: {
                displayName: "Bandaríkjadalur (sama dag)",
                symbol: "USS"
            },
            UYI: {
                displayName: "UYI",
                symbol: "UYI"
            },
            UYP: {
                displayName: "UYP",
                symbol: "UYP"
            },
            UYU: {
                displayName: "úrúgvæskur pesi",
                "displayName-count-one": "úrúgvæskur pesi",
                "displayName-count-other": "úrúgvæskir pesar",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "UYW",
                symbol: "UYW"
            },
            UZS: {
                displayName: "úsbekskt súm",
                "displayName-count-one": "úsbekskt súm",
                "displayName-count-other": "úsbeksk súm",
                symbol: "UZS"
            },
            VEB: {
                displayName: "Bolívar í Venesúela (1871–2008)",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "venesúelskur bólívari (2008–2018)",
                "displayName-count-one": "venesúelskur bólívari (2008–2018)",
                "displayName-count-other": "venesúelskir bólívarar (2008–2018)",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs"
            },
            VES: {
                displayName: "venesúelskur bólívari",
                "displayName-count-one": "venesúelskur bólívari",
                "displayName-count-other": "venesúelskir bólívarar",
                symbol: "VES"
            },
            VND: {
                displayName: "víetnamskt dong",
                "displayName-count-one": "víetnamskt dong",
                "displayName-count-other": "víetnömsk dong",
                symbol: "VND",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "VNN",
                symbol: "VNN"
            },
            VUV: {
                displayName: "vanúatúskt vatú",
                "displayName-count-one": "vanúatúskt vatú",
                "displayName-count-other": "vanúatúsk vatú",
                symbol: "VUV"
            },
            WST: {
                displayName: "Samóatala",
                "displayName-count-one": "Samóatala",
                "displayName-count-other": "Samóatölur",
                symbol: "WST"
            },
            XAF: {
                displayName: "miðafrískur franki",
                "displayName-count-one": "miðafrískur franki",
                "displayName-count-other": "miðafrískir frankar",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "XAG",
                symbol: "XAG"
            },
            XAU: {
                displayName: "XAU",
                symbol: "XAU"
            },
            XBA: {
                displayName: "XBA",
                symbol: "XBA"
            },
            XBB: {
                displayName: "XBB",
                symbol: "XBB"
            },
            XBC: {
                displayName: "XBC",
                symbol: "XBC"
            },
            XBD: {
                displayName: "XBD",
                symbol: "XBD"
            },
            XCD: {
                displayName: "austurkarabískur dalur",
                "displayName-count-one": "austurkarabískur dalur",
                "displayName-count-other": "austurkarabískir dalir",
                symbol: "EC$",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "Sérstök dráttarréttindi",
                symbol: "XDR"
            },
            XEU: {
                displayName: "XEU",
                symbol: "XEU"
            },
            XFO: {
                displayName: "Franskur gullfranki",
                symbol: "XFO"
            },
            XFU: {
                displayName: "Franskur franki, UIC",
                symbol: "XFU"
            },
            XOF: {
                displayName: "vesturafrískur franki",
                "displayName-count-one": "vesturafrískur franki",
                "displayName-count-other": "vesturafrískir frankar",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "XPD",
                symbol: "XPD"
            },
            XPF: {
                displayName: "pólinesískur franki",
                "displayName-count-one": "pólinesískur franki",
                "displayName-count-other": "pólinesískir frankar",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "XPT",
                symbol: "XPT"
            },
            XRE: {
                displayName: "XRE",
                symbol: "XRE"
            },
            XSU: {
                displayName: "XSU",
                symbol: "XSU"
            },
            XTS: {
                displayName: "XTS",
                symbol: "XTS"
            },
            XUA: {
                displayName: "XUA",
                symbol: "XUA"
            },
            XXX: {
                displayName: "óþekktur gjaldmiðill",
                "displayName-count-one": "(óþekkt mynteining gjaldmiðils)",
                "displayName-count-other": "(óþekktur gjaldmiðill)",
                symbol: "¤"
            },
            YDD: {
                displayName: "Jemenskur denari",
                symbol: "YDD"
            },
            YER: {
                displayName: "jemenskt ríal",
                "displayName-count-one": "jemenskt ríal",
                "displayName-count-other": "jemensk ríöl",
                symbol: "YER"
            },
            YUD: {
                displayName: "YUD",
                symbol: "YUD"
            },
            YUM: {
                displayName: "Júgóslavneskur denari",
                symbol: "YUM"
            },
            YUN: {
                displayName: "YUN",
                symbol: "YUN"
            },
            YUR: {
                displayName: "YUR",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "Rand (viðskipta)",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "suðurafrískt rand",
                "displayName-count-one": "suðurafrískt rand",
                "displayName-count-other": "suðurafrísk rönd",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "Zambian Kwacha (1968–2012)",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "sambísk kvaka",
                "displayName-count-one": "sambísk kvaka",
                "displayName-count-other": "sambískar kvökur",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "ZRN",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "ZRZ",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "Simbabveskur dalur",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "ZWL",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "ZWR",
                symbol: "ZWR"
            }
        },
        localeCurrency: "ISK"
    },
    calendar: {
        patterns: {
            d: "d.M.y",
            D: "EEEE, d. MMMM y",
            m: "d. MMM",
            M: "d. MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d. MMMM y HH:mm:ss",
            g: "d.M.y HH:mm",
            G: "d.M.y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} 'kl'. {0}",
            long: "{1} 'kl'. {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d.",
                Ehm: "E, h:mm a",
                EHm: "E, HH:mm",
                Ehms: "E, h:mm:ss a",
                EHms: "E, HH:mm:ss",
                Gy: "y G",
                GyMd: "d/M/y GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "d. MMM y G",
                GyMMMEd: "E, d. MMM y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "v – HH:mm:ss",
                hmv: "h:mm a v",
                Hmv: "v – HH:mm",
                M: "L",
                Md: "d.M.",
                MEd: "E, d.M.",
                MMM: "LLL",
                MMMd: "d. MMM",
                MMMEd: "E, d. MMM",
                MMMMd: "d. MMMM",
                MMMMEd: "E, d. MMMM",
                "MMMMW-count-one": "'viku' W 'í' MMMM",
                "MMMMW-count-other": "'viku' W 'í' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M. y",
                yMd: "d.M.y",
                yMEd: "E, d.M.y",
                yMMM: "MMM y",
                yMMMd: "d. MMM y",
                yMMMEd: "E, d. MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "'viku' w 'af' Y",
                "yw-count-other": "'viku' w 'af' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d. MMMM y",
            long: "d. MMMM y",
            medium: "d. MMM y",
            short: "d.M.y"
        },
        days: {
            format: {
                abbreviated: [
                    "sun.",
                    "mán.",
                    "þri.",
                    "mið.",
                    "fim.",
                    "fös.",
                    "lau."
                ],
                narrow: [
                    "S",
                    "M",
                    "Þ",
                    "M",
                    "F",
                    "F",
                    "L"
                ],
                short: [
                    "su.",
                    "má.",
                    "þr.",
                    "mi.",
                    "fi.",
                    "fö.",
                    "la."
                ],
                wide: [
                    "sunnudagur",
                    "mánudagur",
                    "þriðjudagur",
                    "miðvikudagur",
                    "fimmtudagur",
                    "föstudagur",
                    "laugardagur"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "sun.",
                    "mán.",
                    "þri.",
                    "mið.",
                    "fim.",
                    "fös.",
                    "lau."
                ],
                narrow: [
                    "S",
                    "M",
                    "Þ",
                    "M",
                    "F",
                    "F",
                    "L"
                ],
                short: [
                    "su.",
                    "má.",
                    "þr.",
                    "mi.",
                    "fi.",
                    "fö.",
                    "la."
                ],
                wide: [
                    "sunnudagur",
                    "mánudagur",
                    "þriðjudagur",
                    "miðvikudagur",
                    "fimmtudagur",
                    "föstudagur",
                    "laugardagur"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "jan.",
                    "feb.",
                    "mar.",
                    "apr.",
                    "maí",
                    "jún.",
                    "júl.",
                    "ágú.",
                    "sep.",
                    "okt.",
                    "nóv.",
                    "des."
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "Á",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "janúar",
                    "febrúar",
                    "mars",
                    "apríl",
                    "maí",
                    "júní",
                    "júlí",
                    "ágúst",
                    "september",
                    "október",
                    "nóvember",
                    "desember"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "jan.",
                    "feb.",
                    "mar.",
                    "apr.",
                    "maí",
                    "jún.",
                    "júl.",
                    "ágú.",
                    "sep.",
                    "okt.",
                    "nóv.",
                    "des."
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "Á",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "janúar",
                    "febrúar",
                    "mars",
                    "apríl",
                    "maí",
                    "júní",
                    "júlí",
                    "ágúst",
                    "september",
                    "október",
                    "nóvember",
                    "desember"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "F1",
                    "F2",
                    "F3",
                    "F4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. fjórðungur",
                    "2. fjórðungur",
                    "3. fjórðungur",
                    "4. fjórðungur"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "F1",
                    "F2",
                    "F3",
                    "F4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. fjórðungur",
                    "2. fjórðungur",
                    "3. fjórðungur",
                    "4. fjórðungur"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "miðnætti",
                    am: "f.h.",
                    noon: "hádegi",
                    pm: "e.h.",
                    morning1: "að morgni",
                    afternoon1: "síðdegis",
                    evening1: "að kvöldi",
                    night1: "að nóttu"
                },
                narrow: {
                    midnight: "mn.",
                    am: "f.",
                    noon: "h.",
                    pm: "e.",
                    morning1: "mrg.",
                    afternoon1: "sd.",
                    evening1: "kv.",
                    night1: "n."
                },
                wide: {
                    midnight: "miðnætti",
                    am: "f.h.",
                    noon: "hádegi",
                    pm: "e.h.",
                    morning1: "að morgni",
                    afternoon1: "síðdegis",
                    evening1: "að kvöldi",
                    night1: "að nóttu"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "miðnætti",
                    am: "f.h.",
                    noon: "hádegi",
                    pm: "e.h.",
                    morning1: "morgunn",
                    afternoon1: "síðdegis",
                    evening1: "kvöld",
                    night1: "nótt"
                },
                narrow: {
                    midnight: "mn.",
                    am: "f.h.",
                    noon: "hd.",
                    pm: "e.h.",
                    morning1: "mrg.",
                    afternoon1: "sd.",
                    evening1: "kv.",
                    night1: "n."
                },
                wide: {
                    midnight: "miðnætti",
                    am: "f.h.",
                    noon: "hádegi",
                    pm: "e.h.",
                    morning1: "morgunn",
                    afternoon1: "eftir hádegi",
                    evening1: "kvöld",
                    night1: "nótt"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "fyrir Krist",
                    "1": "eftir Krist",
                    "0-alt-variant": "fyrir kristið tímatal",
                    "1-alt-variant": "kristið tímatal"
                },
                abbreviated: {
                    "0": "f.Kr.",
                    "1": "e.Kr.",
                    "0-alt-variant": "f.l.t.",
                    "1-alt-variant": "l.t."
                },
                narrow: {
                    "0": "f.k.",
                    "1": "e.k.",
                    "0-alt-variant": "f.v.t.",
                    "1-alt-variant": "v.t."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "tímabil",
                short: "tímabil",
                narrow: "tímabil"
            },
            year: {
                wide: "ár",
                short: "ár",
                narrow: "ár"
            },
            quarter: {
                wide: "ársfjórðungur",
                short: "ársfjórð.",
                narrow: "ársfj."
            },
            month: {
                wide: "mánuður",
                short: "mán.",
                narrow: "mán."
            },
            week: {
                wide: "vika",
                short: "vika",
                narrow: "v."
            },
            weekOfMonth: {
                wide: "vika í mánuði",
                short: "vika í mánuði",
                narrow: "vika í mánuði"
            },
            day: {
                wide: "dagur",
                short: "dagur",
                narrow: "dagur"
            },
            dayOfYear: {
                wide: "dagur í ári",
                short: "dagur í ári",
                narrow: "dagur í ári"
            },
            weekday: {
                wide: "vikudagur",
                short: "vikud.",
                narrow: "vikud."
            },
            weekdayOfMonth: {
                wide: "vikudagur í mánuði",
                short: "vikud. í mán.",
                narrow: "vikud. í mán."
            },
            dayperiod: {
                short: "f.h./e.h.",
                wide: "f.h./e.h.",
                narrow: "f.h./e.h."
            },
            hour: {
                wide: "klukkustund",
                short: "klst.",
                narrow: "klst."
            },
            minute: {
                wide: "mínúta",
                short: "mín.",
                narrow: "mín."
            },
            second: {
                wide: "sekúnda",
                short: "sek.",
                narrow: "sek."
            },
            zone: {
                wide: "tímabelti",
                short: "tímab.",
                narrow: "tímab."
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "millisekúnda"
            }
        }
    },
    firstDay: 1,
    weekendRange: {
        start: 6,
        end: 0
    },
    likelySubtags: {
        is: "is-Latn-IS"
    },
    currencyData: {
        ISK: {
            _rounding: "0",
            _digits: "0"
        }
    }
});

