/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "kde",
    likelySubtags: {
        kde: "kde-Latn-TZ"
    },
    identity: {
        language: "kde"
    },
    territory: "TZ",
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, d MMMM y",
            m: "MMM d",
            M: "MMMM d",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d MMMM y HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "M/d",
                MEd: "E, M/d",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, MMM d",
                MMMMd: "MMMM d",
                MMMMEd: "E, MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "y-MM-dd",
                yMEd: "E, M/d/y",
                yMMM: "MMM y",
                yMMMd: "y MMM d",
                yMMMEd: "E, MMM d, y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "dd/MM/y"
        },
        days: {
            format: {
                abbreviated: [
                    "Ll2",
                    "Ll3",
                    "Ll4",
                    "Ll5",
                    "Ll6",
                    "Ll7",
                    "Ll1"
                ],
                narrow: [
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "1"
                ],
                short: [
                    "Ll2",
                    "Ll3",
                    "Ll4",
                    "Ll5",
                    "Ll6",
                    "Ll7",
                    "Ll1"
                ],
                wide: [
                    "Liduva lyapili",
                    "Liduva lyatatu",
                    "Liduva lyanchechi",
                    "Liduva lyannyano",
                    "Liduva lyannyano na linji",
                    "Liduva lyannyano na mavili",
                    "Liduva litandi"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Ll2",
                    "Ll3",
                    "Ll4",
                    "Ll5",
                    "Ll6",
                    "Ll7",
                    "Ll1"
                ],
                narrow: [
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "1"
                ],
                short: [
                    "Ll2",
                    "Ll3",
                    "Ll4",
                    "Ll5",
                    "Ll6",
                    "Ll7",
                    "Ll1"
                ],
                wide: [
                    "Liduva lyapili",
                    "Liduva lyatatu",
                    "Liduva lyanchechi",
                    "Liduva lyannyano",
                    "Liduva lyannyano na linji",
                    "Liduva lyannyano na mavili",
                    "Liduva litandi"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Jan",
                    "Feb",
                    "Mac",
                    "Apr",
                    "Mei",
                    "Jun",
                    "Jul",
                    "Ago",
                    "Sep",
                    "Okt",
                    "Nov",
                    "Des"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Mwedi Ntandi",
                    "Mwedi wa Pili",
                    "Mwedi wa Tatu",
                    "Mwedi wa Nchechi",
                    "Mwedi wa Nnyano",
                    "Mwedi wa Nnyano na Umo",
                    "Mwedi wa Nnyano na Mivili",
                    "Mwedi wa Nnyano na Mitatu",
                    "Mwedi wa Nnyano na Nchechi",
                    "Mwedi wa Nnyano na Nnyano",
                    "Mwedi wa Nnyano na Nnyano na U",
                    "Mwedi wa Nnyano na Nnyano na M"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Jan",
                    "Feb",
                    "Mac",
                    "Apr",
                    "Mei",
                    "Jun",
                    "Jul",
                    "Ago",
                    "Sep",
                    "Okt",
                    "Nov",
                    "Des"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Mwedi Ntandi",
                    "Mwedi wa Pili",
                    "Mwedi wa Tatu",
                    "Mwedi wa Nchechi",
                    "Mwedi wa Nnyano",
                    "Mwedi wa Nnyano na Umo",
                    "Mwedi wa Nnyano na Mivili",
                    "Mwedi wa Nnyano na Mitatu",
                    "Mwedi wa Nnyano na Nchechi",
                    "Mwedi wa Nnyano na Nnyano",
                    "Mwedi wa Nnyano na Nnyano na U",
                    "Mwedi wa Nnyano na Nnyano na M"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "L1",
                    "L2",
                    "L3",
                    "L4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Lobo 1",
                    "Lobo 2",
                    "Lobo 3",
                    "Lobo 4"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "L1",
                    "L2",
                    "L3",
                    "L4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Lobo 1",
                    "Lobo 2",
                    "Lobo 3",
                    "Lobo 4"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "Muhi",
                    pm: "Chilo"
                },
                narrow: {
                    am: "Muhi",
                    pm: "Chilo"
                },
                wide: {
                    am: "Muhi",
                    pm: "Chilo"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "Muhi",
                    pm: "Chilo"
                },
                narrow: {
                    am: "Muhi",
                    pm: "Chilo"
                },
                wide: {
                    am: "Muhi",
                    pm: "Chilo"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Akanapawa Yesu",
                    "1": "Nankuida Yesu",
                    "0-alt-variant": "AY",
                    "1-alt-variant": "NY"
                },
                abbreviated: {
                    "0": "AY",
                    "1": "NY",
                    "0-alt-variant": "AY",
                    "1-alt-variant": "NY"
                },
                narrow: {
                    "0": "AY",
                    "1": "NY",
                    "0-alt-variant": "AY",
                    "1-alt-variant": "NY"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Mahiku",
                short: "Mahiku",
                narrow: "Mahiku"
            },
            year: {
                wide: "Mwaka",
                short: "Mwaka",
                narrow: "Mwaka"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Mwedi",
                short: "Mwedi",
                narrow: "Mwedi"
            },
            week: {
                wide: "Lijuma",
                short: "Lijuma",
                narrow: "Lijuma"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Lihiku",
                short: "Lihiku",
                narrow: "Lihiku"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Disiku dya lijuma",
                short: "Disiku dya lijuma",
                narrow: "Disiku dya lijuma"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Muhi/Chilo",
                wide: "Muhi/Chilo",
                narrow: "Muhi/Chilo"
            },
            hour: {
                wide: "Saa",
                short: "Saa",
                narrow: "Saa"
            },
            minute: {
                wide: "Dakika",
                short: "Dakika",
                narrow: "Dakika"
            },
            second: {
                wide: "Sekunde",
                short: "Sekunde",
                narrow: "Sekunde"
            },
            zone: {
                wide: "Npanda wa muda",
                short: "Npanda wa muda",
                narrow: "Npanda wa muda"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

