/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "kk",
    likelySubtags: {
        kk: "kk-Cyrl-KZ"
    },
    identity: {
        language: "kk"
    },
    territory: "KZ",
    calendar: {
        patterns: {
            d: "dd.MM.y",
            D: "y 'ж'. d MMMM, EEEE",
            m: "d MMM",
            M: "d MMMM",
            y: "y 'ж'. MMM",
            Y: "y 'ж'. MMMM",
            F: "y 'ж'. d MMMM, EEEE HH:mm:ss",
            g: "dd.MM.y HH:mm",
            G: "dd.MM.y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1}, {0}",
            long: "{1}, {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "B h",
                Bhm: "B h:mm",
                Bhms: "B h:mm:ss",
                d: "d",
                E: "ccc",
                EBhm: "E, B h:mm",
                EBhms: "E, B h:mm:ss",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y 'ж'.",
                GyMd: "dd-MM-GGGGG y",
                GyMMM: "G y 'ж'. MMM",
                GyMMMd: "G y 'ж'. d MMM",
                GyMMMEd: "G y 'ж'. d MMM, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "dd.MM",
                MEd: "dd.MM, E",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "d MMM, E",
                MMMMd: "d MMMM",
                "MMMMW-count-one": "MMMM 'айының' W-'аптасы'",
                "MMMMW-count-other": "MMMM 'айының' W-'аптасы'",
                ms: "mm:ss",
                y: "y",
                yM: "MM.y",
                yMd: "dd.MM.y",
                yMEd: "dd.MM.y, E",
                yMMM: "y 'ж'. MMM",
                yMMMd: "y 'ж'. d MMM",
                yMMMEd: "y 'ж'. d MMM, E",
                yMMMM: "y 'ж'. MMMM",
                yQQQ: "y 'ж'. QQQ",
                yQQQQ: "y 'ж'. QQQQ",
                "yw-count-one": "Y 'жылдың' w-'аптасы'",
                "yw-count-other": "Y 'жылдың' w-'аптасы'"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "y 'ж'. d MMMM, EEEE",
            long: "y 'ж'. d MMMM",
            medium: "y 'ж'. dd MMM",
            short: "dd.MM.yy"
        },
        days: {
            format: {
                abbreviated: [
                    "жс",
                    "дс",
                    "сс",
                    "ср",
                    "бс",
                    "жм",
                    "сб"
                ],
                narrow: [
                    "Ж",
                    "Д",
                    "С",
                    "С",
                    "Б",
                    "Ж",
                    "С"
                ],
                short: [
                    "жс",
                    "дс",
                    "сс",
                    "ср",
                    "бс",
                    "жм",
                    "сб"
                ],
                wide: [
                    "жексенбі",
                    "дүйсенбі",
                    "сейсенбі",
                    "сәрсенбі",
                    "бейсенбі",
                    "жұма",
                    "сенбі"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "жс",
                    "дс",
                    "сс",
                    "ср",
                    "бс",
                    "жм",
                    "сб"
                ],
                narrow: [
                    "Ж",
                    "Д",
                    "С",
                    "С",
                    "Б",
                    "Ж",
                    "С"
                ],
                short: [
                    "жс",
                    "дс",
                    "сс",
                    "ср",
                    "бс",
                    "жм",
                    "сб"
                ],
                wide: [
                    "жексенбі",
                    "дүйсенбі",
                    "сейсенбі",
                    "сәрсенбі",
                    "бейсенбі",
                    "жұма",
                    "сенбі"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "қаң.",
                    "ақп.",
                    "нау.",
                    "сәу.",
                    "мам.",
                    "мау.",
                    "шіл.",
                    "там.",
                    "қыр.",
                    "қаз.",
                    "қар.",
                    "жел."
                ],
                narrow: [
                    "Қ",
                    "А",
                    "Н",
                    "С",
                    "М",
                    "М",
                    "Ш",
                    "Т",
                    "Қ",
                    "Қ",
                    "Қ",
                    "Ж"
                ],
                wide: [
                    "қаңтар",
                    "ақпан",
                    "наурыз",
                    "сәуір",
                    "мамыр",
                    "маусым",
                    "шілде",
                    "тамыз",
                    "қыркүйек",
                    "қазан",
                    "қараша",
                    "желтоқсан"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "қаң.",
                    "ақп.",
                    "нау.",
                    "сәу.",
                    "мам.",
                    "мау.",
                    "шіл.",
                    "там.",
                    "қыр.",
                    "қаз.",
                    "қар.",
                    "жел."
                ],
                narrow: [
                    "Қ",
                    "А",
                    "Н",
                    "С",
                    "М",
                    "М",
                    "Ш",
                    "Т",
                    "Қ",
                    "Қ",
                    "Қ",
                    "Ж"
                ],
                wide: [
                    "Қаңтар",
                    "Ақпан",
                    "Наурыз",
                    "Сәуір",
                    "Мамыр",
                    "Маусым",
                    "Шілде",
                    "Тамыз",
                    "Қыркүйек",
                    "Қазан",
                    "Қараша",
                    "Желтоқсан"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "І тқс.",
                    "ІІ тқс.",
                    "ІІІ тқс.",
                    "IV тқс."
                ],
                narrow: [
                    "I",
                    "II",
                    "III",
                    "IV"
                ],
                wide: [
                    "І тоқсан",
                    "ІІ тоқсан",
                    "ІІІ тоқсан",
                    "IV тоқсан"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "І тқс.",
                    "ІІ тқс.",
                    "ІІІ тқс.",
                    "IV тқс."
                ],
                narrow: [
                    "I",
                    "II",
                    "III",
                    "IV"
                ],
                wide: [
                    "І тоқсан",
                    "ІІ тоқсан",
                    "ІІІ тоқсан",
                    "IV тоқсан"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "түн жарымы",
                    am: "AM",
                    noon: "түскі",
                    pm: "PM",
                    morning1: "таңғы",
                    afternoon1: "түстен кейінгі",
                    evening1: "кешкі",
                    night1: "түнгі"
                },
                narrow: {
                    midnight: "түнгі",
                    am: "AM",
                    noon: "түскі",
                    pm: "PM",
                    morning1: "таңғы",
                    afternoon1: "түстен кейінгі",
                    evening1: "кешкі",
                    night1: "түнгі"
                },
                wide: {
                    midnight: "түн жарымы",
                    am: "AM",
                    noon: "түскі",
                    pm: "PM",
                    morning1: "таңғы",
                    afternoon1: "түстен кейінгі",
                    evening1: "кешкі",
                    night1: "түнгі"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "түн жарымы",
                    am: "AM",
                    noon: "талтүс",
                    pm: "PM",
                    morning1: "таң",
                    afternoon1: "түстен кейін",
                    evening1: "кеш",
                    night1: "түн"
                },
                narrow: {
                    midnight: "түн жарымы",
                    am: "AM",
                    noon: "талтүс",
                    pm: "PM",
                    morning1: "таң",
                    afternoon1: "түстен кейін",
                    evening1: "кеш",
                    night1: "түн"
                },
                wide: {
                    midnight: "түн жарымы",
                    am: "AM",
                    noon: "талтүс",
                    pm: "PM",
                    morning1: "таң",
                    afternoon1: "түстен кейін",
                    evening1: "кеш",
                    night1: "түн"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Біздің заманымызға дейін",
                    "1": "біздің заманымыз",
                    "0-alt-variant": "біздің заманымызға дейін",
                    "1-alt-variant": "Біздің заманымыз"
                },
                abbreviated: {
                    "0": "б.з.д.",
                    "1": "б.з.",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                narrow: {
                    "0": "б.з.д.",
                    "1": "б.з.",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "дәуір",
                short: "дәуір",
                narrow: "дәуір"
            },
            year: {
                wide: "жыл",
                short: "ж.",
                narrow: "ж."
            },
            quarter: {
                wide: "ширек",
                short: "ш.",
                narrow: "ш."
            },
            month: {
                wide: "ай",
                short: "ай",
                narrow: "ай"
            },
            week: {
                wide: "апта",
                short: "ап.",
                narrow: "ап."
            },
            weekOfMonth: {
                wide: "айдағы апта",
                short: "айдағы апта",
                narrow: "айдағы апта"
            },
            day: {
                wide: "күн",
                short: "күн",
                narrow: "күн"
            },
            dayOfYear: {
                wide: "жылдағы күн",
                short: "жылдағы күн",
                narrow: "жылдағы күн"
            },
            weekday: {
                wide: "апта күні",
                short: "апта күні",
                narrow: "апта күні"
            },
            weekdayOfMonth: {
                wide: "айдағы апта күні",
                short: "айдағы ап. күні",
                narrow: "айдағы ап. күні"
            },
            dayperiod: {
                short: "АМ/РМ",
                wide: "АМ/РМ",
                narrow: "АМ/РМ"
            },
            hour: {
                wide: "сағат",
                short: "сағ",
                narrow: "сағ"
            },
            minute: {
                wide: "минут",
                short: "мин",
                narrow: "мин"
            },
            second: {
                wide: "секунд",
                short: "с",
                narrow: "с"
            },
            zone: {
                wide: "уақыт белдеуі",
                short: "уақ. белдеуі",
                narrow: "уақ. белдеуі"
            },
            millisecond: {
                narrow: "мс",
                short: "мс",
                wide: "миллисекунд"
            }
        }
    },
    firstDay: 1
});

