/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "kln",
    likelySubtags: {
        kln: "kln-Latn-KE"
    },
    identity: {
        language: "kln"
    },
    territory: "KE",
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, d MMMM y",
            m: "MMM d",
            M: "MMMM d",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d MMMM y HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "M/d",
                MEd: "E, M/d",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, MMM d",
                MMMMd: "MMMM d",
                MMMMEd: "E, MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "y-MM-dd",
                yMEd: "E, M/d/y",
                yMMM: "MMM y",
                yMMMd: "y MMM d",
                yMMMEd: "E, MMM d, y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "dd/MM/y"
        },
        days: {
            format: {
                abbreviated: [
                    "Kts",
                    "Kot",
                    "Koo",
                    "Kos",
                    "Koa",
                    "Kom",
                    "Kol"
                ],
                narrow: [
                    "T",
                    "T",
                    "O",
                    "S",
                    "A",
                    "M",
                    "L"
                ],
                short: [
                    "Kts",
                    "Kot",
                    "Koo",
                    "Kos",
                    "Koa",
                    "Kom",
                    "Kol"
                ],
                wide: [
                    "Kotisap",
                    "Kotaai",
                    "Koaeng’",
                    "Kosomok",
                    "Koang’wan",
                    "Komuut",
                    "Kolo"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Kts",
                    "Kot",
                    "Koo",
                    "Kos",
                    "Koa",
                    "Kom",
                    "Kol"
                ],
                narrow: [
                    "T",
                    "T",
                    "O",
                    "S",
                    "A",
                    "M",
                    "L"
                ],
                short: [
                    "Kts",
                    "Kot",
                    "Koo",
                    "Kos",
                    "Koa",
                    "Kom",
                    "Kol"
                ],
                wide: [
                    "Kotisap",
                    "Kotaai",
                    "Koaeng’",
                    "Kosomok",
                    "Koang’wan",
                    "Komuut",
                    "Kolo"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Mul",
                    "Ngat",
                    "Taa",
                    "Iwo",
                    "Mam",
                    "Paa",
                    "Nge",
                    "Roo",
                    "Bur",
                    "Epe",
                    "Kpt",
                    "Kpa"
                ],
                narrow: [
                    "M",
                    "N",
                    "T",
                    "I",
                    "M",
                    "P",
                    "N",
                    "R",
                    "B",
                    "E",
                    "K",
                    "K"
                ],
                wide: [
                    "Mulgul",
                    "Ng’atyaato",
                    "Kiptaamo",
                    "Iwootkuut",
                    "Mamuut",
                    "Paagi",
                    "Ng’eiyeet",
                    "Rooptui",
                    "Bureet",
                    "Epeeso",
                    "Kipsuunde ne taai",
                    "Kipsuunde nebo aeng’"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Mul",
                    "Ngat",
                    "Taa",
                    "Iwo",
                    "Mam",
                    "Paa",
                    "Nge",
                    "Roo",
                    "Bur",
                    "Epe",
                    "Kpt",
                    "Kpa"
                ],
                narrow: [
                    "M",
                    "N",
                    "T",
                    "I",
                    "M",
                    "P",
                    "N",
                    "R",
                    "B",
                    "E",
                    "K",
                    "K"
                ],
                wide: [
                    "Mulgul",
                    "Ng’atyaato",
                    "Kiptaamo",
                    "Iwootkuut",
                    "Mamuut",
                    "Paagi",
                    "Ng’eiyeet",
                    "Rooptui",
                    "Bureet",
                    "Epeeso",
                    "Kipsuunde ne taai",
                    "Kipsuunde nebo aeng’"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "R1",
                    "R2",
                    "R3",
                    "R4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Robo netai",
                    "Robo nebo aeng’",
                    "Robo nebo somok",
                    "Robo nebo ang’wan"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "R1",
                    "R2",
                    "R3",
                    "R4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Robo netai",
                    "Robo nebo aeng’",
                    "Robo nebo somok",
                    "Robo nebo ang’wan"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "krn",
                    pm: "koosk"
                },
                narrow: {
                    am: "krn",
                    pm: "koosk"
                },
                wide: {
                    am: "karoon",
                    pm: "kooskoliny"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "krn",
                    pm: "koosk"
                },
                narrow: {
                    am: "krn",
                    pm: "koosk"
                },
                wide: {
                    am: "krn",
                    pm: "koosk"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Amait kesich Jesu",
                    "1": "Kokakesich Jesu",
                    "0-alt-variant": "AM",
                    "1-alt-variant": "KO"
                },
                abbreviated: {
                    "0": "AM",
                    "1": "KO",
                    "0-alt-variant": "AM",
                    "1-alt-variant": "KO"
                },
                narrow: {
                    "0": "AM",
                    "1": "KO",
                    "0-alt-variant": "AM",
                    "1-alt-variant": "KO"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Ibinta",
                short: "Ibinta",
                narrow: "Ibinta"
            },
            year: {
                wide: "Kenyit",
                short: "Kenyit",
                narrow: "Kenyit"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Arawet",
                short: "Arawet",
                narrow: "Arawet"
            },
            week: {
                wide: "Wikit",
                short: "Wikit",
                narrow: "Wikit"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Betut",
                short: "Betut",
                narrow: "Betut"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Betutab wikit",
                short: "Betutab wikit",
                narrow: "Betutab wikit"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "BE/KE",
                wide: "BE/KE",
                narrow: "BE/KE"
            },
            hour: {
                wide: "Sait",
                short: "Sait",
                narrow: "Sait"
            },
            minute: {
                wide: "Minitit",
                short: "Minitit",
                narrow: "Minitit"
            },
            second: {
                wide: "Sekondit",
                short: "Sekondit",
                narrow: "Sekondit"
            },
            zone: {
                wide: "Saitab sonit",
                short: "Saitab sonit",
                narrow: "Saitab sonit"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

