/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "kok",
    likelySubtags: {
        kok: "kok-Deva-IN"
    },
    identity: {
        language: "kok"
    },
    territory: "IN",
    calendar: {
        patterns: {
            d: "d-M-y",
            D: "EEEE d MMMM y",
            m: "MMM d",
            M: "d MMMM",
            y: "y MMM",
            Y: "MMMM, y",
            F: "EEEE d MMMM y h:mm:ss a",
            g: "d-M-y h:mm a",
            G: "d-M-y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d-M",
                MEd: "d-M, E",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, d MMM",
                MMMMd: "d MMMM",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M-y",
                yMd: "d-M-y",
                yMEd: "d-M-y, E",
                yMMM: "y MMM",
                yMMMd: "y MMM d",
                yMMMEd: "y MMM d, E",
                yMMMM: "MMMM, y",
                yQQQ: "y QQQ",
                yQQQQ: "y QQQQ",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "EEEE d MMMM y",
            long: "d MMMM y",
            medium: "d-MMM-y",
            short: "d-M-yy"
        },
        days: {
            format: {
                abbreviated: [
                    "आयतार",
                    "सोमार",
                    "मंगळार",
                    "बुधवार",
                    "बिरेस्तार",
                    "शुक्रार",
                    "शेनवार"
                ],
                narrow: [
                    "आ",
                    "सो",
                    "मं",
                    "बु",
                    "बि",
                    "शु",
                    "शे"
                ],
                short: [
                    "आय",
                    "सोम",
                    "मंगळ",
                    "बुध",
                    "बिरे",
                    "शुक्र",
                    "शेन"
                ],
                wide: [
                    "आयतार",
                    "सोमार",
                    "मंगळार",
                    "बुधवार",
                    "बिरेस्तार",
                    "शुक्रार",
                    "शेनवार"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "आयतार",
                    "सोमार",
                    "मंगळार",
                    "बुधवार",
                    "बिरेस्तार",
                    "शुक्रार",
                    "शेनवार"
                ],
                narrow: [
                    "आ",
                    "सो",
                    "मं",
                    "बु",
                    "ब",
                    "शु",
                    "शे"
                ],
                short: [
                    "आय",
                    "सोम",
                    "मंगळ",
                    "बुध",
                    "बिरे",
                    "शुक्र",
                    "शेन"
                ],
                wide: [
                    "आयतार",
                    "सोमार",
                    "मंगळार",
                    "बुधवार",
                    "बिरेस्तार",
                    "शुक्रार",
                    "शेनवार"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "जानेवारी",
                    "फेब्रुवारी",
                    "मार्च",
                    "एप्रील",
                    "मे",
                    "जून",
                    "जुलय",
                    "ऑगस्ट",
                    "सप्टेंबर",
                    "ऑक्टोबर",
                    "नोव्हेंबर",
                    "डिसेंबर"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "जानेवारी",
                    "फेब्रुवारी",
                    "मार्च",
                    "एप्रील",
                    "मे",
                    "जून",
                    "जुलय",
                    "ऑगस्ट",
                    "सप्टेंबर",
                    "ऑक्टोबर",
                    "नोव्हेंबर",
                    "डिसेंबर"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "जाने",
                    "फेब्रु",
                    "मार्च",
                    "एप्री",
                    "मे",
                    "जून",
                    "जुल",
                    "ऑग",
                    "सप्टें",
                    "ऑक्टो",
                    "नो",
                    "डिसे"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "जानेवारी",
                    "फेब्रुवारी",
                    "मार्च",
                    "एप्रील",
                    "मे",
                    "जून",
                    "जुलय",
                    "ऑगस्ट",
                    "सप्टेंबर",
                    "ऑक्टोबर",
                    "नोव्हेंबर",
                    "डिसेंबर"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1लें त्रैमासीक",
                    "2रें त्रैमासीक",
                    "3रें त्रैमासीक",
                    "4थें त्रैमासीक"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1लें त्रैमासीक",
                    "2रें त्रैमासीक",
                    "3रें त्रैमासीक",
                    "4थें त्रैमासीक"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "a",
                    pm: "p"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "क्रिस्तपूर्व",
                    "1": "क्रिस्तशखा",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                abbreviated: {
                    "0": "क्रिस्तपूर्व",
                    "1": "क्रिस्तशखा",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                narrow: {
                    "0": "क्रिस्तपूर्व",
                    "1": "क्रिस्तशखा",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "शक",
                short: "शक",
                narrow: "शक"
            },
            year: {
                wide: "वर्स",
                short: "वर्स",
                narrow: "वर्स"
            },
            quarter: {
                wide: "त्रैमासीक",
                short: "त्रैमासीक",
                narrow: "त्रैमासीक"
            },
            month: {
                wide: "म्हयनो",
                short: "म्हयनो",
                narrow: "म्हयनो"
            },
            week: {
                wide: "सप्तक",
                short: "सप्तक",
                narrow: "सप्तक"
            },
            weekOfMonth: {
                wide: "म्हयन्यातलो सप्तक",
                short: "म्हयन्यातलो सप्तक",
                narrow: "म्हयन्यातलो सप्तक"
            },
            day: {
                wide: "दीस",
                short: "दीस",
                narrow: "दीस"
            },
            dayOfYear: {
                wide: "वर्साचो दीस",
                short: "वर्साचो दीस",
                narrow: "वर्साचो दीस"
            },
            weekday: {
                wide: "सप्तकाचो दीस",
                short: "सप्तकाचो दीस",
                narrow: "सप्तकाचो दीस"
            },
            weekdayOfMonth: {
                wide: "म्हयन्यातलो सप्तकीय दीस",
                short: "म्हयन्यातलो सप्तकीय दीस",
                narrow: "म्हयन्यातलो सप्तकीय दीस"
            },
            dayperiod: {
                short: "AM/PM",
                wide: "AM/PM",
                narrow: "AM/PM"
            },
            hour: {
                wide: "वर",
                short: "वर",
                narrow: "वर"
            },
            minute: {
                wide: "मिनीट",
                short: "मिनीट",
                narrow: "मिनीट"
            },
            second: {
                wide: "सेकंद",
                short: "सेकंद",
                narrow: "सेकंद"
            },
            zone: {
                wide: "वेळ झोन",
                short: "झोन",
                narrow: "झोन"
            },
            millisecond: {
                narrow: "मिसे",
                short: "मिलिसेकंद",
                wide: "मिलिसेकंदांनी"
            }
        }
    },
    firstDay: 0
});

