/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ks-Arab",
    likelySubtags: {
        ks: "ks-Arab-IN"
    },
    identity: {
        language: "ks",
        script: "Arab"
    },
    territory: "IN",
    calendar: {
        patterns: {
            d: "M/d/y",
            D: "EEEE, MMMM d, y",
            m: "MMM d",
            M: "MMMM d",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, MMMM d, y h:mm:ss a",
            g: "M/d/y h:mm a",
            G: "M/d/y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{0} پٮ۪ٹھۍ {1}",
            long: "{0} پٮ۪ٹھۍ {1}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "M/d/y GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "MMM d, y G",
                GyMMMEd: "E, MMM d, y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "M/d",
                MEd: "E, M/d",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, MMM d",
                MMMMd: "MMMM d",
                MMMMEd: "E, MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "M/d/y",
                yMEd: "E, M/d/y",
                yMMM: "MMM y",
                yMMMd: "MMM d, y",
                yMMMEd: "E, MMM d, y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "EEEE, MMMM d, y",
            long: "MMMM d, y",
            medium: "MMM d, y",
            short: "M/d/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "آتھوار",
                    "ژٔندٕروار",
                    "بۆموار",
                    "بودوار",
                    "برؠسوار",
                    "جُمہ",
                    "بٹوار"
                ],
                narrow: [
                    "ا",
                    "ژ",
                    "ب",
                    "ب",
                    "ب",
                    "ج",
                    "ب"
                ],
                short: [
                    "آتھوار",
                    "ژٔندٕروار",
                    "بۆموار",
                    "بودوار",
                    "برؠسوار",
                    "جُمہ",
                    "بٹوار"
                ],
                wide: [
                    "اَتھوار",
                    "ژٔندرٕروار",
                    "بۆموار",
                    "بودوار",
                    "برؠسوار",
                    "جُمہ",
                    "بٹوار"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "آتھوار",
                    "ژٔندٕروار",
                    "بۆموار",
                    "بودوار",
                    "برؠسوار",
                    "جُمہ",
                    "بٹوار"
                ],
                narrow: [
                    "ا",
                    "ژ",
                    "ب",
                    "ب",
                    "ب",
                    "ج",
                    "ب"
                ],
                short: [
                    "آتھوار",
                    "ژٔندٕروار",
                    "بۆموار",
                    "بودوار",
                    "برؠسوار",
                    "جُمہ",
                    "بٹوار"
                ],
                wide: [
                    "اَتھوار",
                    "ژٔندرٕروار",
                    "بۆموار",
                    "بودوار",
                    "برؠسوار",
                    "جُمہ",
                    "بٹوار"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "جنؤری",
                    "فرؤری",
                    "مارٕچ",
                    "اپریل",
                    "مئی",
                    "جوٗن",
                    "جوٗلایی",
                    "اگست",
                    "ستمبر",
                    "اکتوٗبر",
                    "نومبر",
                    "دسمبر"
                ],
                narrow: [
                    "ج",
                    "ف",
                    "م",
                    "ا",
                    "م",
                    "ج",
                    "ج",
                    "ا",
                    "س",
                    "س",
                    "ا",
                    "ن"
                ],
                wide: [
                    "جنؤری",
                    "فرؤری",
                    "مارٕچ",
                    "اپریل",
                    "مئی",
                    "جوٗن",
                    "جوٗلایی",
                    "اگست",
                    "ستمبر",
                    "اکتوٗبر",
                    "نومبر",
                    "دسمبر"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "جنؤری",
                    "فرؤری",
                    "مارٕچ",
                    "اپریل",
                    "مئی",
                    "جوٗن",
                    "جوٗلایی",
                    "اگست",
                    "ستمبر",
                    "اکتوٗبر",
                    "نومبر",
                    "دسمبر"
                ],
                narrow: [
                    "ج",
                    "ف",
                    "م",
                    "ا",
                    "م",
                    "ج",
                    "ج",
                    "ا",
                    "س",
                    "س",
                    "ا",
                    "ن"
                ],
                wide: [
                    "جنؤری",
                    "فرؤری",
                    "مارٕچ",
                    "اپریل",
                    "مئی",
                    "جوٗن",
                    "جوٗلایی",
                    "اگست",
                    "ستمبر",
                    "اکتوٗبر",
                    "نومبر",
                    "دسمبر"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "کیو 1",
                    "کیو 2",
                    "کیو 3",
                    "کیو 4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "گۄڑنیُک ژۄباگ",
                    "دۆیِم ژۄباگ",
                    "تریِم ژۄباگ",
                    "ژوٗرِم ژۄباگ"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "کیو 1",
                    "کیو 2",
                    "کیو 3",
                    "کیو 4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "گۄڑنیُک ژۄباگ",
                    "دۆیِم ژۄباگ",
                    "تریِم ژۄباگ",
                    "ژوٗرِم ژۄباگ"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "قبٕل مسیٖح",
                    "1": "عیٖسوی سنہٕ",
                    "0-alt-variant": "بی سی ای",
                    "1-alt-variant": "سی ای"
                },
                abbreviated: {
                    "0": "بی سی",
                    "1": "اے ڈی",
                    "0-alt-variant": "بی سی ای",
                    "1-alt-variant": "سی ای"
                },
                narrow: {
                    "0": "بی سی",
                    "1": "اے ڈی",
                    "0-alt-variant": "بی سی ای",
                    "1-alt-variant": "سی ای"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "دور",
                short: "دور",
                narrow: "دور"
            },
            year: {
                wide: "ؤری",
                short: "ؤری",
                narrow: "ؤری"
            },
            quarter: {
                wide: "کوارٹر",
                short: "کوارٹر",
                narrow: "کوارٹر"
            },
            month: {
                wide: "رؠتھ",
                short: "رؠتھ",
                narrow: "رؠتھ"
            },
            week: {
                wide: "ہفتہٕ",
                short: "ہفتہٕ",
                narrow: "ہفتہٕ"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "دۄہ",
                short: "دۄہ",
                narrow: "دۄہ"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "ہفتُک دۄہ",
                short: "ہفتُک دۄہ",
                narrow: "ہفتُک دۄہ"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "صُبح/راتھ",
                wide: "صُبح/راتھ",
                narrow: "صُبح/راتھ"
            },
            hour: {
                wide: "گٲنٹہٕ",
                short: "گٲنٹہٕ",
                narrow: "گٲنٹہٕ"
            },
            minute: {
                wide: "مِنَٹ",
                short: "مِنَٹ",
                narrow: "مِنَٹ"
            },
            second: {
                wide: "سؠکَنڈ",
                short: "سؠکَنڈ",
                narrow: "سؠکَنڈ"
            },
            zone: {
                wide: "وَکھ زون",
                short: "وَکھ زون",
                narrow: "وَکھ زون"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

