/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ks-Deva",
    likelySubtags: {
        ks: "ks-Arab-IN"
    },
    identity: {
        language: "ks",
        script: "Deva"
    },
    territory: "IN",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE, d MMMM y",
            m: "MMM d",
            M: "MMMM d",
            y: "y MMM",
            Y: "y MMMM",
            F: "EEEE, d MMMM y a h:mm:ss",
            g: "y-MM-dd a h:mm",
            G: "y-MM-dd a h:mm:ss",
            t: "a h:mm",
            T: "a h:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{0} पेठ {1}",
            long: "{0} पेठ {1}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "MM-dd",
                MEd: "MM-dd, E",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "MMM d, E",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "y-MM",
                yMd: "y-MM-dd",
                yMEd: "y-MM-dd, E",
                yMMM: "y MMM",
                yMMMd: "y MMM d",
                yMMMEd: "y MMM d, E",
                yMMMM: "y MMMM",
                yQQQ: "y QQQ",
                yQQQQ: "y QQQQ",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "a h:mm:ss zzzz",
            long: "a h:mm:ss z",
            medium: "a h:mm:ss",
            short: "a h:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "d/M/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "आथवार",
                    "चंदिरवार",
                    "बुवार",
                    "बोदवार",
                    "ब्रेसवार",
                    "जुम्मा",
                    "बटवार"
                ],
                narrow: [
                    "अ",
                    "च",
                    "ब",
                    "ब",
                    "ब",
                    "ज",
                    "ब"
                ],
                short: [
                    "आथवार",
                    "चंदिरवार",
                    "बुवार",
                    "बोदवार",
                    "ब्रेसवार",
                    "जुम्मा",
                    "बटवार"
                ],
                wide: [
                    "आथवार",
                    "चंदिरवार",
                    "बुवार",
                    "बोदवार",
                    "ब्रेसवार",
                    "जुम्मा",
                    "बटवार"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "आथवार",
                    "चंदिरवार",
                    "बुवार",
                    "बोदवार",
                    "ब्रेसवार",
                    "जुम्मा",
                    "बटवार"
                ],
                narrow: [
                    "अ",
                    "च",
                    "ब",
                    "ब",
                    "ब",
                    "ज",
                    "ब"
                ],
                short: [
                    "आथवार",
                    "चंदिरवार",
                    "बुवार",
                    "बोदवार",
                    "ब्रेसवार",
                    "जुम्मा",
                    "बटवार"
                ],
                wide: [
                    "आथवार",
                    "चंदिरवार",
                    "बुवार",
                    "बोदवार",
                    "ब्रेसवार",
                    "जुम्मा",
                    "बटवार"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "जनवरी",
                    "फ़रवरी",
                    "मार्च",
                    "अप्रैल",
                    "मे",
                    "जून",
                    "जुलाई",
                    "अगस्त",
                    "सतुंबर",
                    "अकतुम्बर",
                    "नवूमबर",
                    "दसूमबर"
                ],
                narrow: [
                    "ज",
                    "फ़",
                    "म",
                    "अ",
                    "म",
                    "ज",
                    "ज",
                    "अ",
                    "स",
                    "ओ",
                    "न",
                    "द"
                ],
                wide: [
                    "जनवरी",
                    "फ़रवरी",
                    "मार्च",
                    "अप्रैल",
                    "मे",
                    "जून",
                    "जुलाई",
                    "अगस्त",
                    "सतुंबर",
                    "अकतुम्बर",
                    "नवूमबर",
                    "दसूमबर"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "जनवरी",
                    "फ़रवरी",
                    "मार्च",
                    "अप्रैल",
                    "मे",
                    "जून",
                    "जुलाई",
                    "अगस्त",
                    "सतुंबर",
                    "अकतुम्बर",
                    "नवूमबर",
                    "दसूमबर"
                ],
                narrow: [
                    "ज",
                    "फ़",
                    "म",
                    "अ",
                    "म",
                    "ज",
                    "ज",
                    "अ",
                    "स",
                    "ओ",
                    "न",
                    "द"
                ],
                wide: [
                    "जनवरी",
                    "फ़रवरी",
                    "मार्च",
                    "अप्रैल",
                    "मे",
                    "जून",
                    "जुलाई",
                    "अगस्त",
                    "सतुंबर",
                    "अकतुम्बर",
                    "नवूमबर",
                    "दसूमबर"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1st सह माह",
                    "2nd सह माह",
                    "3rd सह माह",
                    "4th सह माह"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1st सह माह",
                    "2nd सह माह",
                    "3rd सह माह",
                    "4th सह माह"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "BC",
                    "1": "AD",
                    "0-alt-variant": "BC",
                    "1-alt-variant": "AD"
                },
                abbreviated: {
                    "0": "BC",
                    "1": "AD",
                    "0-alt-variant": "BC",
                    "1-alt-variant": "AD"
                },
                narrow: {
                    "0": "BC",
                    "1": "AD",
                    "0-alt-variant": "BC",
                    "1-alt-variant": "AD"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "दोर",
                short: "दोर",
                narrow: "दोर"
            },
            year: {
                wide: "वरीह",
                short: "वरीह",
                narrow: "वरीह"
            },
            quarter: {
                wide: "चूरिम",
                short: "चूरिम",
                narrow: "चूरिम"
            },
            month: {
                wide: "माह",
                short: "माह",
                narrow: "माह"
            },
            week: {
                wide: "हफ़ति",
                short: "हफ़ति",
                narrow: "हफ़ति"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "दोह",
                short: "दोह",
                narrow: "दोह"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "हफ़तूक दोह",
                short: "हफ़तूक दोह",
                narrow: "हफ़तूक दोह"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "AM/PM",
                wide: "AM/PM",
                narrow: "AM/PM"
            },
            hour: {
                wide: "गनटि",
                short: "गनटि",
                narrow: "गनटि"
            },
            minute: {
                wide: "मिनट",
                short: "मिनट",
                narrow: "मिनट"
            },
            second: {
                wide: "सेकंड",
                short: "सेकंड",
                narrow: "सेकंड"
            },
            zone: {
                wide: "वख ज़ून",
                short: "वख ज़ून",
                narrow: "वख ज़ून"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

