/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ksb",
    likelySubtags: {
        ksb: "ksb-Latn-TZ"
    },
    identity: {
        language: "ksb"
    },
    territory: "TZ",
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, d MMMM y",
            m: "MMM d",
            M: "MMMM d",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d MMMM y HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "M/d",
                MEd: "E, M/d",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, MMM d",
                MMMMd: "MMMM d",
                MMMMEd: "E, MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "y-MM-dd",
                yMEd: "E, M/d/y",
                yMMM: "MMM y",
                yMMMd: "y MMM d",
                yMMMEd: "E, MMM d, y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "dd/MM/y"
        },
        days: {
            format: {
                abbreviated: [
                    "Jpi",
                    "Jtt",
                    "Jmn",
                    "Jtn",
                    "Alh",
                    "Iju",
                    "Jmo"
                ],
                narrow: [
                    "2",
                    "3",
                    "4",
                    "5",
                    "A",
                    "I",
                    "1"
                ],
                short: [
                    "Jpi",
                    "Jtt",
                    "Jmn",
                    "Jtn",
                    "Alh",
                    "Iju",
                    "Jmo"
                ],
                wide: [
                    "Jumaapii",
                    "Jumaatatu",
                    "Jumaane",
                    "Jumaatano",
                    "Alhamisi",
                    "Ijumaa",
                    "Jumaamosi"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Jpi",
                    "Jtt",
                    "Jmn",
                    "Jtn",
                    "Alh",
                    "Iju",
                    "Jmo"
                ],
                narrow: [
                    "2",
                    "3",
                    "4",
                    "5",
                    "A",
                    "I",
                    "1"
                ],
                short: [
                    "Jpi",
                    "Jtt",
                    "Jmn",
                    "Jtn",
                    "Alh",
                    "Iju",
                    "Jmo"
                ],
                wide: [
                    "Jumaapii",
                    "Jumaatatu",
                    "Jumaane",
                    "Jumaatano",
                    "Alhamisi",
                    "Ijumaa",
                    "Jumaamosi"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Jan",
                    "Feb",
                    "Mac",
                    "Apr",
                    "Mei",
                    "Jun",
                    "Jul",
                    "Ago",
                    "Sep",
                    "Okt",
                    "Nov",
                    "Des"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Januali",
                    "Febluali",
                    "Machi",
                    "Aplili",
                    "Mei",
                    "Juni",
                    "Julai",
                    "Agosti",
                    "Septemba",
                    "Oktoba",
                    "Novemba",
                    "Desemba"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Jan",
                    "Feb",
                    "Mac",
                    "Apr",
                    "Mei",
                    "Jun",
                    "Jul",
                    "Ago",
                    "Sep",
                    "Okt",
                    "Nov",
                    "Des"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Januali",
                    "Febluali",
                    "Machi",
                    "Aplili",
                    "Mei",
                    "Juni",
                    "Julai",
                    "Agosti",
                    "Septemba",
                    "Oktoba",
                    "Novemba",
                    "Desemba"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "L1",
                    "L2",
                    "L3",
                    "L4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Lobo ya bosi",
                    "Lobo ya mbii",
                    "Lobo ya nnd’atu",
                    "Lobo ya nne"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "L1",
                    "L2",
                    "L3",
                    "L4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Lobo ya bosi",
                    "Lobo ya mbii",
                    "Lobo ya nnd’atu",
                    "Lobo ya nne"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "makeo",
                    pm: "nyiaghuo"
                },
                narrow: {
                    am: "makeo",
                    pm: "nyiaghuo"
                },
                wide: {
                    am: "makeo",
                    pm: "nyiaghuo"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "makeo",
                    pm: "nyiaghuo"
                },
                narrow: {
                    am: "makeo",
                    pm: "nyiaghuo"
                },
                wide: {
                    am: "makeo",
                    pm: "nyiaghuo"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Kabla ya Klisto",
                    "1": "Baada ya Klisto",
                    "0-alt-variant": "KK",
                    "1-alt-variant": "BK"
                },
                abbreviated: {
                    "0": "KK",
                    "1": "BK",
                    "0-alt-variant": "KK",
                    "1-alt-variant": "BK"
                },
                narrow: {
                    "0": "KK",
                    "1": "BK",
                    "0-alt-variant": "KK",
                    "1-alt-variant": "BK"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Mishi",
                short: "Mishi",
                narrow: "Mishi"
            },
            year: {
                wide: "Ng’waka",
                short: "Ng’waka",
                narrow: "Ng’waka"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Ng’ezi",
                short: "Ng’ezi",
                narrow: "Ng’ezi"
            },
            week: {
                wide: "Niki",
                short: "Niki",
                narrow: "Niki"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Siku",
                short: "Siku",
                narrow: "Siku"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Mwesiku za wiki",
                short: "Mwesiku za wiki",
                narrow: "Mwesiku za wiki"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Namshii",
                wide: "Namshii",
                narrow: "Namshii"
            },
            hour: {
                wide: "Saa",
                short: "Saa",
                narrow: "Saa"
            },
            minute: {
                wide: "Dakika",
                short: "Dakika",
                narrow: "Dakika"
            },
            second: {
                wide: "Sekunde",
                short: "Sekunde",
                narrow: "Sekunde"
            },
            zone: {
                wide: "Majila",
                short: "Majila",
                narrow: "Majila"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

