/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ksf",
    likelySubtags: {
        ksf: "ksf-Latn-CM"
    },
    identity: {
        language: "ksf"
    },
    territory: "CM",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE d MMMM y",
            m: "d MMM",
            M: "MMMM d",
            y: "MMM y",
            Y: "y MMMM",
            F: "EEEE d MMMM y HH:mm:ss",
            g: "d/M/y HH:mm",
            G: "d/M/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E d/M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E d MMM",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "m:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E d/M/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E d MMM y",
                yMMMM: "y MMMM",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "d/M/y"
        },
        days: {
            format: {
                abbreviated: [
                    "sɔ́n",
                    "lǝn",
                    "maa",
                    "mɛk",
                    "jǝǝ",
                    "júm",
                    "sam"
                ],
                narrow: [
                    "s",
                    "l",
                    "m",
                    "m",
                    "j",
                    "j",
                    "s"
                ],
                short: [
                    "sɔ́n",
                    "lǝn",
                    "maa",
                    "mɛk",
                    "jǝǝ",
                    "júm",
                    "sam"
                ],
                wide: [
                    "sɔ́ndǝ",
                    "lǝndí",
                    "maadí",
                    "mɛkrɛdí",
                    "jǝǝdí",
                    "júmbá",
                    "samdí"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "sɔ́n",
                    "lǝn",
                    "maa",
                    "mɛk",
                    "jǝǝ",
                    "júm",
                    "sam"
                ],
                narrow: [
                    "s",
                    "l",
                    "m",
                    "m",
                    "j",
                    "j",
                    "s"
                ],
                short: [
                    "sɔ́n",
                    "lǝn",
                    "maa",
                    "mɛk",
                    "jǝǝ",
                    "júm",
                    "sam"
                ],
                wide: [
                    "sɔ́ndǝ",
                    "lǝndí",
                    "maadí",
                    "mɛkrɛdí",
                    "jǝǝdí",
                    "júmbá",
                    "samdí"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "ŋ1",
                    "ŋ2",
                    "ŋ3",
                    "ŋ4",
                    "ŋ5",
                    "ŋ6",
                    "ŋ7",
                    "ŋ8",
                    "ŋ9",
                    "ŋ10",
                    "ŋ11",
                    "ŋ12"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "ŋwíí a ntɔ́ntɔ",
                    "ŋwíí akǝ bɛ́ɛ",
                    "ŋwíí akǝ ráá",
                    "ŋwíí akǝ nin",
                    "ŋwíí akǝ táan",
                    "ŋwíí akǝ táafɔk",
                    "ŋwíí akǝ táabɛɛ",
                    "ŋwíí akǝ táaraa",
                    "ŋwíí akǝ táanin",
                    "ŋwíí akǝ ntɛk",
                    "ŋwíí akǝ ntɛk di bɔ́k",
                    "ŋwíí akǝ ntɛk di bɛ́ɛ"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ŋ1",
                    "ŋ2",
                    "ŋ3",
                    "ŋ4",
                    "ŋ5",
                    "ŋ6",
                    "ŋ7",
                    "ŋ8",
                    "ŋ9",
                    "ŋ10",
                    "ŋ11",
                    "ŋ12"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "ŋwíí a ntɔ́ntɔ",
                    "ŋwíí akǝ bɛ́ɛ",
                    "ŋwíí akǝ ráá",
                    "ŋwíí akǝ nin",
                    "ŋwíí akǝ táan",
                    "ŋwíí akǝ táafɔk",
                    "ŋwíí akǝ táabɛɛ",
                    "ŋwíí akǝ táaraa",
                    "ŋwíí akǝ táanin",
                    "ŋwíí akǝ ntɛk",
                    "ŋwíí akǝ ntɛk di bɔ́k",
                    "ŋwíí akǝ ntɛk di bɛ́ɛ"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "i1",
                    "i2",
                    "i3",
                    "i4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "id́ɛ́n kǝbǝk kǝ ntɔ́ntɔ́",
                    "idɛ́n kǝbǝk kǝ kǝbɛ́ɛ",
                    "idɛ́n kǝbǝk kǝ kǝráá",
                    "idɛ́n kǝbǝk kǝ kǝnin"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "i1",
                    "i2",
                    "i3",
                    "i4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "id́ɛ́n kǝbǝk kǝ ntɔ́ntɔ́",
                    "idɛ́n kǝbǝk kǝ kǝbɛ́ɛ",
                    "idɛ́n kǝbǝk kǝ kǝráá",
                    "idɛ́n kǝbǝk kǝ kǝnin"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "sárúwá",
                    pm: "cɛɛ́nko"
                },
                narrow: {
                    am: "sárúwá",
                    pm: "cɛɛ́nko"
                },
                wide: {
                    am: "sárúwá",
                    pm: "cɛɛ́nko"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "sárúwá",
                    pm: "cɛɛ́nko"
                },
                narrow: {
                    am: "sárúwá",
                    pm: "cɛɛ́nko"
                },
                wide: {
                    am: "sárúwá",
                    pm: "cɛɛ́nko"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "di Yɛ́sus aká yálɛ",
                    "1": "cámɛɛn kǝ kǝbɔpka Y",
                    "0-alt-variant": "d.Y.",
                    "1-alt-variant": "k.Y."
                },
                abbreviated: {
                    "0": "d.Y.",
                    "1": "k.Y.",
                    "0-alt-variant": "d.Y.",
                    "1-alt-variant": "k.Y."
                },
                narrow: {
                    "0": "d.Y.",
                    "1": "k.Y.",
                    "0-alt-variant": "d.Y.",
                    "1-alt-variant": "k.Y."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Byámɛɛn",
                short: "Byámɛɛn",
                narrow: "Byámɛɛn"
            },
            year: {
                wide: "Bǝk",
                short: "Bǝk",
                narrow: "Bǝk"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Ŋwíí",
                short: "Ŋwíí",
                narrow: "Ŋwíí"
            },
            week: {
                wide: "Sɔ́ndǝ",
                short: "Sɔ́ndǝ",
                narrow: "Sɔ́ndǝ"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Ŋwós",
                short: "Ŋwós",
                narrow: "Ŋwós"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Mǝrú mǝ sɔ́ndǝ",
                short: "Mǝrú mǝ sɔ́ndǝ",
                narrow: "Mǝrú mǝ sɔ́ndǝ"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Sárúwá / Cɛɛ́nko",
                wide: "Sárúwá / Cɛɛ́nko",
                narrow: "Sárúwá / Cɛɛ́nko"
            },
            hour: {
                wide: "Cámɛɛn",
                short: "Cámɛɛn",
                narrow: "Cámɛɛn"
            },
            minute: {
                wide: "Mǝnít",
                short: "Mǝnít",
                narrow: "Mǝnít"
            },
            second: {
                wide: "Háu",
                short: "Háu",
                narrow: "Háu"
            },
            zone: {
                wide: "Wáas",
                short: "Wáas",
                narrow: "Wáas"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

