/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ksh",
    identity: {
        language: "ksh"
    },
    territory: "DE",
    numbers: {
        symbols: {
            decimal: ",",
            group: " ",
            list: ";",
            percentSign: "%",
            plusSign: "+",
            minusSign: "−",
            approximatelySign: "~",
            exponential: "×10^",
            superscriptingExponent: "×",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "n %"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-zero": "n $",
            "unitPattern-count-one": "n $",
            "unitPattern-count-other": "n $"
        },
        accounting: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "ADP",
                symbol: "ADP"
            },
            AED: {
                displayName: "de vereineschte arraabesche Emiraate ier Dirham",
                symbol: "AED"
            },
            AFA: {
                displayName: "AFA",
                symbol: "AFA"
            },
            AFN: {
                displayName: "Afjahni",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "ALK",
                symbol: "ALK"
            },
            ALL: {
                displayName: "albaanesche Lek",
                symbol: "ALL"
            },
            AMD: {
                displayName: "armeenesche Dram",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "neederlängsch antillesche Jullde",
                symbol: "ANG"
            },
            AOA: {
                displayName: "angjolaanesche Kwansa",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "AOK",
                symbol: "AOK"
            },
            AON: {
                displayName: "AON",
                symbol: "AON"
            },
            AOR: {
                displayName: "AOR",
                symbol: "AOR"
            },
            ARA: {
                displayName: "ARA",
                symbol: "ARA"
            },
            ARL: {
                displayName: "ARL",
                symbol: "ARL"
            },
            ARM: {
                displayName: "ARM",
                symbol: "ARM"
            },
            ARP: {
                displayName: "ARP",
                symbol: "ARP"
            },
            ARS: {
                displayName: "ajentiinesche Peeso",
                "displayName-count-zero": "ajentiinesche Peesos",
                "displayName-count-one": "ajentiinesche Peesos",
                "displayName-count-other": "ajentiinesche Peesos",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "ATS",
                symbol: "ATS"
            },
            AUD: {
                displayName: "austraalesche Dollaa",
                symbol: "A$",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "arubesche Florin",
                symbol: "AWG"
            },
            AZM: {
                displayName: "Asserbaidschaani Manat (1993–2006)",
                symbol: "AZM"
            },
            AZN: {
                displayName: "Asserbaidschaani Manat",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "BAD",
                symbol: "BAD"
            },
            BAM: {
                displayName: "ömtuuschbaa Mark us Boßnije un dä Hächejovvina",
                "displayName-count-zero": "öpmtuuschbaa Mark us Boßnije un dä Hächejovvina",
                "displayName-count-one": "öpmtuuschbaa Mark us Boßnije un dä Hächejovvina",
                "displayName-count-other": "öpmtuuschbaa Mark us Boßnije un dä Hächejovvina",
                symbol: "BAM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "BAN",
                symbol: "BAN"
            },
            BBD: {
                displayName: "Barbados-Dollaa",
                symbol: "BBD",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "Taka us Bangladäsch",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "BEC",
                symbol: "BEC"
            },
            BEF: {
                displayName: "BEF",
                symbol: "BEF"
            },
            BEL: {
                displayName: "BEL",
                symbol: "BEL"
            },
            BGL: {
                displayName: "BGL",
                symbol: "BGL"
            },
            BGM: {
                displayName: "BGM",
                symbol: "BGM"
            },
            BGN: {
                displayName: "buljaaresche Lev",
                symbol: "BGN"
            },
            BGO: {
                displayName: "BGO",
                symbol: "BGO"
            },
            BHD: {
                displayName: "Bachrainesche Denaa",
                symbol: "BHD"
            },
            BIF: {
                displayName: "burundesche Frang",
                symbol: "BIF"
            },
            BMD: {
                displayName: "Bermuuda-Dollaa",
                symbol: "BMD",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "Brunei-Dollaa",
                "displayName-count-zero": "Brunei-Dollaaa",
                "displayName-count-one": "Brunei-Dollaaa",
                "displayName-count-other": "Brunei-Dollaaa",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "Bollivijano",
                "displayName-count-zero": "Bollivijano",
                "displayName-count-one": "Bollivijano",
                "displayName-count-other": "Bollivijano",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "BOL",
                symbol: "BOL"
            },
            BOP: {
                displayName: "BOP",
                symbol: "BOP"
            },
            BOV: {
                displayName: "BOV",
                symbol: "BOV"
            },
            BRB: {
                displayName: "BRB",
                symbol: "BRB"
            },
            BRC: {
                displayName: "BRC",
                symbol: "BRC"
            },
            BRE: {
                displayName: "BRE",
                symbol: "BRE"
            },
            BRL: {
                displayName: "brasilljaanesche Real",
                symbol: "R$",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "BRN",
                symbol: "BRN"
            },
            BRR: {
                displayName: "BRR",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "BRZ",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "bahama’sche Dollaa",
                symbol: "BSD",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "bhutanesesche Ngultrum",
                "displayName-count-zero": "Bhutanesesche Ngultrum",
                "displayName-count-one": "Bhutanesesche Ngultrum",
                "displayName-count-other": "Bhutanesesche Ngultrum",
                symbol: "BTN"
            },
            BUK: {
                displayName: "BUK",
                symbol: "BUK"
            },
            BWP: {
                displayName: "Pula us Bozwaana",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "BYB",
                symbol: "BYB"
            },
            BYN: {
                displayName: "wiißrußesche Rubel",
                symbol: "BYN"
            },
            BYR: {
                displayName: "wiißrußesche Rubel (2000–2016)",
                symbol: "BYR"
            },
            BZD: {
                displayName: "belizjaanesche Dollaa",
                "displayName-count-zero": "Belizjaanesche Dollaa",
                "displayName-count-one": "Belizjaanesche Dollaa",
                "displayName-count-other": "Belizjaanesche Dollaa",
                symbol: "BZD",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "kannaadesche Dollaa",
                symbol: "CA$",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "kongjoleesesche Frang",
                symbol: "CDF"
            },
            CHE: {
                displayName: "CHE",
                symbol: "CHE"
            },
            CHF: {
                displayName: "schweijzer Fränkli",
                symbol: "CHF"
            },
            CHW: {
                displayName: "CHW",
                symbol: "CHW"
            },
            CLE: {
                displayName: "CLE",
                symbol: "CLE"
            },
            CLF: {
                displayName: "CLF",
                symbol: "CLF"
            },
            CLP: {
                displayName: "schileenesche Peeso",
                "displayName-count-zero": "schileenesche Peesos",
                "displayName-count-one": "schileenesche Peesos",
                "displayName-count-other": "schileenesche Peesos",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "CNH",
                symbol: "CNH"
            },
            CNX: {
                displayName: "CNX",
                symbol: "CNX"
            },
            CNY: {
                displayName: "schineesesche Yuan Renminbi",
                symbol: "CN¥",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "kolumbesche Peso",
                "displayName-count-zero": "kolumbesche Pesos",
                "displayName-count-one": "kolumbesche Pesos",
                "displayName-count-other": "kolumbesche Pesos",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "COU",
                symbol: "COU"
            },
            CRC: {
                displayName: "koßtarikaanesche Colón",
                "displayName-count-zero": "Kaßtarikaanesche Colón",
                "displayName-count-one": "Kaßtarikaanesche Colón",
                "displayName-count-other": "Kaßtarikaanesche Colón",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "CSD",
                symbol: "CSD"
            },
            CSK: {
                displayName: "CSK",
                symbol: "CSK"
            },
            CUC: {
                displayName: "ömtuuschbaa kubaanesche Pesos",
                "displayName-count-zero": "ömtuuschbaa kubaanesche Pesos",
                "displayName-count-one": "ömtuuschbaa kubaanesche Pesos",
                "displayName-count-other": "ömtuuschbaa kubaanesche Pesos",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "kubaanesche Peesos",
                "displayName-count-zero": "kubaanesche Peesos",
                "displayName-count-one": "kubaanesche Peesos",
                "displayName-count-other": "kubaanesche Peesos",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "kapverdesche Eskuudos",
                "displayName-count-zero": "kapverdesche Eskuudos",
                "displayName-count-one": "kapverdesche Eskuudos",
                "displayName-count-other": "kapverdesche Eskuudos",
                symbol: "CVE"
            },
            CYP: {
                displayName: "CYP",
                symbol: "CYP"
            },
            CZK: {
                displayName: "tschäschesche Kruhne",
                "displayName-count-zero": "tschäschesche Kruhne",
                "displayName-count-one": "tschäschesche Kruhne",
                "displayName-count-other": "tschäschesche Kruhne",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "DDM",
                symbol: "DDM"
            },
            DEM: {
                displayName: "DEM",
                symbol: "DEM"
            },
            DJF: {
                displayName: "Frang uß Dschibuti",
                symbol: "DJF"
            },
            DKK: {
                displayName: "dänesche Kruhne",
                "displayName-count-zero": "dänesche Kruhne",
                "displayName-count-one": "dänesche Kruhne",
                "displayName-count-other": "dänesche Kruhne",
                symbol: "DKK",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "dommenikaanesche Peesos",
                "displayName-count-zero": "dommenikaanesche Peesos",
                "displayName-count-one": "dommenikaanesche Peeso",
                "displayName-count-other": "dommenikaanesche Peesos",
                symbol: "DOP",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "aljeresche Denaa",
                symbol: "DZD"
            },
            ECS: {
                displayName: "ECS",
                symbol: "ECS"
            },
            ECV: {
                displayName: "ECV",
                symbol: "ECV"
            },
            EEK: {
                displayName: "Äßnesche Kruhne",
                symbol: "EEK"
            },
            EGP: {
                displayName: "äjiptesche Pongk",
                symbol: "EGP",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "Nafka uß Erritreja",
                symbol: "ERN"
            },
            ESA: {
                displayName: "ESA",
                symbol: "ESA"
            },
            ESB: {
                displayName: "ESB",
                symbol: "ESB"
            },
            ESP: {
                displayName: "ESP",
                symbol: "ESP",
                "symbol-alt-narrow": "₧"
            },
            ETB: {
                displayName: "ätejoopesche Birr",
                symbol: "ETB"
            },
            EUR: {
                displayName: "Euro",
                symbol: "€",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "FIM",
                symbol: "FIM"
            },
            FJD: {
                displayName: "Fidschi-Dollaa",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "Pongk vun de Falkland-Enselle",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "FRF",
                symbol: "FRF"
            },
            GBP: {
                displayName: "brittesche £",
                symbol: "£",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "GEK",
                symbol: "GEK"
            },
            GEL: {
                displayName: "jeorjesche Lari",
                "displayName-count-zero": "jeorjesche LAri",
                "displayName-count-one": "jeorjesche LAri",
                "displayName-count-other": "jeorjesche LAri",
                symbol: "GEL",
                "symbol-alt-narrow": "₾"
            },
            GHC: {
                displayName: "GHC",
                symbol: "GHC"
            },
            GHS: {
                displayName: "janaaesche Cedi",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "jibraltaa’sche Pongk",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "jambesche Dalasi",
                symbol: "GMD"
            },
            GNF: {
                displayName: "Jineea-Frang",
                "displayName-count-zero": "Jineea-Franke",
                "displayName-count-one": "Jineea-Franke",
                "displayName-count-other": "Jineea-Franke",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "GNS",
                symbol: "GNS"
            },
            GQE: {
                displayName: "GQE",
                symbol: "GQE"
            },
            GRD: {
                displayName: "GRD",
                symbol: "GRD"
            },
            GTQ: {
                displayName: "juatemalesche Quetzal",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "GWE",
                symbol: "GWE"
            },
            GWP: {
                displayName: "GWP",
                symbol: "GWP"
            },
            GYD: {
                displayName: "Juaana-Dollaa",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "Hongkong-Dollaa",
                symbol: "HK$",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "hondureanesche Lempira",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "HRD",
                symbol: "HRD"
            },
            HRK: {
                displayName: "krowaatesche Kuna",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "haiitesche Gourde",
                symbol: "HTG"
            },
            HUF: {
                displayName: "unjarresche Forint",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "indoneesesche Ruupije",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "IEP",
                symbol: "IEP"
            },
            ILP: {
                displayName: "ILP",
                symbol: "ILP"
            },
            ILR: {
                displayName: "ILR",
                symbol: "ILR"
            },
            ILS: {
                displayName: "ißraeelesche Schekel",
                symbol: "₪",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "indesche Ruupije",
                symbol: "₹",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "iraakesche Denaa",
                symbol: "IQD"
            },
            IRR: {
                displayName: "persesche Rial",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "ISJ",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "ißländesche Kruhne",
                "displayName-count-zero": "ißländesche Kruhne",
                "displayName-count-one": "ißländesche Kruhne",
                "displayName-count-other": "ißländesche Kruhne",
                symbol: "ISK",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "ITL",
                symbol: "ITL"
            },
            JMD: {
                displayName: "jamaikaanesche Dollaa",
                symbol: "JMD",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "Jordaanesche Dollaa",
                symbol: "JOD"
            },
            JPY: {
                displayName: "japaanesche Jen",
                symbol: "JP¥",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "Kenjaanesche Schillinge",
                "displayName-count-zero": "Kenjaanesche Schillinge",
                "displayName-count-one": "Kenjaanesche Schillinge",
                "displayName-count-other": "Kenjaanesche Schillinge",
                symbol: "KES"
            },
            KGS: {
                displayName: "kirjiisesche Som",
                symbol: "KGS"
            },
            KHR: {
                displayName: "kambodschaanesche Riel",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "kommooresche Frang",
                symbol: "KMF",
                "symbol-alt-narrow": "CF"
            },
            KPW: {
                displayName: "noodkorejaansche Won",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "KRH",
                symbol: "KRH"
            },
            KRO: {
                displayName: "KRO",
                symbol: "KRO"
            },
            KRW: {
                displayName: "söödkorejaansche Won",
                symbol: "₩",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "kuwaitesche Denaa",
                symbol: "KWD"
            },
            KYD: {
                displayName: "Kaimann-Dollaa",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "kasakesche Tenge",
                "displayName-count-zero": "kasakstaanesche Tenge",
                "displayName-count-one": "kasakstaanesche Tenge",
                "displayName-count-other": "kasakstaanesche Tenge",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "loaatesche Kip",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "libaneesesche Pongk",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "schrilankesche Ruupije",
                "displayName-count-zero": "schri-lankesche Ruupije",
                "displayName-count-one": "schri-lankesche Ruupije",
                "displayName-count-other": "schri-lankesche Ruupije",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "liberijaanesche Dollaa",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "lesoothesche Loti",
                symbol: "LSL"
            },
            LTL: {
                displayName: "littouesche Litas",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "LTT",
                symbol: "LTT"
            },
            LUC: {
                displayName: "LUC",
                symbol: "LUC"
            },
            LUF: {
                displayName: "LUF",
                symbol: "LUF"
            },
            LUL: {
                displayName: "LUL",
                symbol: "LUL"
            },
            LVL: {
                displayName: "lättesche Lats",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "LVR",
                symbol: "LVR"
            },
            LYD: {
                displayName: "libesche Denaa",
                symbol: "LYD"
            },
            MAD: {
                displayName: "marrokaanesche Dirhamm",
                symbol: "MAD"
            },
            MAF: {
                displayName: "MAF",
                symbol: "MAF"
            },
            MCF: {
                displayName: "MCF",
                symbol: "MCF"
            },
            MDC: {
                displayName: "MDC",
                symbol: "MDC"
            },
            MDL: {
                displayName: "moldaavesche Leu",
                symbol: "MDL"
            },
            MGA: {
                displayName: "madajaskesche Ariary",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "MGF",
                symbol: "MGF"
            },
            MKD: {
                displayName: "mazedoonesche Denaa",
                symbol: "MKD"
            },
            MKN: {
                displayName: "MKN",
                symbol: "MKN"
            },
            MLF: {
                displayName: "MLF",
                symbol: "MLF"
            },
            MMK: {
                displayName: "burmeesesche Kyat",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "mongjoolesche Tugrik",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "makaneesesche Pataca",
                symbol: "MOP"
            },
            MRO: {
                displayName: "mauretanesche Ouguiya (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "mauretanesche Ouguiya",
                symbol: "MRU"
            },
            MTL: {
                displayName: "MTL",
                symbol: "MTL"
            },
            MTP: {
                displayName: "MTP",
                symbol: "MTP"
            },
            MUR: {
                displayName: "maurizjahnesche Ruupije",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "MVP",
                symbol: "MVP"
            },
            MVR: {
                displayName: "mallediivesche Rufiyaa",
                symbol: "MVR"
            },
            MWK: {
                displayName: "malaawesche Kwache",
                symbol: "MWK"
            },
            MXN: {
                displayName: "mexekaanesche Peeso",
                "displayName-count-zero": "mexekaanesche Peeso",
                "displayName-count-one": "mexekaanesche Peeso",
                "displayName-count-other": "mexekaanesche Peeso",
                symbol: "MX$",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "MXP",
                symbol: "MXP"
            },
            MXV: {
                displayName: "MXV",
                symbol: "MXV"
            },
            MYR: {
                displayName: "malaisesche Ringgit",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "MZE",
                symbol: "MZE"
            },
            MZM: {
                displayName: "mosambikaanesche Metical (1980–2006)",
                symbol: "MZM"
            },
            MZN: {
                displayName: "mossambikaanesche Metical",
                symbol: "MZN"
            },
            NAD: {
                displayName: "namiibesche Dollaa",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "nijerijaanesche Naira",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "NIC",
                symbol: "NIC"
            },
            NIO: {
                displayName: "nikarajaanesche Córdoba",
                "displayName-count-zero": "nikarajaanesche Córdoba",
                "displayName-count-one": "nikarajaanesche Córdoba",
                "displayName-count-other": "nikarajaanesche Córdoba",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "NLG",
                symbol: "NLG"
            },
            NOK: {
                displayName: "norrweejesche Kruhne",
                "displayName-count-zero": "norrweejesche Kruhne",
                "displayName-count-one": "norrweejesche Kruhne",
                "displayName-count-other": "norrweejesche Kruhne",
                symbol: "NOK",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "nepaleesesche Ruupije",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "neuseeländesche Dollaa",
                symbol: "NZ$",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "ommaanesche Rijal",
                symbol: "OMR"
            },
            PAB: {
                displayName: "pannameesesche Balboa",
                "displayName-count-zero": "pannameesesche Balboa",
                "displayName-count-one": "pannameesesche Balboa",
                "displayName-count-other": "pannameesesche Balboa",
                symbol: "PAB"
            },
            PEI: {
                displayName: "PEI",
                symbol: "PEI"
            },
            PEN: {
                displayName: "perruaanesche Sol",
                symbol: "PEN"
            },
            PES: {
                displayName: "PES",
                symbol: "PES"
            },
            PGK: {
                displayName: "papua neujinejaanesche Kina",
                symbol: "PGK"
            },
            PHP: {
                displayName: "fillipiinesche Pesos",
                "displayName-count-zero": "fillipiinesche Pesos",
                "displayName-count-one": "fillipiinesche Pesos",
                "displayName-count-other": "fillipiinesche Pesos",
                symbol: "₱",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "pakestaanesche Ruupije",
                symbol: "PKR",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "polnesche Złoty",
                "displayName-count-zero": "polnesche Złoty",
                "displayName-count-one": "polnesche Złoty",
                "displayName-count-other": "polnesche Złoty",
                symbol: "PLN",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "PLZ",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "PTE",
                symbol: "PTE"
            },
            PYG: {
                displayName: "parajuaanesche Juarani",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "kataaresche Rijal",
                symbol: "QAR"
            },
            RHD: {
                displayName: "RHD",
                symbol: "RHD"
            },
            ROL: {
                displayName: "romäänesche Leu (1952–2006)",
                symbol: "ROL"
            },
            RON: {
                displayName: "romäänesche Leu",
                symbol: "RON",
                "symbol-alt-narrow": "lei"
            },
            RSD: {
                displayName: "särbesche Denaare",
                symbol: "RSD"
            },
            RUB: {
                displayName: "russesche Ruubel",
                symbol: "RUB",
                "symbol-alt-narrow": "₽"
            },
            RUR: {
                displayName: "RUR",
                symbol: "RUR"
            },
            RWF: {
                displayName: "ruandesche Frang",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "saudesche Rijal",
                symbol: "SAR"
            },
            SBD: {
                displayName: "solomonesche Dollaa",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "seischellesche Ruupije",
                symbol: "SCR"
            },
            SDD: {
                displayName: "SDD",
                symbol: "SDD"
            },
            SDG: {
                displayName: "sudaneesesche Pongk",
                symbol: "SDG"
            },
            SDP: {
                displayName: "SDP",
                symbol: "SDP"
            },
            SEK: {
                displayName: "schweedesche Kruhne",
                "displayName-count-zero": "schweedesche Kruhne",
                "displayName-count-one": "schweedesche Kruhne",
                "displayName-count-other": "schweedesche Kruhne",
                symbol: "SEK",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "singjapurejaanesche Dollaa",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "Zint-Hellena-Pongk",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "SIT",
                symbol: "SIT"
            },
            SKK: {
                displayName: "ßlovaakesche Kruhne",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "ẞjärra-lejoneesesche Leone",
                symbol: "SLL"
            },
            SOS: {
                displayName: "somaalesche Schillenge",
                "displayName-count-zero": "somaalesche Schillenge",
                "displayName-count-one": "somaalesche Schillenge",
                "displayName-count-other": "somaalesche Schillenge",
                symbol: "SOS"
            },
            SRD: {
                displayName: "sürinameesesche Dollaa",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "SRG",
                symbol: "SRG"
            },
            SSP: {
                displayName: "södsudaneesesche Pongk",
                "displayName-count-zero": "södsudaneesesche Pongk",
                "displayName-count-one": "södsudaneesesche Pongk",
                "displayName-count-other": "södsudaneesesche Pongk",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "Dobra vun São Tomé un Príncipe (1977–2017)",
                "displayName-count-zero": "Dobra vun São Tomé un Príncipe (1977–2017)",
                "displayName-count-one": "Dobra vun São Tomé un Príncipe (1977–2017)",
                "displayName-count-other": "Dobra vun São Tomé un Príncipe (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "Dobra vun São Tomé un Príncipe",
                "displayName-count-zero": "Dobra vun São Tomé un Príncipe",
                "displayName-count-one": "Dobra vun São Tomé un Príncipe",
                "displayName-count-other": "Dobra vun São Tomé un Príncipe",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "SUR",
                symbol: "SUR"
            },
            SVC: {
                displayName: "asalvadorejaanesche Cosan",
                symbol: "SVC"
            },
            SYP: {
                displayName: "süüresche Pund",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "swasiländesche Lilangeni",
                symbol: "SZL"
            },
            THB: {
                displayName: "tailändesche Baht",
                symbol: "THB",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "TJR",
                symbol: "TJR"
            },
            TJS: {
                displayName: "tadschikißtaanesche Somoni",
                symbol: "TJS"
            },
            TMM: {
                displayName: "turkmeneßtaanesche Manat (1993–2009)",
                symbol: "TMM"
            },
            TMT: {
                displayName: "turkmeneßtaanesche Manat",
                "displayName-count-zero": "turkmeneßtaanesche Manat",
                "displayName-count-one": "turkmeneßtaanesche Manat",
                "displayName-count-other": "turkmeneßtaanesche Manat",
                symbol: "TMT"
            },
            TND: {
                displayName: "tuneesesche Denaa",
                symbol: "TND"
            },
            TOP: {
                displayName: "tongjanes Paʻangache",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "TPE",
                symbol: "TPE"
            },
            TRL: {
                displayName: "TRL",
                symbol: "TRL"
            },
            TRY: {
                displayName: "törkesche Liire",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "Dollaa uß Trinidad un Tobääjo",
                "displayName-count-zero": "Dollaa uß Trinidad un Tobääjo",
                "displayName-count-one": "Dollaa uß Trinidad un Tobääjo",
                "displayName-count-other": "Dollaa uß Trinidad un Tobääjo",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "neu taiwaneesesche Dollaa",
                symbol: "NT$",
                "symbol-alt-narrow": "$"
            },
            TZS: {
                displayName: "tansaanesche Schillenge",
                "displayName-count-zero": "tansaanesche Schillenge",
                "displayName-count-one": "tansaanesche Schillenge",
                "displayName-count-other": "tansaanesche Schillenge",
                symbol: "TZS"
            },
            UAH: {
                displayName: "ukraijnesche Hryvnia",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "UAK",
                symbol: "UAK"
            },
            UGS: {
                displayName: "UGS",
                symbol: "UGS"
            },
            UGX: {
                displayName: "ujandesche Schillenge",
                "displayName-count-zero": "ujandesche Schillenge",
                "displayName-count-one": "ujandesche Schillenge",
                "displayName-count-other": "ujandesche Schillenge",
                symbol: "UGX"
            },
            USD: {
                displayName: "ammärrikaanesche Dollaa",
                symbol: "US$",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "USN",
                symbol: "USN"
            },
            USS: {
                displayName: "USS",
                symbol: "USS"
            },
            UYI: {
                displayName: "UYI",
                symbol: "UYI"
            },
            UYP: {
                displayName: "UYP",
                symbol: "UYP"
            },
            UYU: {
                displayName: "urrujuwaische Peeso",
                "displayName-count-zero": "urrujuwaische Peeso",
                "displayName-count-one": "urrujuwaische Peeso",
                "displayName-count-other": "urrujuwaische Peeso",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "UYW",
                symbol: "UYW"
            },
            UZS: {
                displayName: "ußbeekesche Som",
                symbol: "UZS"
            },
            VEB: {
                displayName: "VEB",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "venezuelaanesche Bolívar (2008–2018)",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs"
            },
            VES: {
                displayName: "venezuelaanesche Bolívar",
                symbol: "VES"
            },
            VND: {
                displayName: "vijätnammeesesche Dong",
                symbol: "₫",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "VNN",
                symbol: "VNN"
            },
            VUV: {
                displayName: "vanuatesche Vatu",
                symbol: "VUV"
            },
            WST: {
                displayName: "samowaanesche Tala",
                symbol: "WST"
            },
            XAF: {
                displayName: "Kmmeruhner Frang",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "Sellver",
                symbol: "XAG"
            },
            XAU: {
                displayName: "Jold",
                symbol: "XAU"
            },
            XBA: {
                displayName: "XBA",
                symbol: "XBA"
            },
            XBB: {
                displayName: "XBB",
                symbol: "XBB"
            },
            XBC: {
                displayName: "XBC",
                symbol: "XBC"
            },
            XBD: {
                displayName: "XBD",
                symbol: "XBD"
            },
            XCD: {
                displayName: "oß-karribbesche Dollaa",
                symbol: "EC$",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "XDR",
                symbol: "XDR"
            },
            XEU: {
                displayName: "XEU",
                symbol: "XEU"
            },
            XFO: {
                displayName: "franzüüsesche Joldfranke",
                symbol: "XFO"
            },
            XFU: {
                displayName: "XFU",
                symbol: "XFU"
            },
            XOF: {
                displayName: "Frang uß de Älfebeinköß",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "Palladijum",
                symbol: "XPD"
            },
            XPF: {
                displayName: "polineesesche Frang",
                "displayName-count-zero": "polineesesche Frang",
                "displayName-count-one": "polineesesche Frang",
                "displayName-count-other": "polineesesche Frang",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "Plaatin",
                symbol: "XPT"
            },
            XRE: {
                displayName: "XRE",
                symbol: "XRE"
            },
            XSU: {
                displayName: "XSU",
                symbol: "XSU"
            },
            XTS: {
                displayName: "Währong zum Prööfe",
                symbol: "XTS"
            },
            XUA: {
                displayName: "XUA",
                symbol: "XUA"
            },
            XXX: {
                displayName: "onbikannte Währong",
                symbol: "¤"
            },
            YDD: {
                displayName: "YDD",
                symbol: "YDD"
            },
            YER: {
                displayName: "jemenitesche Rijal",
                symbol: "YER"
            },
            YUD: {
                displayName: "YUD",
                symbol: "YUD"
            },
            YUM: {
                displayName: "YUM",
                symbol: "YUM"
            },
            YUN: {
                displayName: "YUN",
                symbol: "YUN"
            },
            YUR: {
                displayName: "YUR",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "ZAL",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "södaffrekaanesche Rand",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "sambesche Kwacha (1968–2012)",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "sambesche Kwacha",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "ZRN",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "ZRZ",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "simbabwesche Dollaa (1980–2008)",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "simbabwesche Dollaa (2009)",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "ZWR",
                symbol: "ZWR"
            }
        },
        localeCurrency: "EUR"
    },
    calendar: {
        patterns: {
            d: "d. M. y",
            D: "EEEE, 'dä' d. MMMM y",
            m: "d. MMM",
            M: "d. MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, 'dä' d. MMMM y HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E 'dä' d.",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "H:mm",
                hms: "h:mm:ss a",
                Hms: "H:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "MM-dd",
                MEd: "E d. M.",
                MMM: "LLL",
                MMMd: "d. MMM",
                MMMEd: "E d. MMM",
                MMMMd: "d. MMMM",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "Y-MM",
                yMd: "y-MM-dd",
                yMEd: "E y-MM-dd",
                yMMM: "MMM y",
                yMMMd: "d. MMM. y",
                yMMMEd: "E d. MMM. y",
                yMMMM: "MMMM y",
                yQQQ: "QQQy",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, 'dä' d. MMMM y",
            long: "d. MMMM y",
            medium: "d. MMM. y",
            short: "d. M. y"
        },
        days: {
            format: {
                abbreviated: [
                    "Su.",
                    "Mo.",
                    "Di.",
                    "Me.",
                    "Du.",
                    "Fr.",
                    "Sa."
                ],
                narrow: [
                    "S",
                    "M",
                    "D",
                    "M",
                    "D",
                    "F",
                    "S"
                ],
                short: [
                    "Su",
                    "Mo",
                    "Di",
                    "Me",
                    "Du",
                    "Fr",
                    "Sa"
                ],
                wide: [
                    "Sunndaach",
                    "Mohndaach",
                    "Dinnsdaach",
                    "Metwoch",
                    "Dunnersdaach",
                    "Friidaach",
                    "Samsdaach"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Su.",
                    "Mo.",
                    "Di.",
                    "Me.",
                    "Du.",
                    "Fr.",
                    "Sa."
                ],
                narrow: [
                    "S",
                    "M",
                    "D",
                    "M",
                    "D",
                    "F",
                    "S"
                ],
                short: [
                    "Su",
                    "Mo",
                    "Di",
                    "Me",
                    "Du",
                    "Fr",
                    "Sa"
                ],
                wide: [
                    "Sunndaach",
                    "Mohndaach",
                    "Dinnsdaach",
                    "Metwoch",
                    "Dunnersdaach",
                    "Friidaach",
                    "Samsdaach"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Jan",
                    "Fäb",
                    "Mäz",
                    "Apr",
                    "Mai",
                    "Jun",
                    "Jul",
                    "Ouj",
                    "Säp",
                    "Okt",
                    "Nov",
                    "Dez"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "O",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Jannewa",
                    "Fäbrowa",
                    "Määz",
                    "Aprell",
                    "Mai",
                    "Juuni",
                    "Juuli",
                    "Oujoß",
                    "Septämber",
                    "Oktohber",
                    "Novämber",
                    "Dezämber"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Jan.",
                    "Fäb.",
                    "Mäz.",
                    "Apr.",
                    "Mai",
                    "Jun.",
                    "Jul.",
                    "Ouj.",
                    "Säp.",
                    "Okt.",
                    "Nov.",
                    "Dez."
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "O",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Jannewa",
                    "Fäbrowa",
                    "Määz",
                    "Aprell",
                    "Mai",
                    "Juuni",
                    "Juuli",
                    "Oujoß",
                    "Septämber",
                    "Oktohber",
                    "Novämber",
                    "Dezämber"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1.Q.",
                    "2.Q.",
                    "3.Q.",
                    "4.Q."
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. Quattahl",
                    "2. Quattahl",
                    "3. Quattahl",
                    "4. Quattahl"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1.Q.",
                    "2.Q.",
                    "3.Q.",
                    "4.Q."
                ],
                narrow: [
                    "1Q",
                    "2Q",
                    "3Q",
                    "4Q"
                ],
                wide: [
                    "1. Quattahl",
                    "2. Quattahl",
                    "3. Quattahl",
                    "4. Quattahl"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "v.M.",
                    pm: "n.M."
                },
                narrow: {
                    am: "v.M.",
                    pm: "n.M."
                },
                wide: {
                    am: "Uhr vörmiddaachs",
                    pm: "Uhr nommendaachs"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "v.M.",
                    pm: "n.M."
                },
                narrow: {
                    am: "v.M.",
                    pm: "n.M."
                },
                wide: {
                    am: "Vörmeddaach",
                    pm: "Nommendaach"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "vür Krestos",
                    "1": "noh Krestos",
                    "0-alt-variant": "vür de jewöhnlejje Ziggrääschnong",
                    "1-alt-variant": "en de jewöhnlejje Ziggrääschnong"
                },
                abbreviated: {
                    "0": "v. Chr.",
                    "1": "n. Chr.",
                    "0-alt-variant": "v. Kr.",
                    "1-alt-variant": "n. K."
                },
                narrow: {
                    "0": "vC",
                    "1": "nC",
                    "0-alt-variant": "vdZ",
                    "1-alt-variant": "dZ"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Ähra",
                short: "Ähra",
                narrow: "Ähra"
            },
            year: {
                wide: "Johr",
                short: "J.",
                narrow: "J."
            },
            quarter: {
                wide: "Quattahl",
                short: "Q.",
                narrow: "Q."
            },
            month: {
                wide: "Mohnd",
                short: "Mohnd",
                narrow: "M."
            },
            week: {
                wide: "Woch",
                short: "W.",
                narrow: "W."
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Daach",
                short: "D.",
                narrow: "D."
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Wochedaach",
                short: "Wochedaach",
                narrow: "Wochedaach"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Daachteil",
                wide: "Daachteil",
                narrow: "Daachteil"
            },
            hour: {
                wide: "Schtund",
                short: "Std.",
                narrow: "S."
            },
            minute: {
                wide: "Menutt",
                short: "min.",
                narrow: "m."
            },
            second: {
                wide: "Sekond",
                short: "sek.",
                narrow: "s."
            },
            zone: {
                wide: "Zickzohn",
                short: "Zickzohn",
                narrow: "Zickzohn"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "Millisekunde"
            }
        }
    },
    firstDay: 1,
    weekendRange: {
        start: 6,
        end: 0
    },
    likelySubtags: {
        ksh: "ksh-Latn-DE"
    }
});

