/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ksh",
    likelySubtags: {
        ksh: "ksh-Latn-DE"
    },
    identity: {
        language: "ksh"
    },
    territory: "DE",
    calendar: {
        patterns: {
            d: "d. M. y",
            D: "EEEE, 'dä' d. MMMM y",
            m: "d. MMM",
            M: "d. MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, 'dä' d. MMMM y HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E 'dä' d.",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "H:mm",
                hms: "h:mm:ss a",
                Hms: "H:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "MM-dd",
                MEd: "E d. M.",
                MMM: "LLL",
                MMMd: "d. MMM",
                MMMEd: "E d. MMM",
                MMMMd: "d. MMMM",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "Y-MM",
                yMd: "y-MM-dd",
                yMEd: "E y-MM-dd",
                yMMM: "MMM y",
                yMMMd: "d. MMM. y",
                yMMMEd: "E d. MMM. y",
                yMMMM: "MMMM y",
                yQQQ: "QQQy",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, 'dä' d. MMMM y",
            long: "d. MMMM y",
            medium: "d. MMM. y",
            short: "d. M. y"
        },
        days: {
            format: {
                abbreviated: [
                    "Su.",
                    "Mo.",
                    "Di.",
                    "Me.",
                    "Du.",
                    "Fr.",
                    "Sa."
                ],
                narrow: [
                    "S",
                    "M",
                    "D",
                    "M",
                    "D",
                    "F",
                    "S"
                ],
                short: [
                    "Su",
                    "Mo",
                    "Di",
                    "Me",
                    "Du",
                    "Fr",
                    "Sa"
                ],
                wide: [
                    "Sunndaach",
                    "Mohndaach",
                    "Dinnsdaach",
                    "Metwoch",
                    "Dunnersdaach",
                    "Friidaach",
                    "Samsdaach"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Su.",
                    "Mo.",
                    "Di.",
                    "Me.",
                    "Du.",
                    "Fr.",
                    "Sa."
                ],
                narrow: [
                    "S",
                    "M",
                    "D",
                    "M",
                    "D",
                    "F",
                    "S"
                ],
                short: [
                    "Su",
                    "Mo",
                    "Di",
                    "Me",
                    "Du",
                    "Fr",
                    "Sa"
                ],
                wide: [
                    "Sunndaach",
                    "Mohndaach",
                    "Dinnsdaach",
                    "Metwoch",
                    "Dunnersdaach",
                    "Friidaach",
                    "Samsdaach"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Jan",
                    "Fäb",
                    "Mäz",
                    "Apr",
                    "Mai",
                    "Jun",
                    "Jul",
                    "Ouj",
                    "Säp",
                    "Okt",
                    "Nov",
                    "Dez"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "O",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Jannewa",
                    "Fäbrowa",
                    "Määz",
                    "Aprell",
                    "Mai",
                    "Juuni",
                    "Juuli",
                    "Oujoß",
                    "Septämber",
                    "Oktohber",
                    "Novämber",
                    "Dezämber"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Jan.",
                    "Fäb.",
                    "Mäz.",
                    "Apr.",
                    "Mai",
                    "Jun.",
                    "Jul.",
                    "Ouj.",
                    "Säp.",
                    "Okt.",
                    "Nov.",
                    "Dez."
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "O",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Jannewa",
                    "Fäbrowa",
                    "Määz",
                    "Aprell",
                    "Mai",
                    "Juuni",
                    "Juuli",
                    "Oujoß",
                    "Septämber",
                    "Oktohber",
                    "Novämber",
                    "Dezämber"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1.Q.",
                    "2.Q.",
                    "3.Q.",
                    "4.Q."
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. Quattahl",
                    "2. Quattahl",
                    "3. Quattahl",
                    "4. Quattahl"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1.Q.",
                    "2.Q.",
                    "3.Q.",
                    "4.Q."
                ],
                narrow: [
                    "1Q",
                    "2Q",
                    "3Q",
                    "4Q"
                ],
                wide: [
                    "1. Quattahl",
                    "2. Quattahl",
                    "3. Quattahl",
                    "4. Quattahl"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "v.M.",
                    pm: "n.M."
                },
                narrow: {
                    am: "v.M.",
                    pm: "n.M."
                },
                wide: {
                    am: "Uhr vörmiddaachs",
                    pm: "Uhr nommendaachs"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "v.M.",
                    pm: "n.M."
                },
                narrow: {
                    am: "v.M.",
                    pm: "n.M."
                },
                wide: {
                    am: "Vörmeddaach",
                    pm: "Nommendaach"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "vür Krestos",
                    "1": "noh Krestos",
                    "0-alt-variant": "vür de jewöhnlejje Ziggrääschnong",
                    "1-alt-variant": "en de jewöhnlejje Ziggrääschnong"
                },
                abbreviated: {
                    "0": "v. Chr.",
                    "1": "n. Chr.",
                    "0-alt-variant": "v. Kr.",
                    "1-alt-variant": "n. K."
                },
                narrow: {
                    "0": "vC",
                    "1": "nC",
                    "0-alt-variant": "vdZ",
                    "1-alt-variant": "dZ"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Ähra",
                short: "Ähra",
                narrow: "Ähra"
            },
            year: {
                wide: "Johr",
                short: "J.",
                narrow: "J."
            },
            quarter: {
                wide: "Quattahl",
                short: "Q.",
                narrow: "Q."
            },
            month: {
                wide: "Mohnd",
                short: "Mohnd",
                narrow: "M."
            },
            week: {
                wide: "Woch",
                short: "W.",
                narrow: "W."
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Daach",
                short: "D.",
                narrow: "D."
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Wochedaach",
                short: "Wochedaach",
                narrow: "Wochedaach"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Daachteil",
                wide: "Daachteil",
                narrow: "Daachteil"
            },
            hour: {
                wide: "Schtund",
                short: "Std.",
                narrow: "S."
            },
            minute: {
                wide: "Menutt",
                short: "min.",
                narrow: "m."
            },
            second: {
                wide: "Sekond",
                short: "sek.",
                narrow: "s."
            },
            zone: {
                wide: "Zickzohn",
                short: "Zickzohn",
                narrow: "Zickzohn"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "Millisekunde"
            }
        }
    },
    firstDay: 1
});

