/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ky",
    likelySubtags: {
        ky: "ky-Cyrl-KG"
    },
    identity: {
        language: "ky"
    },
    territory: "KG",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "y-'ж'., d-MMMM, EEEE",
            m: "d-MMM",
            M: "d-MMMM",
            y: "y-'ж'. MMM",
            Y: "y-'ж'., MMMM",
            F: "y-'ж'., d-MMMM, EEEE HH:mm:ss",
            g: "y-dd-MM HH:mm",
            G: "y-dd-MM HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y-'ж'.",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y-'ж'. MMM",
                GyMMMd: "G y-'ж'. d-MMM",
                GyMMMEd: "G y-'ж'. d-MMM, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "dd-MM",
                MEd: "dd-MM, E",
                MMM: "LLL",
                MMMd: "d-MMM",
                MMMEd: "d-MMM, E",
                MMMMd: "d-MMMM",
                "MMMMW-count-one": "MMMM 'айынын' W-'аптасы'",
                "MMMMW-count-other": "MMMM 'айынын' W-'аптасы'",
                ms: "mm:ss",
                y: "y",
                yM: "y-MM",
                yMd: "y-dd-MM",
                yMEd: "y-dd-MM, E",
                yMMM: "y-'ж'. MMM",
                yMMMd: "y-'ж'. d-MMM",
                yMMMEd: "y-'ж'. d-MMM, E",
                yMMMM: "y-'ж'., MMMM",
                yQQQ: "y-'ж'., QQQ",
                yQQQQ: "y-'ж'., QQQQ",
                "yw-count-one": "Y-'жылдын' w-'аптасы'",
                "yw-count-other": "Y-'жылдын' w-'аптасы'"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "y-'ж'., d-MMMM, EEEE",
            long: "y-'ж'., d-MMMM",
            medium: "y-'ж'., d-MMM",
            short: "d/M/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "жек.",
                    "дүй.",
                    "шейш.",
                    "шарш.",
                    "бейш.",
                    "жума",
                    "ишм."
                ],
                narrow: [
                    "Ж",
                    "Д",
                    "Ш",
                    "Ш",
                    "Б",
                    "Ж",
                    "И"
                ],
                short: [
                    "жш.",
                    "дш.",
                    "шш.",
                    "шр.",
                    "бш.",
                    "жм.",
                    "иш."
                ],
                wide: [
                    "жекшемби",
                    "дүйшөмбү",
                    "шейшемби",
                    "шаршемби",
                    "бейшемби",
                    "жума",
                    "ишемби"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "жек.",
                    "дүй.",
                    "шейш.",
                    "шарш.",
                    "бейш.",
                    "жума",
                    "ишм."
                ],
                narrow: [
                    "Ж",
                    "Д",
                    "Ш",
                    "Ш",
                    "Б",
                    "Ж",
                    "И"
                ],
                short: [
                    "жш.",
                    "дш.",
                    "шш.",
                    "шр.",
                    "бш.",
                    "жм.",
                    "иш."
                ],
                wide: [
                    "жекшемби",
                    "дүйшөмбү",
                    "шейшемби",
                    "шаршемби",
                    "бейшемби",
                    "жума",
                    "ишемби"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "янв.",
                    "фев.",
                    "мар.",
                    "апр.",
                    "май",
                    "июн.",
                    "июл.",
                    "авг.",
                    "сен.",
                    "окт.",
                    "ноя.",
                    "дек."
                ],
                narrow: [
                    "Я",
                    "Ф",
                    "М",
                    "А",
                    "М",
                    "И",
                    "И",
                    "А",
                    "С",
                    "О",
                    "Н",
                    "Д"
                ],
                wide: [
                    "январь",
                    "февраль",
                    "март",
                    "апрель",
                    "май",
                    "июнь",
                    "июль",
                    "август",
                    "сентябрь",
                    "октябрь",
                    "ноябрь",
                    "декабрь"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Янв",
                    "Фев",
                    "Мар",
                    "Апр",
                    "Май",
                    "Июн",
                    "Июл",
                    "Авг",
                    "Сен",
                    "Окт",
                    "Ноя",
                    "Дек"
                ],
                narrow: [
                    "Я",
                    "Ф",
                    "М",
                    "А",
                    "М",
                    "И",
                    "И",
                    "А",
                    "С",
                    "О",
                    "Н",
                    "Д"
                ],
                wide: [
                    "Январь",
                    "Февраль",
                    "Март",
                    "Апрель",
                    "Май",
                    "Июнь",
                    "Июль",
                    "Август",
                    "Сентябрь",
                    "Октябрь",
                    "Ноябрь",
                    "Декабрь"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1-чей.",
                    "2-чей.",
                    "3-чей.",
                    "4-чей."
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1-чейрек",
                    "2-чейрек",
                    "3-чейрек",
                    "4-чейрек"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1-ч.",
                    "2-ч.",
                    "3-ч.",
                    "4-ч."
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1-чейрек",
                    "2-чейрек",
                    "3-чейрек",
                    "4-чейрек"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "түн ортосу",
                    am: "тң",
                    noon: "чак түш",
                    pm: "тк",
                    morning1: "эртең менен",
                    afternoon1: "түштөн кийин",
                    evening1: "кечинде",
                    night1: "түн ичинде"
                },
                narrow: {
                    midnight: "түн орт",
                    am: "тң",
                    noon: "чт",
                    pm: "тк",
                    morning1: "эртң мн",
                    afternoon1: "түшт кйн",
                    evening1: "кечк",
                    night1: "түн"
                },
                wide: {
                    midnight: "түн ортосу",
                    am: "таңкы",
                    noon: "чак түш",
                    pm: "түштөн кийинки",
                    morning1: "эртең менен",
                    afternoon1: "түштөн кийин",
                    evening1: "кечинде",
                    night1: "түн ичинде"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "түн ортосу",
                    am: "тң",
                    noon: "чак түш",
                    pm: "тк",
                    morning1: "эртең менен",
                    afternoon1: "түштөн кийин",
                    evening1: "кечкурун",
                    night1: "түн"
                },
                narrow: {
                    midnight: "түн ортосу",
                    am: "тң",
                    noon: "чак түш",
                    pm: "тк",
                    morning1: "эртең менен",
                    afternoon1: "түштөн кийин",
                    evening1: "кечкурун",
                    night1: "түн"
                },
                wide: {
                    midnight: "түн ортосу",
                    am: "таңкы",
                    noon: "чак түш",
                    pm: "түштөн кийинки",
                    morning1: "эртең менен",
                    afternoon1: "түштөн кийин",
                    evening1: "кечкурун",
                    night1: "түн"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "биздин заманга чейин",
                    "1": "биздин заман",
                    "0-alt-variant": "б.з.ч.",
                    "1-alt-variant": "б.з."
                },
                abbreviated: {
                    "0": "б.з.ч.",
                    "1": "б.з.",
                    "0-alt-variant": "б.з.ч.",
                    "1-alt-variant": "б.з."
                },
                narrow: {
                    "0": "б.з.ч.",
                    "1": "б.з.",
                    "0-alt-variant": "б.з.ч.",
                    "1-alt-variant": "б.з."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "заман",
                short: "заман",
                narrow: "заман"
            },
            year: {
                wide: "жыл",
                short: "ж.",
                narrow: "ж."
            },
            quarter: {
                wide: "чейрек",
                short: "чейр.",
                narrow: "чейр."
            },
            month: {
                wide: "ай",
                short: "ай",
                narrow: "ай"
            },
            week: {
                wide: "апта",
                short: "апт",
                narrow: "апт"
            },
            weekOfMonth: {
                wide: "айдын жумасы",
                short: "айдын жумасы",
                narrow: "айдын жумасы"
            },
            day: {
                wide: "күн",
                short: "күн",
                narrow: "күн"
            },
            dayOfYear: {
                wide: "жылдын күнү",
                short: "жылдын күнү",
                narrow: "жылдын күнү"
            },
            weekday: {
                wide: "аптанын күнү",
                short: "аптанын күнү",
                narrow: "аптанын күнү"
            },
            weekdayOfMonth: {
                wide: "айдын жумуш күнү",
                short: "айдын жумуш күнү",
                narrow: "айдын жумуш күнү"
            },
            dayperiod: {
                short: "тң/тк",
                wide: "ТЧ/ТК",
                narrow: "тң/тк"
            },
            hour: {
                wide: "саат",
                short: "ст",
                narrow: "ст"
            },
            minute: {
                wide: "мүнөт",
                short: "мүн.",
                narrow: "м."
            },
            second: {
                wide: "секунд",
                short: "сек.",
                narrow: "сек."
            },
            zone: {
                wide: "убакыт алкагы",
                short: "убакыт алкагы",
                narrow: "убакыт алкагы"
            },
            millisecond: {
                narrow: "мсек",
                short: "мсек",
                wide: "миллисекунд"
            }
        }
    },
    firstDay: 1
});

