/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "lag",
    likelySubtags: {
        lag: "lag-Latn-TZ"
    },
    identity: {
        language: "lag"
    },
    territory: "TZ",
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, d MMMM y",
            m: "MMM d",
            M: "MMMM d",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d MMMM y HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "M/d",
                MEd: "E, M/d",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, MMM d",
                MMMMd: "MMMM d",
                MMMMEd: "E, MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "y-MM-dd",
                yMEd: "E, M/d/y",
                yMMM: "MMM y",
                yMMMd: "y MMM d",
                yMMMEd: "E, MMM d, y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "dd/MM/y"
        },
        days: {
            format: {
                abbreviated: [
                    "Píili",
                    "Táatu",
                    "Íne",
                    "Táano",
                    "Alh",
                    "Ijm",
                    "Móosi"
                ],
                narrow: [
                    "P",
                    "T",
                    "E",
                    "O",
                    "A",
                    "I",
                    "M"
                ],
                short: [
                    "Píili",
                    "Táatu",
                    "Íne",
                    "Táano",
                    "Alh",
                    "Ijm",
                    "Móosi"
                ],
                wide: [
                    "Jumapíiri",
                    "Jumatátu",
                    "Jumaíne",
                    "Jumatáano",
                    "Alamíisi",
                    "Ijumáa",
                    "Jumamóosi"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Píili",
                    "Táatu",
                    "Íne",
                    "Táano",
                    "Alh",
                    "Ijm",
                    "Móosi"
                ],
                narrow: [
                    "P",
                    "T",
                    "E",
                    "O",
                    "A",
                    "I",
                    "M"
                ],
                short: [
                    "Píili",
                    "Táatu",
                    "Íne",
                    "Táano",
                    "Alh",
                    "Ijm",
                    "Móosi"
                ],
                wide: [
                    "Jumapíiri",
                    "Jumatátu",
                    "Jumaíne",
                    "Jumatáano",
                    "Alamíisi",
                    "Ijumáa",
                    "Jumamóosi"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Fúngatɨ",
                    "Naanɨ",
                    "Keenda",
                    "Ikúmi",
                    "Inyambala",
                    "Idwaata",
                    "Mʉʉnchɨ",
                    "Vɨɨrɨ",
                    "Saatʉ",
                    "Inyi",
                    "Saano",
                    "Sasatʉ"
                ],
                narrow: [
                    "F",
                    "N",
                    "K",
                    "I",
                    "I",
                    "I",
                    "M",
                    "V",
                    "S",
                    "I",
                    "S",
                    "S"
                ],
                wide: [
                    "Kʉfúngatɨ",
                    "Kʉnaanɨ",
                    "Kʉkeenda",
                    "Kwiikumi",
                    "Kwiinyambála",
                    "Kwiidwaata",
                    "Kʉmʉʉnchɨ",
                    "Kʉvɨɨrɨ",
                    "Kʉsaatʉ",
                    "Kwiinyi",
                    "Kʉsaano",
                    "Kʉsasatʉ"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Fúngatɨ",
                    "Naanɨ",
                    "Keenda",
                    "Ikúmi",
                    "Inyambala",
                    "Idwaata",
                    "Mʉʉnchɨ",
                    "Vɨɨrɨ",
                    "Saatʉ",
                    "Inyi",
                    "Saano",
                    "Sasatʉ"
                ],
                narrow: [
                    "F",
                    "N",
                    "K",
                    "I",
                    "I",
                    "I",
                    "M",
                    "V",
                    "S",
                    "I",
                    "S",
                    "S"
                ],
                wide: [
                    "Kʉfúngatɨ",
                    "Kʉnaanɨ",
                    "Kʉkeenda",
                    "Kwiikumi",
                    "Kwiinyambála",
                    "Kwiidwaata",
                    "Kʉmʉʉnchɨ",
                    "Kʉvɨɨrɨ",
                    "Kʉsaatʉ",
                    "Kwiinyi",
                    "Kʉsaano",
                    "Kʉsasatʉ"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Ncho 1",
                    "Ncho 2",
                    "Ncho 3",
                    "Ncho 4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Ncholo ya 1",
                    "Ncholo ya 2",
                    "Ncholo ya 3",
                    "Ncholo ya 4"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Ncho 1",
                    "Ncho 2",
                    "Ncho 3",
                    "Ncho 4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Ncholo ya 1",
                    "Ncholo ya 2",
                    "Ncholo ya 3",
                    "Ncholo ya 4"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "TOO",
                    pm: "MUU"
                },
                narrow: {
                    am: "TOO",
                    pm: "MUU"
                },
                wide: {
                    am: "TOO",
                    pm: "MUU"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "TOO",
                    pm: "MUU"
                },
                narrow: {
                    am: "TOO",
                    pm: "MUU"
                },
                wide: {
                    am: "TOO",
                    pm: "MUU"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Kɨrɨsitʉ sɨ anavyaal",
                    "1": "Kɨrɨsitʉ akavyaalwe",
                    "0-alt-variant": "KSA",
                    "1-alt-variant": "KA"
                },
                abbreviated: {
                    "0": "KSA",
                    "1": "KA",
                    "0-alt-variant": "KSA",
                    "1-alt-variant": "KA"
                },
                narrow: {
                    "0": "KSA",
                    "1": "KA",
                    "0-alt-variant": "KSA",
                    "1-alt-variant": "KA"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Mpɨɨndɨ",
                short: "Mpɨɨndɨ",
                narrow: "Mpɨɨndɨ"
            },
            year: {
                wide: "Mwaáka",
                short: "Mwaáka",
                narrow: "Mwaáka"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Mweéri",
                short: "Mweéri",
                narrow: "Mweéri"
            },
            week: {
                wide: "Wíiki",
                short: "Wíiki",
                narrow: "Wíiki"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Sikʉ",
                short: "Sikʉ",
                narrow: "Sikʉ"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Sikʉ ya júma",
                short: "Sikʉ ya júma",
                narrow: "Sikʉ ya júma"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Mpɨɨndɨ ja sikʉ",
                wide: "Mpɨɨndɨ ja sikʉ",
                narrow: "Mpɨɨndɨ ja sikʉ"
            },
            hour: {
                wide: "Sáa",
                short: "Sáa",
                narrow: "Sáa"
            },
            minute: {
                wide: "Dakíka",
                short: "Dakíka",
                narrow: "Dakíka"
            },
            second: {
                wide: "Sekúunde",
                short: "Sekúunde",
                narrow: "Sekúunde"
            },
            zone: {
                wide: "Mpɨɨndɨ ja mɨɨtʉ",
                short: "Mpɨɨndɨ ja mɨɨtʉ",
                narrow: "Mpɨɨndɨ ja mɨɨtʉ"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

