/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "lv",
    likelySubtags: {
        lv: "lv-Latn-LV"
    },
    identity: {
        language: "lv"
    },
    territory: "LV",
    calendar: {
        patterns: {
            d: "dd.MM.y",
            D: "EEEE, y. 'gada' d. MMMM",
            m: "d. MMM",
            M: "d. MMMM",
            y: "y. 'g'. MMM",
            Y: "y. 'g'. MMMM",
            F: "EEEE, y. 'gada' d. MMMM HH:mm:ss",
            g: "d.MM.y. HH:mm",
            G: "d.MM.y. HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E, h:mm B",
                EBhms: "E, h:mm:ss B",
                Ed: "E, d.",
                Ehm: "E, h:mm a",
                EHm: "E, HH:mm",
                Ehms: "E, h:mm:ss a",
                EHms: "E, HH:mm:ss",
                Gy: "G y. 'g'.",
                GyMd: "GGGGG dd-MM-y",
                GyMMM: "G y. 'g'. MMM",
                GyMMMd: "G y. 'g'. d. MMM",
                GyMMMEd: "E, G y. 'g'. d. MMM",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "dd.MM.",
                MEd: "E, dd.MM.",
                MMM: "LLL",
                MMMd: "d. MMM",
                MMMEd: "E, d. MMM",
                MMMMd: "d. MMMM",
                MMMMEd: "E, d. MMMM",
                "MMMMW-count-zero": "MMMM, W. 'nedēļa'",
                "MMMMW-count-one": "MMMM, W. 'nedēļa'",
                "MMMMW-count-other": "MMMM, W. 'nedēļa'",
                mmss: "mm:ss",
                ms: "mm:ss",
                y: "y. 'g'.",
                yM: "MM.y.",
                yMd: "d.MM.y.",
                yMEd: "E, d.M.y.",
                yMMM: "y. 'g'. MMM",
                yMMMd: "y. 'g'. d. MMM",
                yMMMEd: "E, y. 'g'. d. MMM",
                yMMMM: "y. 'g'. MMMM",
                yQQQ: "y. 'g'. QQQ",
                yQQQQ: "y. 'g'. QQQQ",
                "yw-count-zero": "Y. 'g'. w. 'nedēļa'",
                "yw-count-one": "Y. 'g'. w. 'nedēļa'",
                "yw-count-other": "Y. 'g'. w. 'nedēļa'"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, y. 'gada' d. MMMM",
            long: "y. 'gada' d. MMMM",
            medium: "y. 'gada' d. MMM",
            short: "dd.MM.yy"
        },
        days: {
            format: {
                abbreviated: [
                    "svētd.",
                    "pirmd.",
                    "otrd.",
                    "trešd.",
                    "ceturtd.",
                    "piektd.",
                    "sestd."
                ],
                narrow: [
                    "S",
                    "P",
                    "O",
                    "T",
                    "C",
                    "P",
                    "S"
                ],
                short: [
                    "Sv",
                    "Pr",
                    "Ot",
                    "Tr",
                    "Ce",
                    "Pk",
                    "Se"
                ],
                wide: [
                    "svētdiena",
                    "pirmdiena",
                    "otrdiena",
                    "trešdiena",
                    "ceturtdiena",
                    "piektdiena",
                    "sestdiena"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Svētd.",
                    "Pirmd.",
                    "Otrd.",
                    "Trešd.",
                    "Ceturtd.",
                    "Piektd.",
                    "Sestd."
                ],
                narrow: [
                    "S",
                    "P",
                    "O",
                    "T",
                    "C",
                    "P",
                    "S"
                ],
                short: [
                    "Sv",
                    "Pr",
                    "Ot",
                    "Tr",
                    "Ce",
                    "Pk",
                    "Se"
                ],
                wide: [
                    "Svētdiena",
                    "Pirmdiena",
                    "Otrdiena",
                    "Trešdiena",
                    "Ceturtdiena",
                    "Piektdiena",
                    "Sestdiena"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "janv.",
                    "febr.",
                    "marts",
                    "apr.",
                    "maijs",
                    "jūn.",
                    "jūl.",
                    "aug.",
                    "sept.",
                    "okt.",
                    "nov.",
                    "dec."
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "janvāris",
                    "februāris",
                    "marts",
                    "aprīlis",
                    "maijs",
                    "jūnijs",
                    "jūlijs",
                    "augusts",
                    "septembris",
                    "oktobris",
                    "novembris",
                    "decembris"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "janv.",
                    "febr.",
                    "marts",
                    "apr.",
                    "maijs",
                    "jūn.",
                    "jūl.",
                    "aug.",
                    "sept.",
                    "okt.",
                    "nov.",
                    "dec."
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "janvāris",
                    "februāris",
                    "marts",
                    "aprīlis",
                    "maijs",
                    "jūnijs",
                    "jūlijs",
                    "augusts",
                    "septembris",
                    "oktobris",
                    "novembris",
                    "decembris"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1. cet.",
                    "2. cet.",
                    "3. cet.",
                    "4. cet."
                ],
                narrow: [
                    "1.",
                    "2.",
                    "3.",
                    "4."
                ],
                wide: [
                    "1. ceturksnis",
                    "2. ceturksnis",
                    "3. ceturksnis",
                    "4. ceturksnis"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1. cet.",
                    "2. cet.",
                    "3. cet.",
                    "4. cet."
                ],
                narrow: [
                    "1.",
                    "2.",
                    "3.",
                    "4."
                ],
                wide: [
                    "1. ceturksnis",
                    "2. ceturksnis",
                    "3. ceturksnis",
                    "4. ceturksnis"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "pusnaktī",
                    am: "priekšp.",
                    noon: "pusd.",
                    pm: "pēcp.",
                    morning1: "no rīta",
                    afternoon1: "pēcpusd.",
                    evening1: "vakarā",
                    night1: "naktī"
                },
                narrow: {
                    midnight: "pusnaktī",
                    am: "priekšp.",
                    noon: "pusd.",
                    pm: "pēcp.",
                    morning1: "no rīta",
                    afternoon1: "pēcpusd.",
                    evening1: "vakarā",
                    night1: "naktī"
                },
                wide: {
                    midnight: "pusnaktī",
                    am: "priekšpusdienā",
                    noon: "pusdienlaikā",
                    pm: "pēcpusdienā",
                    morning1: "no rīta",
                    afternoon1: "pēcpusdienā",
                    evening1: "vakarā",
                    night1: "naktī"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "pusnakts",
                    am: "priekšp.",
                    noon: "pusd.",
                    pm: "pēcpusd.",
                    morning1: "rīts",
                    afternoon1: "pēcpusd.",
                    evening1: "vakars",
                    night1: "nakts"
                },
                narrow: {
                    midnight: "pusnakts",
                    am: "priekšp.",
                    noon: "pusd.",
                    pm: "pēcpusd.",
                    morning1: "rīts",
                    afternoon1: "pēcpusd.",
                    evening1: "vakars",
                    night1: "nakts"
                },
                wide: {
                    midnight: "pusnakts",
                    am: "priekšpusdiena",
                    noon: "pusdienlaiks",
                    pm: "pēcpusdiena",
                    morning1: "rīts",
                    afternoon1: "pēcpusdiena",
                    evening1: "vakars",
                    night1: "nakts"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "pirms mūsu ēras",
                    "1": "mūsu ērā",
                    "0-alt-variant": "pirms mūsu ēras",
                    "1-alt-variant": "mūsu ērā"
                },
                abbreviated: {
                    "0": "p.m.ē.",
                    "1": "m.ē.",
                    "0-alt-variant": "p.m.ē.",
                    "1-alt-variant": "m.ē."
                },
                narrow: {
                    "0": "p.m.ē.",
                    "1": "m.ē.",
                    "0-alt-variant": "p.m.ē.",
                    "1-alt-variant": "m.ē."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "ēra",
                short: "ēra",
                narrow: "ēra"
            },
            year: {
                wide: "gads",
                short: "g.",
                narrow: "g."
            },
            quarter: {
                wide: "ceturksnis",
                short: "cet.",
                narrow: "cet."
            },
            month: {
                wide: "mēnesis",
                short: "mēn.",
                narrow: "mēn."
            },
            week: {
                wide: "nedēļa",
                short: "ned.",
                narrow: "ned."
            },
            weekOfMonth: {
                wide: "mēneša nedēļa",
                short: "mēneša ned.",
                narrow: "mēneša ned."
            },
            day: {
                wide: "diena",
                short: "d.",
                narrow: "d."
            },
            dayOfYear: {
                wide: "gada diena",
                short: "gada diena",
                narrow: "gada diena"
            },
            weekday: {
                wide: "nedēļas diena",
                short: "nedēļas diena",
                narrow: "nedēļas diena"
            },
            weekdayOfMonth: {
                wide: "mēneša nedēļas diena",
                short: "mēneša ned. diena",
                narrow: "mēneša ned. diena"
            },
            dayperiod: {
                short: "priekšpusd./pēcpusd.",
                wide: "priekšpusdienā/pēcpusdienā",
                narrow: "priekšpusd./pēcpusd."
            },
            hour: {
                wide: "stundas",
                short: "st.",
                narrow: "h"
            },
            minute: {
                wide: "minūtes",
                short: "min",
                narrow: "min"
            },
            second: {
                wide: "sekundes",
                short: "sek.",
                narrow: "s"
            },
            zone: {
                wide: "laika josla",
                short: "laika josla",
                narrow: "laika josla"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "milisekunde"
            }
        }
    },
    firstDay: 1
});

