/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "mai",
    likelySubtags: {
        mai: "mai-Deva-IN"
    },
    identity: {
        language: "mai"
    },
    territory: "IN",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE, d MMMM y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d MMMM y h:mm:ss a",
            g: "d/M/y h:mm a",
            G: "d/M/y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} के {0}",
            long: "{1} के {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "B h",
                Bhm: "B h:mm",
                Bhms: "B h:mm:ss",
                d: "d",
                E: "ccc",
                EBhm: "E B h:mm",
                EBhms: "E B h:mm:ss",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "dd-MM-y G",
                GyMMM: "MMM G y",
                GyMMMd: "d MMM y G",
                GyMMMEd: "E, MMM d, y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E, d/M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E, d MMM",
                MMMMd: "d MMMM",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E, d/M/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E, d MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "EEEE, d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "d/M/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "रवि",
                    "सोम",
                    "मंगल",
                    "बुध",
                    "गुरु",
                    "शुक्र",
                    "शनि"
                ],
                narrow: [
                    "र",
                    "सो",
                    "मं",
                    "बु",
                    "गु",
                    "शु",
                    "श"
                ],
                short: [
                    "रवि",
                    "सोम",
                    "मंगल",
                    "बुध",
                    "गुरु",
                    "शुक्र",
                    "शनि"
                ],
                wide: [
                    "रवि दिन",
                    "सोम दिन",
                    "मंगल दिन",
                    "बुध दिन",
                    "बृहस्पति दिन",
                    "शुक्र दिन",
                    "शनि दिन"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "रवि",
                    "सोम",
                    "मंगल",
                    "बुध",
                    "गुरु",
                    "शुक्र",
                    "शनि"
                ],
                narrow: [
                    "र",
                    "सो",
                    "मं",
                    "बु",
                    "गु",
                    "शु",
                    "श"
                ],
                short: [
                    "रवि",
                    "सोम",
                    "मंगल",
                    "बुध",
                    "गुरु",
                    "शुक्र",
                    "शनि"
                ],
                wide: [
                    "रवि दिन",
                    "सोम दिन",
                    "मंगल दिन",
                    "बुध दिन",
                    "बृहस्पति दिन",
                    "शुक्र दिन",
                    "शनि दिन"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "जन॰",
                    "फ़र॰",
                    "मार्च",
                    "अप्रैल",
                    "मई",
                    "जून",
                    "जुल॰",
                    "अग॰",
                    "सित॰",
                    "अक्तू॰",
                    "नव॰",
                    "दिस॰"
                ],
                narrow: [
                    "ज",
                    "फ",
                    "मा",
                    "अ",
                    "म",
                    "जू",
                    "जु",
                    "अ",
                    "सि",
                    "अ",
                    "न",
                    "दि"
                ],
                wide: [
                    "जनवरी",
                    "फरवरी",
                    "मार्च",
                    "अप्रैल",
                    "मई",
                    "जून",
                    "जुलाई",
                    "अगस्त",
                    "सितंबर",
                    "अक्तूबर",
                    "नवंबर",
                    "दिसंबर"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "जन॰",
                    "फर॰",
                    "मार्च",
                    "अप्रैल",
                    "मई",
                    "जून",
                    "जुल॰",
                    "अग॰",
                    "सित॰",
                    "अक्तू॰",
                    "नव॰",
                    "दिस॰"
                ],
                narrow: [
                    "ज",
                    "फ",
                    "मा",
                    "अ",
                    "म",
                    "जू",
                    "जु",
                    "अ",
                    "सि",
                    "अ",
                    "न",
                    "दि"
                ],
                wide: [
                    "जनवरी",
                    "फरवरी",
                    "मार्च",
                    "अप्रैल",
                    "मई",
                    "जून",
                    "जुलाई",
                    "अगस्त",
                    "सितंबर",
                    "अक्टूबर",
                    "नवंबर",
                    "दिसंबर"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "ति1",
                    "ति2",
                    "ति3",
                    "ति4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "पहिल तिमाही",
                    "दोसर तिमाही",
                    "तेसर तिमाही",
                    "चारिम तिमाही"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ति1",
                    "ति2",
                    "ति3",
                    "ति4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "पहिल तिमाही",
                    "दोसर तिमाही",
                    "तेसर तिमाही",
                    "चारिम तिमाही"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "भोर",
                    pm: "सांझ"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "ईसा-पूर्व",
                    "1": "ईसवी",
                    "0-alt-variant": "ईसवी पूर्व",
                    "1-alt-variant": "ईसवी"
                },
                abbreviated: {
                    "0": "ईसा-पूर्व",
                    "1": "ईसवी",
                    "0-alt-variant": "ईसवी पूर्व",
                    "1-alt-variant": "ईसवी"
                },
                narrow: {
                    "0": "ईसा-पूर्व",
                    "1": "ईसवी",
                    "0-alt-variant": "ईसवी पूर्व",
                    "1-alt-variant": "ईसवी"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "युग",
                short: "युग",
                narrow: "युग"
            },
            year: {
                wide: "वर्ष",
                short: "वर्ष",
                narrow: "वर्ष"
            },
            quarter: {
                wide: "तिमाही",
                short: "तिमाही",
                narrow: "तिमाही"
            },
            month: {
                wide: "महीना",
                short: "मास",
                narrow: "मास"
            },
            week: {
                wide: "सप्ताह",
                short: "सप्ताह",
                narrow: "सप्ताह"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "दिन",
                short: "दिन",
                narrow: "दिन"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "सप्ताहक दिन",
                short: "सप्ताहक दिन",
                narrow: "सप्ताहक दिन"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "पूर्वाह्न/अपराह्न",
                wide: "पूर्वाह्न/अपराह्न",
                narrow: "पूर्वाह्न/अपराह्न"
            },
            hour: {
                wide: "घंटा",
                short: "घंटा",
                narrow: "घंटा"
            },
            minute: {
                wide: "मिनट",
                short: "मिनट",
                narrow: "मिनट"
            },
            second: {
                wide: "सेकंड",
                short: "सेकंड",
                narrow: "सेकंड"
            },
            zone: {
                wide: "समय क्षेत्र",
                short: "समय क्षेत्र",
                narrow: "समय क्षेत्र"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

