/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "mfe",
    likelySubtags: {
        mfe: "mfe-Latn-MU"
    },
    identity: {
        language: "mfe"
    },
    territory: "MU",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE d MMMM y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE d MMMM y HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "M",
                Md: "d/M",
                MEd: "MM-dd, E",
                MMd: "d/MM",
                MMdd: "dd/MM",
                MMM: "MMM",
                MMMd: "d MMM",
                MMMEd: "E d MMM",
                MMMMd: "d MMMM",
                MMMMEd: "E d MMMM",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "m:ss",
                y: "y",
                yM: "M/y",
                yMd: "y-MM-dd",
                yMEd: "E d/M/y",
                yMM: "MM/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E d MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE d MMMM y",
            long: "d MMMM y",
            medium: "d MMM, y",
            short: "d/M/y"
        },
        days: {
            format: {
                abbreviated: [
                    "dim",
                    "lin",
                    "mar",
                    "mer",
                    "ze",
                    "van",
                    "sam"
                ],
                narrow: [
                    "d",
                    "l",
                    "m",
                    "m",
                    "z",
                    "v",
                    "s"
                ],
                short: [
                    "dim",
                    "lin",
                    "mar",
                    "mer",
                    "ze",
                    "van",
                    "sam"
                ],
                wide: [
                    "dimans",
                    "lindi",
                    "mardi",
                    "merkredi",
                    "zedi",
                    "vandredi",
                    "samdi"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "dim",
                    "lin",
                    "mar",
                    "mer",
                    "ze",
                    "van",
                    "sam"
                ],
                narrow: [
                    "d",
                    "l",
                    "m",
                    "m",
                    "z",
                    "v",
                    "s"
                ],
                short: [
                    "dim",
                    "lin",
                    "mar",
                    "mer",
                    "ze",
                    "van",
                    "sam"
                ],
                wide: [
                    "dimans",
                    "lindi",
                    "mardi",
                    "merkredi",
                    "zedi",
                    "vandredi",
                    "samdi"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "zan",
                    "fev",
                    "mar",
                    "avr",
                    "me",
                    "zin",
                    "zil",
                    "out",
                    "sep",
                    "okt",
                    "nov",
                    "des"
                ],
                narrow: [
                    "z",
                    "f",
                    "m",
                    "a",
                    "m",
                    "z",
                    "z",
                    "o",
                    "s",
                    "o",
                    "n",
                    "d"
                ],
                wide: [
                    "zanvie",
                    "fevriye",
                    "mars",
                    "avril",
                    "me",
                    "zin",
                    "zilye",
                    "out",
                    "septam",
                    "oktob",
                    "novam",
                    "desam"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "zan",
                    "fev",
                    "mar",
                    "avr",
                    "me",
                    "zin",
                    "zil",
                    "out",
                    "sep",
                    "okt",
                    "nov",
                    "des"
                ],
                narrow: [
                    "z",
                    "f",
                    "m",
                    "a",
                    "m",
                    "z",
                    "z",
                    "o",
                    "s",
                    "o",
                    "n",
                    "d"
                ],
                wide: [
                    "zanvie",
                    "fevriye",
                    "mars",
                    "avril",
                    "me",
                    "zin",
                    "zilye",
                    "out",
                    "septam",
                    "oktob",
                    "novam",
                    "desam"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "T1",
                    "T2",
                    "T3",
                    "T4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1e trimes",
                    "2em trimes",
                    "3em trimes",
                    "4em trimes"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "T1",
                    "T2",
                    "T3",
                    "T4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1e trimes",
                    "2em trimes",
                    "3em trimes",
                    "4em trimes"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "avan Zezi-Krist",
                    "1": "apre Zezi-Krist",
                    "0-alt-variant": "av. Z-K",
                    "1-alt-variant": "ap. Z-K"
                },
                abbreviated: {
                    "0": "av. Z-K",
                    "1": "ap. Z-K",
                    "0-alt-variant": "av. Z-K",
                    "1-alt-variant": "ap. Z-K"
                },
                narrow: {
                    "0": "av. Z-K",
                    "1": "ap. Z-K",
                    "0-alt-variant": "av. Z-K",
                    "1-alt-variant": "ap. Z-K"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Lepok",
                short: "Lepok",
                narrow: "Lepok"
            },
            year: {
                wide: "Lane",
                short: "Lane",
                narrow: "Lane"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Mwa",
                short: "Mwa",
                narrow: "Mwa"
            },
            week: {
                wide: "Semenn",
                short: "Semenn",
                narrow: "Semenn"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Zour",
                short: "Zour",
                narrow: "Zour"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Zour lasemenn",
                short: "Zour lasemenn",
                narrow: "Zour lasemenn"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Peryod dan lazourne",
                wide: "Peryod dan lazourne",
                narrow: "Peryod dan lazourne"
            },
            hour: {
                wide: "Ler",
                short: "Ler",
                narrow: "Ler"
            },
            minute: {
                wide: "Minit",
                short: "Minit",
                narrow: "Minit"
            },
            second: {
                wide: "Segonn",
                short: "Segonn",
                narrow: "Segonn"
            },
            zone: {
                wide: "Peryod letan",
                short: "Peryod letan",
                narrow: "Peryod letan"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

