/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "mg",
    likelySubtags: {
        mg: "mg-Latn-MG"
    },
    identity: {
        language: "mg"
    },
    territory: "MG",
    calendar: {
        patterns: {
            d: "y-MM-dd",
            D: "EEEE d MMMM y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE d MMMM y HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "M",
                Md: "d/M",
                MEd: "E d/M",
                MMd: "d/MM",
                MMdd: "dd/MM",
                MMM: "MMM",
                MMMd: "d MMM",
                MMMEd: "E d MMM",
                MMMMd: "d MMMM",
                MMMMEd: "E d MMMM",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "m:ss",
                y: "y",
                yM: "M/y",
                yMd: "y-MM-dd",
                yMEd: "E d/M/y",
                yMM: "MM/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E d MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE d MMMM y",
            long: "d MMMM y",
            medium: "y MMM d",
            short: "y-MM-dd"
        },
        days: {
            format: {
                abbreviated: [
                    "Alah",
                    "Alats",
                    "Tal",
                    "Alar",
                    "Alak",
                    "Zom",
                    "Asab"
                ],
                narrow: [
                    "A",
                    "A",
                    "T",
                    "A",
                    "A",
                    "Z",
                    "A"
                ],
                short: [
                    "Alah",
                    "Alats",
                    "Tal",
                    "Alar",
                    "Alak",
                    "Zom",
                    "Asab"
                ],
                wide: [
                    "Alahady",
                    "Alatsinainy",
                    "Talata",
                    "Alarobia",
                    "Alakamisy",
                    "Zoma",
                    "Asabotsy"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Alah",
                    "Alats",
                    "Tal",
                    "Alar",
                    "Alak",
                    "Zom",
                    "Asab"
                ],
                narrow: [
                    "A",
                    "A",
                    "T",
                    "A",
                    "A",
                    "Z",
                    "A"
                ],
                short: [
                    "Alah",
                    "Alats",
                    "Tal",
                    "Alar",
                    "Alak",
                    "Zom",
                    "Asab"
                ],
                wide: [
                    "Alahady",
                    "Alatsinainy",
                    "Talata",
                    "Alarobia",
                    "Alakamisy",
                    "Zoma",
                    "Asabotsy"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Jan",
                    "Feb",
                    "Mar",
                    "Apr",
                    "Mey",
                    "Jon",
                    "Jol",
                    "Aog",
                    "Sep",
                    "Okt",
                    "Nov",
                    "Des"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Janoary",
                    "Febroary",
                    "Martsa",
                    "Aprily",
                    "Mey",
                    "Jona",
                    "Jolay",
                    "Aogositra",
                    "Septambra",
                    "Oktobra",
                    "Novambra",
                    "Desambra"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Jan",
                    "Feb",
                    "Mar",
                    "Apr",
                    "Mey",
                    "Jon",
                    "Jol",
                    "Aog",
                    "Sep",
                    "Okt",
                    "Nov",
                    "Des"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Janoary",
                    "Febroary",
                    "Martsa",
                    "Aprily",
                    "Mey",
                    "Jona",
                    "Jolay",
                    "Aogositra",
                    "Septambra",
                    "Oktobra",
                    "Novambra",
                    "Desambra"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "T1",
                    "T2",
                    "T3",
                    "T4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Telovolana voalohany",
                    "Telovolana faharoa",
                    "Telovolana fahatelo",
                    "Telovolana fahefatra"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "T1",
                    "T2",
                    "T3",
                    "T4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Telovolana voalohany",
                    "Telovolana faharoa",
                    "Telovolana fahatelo",
                    "Telovolana fahefatra"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Alohan’i JK",
                    "1": "Aorian’i JK",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                abbreviated: {
                    "0": "BC",
                    "1": "AD",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                narrow: {
                    "0": "BC",
                    "1": "AD",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Era",
                short: "Era",
                narrow: "Era"
            },
            year: {
                wide: "Taona",
                short: "Taona",
                narrow: "Taona"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Volana",
                short: "Volana",
                narrow: "Volana"
            },
            week: {
                wide: "Herinandro",
                short: "Herinandro",
                narrow: "Herinandro"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Andro",
                short: "Andro",
                narrow: "Andro"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Day of the Week",
                short: "Day of the Week",
                narrow: "Day of the Week"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "AM/PM",
                wide: "AM/PM",
                narrow: "AM/PM"
            },
            hour: {
                wide: "Ora",
                short: "Ora",
                narrow: "Ora"
            },
            minute: {
                wide: "Minitra",
                short: "Minitra",
                narrow: "Minitra"
            },
            second: {
                wide: "Segondra",
                short: "Segondra",
                narrow: "Segondra"
            },
            zone: {
                wide: "Zone",
                short: "Zone",
                narrow: "Zone"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

