/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "mn",
    likelySubtags: {
        mn: "mn-Cyrl-MN"
    },
    identity: {
        language: "mn"
    },
    territory: "MN",
    calendar: {
        patterns: {
            d: "y.MM.dd",
            D: "y 'оны' MMMM'ын' d, EEEE 'гараг'",
            m: "MMM'ын' d",
            M: "MMMM'ын' d",
            y: "y 'оны' MMM",
            Y: "y 'оны' MMMM",
            F: "y 'оны' MMMM'ын' d, EEEE 'гараг' HH:mm:ss",
            g: "y.MM.dd HH:mm",
            G: "y.MM.dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "B h 'ц'",
                Bhm: "B h:mm",
                Bhms: "B h:mm:ss",
                d: "d",
                E: "ccc",
                EBhm: "E. B h:mm",
                EBhms: "E. B h:mm:ss",
                Ed: "dd. E",
                Ehm: "E. h:mm a",
                EHm: "E. HH:mm",
                Ehms: "E. h:mm:ss a",
                EHms: "E. HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y 'оны' MMM",
                GyMMMd: "G y 'оны' MMM'ын' d",
                GyMMMEd: "G y 'оны' MMM'ын' d. E",
                h: "h 'ц' a",
                H: "HH 'ц'",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a (v)",
                Hmsv: "HH:mm:ss (v)",
                hmv: "h:mm a (v)",
                Hmv: "HH:mm (v)",
                M: "LLLLL",
                Md: "MMMMM/dd",
                MEd: "MMMMM/dd. E",
                MMM: "LLL",
                MMMd: "MMM'ын' d",
                MMMEd: "MMM'ын' d. E",
                MMMMd: "MMMM'ын' d",
                "MMMMW-count-one": "MMMM'ын' W-'р' 'долоо' 'хоног'",
                "MMMMW-count-other": "MMMM'ын' W-'р' 'долоо' 'хоног'",
                ms: "mm:ss",
                y: "y",
                yM: "y MMMMM",
                yMd: "y.MM.dd",
                yMEd: "y.MM.dd. E",
                yMMM: "y 'оны' MMM",
                yMMMd: "y 'оны' MMM'ын' d",
                yMMMEd: "y 'оны' MMM'ын' d. E",
                yMMMM: "y 'оны' MMMM",
                yQQQ: "y 'оны' QQQ",
                yQQQQ: "y 'оны' QQQQ",
                "yw-count-one": "Y 'оны' w-'р' 'долоо' 'хоног'",
                "yw-count-other": "Y 'оны' w-'р' 'долоо' 'хоног'"
            }
        },
        timeFormats: {
            full: "HH:mm:ss (zzzz)",
            long: "HH:mm:ss (z)",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "y 'оны' MMMM'ын' d, EEEE 'гараг'",
            long: "y 'оны' MMMM'ын' d",
            medium: "y 'оны' MMM'ын' d",
            short: "y.MM.dd"
        },
        days: {
            format: {
                abbreviated: [
                    "Ня",
                    "Да",
                    "Мя",
                    "Лх",
                    "Пү",
                    "Ба",
                    "Бя"
                ],
                narrow: [
                    "Ня",
                    "Да",
                    "Мя",
                    "Лх",
                    "Пү",
                    "Ба",
                    "Бя"
                ],
                short: [
                    "Ня",
                    "Да",
                    "Мя",
                    "Лх",
                    "Пү",
                    "Ба",
                    "Бя"
                ],
                wide: [
                    "ням",
                    "даваа",
                    "мягмар",
                    "лхагва",
                    "пүрэв",
                    "баасан",
                    "бямба"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Ня",
                    "Да",
                    "Мя",
                    "Лх",
                    "Пү",
                    "Ба",
                    "Бя"
                ],
                narrow: [
                    "Ня",
                    "Да",
                    "Мя",
                    "Лх",
                    "Пү",
                    "Ба",
                    "Бя"
                ],
                short: [
                    "Ня",
                    "Да",
                    "Мя",
                    "Лх",
                    "Пү",
                    "Ба",
                    "Бя"
                ],
                wide: [
                    "Ням",
                    "Даваа",
                    "Мягмар",
                    "Лхагва",
                    "Пүрэв",
                    "Баасан",
                    "Бямба"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "1-р сар",
                    "2-р сар",
                    "3-р сар",
                    "4-р сар",
                    "5-р сар",
                    "6-р сар",
                    "7-р сар",
                    "8-р сар",
                    "9-р сар",
                    "10-р сар",
                    "11-р сар",
                    "12-р сар"
                ],
                narrow: [
                    "I",
                    "II",
                    "III",
                    "IV",
                    "V",
                    "VI",
                    "VII",
                    "VIII",
                    "IX",
                    "X",
                    "XI",
                    "XII"
                ],
                wide: [
                    "нэгдүгээр сар",
                    "хоёрдугаар сар",
                    "гуравдугаар сар",
                    "дөрөвдүгээр сар",
                    "тавдугаар сар",
                    "зургаадугаар сар",
                    "долоодугаар сар",
                    "наймдугаар сар",
                    "есдүгээр сар",
                    "аравдугаар сар",
                    "арван нэгдүгээр сар",
                    "арван хоёрдугаар сар"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1-р сар",
                    "2-р сар",
                    "3-р сар",
                    "4-р сар",
                    "5-р сар",
                    "6-р сар",
                    "7-р сар",
                    "8-р сар",
                    "9-р сар",
                    "10-р сар",
                    "11-р сар",
                    "12-р сар"
                ],
                narrow: [
                    "I",
                    "II",
                    "III",
                    "IV",
                    "V",
                    "VI",
                    "VII",
                    "VIII",
                    "IX",
                    "X",
                    "XI",
                    "XII"
                ],
                wide: [
                    "Нэгдүгээр сар",
                    "Хоёрдугаар сар",
                    "Гуравдугаар сар",
                    "Дөрөвдүгээр сар",
                    "Тавдугаар сар",
                    "Зургаадугаар сар",
                    "Долоодугаар сар",
                    "Наймдугаар сар",
                    "Есдүгээр сар",
                    "Аравдугаар сар",
                    "Арван нэгдүгээр сар",
                    "Арван хоёрдугаар сар"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "I улирал",
                    "II улирал",
                    "III улирал",
                    "IV улирал"
                ],
                narrow: [
                    "I",
                    "II",
                    "III",
                    "IV"
                ],
                wide: [
                    "1-р улирал",
                    "2-р улирал",
                    "3-р улирал",
                    "4-р улирал"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "I улирал",
                    "II улирал",
                    "III улирал",
                    "IV улирал"
                ],
                narrow: [
                    "I",
                    "II",
                    "III",
                    "IV"
                ],
                wide: [
                    "1-р улирал",
                    "2-р улирал",
                    "3-р улирал",
                    "4-р улирал"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "шөнө дунд",
                    am: "ү.ө.",
                    noon: "үд дунд",
                    pm: "ү.х.",
                    morning1: "өглөө",
                    afternoon1: "өдөр",
                    evening1: "орой",
                    night1: "шөнө"
                },
                narrow: {
                    midnight: "шөнө дунд",
                    am: "ү.ө.",
                    noon: "үд дунд",
                    pm: "ү.х.",
                    morning1: "өглөө",
                    afternoon1: "өдөр",
                    evening1: "орой",
                    night1: "шөнө"
                },
                wide: {
                    midnight: "шөнө дунд",
                    am: "ү.ө.",
                    noon: "үд дунд",
                    pm: "ү.х.",
                    morning1: "өглөө",
                    afternoon1: "өдөр",
                    evening1: "орой",
                    night1: "шөнө"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "шөнө дунд",
                    am: "ү.ө.",
                    noon: "үд дунд",
                    pm: "ү.х.",
                    morning1: "өглөө",
                    afternoon1: "өдөр",
                    evening1: "орой",
                    night1: "шөнө"
                },
                narrow: {
                    midnight: "шөнө дунд",
                    am: "ү.ө.",
                    noon: "үд дунд",
                    pm: "ү.х.",
                    morning1: "өглөө",
                    afternoon1: "өдөр",
                    evening1: "орой",
                    night1: "шөнө"
                },
                wide: {
                    midnight: "шөнө дунд",
                    am: "ү.ө.",
                    noon: "үд дунд",
                    pm: "ү.х.",
                    morning1: "өглөө",
                    afternoon1: "өдөр",
                    evening1: "орой",
                    night1: "шөнө"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "манай эриний өмнөх",
                    "1": "манай эриний",
                    "0-alt-variant": "НТӨ",
                    "1-alt-variant": "НТ"
                },
                abbreviated: {
                    "0": "МЭӨ",
                    "1": "МЭ",
                    "0-alt-variant": "НТӨ",
                    "1-alt-variant": "НТ"
                },
                narrow: {
                    "0": "МЭӨ",
                    "1": "МЭ",
                    "0-alt-variant": "НТӨ",
                    "1-alt-variant": "НТ"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "эрин",
                short: "эрин",
                narrow: "эрин"
            },
            year: {
                wide: "жил",
                short: "жил",
                narrow: "жил"
            },
            quarter: {
                wide: "улирал",
                short: "улирал",
                narrow: "улирал"
            },
            month: {
                wide: "сар",
                short: "сар",
                narrow: "сар"
            },
            week: {
                wide: "долоо хоног",
                short: "7 хоног",
                narrow: "7 хоног"
            },
            weekOfMonth: {
                wide: "сарын долоо хоног",
                short: "сарын 7 хоног",
                narrow: "сарын 7 хоног"
            },
            day: {
                wide: "өдөр",
                short: "өдөр",
                narrow: "өдөр"
            },
            dayOfYear: {
                wide: "жилийн хоног",
                short: "жилийн хоног",
                narrow: "жилийн хоног"
            },
            weekday: {
                wide: "гараг",
                short: "гараг",
                narrow: "гараг"
            },
            weekdayOfMonth: {
                wide: "ажлын өдөр",
                short: "ажлын өдөр",
                narrow: "ажлын өдөр"
            },
            dayperiod: {
                short: "ү.ө./ү.х.",
                wide: "ү.ө./ү.х.",
                narrow: "ү.ө./ү.х."
            },
            hour: {
                wide: "цаг",
                short: "ц",
                narrow: "ц"
            },
            minute: {
                wide: "минут",
                short: "мин",
                narrow: "мин"
            },
            second: {
                wide: "секунд",
                short: "сек",
                narrow: "сек"
            },
            zone: {
                wide: "цагийн бүс",
                short: "цагийн бүс",
                narrow: "цагийн бүс"
            },
            millisecond: {
                narrow: "мс",
                short: "мс",
                wide: "миллисекунд"
            }
        }
    },
    firstDay: 1
});

