/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "mni",
    likelySubtags: {
        mni: "mni-Beng-IN"
    },
    identity: {
        language: "mni"
    },
    territory: "IN",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "MMMM d, y, EEEE",
            m: "MMM d",
            M: "MMMM d",
            y: "MMM y",
            Y: "MMMM y",
            F: "MMMM d, y, EEEE h:mm:ss a",
            g: "d/M/y h:mm a",
            G: "d/M/y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} গী {0} দা",
            long: "{1} গী {0} দা",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG dd-MM-y",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "d/M, E",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "MMM d, E",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "d/M/y, E",
                yMMM: "MMM y",
                yMMMd: "MMM d, y",
                yMMMEd: "MMM d, y, E",
                yMMMM: "MMMM y",
                yQQQ: "y QQQ",
                yQQQQ: "y QQQQ",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "MMMM d, y, EEEE",
            long: "MMMM d, y",
            medium: "MMM d, y",
            short: "d/M/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "নোংমাইজিং",
                    "নিংথৌকাবা",
                    "লৈবাকপোকপা",
                    "য়ুমশকৈশা",
                    "শগোলশেন",
                    "ইরাই",
                    "থাংজ"
                ],
                narrow: [
                    "নোং",
                    "নিং",
                    "লৈবা",
                    "য়ুম",
                    "শগো",
                    "ইরা",
                    "থাং"
                ],
                short: [
                    "নোংমাইজিং",
                    "নিংথৌকাবা",
                    "লৈবাকপোকপা",
                    "য়ুমশকৈশা",
                    "শগোলশেন",
                    "ইরাই",
                    "থাংজ"
                ],
                wide: [
                    "নোংমাইজিং",
                    "নিংথৌকাবা",
                    "লৈবাকপোকপা",
                    "য়ুমশকৈশা",
                    "শগোলশেন",
                    "ইরাই",
                    "থাংজ"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "নোংমাইজিং",
                    "নিংথৌকাবা",
                    "লৈবাকপোকপা",
                    "য়ুমশকৈশা",
                    "শগোলশেন",
                    "ইরাই",
                    "থাংজ"
                ],
                narrow: [
                    "নো",
                    "নিং",
                    "লৈ",
                    "য়ুম",
                    "শগ",
                    "ইরা",
                    "থাং"
                ],
                short: [
                    "নোংমাইজিং",
                    "নিংথৌকাবা",
                    "লৈবাকপোকপা",
                    "য়ুমশকৈশা",
                    "শগোলশেন",
                    "ইরাই",
                    "থাংজ"
                ],
                wide: [
                    "নোংমাইজিং",
                    "নিংথৌকাবা",
                    "লৈবাকপোকপা",
                    "য়ুমশকৈশা",
                    "শগোলশেন",
                    "ইরাই",
                    "থাংজ"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "জানুৱারি",
                    "ফেব্রুৱারি",
                    "মার্চ",
                    "এপ্রিল",
                    "মে",
                    "জুন",
                    "জুলাই",
                    "আগস্ট",
                    "সেপ্টেম্বর",
                    "ওক্টোবর",
                    "নভেম্বর",
                    "ডিসেম্বর"
                ],
                narrow: [
                    "জা",
                    "ফে",
                    "মার",
                    "এপ",
                    "মে",
                    "জুন",
                    "জুল",
                    "আ",
                    "সে",
                    "ওক",
                    "নব",
                    "ডি"
                ],
                wide: [
                    "জানুৱারি",
                    "ফেব্রুৱারি",
                    "মার্চ",
                    "এপ্রিল",
                    "মে",
                    "জুন",
                    "জুলাই",
                    "আগস্ট",
                    "সেপ্টেম্বর",
                    "ওক্টোবর",
                    "নভেম্বর",
                    "ডিসেম্বর"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "জানু",
                    "ফেব্রু",
                    "মার",
                    "এপ্রি",
                    "মে",
                    "জুন",
                    "জুলা",
                    "আগ",
                    "সেপ্ট",
                    "ওক্টো",
                    "নভে",
                    "ডিসে"
                ],
                narrow: [
                    "জা",
                    "ফে",
                    "মার",
                    "এপ",
                    "মে",
                    "জুন",
                    "জুল",
                    "আ",
                    "সে",
                    "ও",
                    "নব",
                    "ডি"
                ],
                wide: [
                    "জানুৱারি",
                    "ফেব্রুৱারি",
                    "মার্চ",
                    "এপ্রিল",
                    "মে",
                    "জুন",
                    "জুলাই",
                    "ওগষ্ট",
                    "সেপ্টেম্বর",
                    "ওক্টোবর",
                    "নবেম্বর",
                    "ডিসেম্বর"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "অহানবা মসুং",
                    "অনীশুবা মসুং",
                    "অহুমশুবা মসুং",
                    "মরীশুবা মসুং"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "অহানবা মসুং",
                    "অনীশুবা মসুং",
                    "অহুমশুবা মসুং",
                    "মরীশুবা মসুং"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "অহানবা মসুং",
                    "অনীশুবা মসুং",
                    "অহুমশুবা মসুং",
                    "মরীশুবা মসুং"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "অহানবা মসুং",
                    "অনীশুবা মসুং",
                    "অহুমশুবা মসুং",
                    "মরীশুবা মসুং"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "নুমাং",
                    pm: "PM"
                },
                narrow: {
                    am: "নুমাং",
                    pm: "PM"
                },
                wide: {
                    am: "এ এম",
                    pm: "পি এম"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "নুমাং",
                    pm: "PM"
                },
                narrow: {
                    am: "নুমাং",
                    pm: "PM"
                },
                wide: {
                    am: "নুমাং",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "খৃ: মমাং",
                    "1": "খৃ: মতুং",
                    "0-alt-variant": "বি সি ই",
                    "1-alt-variant": "সি ই"
                },
                abbreviated: {
                    "0": "খৃ: মমাং",
                    "1": "খৃ: মতুং",
                    "0-alt-variant": "বি সি ই",
                    "1-alt-variant": "সি ই"
                },
                narrow: {
                    "0": "খৃ: মমাং",
                    "1": "খৃ: মতুং",
                    "0-alt-variant": "বি সি ই",
                    "1-alt-variant": "সি ই"
                }
            }
        },
        gmtFormat: "জি এম টি {0}",
        gmtZeroFormat: "জি এম টি",
        dateFields: {
            era: {
                wide: "চক",
                short: "চক",
                narrow: "চক"
            },
            year: {
                wide: "চহী",
                short: "চহী",
                narrow: "চহী"
            },
            quarter: {
                wide: "মসুং",
                short: "মসুং",
                narrow: "মসুং"
            },
            month: {
                wide: "থা",
                short: "থা",
                narrow: "থা"
            },
            week: {
                wide: "চয়োল",
                short: "চয়োল",
                narrow: "চয়োল"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "নুমিৎ",
                short: "নুমিৎ",
                narrow: "নুমিৎ"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "চয়োলগী নুমিৎ",
                short: "চয়োলগী নুমিৎ",
                narrow: "চয়োলগী নুমিৎ"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "এ এম/পি এম",
                wide: "এ এম/পি এম",
                narrow: "এ এম/পি এম"
            },
            hour: {
                wide: "পুং",
                short: "পুং",
                narrow: "পুং"
            },
            minute: {
                wide: "মিনট",
                short: "মিনট",
                narrow: "মিনট"
            },
            second: {
                wide: "সেকেণ্ড",
                short: "সেকেণ্ড",
                narrow: "সেকেণ্ড"
            },
            zone: {
                wide: "টাইম জোন",
                short: "টাইম জোন",
                narrow: "টাইম জোন"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

