/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "mr",
    likelySubtags: {
        mr: "mr-Deva-IN"
    },
    identity: {
        language: "mr"
    },
    territory: "IN",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE, d MMMM, y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d MMMM, y h:mm:ss a",
            g: "d/M/y h:mm a",
            G: "d/M/y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} रोजी {0}",
            long: "{1} रोजी {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "B h",
                Bhm: "B h:mm",
                Bhms: "B h:mm:ss",
                d: "d",
                E: "ccc",
                EBhm: "E B h:mm",
                EBhms: "E B h:mm:ss",
                Ed: "d E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "d/M/y GGGGG",
                GyMMM: "MMM G y",
                GyMMMd: "d MMM, G y",
                GyMMMEd: "E, d MMM, G y",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "H:mm",
                hms: "h:mm:ss a",
                Hms: "H:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E, d/M",
                MMdd: "dd-MM",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E, d MMM",
                MMMMd: "d MMMM",
                "MMMMW-count-one": "MMMM चा W रा आठवडा",
                "MMMMW-count-other": "MMMM चा W रा आठवडा",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E, d/M/y",
                yMM: "MM-y",
                yMMM: "MMM y",
                yMMMd: "d MMM, y",
                yMMMEd: "E, d, MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "Y चा w रा आठवडा",
                "yw-count-other": "Y चा w रा आठवडा"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "EEEE, d MMMM, y",
            long: "d MMMM, y",
            medium: "d MMM, y",
            short: "d/M/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "रवि",
                    "सोम",
                    "मंगळ",
                    "बुध",
                    "गुरु",
                    "शुक्र",
                    "शनि"
                ],
                narrow: [
                    "र",
                    "सो",
                    "मं",
                    "बु",
                    "गु",
                    "शु",
                    "श"
                ],
                short: [
                    "र",
                    "सो",
                    "मं",
                    "बु",
                    "गु",
                    "शु",
                    "श"
                ],
                wide: [
                    "रविवार",
                    "सोमवार",
                    "मंगळवार",
                    "बुधवार",
                    "गुरुवार",
                    "शुक्रवार",
                    "शनिवार"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "रवि",
                    "सोम",
                    "मंगळ",
                    "बुध",
                    "गुरु",
                    "शुक्र",
                    "शनि"
                ],
                narrow: [
                    "र",
                    "सो",
                    "मं",
                    "बु",
                    "गु",
                    "शु",
                    "श"
                ],
                short: [
                    "र",
                    "सो",
                    "मं",
                    "बु",
                    "गु",
                    "शु",
                    "श"
                ],
                wide: [
                    "रविवार",
                    "सोमवार",
                    "मंगळवार",
                    "बुधवार",
                    "गुरुवार",
                    "शुक्रवार",
                    "शनिवार"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "जाने",
                    "फेब्रु",
                    "मार्च",
                    "एप्रि",
                    "मे",
                    "जून",
                    "जुलै",
                    "ऑग",
                    "सप्टें",
                    "ऑक्टो",
                    "नोव्हें",
                    "डिसें"
                ],
                narrow: [
                    "जा",
                    "फे",
                    "मा",
                    "ए",
                    "मे",
                    "जू",
                    "जु",
                    "ऑ",
                    "स",
                    "ऑ",
                    "नो",
                    "डि"
                ],
                wide: [
                    "जानेवारी",
                    "फेब्रुवारी",
                    "मार्च",
                    "एप्रिल",
                    "मे",
                    "जून",
                    "जुलै",
                    "ऑगस्ट",
                    "सप्टेंबर",
                    "ऑक्टोबर",
                    "नोव्हेंबर",
                    "डिसेंबर"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "जाने",
                    "फेब्रु",
                    "मार्च",
                    "एप्रि",
                    "मे",
                    "जून",
                    "जुलै",
                    "ऑग",
                    "सप्टें",
                    "ऑक्टो",
                    "नोव्हें",
                    "डिसें"
                ],
                narrow: [
                    "जा",
                    "फे",
                    "मा",
                    "ए",
                    "मे",
                    "जू",
                    "जु",
                    "ऑ",
                    "स",
                    "ऑ",
                    "नो",
                    "डि"
                ],
                wide: [
                    "जानेवारी",
                    "फेब्रुवारी",
                    "मार्च",
                    "एप्रिल",
                    "मे",
                    "जून",
                    "जुलै",
                    "ऑगस्ट",
                    "सप्टेंबर",
                    "ऑक्टोबर",
                    "नोव्हेंबर",
                    "डिसेंबर"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "ति१",
                    "ति२",
                    "ति३",
                    "ति४"
                ],
                narrow: [
                    "१",
                    "२",
                    "३",
                    "४"
                ],
                wide: [
                    "प्रथम तिमाही",
                    "द्वितीय तिमाही",
                    "तृतीय तिमाही",
                    "चतुर्थ तिमाही"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ति१",
                    "ति२",
                    "ति३",
                    "ति४"
                ],
                narrow: [
                    "१",
                    "२",
                    "३",
                    "४"
                ],
                wide: [
                    "प्रथम तिमाही",
                    "द्वितीय तिमाही",
                    "तृतीय तिमाही",
                    "चतुर्थ तिमाही"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "मध्यरात्र",
                    am: "AM",
                    noon: "मध्यान्ह",
                    pm: "PM",
                    morning1: "पहाट",
                    morning2: "सकाळ",
                    afternoon1: "दुपार",
                    evening1: "संध्याकाळ",
                    evening2: "सायंकाळ",
                    night1: "रात्र"
                },
                narrow: {
                    midnight: "म.रा.",
                    am: "a",
                    noon: "दु",
                    pm: "p",
                    morning1: "प",
                    morning2: "स",
                    afternoon1: "दु",
                    evening1: "सं",
                    evening2: "सा",
                    night1: "रा"
                },
                wide: {
                    midnight: "मध्यरात्र",
                    am: "AM",
                    noon: "मध्यान्ह",
                    pm: "PM",
                    morning1: "पहाट",
                    morning2: "सकाळ",
                    afternoon1: "दुपार",
                    evening1: "संध्याकाळ",
                    evening2: "सायंकाळ",
                    night1: "रात्र"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "मध्यरात्र",
                    am: "AM",
                    noon: "मध्यान्ह",
                    pm: "PM",
                    morning1: "पहाट",
                    morning2: "सकाळ",
                    afternoon1: "दुपार",
                    evening1: "संध्याकाळ",
                    evening2: "सायंकाळ",
                    night1: "रात्र"
                },
                narrow: {
                    midnight: "म.रा.",
                    am: "AM",
                    noon: "म",
                    pm: "PM",
                    morning1: "प",
                    morning2: "स",
                    afternoon1: "दु",
                    evening1: "सं",
                    evening2: "सा",
                    night1: "रात्र"
                },
                wide: {
                    midnight: "मध्यरात्र",
                    am: "AM",
                    noon: "मध्यान्ह",
                    pm: "PM",
                    morning1: "पहाट",
                    morning2: "सकाळ",
                    afternoon1: "दुपार",
                    evening1: "संध्याकाळ",
                    evening2: "सायंकाळ",
                    night1: "रात्र"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "ईसवीसनपूर्व",
                    "1": "ईसवीसन",
                    "0-alt-variant": "ईसापूर्व युग",
                    "1-alt-variant": "ख्रिस्तयुग"
                },
                abbreviated: {
                    "0": "इ. स. पू.",
                    "1": "इ. स.",
                    "0-alt-variant": "इ. स. पू. युग",
                    "1-alt-variant": "ख्रि. यु."
                },
                narrow: {
                    "0": "इ. स. पू.",
                    "1": "इ. स.",
                    "0-alt-variant": "इ. स. पू. युग",
                    "1-alt-variant": "ख्रि. यु."
                }
            }
        },
        gmtFormat: "[GMT]{0}",
        gmtZeroFormat: "[GMT]",
        dateFields: {
            era: {
                wide: "युग",
                short: "युग",
                narrow: "युग"
            },
            year: {
                wide: "वर्ष",
                short: "वर्ष",
                narrow: "वर्ष"
            },
            quarter: {
                wide: "तिमाही",
                short: "तिमाही",
                narrow: "तिमाही"
            },
            month: {
                wide: "महिना",
                short: "महिना",
                narrow: "महिना"
            },
            week: {
                wide: "आठवडा",
                short: "आठवडा",
                narrow: "आठवडा"
            },
            weekOfMonth: {
                wide: "महिन्याचा आठवडा",
                short: "महिन्याचा आठ.",
                narrow: "महिन्याचा आठ."
            },
            day: {
                wide: "दिवस",
                short: "दिवस",
                narrow: "दिवस"
            },
            dayOfYear: {
                wide: "वर्षातील दिवस",
                short: "वर्षातील दिवस",
                narrow: "वर्षातील दिवस"
            },
            weekday: {
                wide: "आठवड्याचा दिवस",
                short: "आठवड्याचा दिवस",
                narrow: "आठवड्याचा दिवस"
            },
            weekdayOfMonth: {
                wide: "महिन्यातील साप्ताहिक दिवस",
                short: "महिन्यातील साप्ता. दिवस",
                narrow: "महिन्यातील साप्ता. दिवस"
            },
            dayperiod: {
                short: "AM/PM",
                wide: "AM/PM",
                narrow: "AM/PM"
            },
            hour: {
                wide: "तास",
                short: "तास",
                narrow: "तास"
            },
            minute: {
                wide: "मिनिट",
                short: "मि.",
                narrow: "मि."
            },
            second: {
                wide: "सेकंद",
                short: "से.",
                narrow: "से."
            },
            zone: {
                wide: "वेळ क्षेत्र",
                short: "क्षेत्र",
                narrow: "क्षेत्र"
            },
            millisecond: {
                narrow: "मिलिसे",
                short: "मिलिसे",
                wide: "मिलिसेकंद"
            }
        }
    },
    firstDay: 0
});

