/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ms-BN",
    likelySubtags: {
        ms: "ms-Latn-MY"
    },
    identity: {
        language: "ms",
        territory: "BN"
    },
    territory: "BN",
    calendar: {
        patterns: {
            d: "d/MM/y",
            D: "dd MMMM y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "dd MMMM y h:mm:ss a",
            g: "d/M/y h:mm a",
            G: "d/M/y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "MMM y G",
                GyMMMd: "d MMM y G",
                GyMMMEd: "E, d MMM y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d-M",
                MEd: "E, d-M",
                MMdd: "dd/MM",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E, d MMM",
                MMMMd: "d MMMM",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M-y",
                yMd: "d/M/y",
                yMEd: "E, d/M/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E, d MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "dd MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "d/MM/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "Ahd",
                    "Isn",
                    "Sel",
                    "Rab",
                    "Kha",
                    "Jum",
                    "Sab"
                ],
                narrow: [
                    "A",
                    "I",
                    "S",
                    "R",
                    "K",
                    "J",
                    "S"
                ],
                short: [
                    "Ah",
                    "Is",
                    "Se",
                    "Ra",
                    "Kh",
                    "Ju",
                    "Sa"
                ],
                wide: [
                    "Ahad",
                    "Isnin",
                    "Selasa",
                    "Rabu",
                    "Khamis",
                    "Jumaat",
                    "Sabtu"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Ahd",
                    "Isn",
                    "Sel",
                    "Rab",
                    "Kha",
                    "Jum",
                    "Sab"
                ],
                narrow: [
                    "A",
                    "I",
                    "S",
                    "R",
                    "K",
                    "J",
                    "S"
                ],
                short: [
                    "Ah",
                    "Is",
                    "Se",
                    "Ra",
                    "Kh",
                    "Ju",
                    "Sa"
                ],
                wide: [
                    "Ahad",
                    "Isnin",
                    "Selasa",
                    "Rabu",
                    "Khamis",
                    "Jumaat",
                    "Sabtu"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Jan",
                    "Feb",
                    "Mac",
                    "Apr",
                    "Mei",
                    "Jun",
                    "Jul",
                    "Ogo",
                    "Sep",
                    "Okt",
                    "Nov",
                    "Dis"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "O",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Januari",
                    "Februari",
                    "Mac",
                    "April",
                    "Mei",
                    "Jun",
                    "Julai",
                    "Ogos",
                    "September",
                    "Oktober",
                    "November",
                    "Disember"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Jan",
                    "Feb",
                    "Mac",
                    "Apr",
                    "Mei",
                    "Jun",
                    "Jul",
                    "Ogo",
                    "Sep",
                    "Okt",
                    "Nov",
                    "Dis"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "O",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Januari",
                    "Februari",
                    "Mac",
                    "April",
                    "Mei",
                    "Jun",
                    "Julai",
                    "Ogos",
                    "September",
                    "Oktober",
                    "November",
                    "Disember"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "S1",
                    "S2",
                    "S3",
                    "S4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Suku pertama",
                    "Suku Ke-2",
                    "Suku Ke-3",
                    "Suku Ke-4"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "S1",
                    "S2",
                    "S3",
                    "S4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Suku pertama",
                    "Suku Ke-2",
                    "Suku Ke-3",
                    "Suku Ke-4"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "PG",
                    pm: "PTG",
                    morning1: "pagi",
                    morning2: "pagi",
                    afternoon1: "tengah hari",
                    evening1: "petang",
                    night1: "malam"
                },
                narrow: {
                    am: "a",
                    pm: "p",
                    morning1: "pagi",
                    morning2: "pagi",
                    afternoon1: "tengah hari",
                    evening1: "petang",
                    night1: "malam"
                },
                wide: {
                    am: "PG",
                    pm: "PTG",
                    morning1: "tengah malam",
                    morning2: "pagi",
                    afternoon1: "tengah hari",
                    evening1: "petang",
                    night1: "malam"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "PG",
                    pm: "PTG",
                    morning1: "tengah malam",
                    morning2: "pagi",
                    afternoon1: "tengah hari",
                    evening1: "petang",
                    night1: "malam"
                },
                narrow: {
                    am: "a",
                    pm: "p",
                    morning1: "pagi",
                    morning2: "pagi",
                    afternoon1: "tengah hari",
                    evening1: "petang",
                    night1: "malam"
                },
                wide: {
                    am: "PG",
                    pm: "PTG",
                    morning1: "tengah malam",
                    morning2: "pagi",
                    afternoon1: "tengah hari",
                    evening1: "petang",
                    night1: "malam"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "S.M.",
                    "1": "TM",
                    "0-alt-variant": "S.M.",
                    "1-alt-variant": "TM"
                },
                abbreviated: {
                    "0": "S.M.",
                    "1": "TM",
                    "0-alt-variant": "S.M.",
                    "1-alt-variant": "TM"
                },
                narrow: {
                    "0": "S.M.",
                    "1": "TM",
                    "0-alt-variant": "S.M.",
                    "1-alt-variant": "TM"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "era",
                short: "era",
                narrow: "era"
            },
            year: {
                wide: "tahun",
                short: "thn",
                narrow: "thn"
            },
            quarter: {
                wide: "suku tahun",
                short: "suku",
                narrow: "suku"
            },
            month: {
                wide: "bulan",
                short: "bln",
                narrow: "bln"
            },
            week: {
                wide: "minggu",
                short: "mgu",
                narrow: "mgu"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "hari",
                short: "hari",
                narrow: "hari"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Hari dalam Minggu",
                short: "Hari dalam Minggu",
                narrow: "Hari dalam Minggu"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "PG/PTG",
                wide: "PG/PTG",
                narrow: "PG/PTG"
            },
            hour: {
                wide: "jam",
                short: "jam",
                narrow: "jam"
            },
            minute: {
                wide: "minit",
                short: "min",
                narrow: "min"
            },
            second: {
                wide: "saat",
                short: "saat",
                narrow: "saat"
            },
            zone: {
                wide: "zon waktu",
                short: "zon",
                narrow: "zon"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "milisaat"
            }
        }
    },
    firstDay: 1
});

