/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "mt",
    likelySubtags: {
        mt: "mt-Latn-MT"
    },
    identity: {
        language: "mt"
    },
    territory: "MT",
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, d 'ta'’ MMMM y",
            m: "MMM d",
            M: "d 'ta'’ MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d 'ta'’ MMMM y HH:mm:ss",
            g: "M/d/y HH:mm",
            G: "M/d/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "MMM y G",
                GyMMMd: "d MMM, y G",
                GyMMMEd: "E, d 'ta'’ MMM, y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "MM-dd",
                MEd: "E, M-d",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, d 'ta'’ MMM",
                MMMMd: "d 'ta'’ MMMM",
                "MMMMW-count-one": "W 'ġimgħa' 'ta''' MMMM",
                "MMMMW-count-few": "W 'ġimgħa' 'ta''' MMMM",
                "MMMMW-count-many": "W 'ġimgħa' 'ta''' MMMM",
                "MMMMW-count-other": "W 'ġimgħa' 'ta''' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "y-MM",
                yMd: "M/d/y",
                yMEd: "E, d/M/y",
                yMMM: "MMM y",
                yMMMd: "d 'ta'’ MMM, y",
                yMMMEd: "E, d 'ta'’ MMM, y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ - y",
                yQQQQ: "QQQQ - y",
                "yw-count-one": "w 'ġimgħa' 'ta''' Y",
                "yw-count-few": "w 'ġimgħa' 'ta''' Y",
                "yw-count-many": "w 'ġimgħa' 'ta''' Y",
                "yw-count-other": "w 'ġimgħa' 'ta''' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d 'ta'’ MMMM y",
            long: "d 'ta'’ MMMM y",
            medium: "dd MMM y",
            short: "dd/MM/y"
        },
        days: {
            format: {
                abbreviated: [
                    "Ħad",
                    "Tne",
                    "Tli",
                    "Erb",
                    "Ħam",
                    "Ġim",
                    "Sib"
                ],
                narrow: [
                    "Ħd",
                    "T",
                    "Tl",
                    "Er",
                    "Ħm",
                    "Ġm",
                    "Sb"
                ],
                short: [
                    "Ħad",
                    "Tne",
                    "Tli",
                    "Erb",
                    "Ħam",
                    "Ġim",
                    "Sib"
                ],
                wide: [
                    "Il-Ħadd",
                    "It-Tnejn",
                    "It-Tlieta",
                    "L-Erbgħa",
                    "Il-Ħamis",
                    "Il-Ġimgħa",
                    "Is-Sibt"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Ħad",
                    "Tne",
                    "Tli",
                    "Erb",
                    "Ħam",
                    "Ġim",
                    "Sib"
                ],
                narrow: [
                    "Ħd",
                    "Tn",
                    "Tl",
                    "Er",
                    "Ħm",
                    "Ġm",
                    "Sb"
                ],
                short: [
                    "Ħad",
                    "Tne",
                    "Tli",
                    "Erb",
                    "Ħam",
                    "Ġim",
                    "Sib"
                ],
                wide: [
                    "Il-Ħadd",
                    "It-Tnejn",
                    "It-Tlieta",
                    "L-Erbgħa",
                    "Il-Ħamis",
                    "Il-Ġimgħa",
                    "Is-Sibt"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Jan",
                    "Fra",
                    "Mar",
                    "Apr",
                    "Mej",
                    "Ġun",
                    "Lul",
                    "Aww",
                    "Set",
                    "Ott",
                    "Nov",
                    "Diċ"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "Ġ",
                    "L",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Jannar",
                    "Frar",
                    "Marzu",
                    "April",
                    "Mejju",
                    "Ġunju",
                    "Lulju",
                    "Awwissu",
                    "Settembru",
                    "Ottubru",
                    "Novembru",
                    "Diċembru"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Jan",
                    "Fra",
                    "Mar",
                    "Apr",
                    "Mej",
                    "Ġun",
                    "Lul",
                    "Aww",
                    "Set",
                    "Ott",
                    "Nov",
                    "Diċ"
                ],
                narrow: [
                    "Jn",
                    "Fr",
                    "Mz",
                    "Ap",
                    "Mj",
                    "Ġn",
                    "Lj",
                    "Aw",
                    "St",
                    "Ob",
                    "Nv",
                    "Dċ"
                ],
                wide: [
                    "Jannar",
                    "Frar",
                    "Marzu",
                    "April",
                    "Mejju",
                    "Ġunju",
                    "Lulju",
                    "Awwissu",
                    "Settembru",
                    "Ottubru",
                    "Novembru",
                    "Diċembru"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1el kwart",
                    "2ni kwart",
                    "3et kwart",
                    "4ba’ kwart"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1el kwart",
                    "2ni kwart",
                    "3et kwart",
                    "4ba’ kwart"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "am",
                    pm: "pm"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "am",
                    pm: "pm"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Qabel Kristu",
                    "1": "Wara Kristu",
                    "0-alt-variant": "QEK",
                    "1-alt-variant": "EK"
                },
                abbreviated: {
                    "0": "QK",
                    "1": "WK",
                    "0-alt-variant": "QEK",
                    "1-alt-variant": "EK"
                },
                narrow: {
                    "0": "QK",
                    "1": "WK",
                    "0-alt-variant": "QEK",
                    "1-alt-variant": "EK"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Era",
                short: "Era",
                narrow: "Era"
            },
            year: {
                wide: "Sena",
                short: "Sena",
                narrow: "Sena"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "l-ewwel kwart tas-sena, it-tieni kwart tas-sena, it-tielet kwart tas-sena, ir-raba’ kwart tas-sena"
            },
            month: {
                wide: "xahar",
                short: "Xahar",
                narrow: "Xahar"
            },
            week: {
                wide: "ġimgħa",
                short: "ġimgħa",
                narrow: "ġimgħa"
            },
            weekOfMonth: {
                wide: "ġimgħa tax-xahar",
                short: "ġimgħa tax-xahar",
                narrow: "ġimgħa tax-xahar"
            },
            day: {
                wide: "jum",
                short: "Jum",
                narrow: "Jum"
            },
            dayOfYear: {
                wide: "jum tas-sena",
                short: "jum tas-sena",
                narrow: "jum tas-sena"
            },
            weekday: {
                wide: "jum tal-ġimgħa",
                short: "jum tal-ġimgħa",
                narrow: "jum tal-ġimgħa"
            },
            weekdayOfMonth: {
                wide: "jum tax-xahar",
                short: "jum tax-xahar",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "AM/PM",
                wide: "AM/PM",
                narrow: "AM/PM"
            },
            hour: {
                wide: "siegħa",
                short: "siegħa",
                narrow: "siegħa"
            },
            minute: {
                wide: "minuta",
                short: "min.",
                narrow: "m"
            },
            second: {
                wide: "sekonda",
                short: "sek.",
                narrow: "s"
            },
            zone: {
                wide: "żona tal-ħin",
                short: "żona",
                narrow: "żona"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "millisekonda"
            }
        }
    },
    firstDay: 0
});

