/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "mua",
    likelySubtags: {
        mua: "mua-Latn-CM"
    },
    identity: {
        language: "mua"
    },
    territory: "CM",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE d MMMM y",
            m: "d MMM",
            M: "MMMM d",
            y: "MMM y",
            Y: "y MMMM",
            F: "EEEE d MMMM y HH:mm:ss",
            g: "d/M/y HH:mm",
            G: "d/M/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E d/M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E d MMM",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "m:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E d/M/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E d MMM y",
                yMMMM: "y MMMM",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "d/M/y"
        },
        days: {
            format: {
                abbreviated: [
                    "Cya",
                    "Cla",
                    "Czi",
                    "Cko",
                    "Cka",
                    "Cga",
                    "Cze"
                ],
                narrow: [
                    "Y",
                    "L",
                    "Z",
                    "O",
                    "A",
                    "G",
                    "E"
                ],
                short: [
                    "Cya",
                    "Cla",
                    "Czi",
                    "Cko",
                    "Cka",
                    "Cga",
                    "Cze"
                ],
                wide: [
                    "Com’yakke",
                    "Comlaaɗii",
                    "Comzyiiɗii",
                    "Comkolle",
                    "Comkaldǝɓlii",
                    "Comgaisuu",
                    "Comzyeɓsuu"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Cya",
                    "Cla",
                    "Czi",
                    "Cko",
                    "Cka",
                    "Cga",
                    "Cze"
                ],
                narrow: [
                    "Y",
                    "L",
                    "Z",
                    "O",
                    "A",
                    "G",
                    "E"
                ],
                short: [
                    "Cya",
                    "Cla",
                    "Czi",
                    "Cko",
                    "Cka",
                    "Cga",
                    "Cze"
                ],
                wide: [
                    "Com’yakke",
                    "Comlaaɗii",
                    "Comzyiiɗii",
                    "Comkolle",
                    "Comkaldǝɓlii",
                    "Comgaisuu",
                    "Comzyeɓsuu"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "FLO",
                    "CLA",
                    "CKI",
                    "FMF",
                    "MAD",
                    "MBI",
                    "MLI",
                    "MAM",
                    "FDE",
                    "FMU",
                    "FGW",
                    "FYU"
                ],
                narrow: [
                    "O",
                    "A",
                    "I",
                    "F",
                    "D",
                    "B",
                    "L",
                    "M",
                    "E",
                    "U",
                    "W",
                    "Y"
                ],
                wide: [
                    "Fĩi Loo",
                    "Cokcwaklaŋne",
                    "Cokcwaklii",
                    "Fĩi Marfoo",
                    "Madǝǝuutǝbijaŋ",
                    "Mamǝŋgwãafahbii",
                    "Mamǝŋgwãalii",
                    "Madǝmbii",
                    "Fĩi Dǝɓlii",
                    "Fĩi Mundaŋ",
                    "Fĩi Gwahlle",
                    "Fĩi Yuru"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "FLO",
                    "CLA",
                    "CKI",
                    "FMF",
                    "MAD",
                    "MBI",
                    "MLI",
                    "MAM",
                    "FDE",
                    "FMU",
                    "FGW",
                    "FYU"
                ],
                narrow: [
                    "O",
                    "A",
                    "I",
                    "F",
                    "D",
                    "B",
                    "L",
                    "M",
                    "E",
                    "U",
                    "W",
                    "Y"
                ],
                wide: [
                    "Fĩi Loo",
                    "Cokcwaklaŋne",
                    "Cokcwaklii",
                    "Fĩi Marfoo",
                    "Madǝǝuutǝbijaŋ",
                    "Mamǝŋgwãafahbii",
                    "Mamǝŋgwãalii",
                    "Madǝmbii",
                    "Fĩi Dǝɓlii",
                    "Fĩi Mundaŋ",
                    "Fĩi Gwahlle",
                    "Fĩi Yuru"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "F1",
                    "F2",
                    "F3",
                    "F4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Tai fĩi sai ma tǝn kee zah",
                    "Tai fĩi sai zah lǝn gwa ma kee",
                    "Tai fĩi sai zah lǝn sai ma kee",
                    "Tai fĩi sai ma coo kee zah ‘na"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "F1",
                    "F2",
                    "F3",
                    "F4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Tai fĩi sai ma tǝn kee zah",
                    "Tai fĩi sai zah lǝn gwa ma kee",
                    "Tai fĩi sai zah lǝn sai ma kee",
                    "Tai fĩi sai ma coo kee zah ‘na"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "comme",
                    pm: "lilli"
                },
                narrow: {
                    am: "comme",
                    pm: "lilli"
                },
                wide: {
                    am: "comme",
                    pm: "lilli"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "comme",
                    pm: "lilli"
                },
                narrow: {
                    am: "comme",
                    pm: "lilli"
                },
                wide: {
                    am: "comme",
                    pm: "lilli"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "KǝPel Kristu",
                    "1": "Pel Kristu",
                    "0-alt-variant": "KK",
                    "1-alt-variant": "PK"
                },
                abbreviated: {
                    "0": "KK",
                    "1": "PK",
                    "0-alt-variant": "KK",
                    "1-alt-variant": "PK"
                },
                narrow: {
                    "0": "KK",
                    "1": "PK",
                    "0-alt-variant": "KK",
                    "1-alt-variant": "PK"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Syii ma tãa",
                short: "Syii ma tãa",
                narrow: "Syii ma tãa"
            },
            year: {
                wide: "Syii",
                short: "Syii",
                narrow: "Syii"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Fĩi",
                short: "Fĩi",
                narrow: "Fĩi"
            },
            week: {
                wide: "Luma",
                short: "Luma",
                narrow: "Luma"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Zah’nane/ Comme",
                short: "Zah’nane/ Comme",
                narrow: "Zah’nane/ Comme"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Kǝsyil luma",
                short: "Kǝsyil luma",
                narrow: "Kǝsyil luma"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Dayperiod",
                wide: "Dayperiod",
                narrow: "Dayperiod"
            },
            hour: {
                wide: "Cok comme",
                short: "Cok comme",
                narrow: "Cok comme"
            },
            minute: {
                wide: "Cok comme ma laŋne",
                short: "Cok comme ma laŋne",
                narrow: "Cok comme ma laŋne"
            },
            second: {
                wide: "Cok comme ma laŋ tǝ biŋ",
                short: "Cok comme ma laŋ tǝ biŋ",
                narrow: "Cok comme ma laŋ tǝ biŋ"
            },
            zone: {
                wide: "Waŋ cok comme",
                short: "Waŋ cok comme",
                narrow: "Waŋ cok comme"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

