/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "mzn",
    likelySubtags: {
        mzn: "mzn-Arab-IR"
    },
    identity: {
        language: "mzn"
    },
    territory: "IR",
    calendar: {
        patterns: {
            d: "y-MM-dd",
            D: "y MMMM d, EEEE",
            m: "MMM d",
            M: "MMMM d",
            y: "y MMM",
            Y: "y MMMM",
            F: "y MMMM d, EEEE HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "MM-dd",
                MEd: "MM-dd, E",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "MMM d, E",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "y-MM",
                yMd: "y-MM-dd",
                yMEd: "y-MM-dd, E",
                yMMM: "y MMM",
                yMMMd: "y MMM d",
                yMMMEd: "y MMM d, E",
                yMMMM: "y MMMM",
                yQQQ: "y QQQ",
                yQQQQ: "y QQQQ",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "y MMMM d, EEEE",
            long: "y MMMM d",
            medium: "y MMM d",
            short: "y-MM-dd"
        },
        days: {
            format: {
                abbreviated: [
                    "Sun",
                    "Mon",
                    "Tue",
                    "Wed",
                    "Thu",
                    "Fri",
                    "Sat"
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "W",
                    "T",
                    "F",
                    "S"
                ],
                short: [
                    "Sun",
                    "Mon",
                    "Tue",
                    "Wed",
                    "Thu",
                    "Fri",
                    "Sat"
                ],
                wide: [
                    "Sun",
                    "Mon",
                    "Tue",
                    "Wed",
                    "Thu",
                    "Fri",
                    "Sat"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Sun",
                    "Mon",
                    "Tue",
                    "Wed",
                    "Thu",
                    "Fri",
                    "Sat"
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "W",
                    "T",
                    "F",
                    "S"
                ],
                short: [
                    "Sun",
                    "Mon",
                    "Tue",
                    "Wed",
                    "Thu",
                    "Fri",
                    "Sat"
                ],
                wide: [
                    "Sun",
                    "Mon",
                    "Tue",
                    "Wed",
                    "Thu",
                    "Fri",
                    "Sat"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "ژانویه",
                    "فوریه",
                    "مارس",
                    "آوریل",
                    "مه",
                    "ژوئن",
                    "ژوئیه",
                    "اوت",
                    "سپتامبر",
                    "اکتبر",
                    "نوامبر",
                    "دسامبر"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "ژانویه",
                    "فوریه",
                    "مارس",
                    "آوریل",
                    "مه",
                    "ژوئن",
                    "ژوئیه",
                    "اوت",
                    "سپتامبر",
                    "اکتبر",
                    "نوامبر",
                    "دسامبر"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ژانویه",
                    "فوریه",
                    "مارس",
                    "آوریل",
                    "مه",
                    "ژوئن",
                    "ژوئیه",
                    "اوت",
                    "سپتامبر",
                    "اکتبر",
                    "نوامبر",
                    "دسامبر"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "ژانویه",
                    "فوریه",
                    "مارس",
                    "آوریل",
                    "مه",
                    "ژوئن",
                    "ژوئیه",
                    "اوت",
                    "سپتامبر",
                    "اکتبر",
                    "نوامبر",
                    "دسامبر"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "قبل میلاد",
                    "1": "بعد میلاد",
                    "0-alt-variant": "قبل میلادی تقویم",
                    "1-alt-variant": "میلادی"
                },
                abbreviated: {
                    "0": "پ.م",
                    "1": "م.",
                    "0-alt-variant": "پ.م.",
                    "1-alt-variant": "م"
                },
                narrow: {
                    "0": "پ.م",
                    "1": "م.",
                    "0-alt-variant": "پ.م.",
                    "1-alt-variant": "م"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "تقویم",
                short: "تقویم",
                narrow: "تقویم"
            },
            year: {
                wide: "سال",
                short: "سال",
                narrow: "سال"
            },
            quarter: {
                wide: "ربع",
                short: "ربع",
                narrow: "ربع"
            },
            month: {
                wide: "ماه",
                short: "ماه",
                narrow: "ماه"
            },
            week: {
                wide: "هفته",
                short: "هفته",
                narrow: "هفته"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "روز",
                short: "روز",
                narrow: "روز"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "هفته‌ی ِروز",
                short: "هفته‌ی ِروز",
                narrow: "هفته‌ی ِروز"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "صواحی/ظُر",
                wide: "صواحی/ظُر",
                narrow: "صواحی/ظُر"
            },
            hour: {
                wide: "ساعِت",
                short: "ساعت",
                narrow: "ساعت"
            },
            minute: {
                wide: "دقیقه",
                short: "دَقه",
                narrow: "دَقه"
            },
            second: {
                wide: "ثانیه",
                short: "ثانیه",
                narrow: "ثانیه"
            },
            zone: {
                wide: "زمونی منقطه",
                short: "زمونی منقطه",
                narrow: "زمونی منقطه"
            },
            millisecond: {
                narrow: "میلی‌ثانیه",
                short: "میلی‌ثانیه",
                wide: "میلی‌ثانیه"
            }
        }
    },
    firstDay: 6
});

