/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "nmg",
    likelySubtags: {
        nmg: "nmg-Latn-CM"
    },
    identity: {
        language: "nmg"
    },
    territory: "CM",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE d MMMM y",
            m: "d MMM",
            M: "MMMM d",
            y: "MMM y",
            Y: "y MMMM",
            F: "EEEE d MMMM y HH:mm:ss",
            g: "d/M/y HH:mm",
            G: "d/M/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E d/M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E d MMM",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "m:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E d/M/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E d MMM y",
                yMMMM: "y MMMM",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "d/M/y"
        },
        days: {
            format: {
                abbreviated: [
                    "sɔ́n",
                    "mɔ́n",
                    "smb",
                    "sml",
                    "smn",
                    "mbs",
                    "sas"
                ],
                narrow: [
                    "s",
                    "m",
                    "s",
                    "s",
                    "s",
                    "m",
                    "s"
                ],
                short: [
                    "sɔ́n",
                    "mɔ́n",
                    "smb",
                    "sml",
                    "smn",
                    "mbs",
                    "sas"
                ],
                wide: [
                    "sɔ́ndɔ",
                    "mɔ́ndɔ",
                    "sɔ́ndɔ mafú mába",
                    "sɔ́ndɔ mafú málal",
                    "sɔ́ndɔ mafú mána",
                    "mabágá má sukul",
                    "sásadi"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "sɔ́n",
                    "mɔ́n",
                    "smb",
                    "sml",
                    "smn",
                    "mbs",
                    "sas"
                ],
                narrow: [
                    "s",
                    "m",
                    "s",
                    "s",
                    "s",
                    "m",
                    "s"
                ],
                short: [
                    "sɔ́n",
                    "mɔ́n",
                    "smb",
                    "sml",
                    "smn",
                    "mbs",
                    "sas"
                ],
                wide: [
                    "sɔ́ndɔ",
                    "mɔ́ndɔ",
                    "sɔ́ndɔ mafú mába",
                    "sɔ́ndɔ mafú málal",
                    "sɔ́ndɔ mafú mána",
                    "mabágá má sukul",
                    "sásadi"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "ng1",
                    "ng2",
                    "ng3",
                    "ng4",
                    "ng5",
                    "ng6",
                    "ng7",
                    "ng8",
                    "ng9",
                    "ng10",
                    "ng11",
                    "kris"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "ngwɛn matáhra",
                    "ngwɛn ńmba",
                    "ngwɛn ńlal",
                    "ngwɛn ńna",
                    "ngwɛn ńtan",
                    "ngwɛn ńtuó",
                    "ngwɛn hɛmbuɛrí",
                    "ngwɛn lɔmbi",
                    "ngwɛn rɛbvuâ",
                    "ngwɛn wum",
                    "ngwɛn wum navǔr",
                    "krísimin"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ng1",
                    "ng2",
                    "ng3",
                    "ng4",
                    "ng5",
                    "ng6",
                    "ng7",
                    "ng8",
                    "ng9",
                    "ng10",
                    "ng11",
                    "kris"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "ngwɛn matáhra",
                    "ngwɛn ńmba",
                    "ngwɛn ńlal",
                    "ngwɛn ńna",
                    "ngwɛn ńtan",
                    "ngwɛn ńtuó",
                    "ngwɛn hɛmbuɛrí",
                    "ngwɛn lɔmbi",
                    "ngwɛn rɛbvuâ",
                    "ngwɛn wum",
                    "ngwɛn wum navǔr",
                    "krísimin"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "T1",
                    "T2",
                    "T3",
                    "T4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Tindɛ nvúr",
                    "Tindɛ ńmba",
                    "Tindɛ ńlal",
                    "Tindɛ ńna"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "T1",
                    "T2",
                    "T3",
                    "T4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Tindɛ nvúr",
                    "Tindɛ ńmba",
                    "Tindɛ ńlal",
                    "Tindɛ ńna"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "maná",
                    pm: "kugú"
                },
                narrow: {
                    am: "maná",
                    pm: "kugú"
                },
                wide: {
                    am: "maná",
                    pm: "kugú"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "maná",
                    pm: "kugú"
                },
                narrow: {
                    am: "maná",
                    pm: "kugú"
                },
                wide: {
                    am: "maná",
                    pm: "kugú"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Bó Lahlɛ̄",
                    "1": "Pfiɛ Burī",
                    "0-alt-variant": "BL",
                    "1-alt-variant": "PB"
                },
                abbreviated: {
                    "0": "BL",
                    "1": "PB",
                    "0-alt-variant": "BL",
                    "1-alt-variant": "PB"
                },
                narrow: {
                    "0": "BL",
                    "1": "PB",
                    "0-alt-variant": "BL",
                    "1-alt-variant": "PB"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Pīl/Lahlɛ̄",
                short: "Pīl/Lahlɛ̄",
                narrow: "Pīl/Lahlɛ̄"
            },
            year: {
                wide: "Mbvu",
                short: "Mbvu",
                narrow: "Mbvu"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Ngwɛn",
                short: "Ngwɛn",
                narrow: "Ngwɛn"
            },
            week: {
                wide: "Sɔ́ndɔ",
                short: "Sɔ́ndɔ",
                narrow: "Sɔ́ndɔ"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Duö",
                short: "Duö",
                narrow: "Duö"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Day of the Week",
                short: "Day of the Week",
                narrow: "Day of the Week"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Máná, Muó, Kugú, Bvul",
                wide: "Máná, Muó, Kugú, Bvul",
                narrow: "Máná, Muó, Kugú, Bvul"
            },
            hour: {
                wide: "Wulā",
                short: "Wulā",
                narrow: "Wulā"
            },
            minute: {
                wide: "Mpálâ",
                short: "Mpálâ",
                narrow: "Mpálâ"
            },
            second: {
                wide: "Nyiɛl",
                short: "Nyiɛl",
                narrow: "Nyiɛl"
            },
            zone: {
                wide: "Nkɛ̌l wulā",
                short: "Nkɛ̌l wulā",
                narrow: "Nkɛ̌l wulā"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

