/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "nn",
    likelySubtags: {
        nn: "nn-Latn-NO"
    },
    identity: {
        language: "nn"
    },
    territory: "NO",
    calendar: {
        patterns: {
            d: "dd.MM.y",
            D: "EEEE d. MMMM y",
            m: "d. MMM",
            M: "d. MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE d. MMMM y HH:mm:ss",
            g: "d.M.y HH:mm",
            G: "d.M.y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} 'kl'. {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d.",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d.",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "dd.MM.y GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "d. MMM y G",
                GyMMMEd: "E d. MMM y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L.",
                Md: "d.M.",
                MEd: "E d.M",
                MMdd: "d.M.",
                MMM: "LLL",
                MMMd: "d. MMM",
                MMMEd: "E d. MMM",
                MMMMd: "d. MMMM",
                "MMMMW-count-one": "'veke' W 'i' MMMM",
                "MMMMW-count-other": "'veke' W 'i' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M.y",
                yMd: "d.M.y",
                yMEd: "E d.M.y",
                yMM: "MM.y",
                yMMM: "MMM y",
                yMMMd: "d. MMM y",
                yMMMEd: "E d. MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "'veke' w 'i' Y",
                "yw-count-other": "'veke' w 'i' Y"
            }
        },
        timeFormats: {
            full: "'kl'. HH:mm:ss zzzz",
            "full-alt-variant": "'kl'. HH.mm.ss zzzz",
            long: "HH:mm:ss z",
            "long-alt-variant": "HH.mm.ss z",
            medium: "HH:mm:ss",
            "medium-alt-variant": "HH.mm.ss",
            short: "HH:mm",
            "short-alt-variant": "HH.mm"
        },
        dateFormats: {
            full: "EEEE d. MMMM y",
            long: "d. MMMM y",
            medium: "d. MMM y",
            short: "dd.MM.y"
        },
        days: {
            format: {
                abbreviated: [
                    "sø.",
                    "må.",
                    "ty.",
                    "on.",
                    "to.",
                    "fr.",
                    "la."
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "O",
                    "T",
                    "F",
                    "L"
                ],
                short: [
                    "sø.",
                    "må.",
                    "ty.",
                    "on.",
                    "to.",
                    "fr.",
                    "la."
                ],
                wide: [
                    "søndag",
                    "måndag",
                    "tysdag",
                    "onsdag",
                    "torsdag",
                    "fredag",
                    "laurdag"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "søn",
                    "mån",
                    "tys",
                    "ons",
                    "tor",
                    "fre",
                    "lau"
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "O",
                    "T",
                    "F",
                    "L"
                ],
                short: [
                    "sø.",
                    "må.",
                    "ty.",
                    "on.",
                    "to.",
                    "fr.",
                    "la."
                ],
                wide: [
                    "søndag",
                    "måndag",
                    "tysdag",
                    "onsdag",
                    "torsdag",
                    "fredag",
                    "laurdag"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "jan.",
                    "feb.",
                    "mars",
                    "apr.",
                    "mai",
                    "juni",
                    "juli",
                    "aug.",
                    "sep.",
                    "okt.",
                    "nov.",
                    "des."
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "januar",
                    "februar",
                    "mars",
                    "april",
                    "mai",
                    "juni",
                    "juli",
                    "august",
                    "september",
                    "oktober",
                    "november",
                    "desember"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "jan",
                    "feb",
                    "mar",
                    "apr",
                    "mai",
                    "jun",
                    "jul",
                    "aug",
                    "sep",
                    "okt",
                    "nov",
                    "des"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "januar",
                    "februar",
                    "mars",
                    "april",
                    "mai",
                    "juni",
                    "juli",
                    "august",
                    "september",
                    "oktober",
                    "november",
                    "desember"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. kvartal",
                    "2. kvartal",
                    "3. kvartal",
                    "4. kvartal"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. kvartal",
                    "2. kvartal",
                    "3. kvartal",
                    "4. kvartal"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "midn.",
                    am: "f.m.",
                    pm: "e.m.",
                    morning1: "morg.",
                    morning2: "form.",
                    afternoon1: "etterm.",
                    evening1: "kveld",
                    night1: "natt"
                },
                narrow: {
                    midnight: "mn.",
                    am: "a",
                    pm: "p",
                    morning1: "mg.",
                    morning2: "fm.",
                    afternoon1: "em.",
                    evening1: "kv.",
                    night1: "nt."
                },
                wide: {
                    midnight: "midnatt",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "på morgonen",
                    morning2: "på formiddagen",
                    afternoon1: "på ettermiddagen",
                    evening1: "på kvelden",
                    night1: "på natta"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "midn.",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "morg.",
                    morning2: "form.",
                    afternoon1: "etterm.",
                    evening1: "kveld",
                    night1: "natt"
                },
                narrow: {
                    midnight: "mn.",
                    am: "f.m.",
                    pm: "e.m.",
                    morning1: "mg.",
                    morning2: "fm.",
                    afternoon1: "em.",
                    evening1: "kv.",
                    night1: "nt."
                },
                wide: {
                    midnight: "midnatt",
                    am: "a.m.",
                    pm: "p.m.",
                    morning1: "morgon",
                    morning2: "formiddag",
                    afternoon1: "ettermiddag",
                    evening1: "kveld",
                    night1: "natt"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "før Kristus",
                    "1": "etter Kristus",
                    "0-alt-variant": "før vår tidsrekning",
                    "1-alt-variant": "etter vår tidsrekning"
                },
                abbreviated: {
                    "0": "f.Kr.",
                    "1": "e.Kr.",
                    "0-alt-variant": "fvt.",
                    "1-alt-variant": "evt."
                },
                narrow: {
                    "0": "f.Kr.",
                    "1": "e.Kr.",
                    "0-alt-variant": "fvt.",
                    "1-alt-variant": "vt."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "tidsalder",
                short: "tidsalder",
                narrow: "tidsalder"
            },
            year: {
                wide: "år",
                short: "år",
                narrow: "år"
            },
            quarter: {
                wide: "kvartal",
                short: "kv.",
                narrow: "kv."
            },
            month: {
                wide: "månad",
                short: "md.",
                narrow: "md."
            },
            week: {
                wide: "veke",
                short: "veke",
                narrow: "v."
            },
            weekOfMonth: {
                wide: "veke i månaden",
                short: "veke i md.",
                narrow: "veke i md."
            },
            day: {
                wide: "dag",
                short: "dag",
                narrow: "d."
            },
            dayOfYear: {
                wide: "dag i året",
                short: "dag i året",
                narrow: "d. i året"
            },
            weekday: {
                wide: "vekedag",
                short: "vekedag",
                narrow: "veked."
            },
            weekdayOfMonth: {
                wide: "vekedag i månaden",
                short: "veked. i md.",
                narrow: "veked. i md."
            },
            dayperiod: {
                short: "am/pm",
                wide: "a.m./p.m.",
                narrow: "am/pm"
            },
            hour: {
                wide: "time",
                short: "t",
                narrow: "t"
            },
            minute: {
                wide: "minutt",
                short: "min",
                narrow: "m"
            },
            second: {
                wide: "sekund",
                short: "sek",
                narrow: "s"
            },
            zone: {
                wide: "tidssone",
                short: "tidssone",
                narrow: "tidssone"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "millisekund"
            }
        }
    },
    firstDay: 1
});

