/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "om-KE",
    likelySubtags: {
        om: "om-Latn-ET"
    },
    identity: {
        language: "om",
        territory: "KE"
    },
    territory: "KE",
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, MMMM d, y",
            m: "MMM d",
            M: "MMMM d",
            y: "y MMM",
            Y: "MMMM y",
            F: "EEEE, MMMM d, y HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "MM-dd",
                MEd: "MM-dd, E",
                MMdd: "dd/MM",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "MMM d, E",
                MMMMd: "MMMM d",
                MMMMdd: "dd MMMM",
                "MMMMW-count-one": "'week' W 'of' MMMM",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "y-MM",
                yMd: "y-MM-dd",
                yMEd: "y-MM-dd, E",
                yMM: "MM/y",
                yMMM: "y MMM",
                yMMMd: "y MMM d",
                yMMMEd: "y MMM d, E",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "y QQQQ",
                "yw-count-one": "'week' w 'of' Y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, MMMM d, y",
            long: "dd MMMM y",
            medium: "dd-MMM-y",
            short: "dd/MM/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "Dil",
                    "Wix",
                    "Qib",
                    "Rob",
                    "Kam",
                    "Jim",
                    "San"
                ],
                narrow: [
                    "D",
                    "W",
                    "Q",
                    "R",
                    "K",
                    "J",
                    "S"
                ],
                short: [
                    "Dil",
                    "Wix",
                    "Qib",
                    "Rob",
                    "Kam",
                    "Jim",
                    "San"
                ],
                wide: [
                    "Dilbata",
                    "Wiixata",
                    "Qibxata",
                    "Roobii",
                    "Kamiisa",
                    "Jimaata",
                    "Sanbata"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Dil",
                    "Wix",
                    "Qib",
                    "Rob",
                    "Kam",
                    "Jim",
                    "San"
                ],
                narrow: [
                    "D",
                    "W",
                    "Q",
                    "R",
                    "K",
                    "J",
                    "S"
                ],
                short: [
                    "Dil",
                    "Wix",
                    "Qib",
                    "Rob",
                    "Kam",
                    "Jim",
                    "San"
                ],
                wide: [
                    "Dilbata",
                    "Wiixata",
                    "Qibxata",
                    "Roobii",
                    "Kamiisa",
                    "Jimaata",
                    "Sanbata"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Ama",
                    "Gur",
                    "Bit",
                    "Elb",
                    "Cam",
                    "Wax",
                    "Ado",
                    "Hag",
                    "Ful",
                    "Onk",
                    "Sad",
                    "Mud"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Amajjii",
                    "Guraandhala",
                    "Bitooteessa",
                    "Elba",
                    "Caamsa",
                    "Waxabajjii",
                    "Adooleessa",
                    "Hagayya",
                    "Fuulbana",
                    "Onkololeessa",
                    "Sadaasa",
                    "Muddee"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Ama",
                    "Gur",
                    "Bit",
                    "Elb",
                    "Cam",
                    "Wax",
                    "Ado",
                    "Hag",
                    "Ful",
                    "Onk",
                    "Sad",
                    "Mud"
                ],
                narrow: [
                    "A",
                    "G",
                    "B",
                    "E",
                    "C",
                    "W",
                    "A",
                    "H",
                    "F",
                    "O",
                    "S",
                    "M"
                ],
                wide: [
                    "Amajjii",
                    "Guraandhala",
                    "Bitooteessa",
                    "Elba",
                    "Caamsa",
                    "Waxabajjii",
                    "Adooleessa",
                    "Hagayya",
                    "Fuulbana",
                    "Onkololeessa",
                    "Sadaasa",
                    "Muddee"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Kurmaana 1",
                    "Kurmaana 2",
                    "Kurmaana 3",
                    "Kurmaana 4"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Kurmaana 1",
                    "Kurmaana 2",
                    "Kurmaana 3",
                    "Kurmaana 4"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "WD",
                    pm: "WB"
                },
                narrow: {
                    am: "WD",
                    pm: "WB"
                },
                wide: {
                    am: "WD",
                    pm: "WB"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "WD",
                    pm: "WB"
                },
                narrow: {
                    am: "WD",
                    pm: "WB"
                },
                wide: {
                    am: "WD",
                    pm: "WB"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Dheengadda Jeesu",
                    "1": "CE",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                abbreviated: {
                    "0": "KD",
                    "1": "CE",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "KB"
                },
                narrow: {
                    "0": "KD",
                    "1": "CE",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "KB"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Era",
                short: "Era",
                narrow: "Era"
            },
            year: {
                wide: "Year",
                short: "Year",
                narrow: "Year"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Month",
                short: "Month",
                narrow: "Month"
            },
            week: {
                wide: "Week",
                short: "Week",
                narrow: "Week"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Day",
                short: "Day",
                narrow: "Day"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Day of the Week",
                short: "Day of the Week",
                narrow: "Day of the Week"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Dayperiod",
                wide: "Dayperiod",
                narrow: "Dayperiod"
            },
            hour: {
                wide: "Hour",
                short: "Hour",
                narrow: "Hour"
            },
            minute: {
                wide: "Minute",
                short: "Minute",
                narrow: "Minute"
            },
            second: {
                wide: "Second",
                short: "Second",
                narrow: "Second"
            },
            zone: {
                wide: "Zone",
                short: "Zone",
                narrow: "Zone"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

