/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "os-RU",
    likelySubtags: {
        os: "os-Cyrl-GE"
    },
    identity: {
        language: "os",
        territory: "RU"
    },
    territory: "RU",
    calendar: {
        patterns: {
            d: "dd.MM.y",
            D: "EEEE, d MMMM, y 'аз'",
            m: "d MMM",
            M: "MMMM d",
            y: "LLL y",
            Y: "y MMMM",
            F: "EEEE, d MMMM, y 'аз' HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1}, {0}",
            long: "{1}, {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "dd.MM",
                MEd: "E, dd.MM",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "ccc, d MMM",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "MM.y",
                yMd: "y-MM-dd",
                yMEd: "E, dd.MM.y",
                yMMM: "LLL y",
                yMMMd: "y MMM d",
                yMMMEd: "E, d MMM y",
                yMMMM: "y MMMM",
                yQQQ: "y-'ӕм' 'азы' QQQ",
                yQQQQ: "y-'ӕм' 'азы' QQQQ",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM, y 'аз'",
            long: "d MMMM, y 'аз'",
            medium: "dd MMM y 'аз'",
            short: "dd.MM.yy"
        },
        days: {
            format: {
                abbreviated: [
                    "хцб",
                    "крс",
                    "дцг",
                    "ӕрт",
                    "цпр",
                    "мрб",
                    "сбт"
                ],
                narrow: [
                    "Х",
                    "К",
                    "Д",
                    "Ӕ",
                    "Ц",
                    "М",
                    "С"
                ],
                short: [
                    "хцб",
                    "крс",
                    "дцг",
                    "ӕрт",
                    "цпр",
                    "мрб",
                    "сбт"
                ],
                wide: [
                    "хуыцаубон",
                    "къуырисӕр",
                    "дыццӕг",
                    "ӕртыццӕг",
                    "цыппӕрӕм",
                    "майрӕмбон",
                    "сабат"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Хцб",
                    "Крс",
                    "Дцг",
                    "Ӕрт",
                    "Цпр",
                    "Мрб",
                    "Сбт"
                ],
                narrow: [
                    "Х",
                    "К",
                    "Д",
                    "Ӕ",
                    "Ц",
                    "М",
                    "С"
                ],
                short: [
                    "хцб",
                    "крс",
                    "дцг",
                    "ӕрт",
                    "цпр",
                    "мрб",
                    "сбт"
                ],
                wide: [
                    "Хуыцаубон",
                    "Къуырисӕр",
                    "Дыццӕг",
                    "Ӕртыццӕг",
                    "Цыппӕрӕм",
                    "Майрӕмбон",
                    "Сабат"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "янв.",
                    "фев.",
                    "мар.",
                    "апр.",
                    "майы",
                    "июны",
                    "июлы",
                    "авг.",
                    "сен.",
                    "окт.",
                    "ноя.",
                    "дек."
                ],
                narrow: [
                    "Я",
                    "Ф",
                    "М",
                    "А",
                    "М",
                    "И",
                    "И",
                    "А",
                    "С",
                    "О",
                    "Н",
                    "Д"
                ],
                wide: [
                    "январы",
                    "февралы",
                    "мартъийы",
                    "апрелы",
                    "майы",
                    "июны",
                    "июлы",
                    "августы",
                    "сентябры",
                    "октябры",
                    "ноябры",
                    "декабры"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Янв.",
                    "Февр.",
                    "Март.",
                    "Апр.",
                    "Май",
                    "Июнь",
                    "Июль",
                    "Авг.",
                    "Сент.",
                    "Окт.",
                    "Нояб.",
                    "Дек."
                ],
                narrow: [
                    "Я",
                    "Ф",
                    "М",
                    "А",
                    "М",
                    "И",
                    "И",
                    "А",
                    "С",
                    "О",
                    "Н",
                    "Д"
                ],
                wide: [
                    "Январь",
                    "Февраль",
                    "Мартъи",
                    "Апрель",
                    "Май",
                    "Июнь",
                    "Июль",
                    "Август",
                    "Сентябрь",
                    "Октябрь",
                    "Ноябрь",
                    "Декабрь"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1-аг кв.",
                    "2-аг кв.",
                    "3-аг кв.",
                    "4-ӕм кв."
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1-аг квартал",
                    "2-аг квартал",
                    "3-аг квартал",
                    "4-ӕм квартал"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1-аг кв.",
                    "2-аг кв.",
                    "3-аг кв.",
                    "4-ӕм кв."
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1-аг квартал",
                    "2-аг квартал",
                    "3-аг квартал",
                    "4-ӕм квартал"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "ӕмбисбоны размӕ",
                    pm: "ӕмбисбоны фӕстӕ"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "н.д.а.",
                    "1": "н.д.",
                    "0-alt-variant": "н.д.а.",
                    "1-alt-variant": "н.д."
                },
                abbreviated: {
                    "0": "н.д.а.",
                    "1": "н.д.",
                    "0-alt-variant": "н.д.а.",
                    "1-alt-variant": "н.д."
                },
                narrow: {
                    "0": "н.д.а.",
                    "1": "н.д.",
                    "0-alt-variant": "н.д.а.",
                    "1-alt-variant": "н.д."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Дуг",
                short: "Дуг",
                narrow: "Дуг"
            },
            year: {
                wide: "Аз",
                short: "Аз",
                narrow: "Аз"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Мӕй",
                short: "Мӕй",
                narrow: "Мӕй"
            },
            week: {
                wide: "Къуыри",
                short: "Къуыри",
                narrow: "Къуыри"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Бон",
                short: "Бон",
                narrow: "Бон"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Къуырийы бон",
                short: "Къуырийы бон",
                narrow: "Къуырийы бон"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Боны период",
                wide: "Боны период",
                narrow: "Боны период"
            },
            hour: {
                wide: "Сахат",
                short: "Сахат",
                narrow: "Сахат"
            },
            minute: {
                wide: "Минут",
                short: "Минут",
                narrow: "Минут"
            },
            second: {
                wide: "Секунд",
                short: "Секунд",
                narrow: "Секунд"
            },
            zone: {
                wide: "Рӕстӕджы зонӕ",
                short: "Рӕстӕджы зонӕ",
                narrow: "Рӕстӕджы зонӕ"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

