/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "pa-Arab",
    likelySubtags: {
        pa: "pa-Guru-IN",
        "pa-Arab": "pa-Arab-PK"
    },
    identity: {
        language: "pa",
        script: "Arab"
    },
    territory: "PK",
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, dd MMMM y",
            m: "MMM d",
            M: "MMMM d",
            y: "MMM y",
            Y: "y MMMM",
            F: "EEEE, dd MMMM y h:mm:ss a",
            g: "y-MM-dd h:mm a",
            G: "y-MM-dd h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                HHmmss: "HH:mm:ss",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "MM-dd, E",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "MMM d, E",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                mmss: "mm:ss",
                ms: "mm:ss",
                y: "y",
                yM: "y-MM",
                yMd: "y-MM-dd",
                yMEd: "y-MM-dd, E",
                yMMM: "MMM y",
                yMMMd: "y MMM d",
                yMMMEd: "y MMM d, E",
                yMMMM: "y MMMM",
                yQQQ: "QQQ y",
                yQQQQ: "y QQQQ",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "EEEE, dd MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "dd/MM/y"
        },
        days: {
            format: {
                abbreviated: [
                    "اتوار",
                    "پیر",
                    "منگل",
                    "بُدھ",
                    "جمعرات",
                    "جمعہ",
                    "ہفتہ"
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "W",
                    "T",
                    "F",
                    "S"
                ],
                short: [
                    "اتوار",
                    "پیر",
                    "منگل",
                    "بُدھ",
                    "جمعرات",
                    "جمعہ",
                    "ہفتہ"
                ],
                wide: [
                    "اتوار",
                    "پیر",
                    "منگل",
                    "بُدھ",
                    "جمعرات",
                    "جمعہ",
                    "ہفتہ"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "اتوار",
                    "پیر",
                    "منگل",
                    "بُدھ",
                    "جمعرات",
                    "جمعہ",
                    "ہفتہ"
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "W",
                    "T",
                    "F",
                    "S"
                ],
                short: [
                    "اتوار",
                    "پیر",
                    "منگل",
                    "بُدھ",
                    "جمعرات",
                    "جمعہ",
                    "ہفتہ"
                ],
                wide: [
                    "اتوار",
                    "پیر",
                    "منگل",
                    "بُدھ",
                    "جمعرات",
                    "جمعہ",
                    "ہفتہ"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "جنوری",
                    "فروری",
                    "مارچ",
                    "اپریل",
                    "مئ",
                    "جون",
                    "جولائی",
                    "اگست",
                    "ستمبر",
                    "اکتوبر",
                    "نومبر",
                    "دسمبر"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "جنوری",
                    "فروری",
                    "مارچ",
                    "اپریل",
                    "مئ",
                    "جون",
                    "جولائی",
                    "اگست",
                    "ستمبر",
                    "اکتوبر",
                    "نومبر",
                    "دسمبر"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "جنوری",
                    "فروری",
                    "مارچ",
                    "اپریل",
                    "مئ",
                    "جون",
                    "جولائی",
                    "اگست",
                    "ستمبر",
                    "اکتوبر",
                    "نومبر",
                    "دسمبر"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "جنوری",
                    "فروری",
                    "مارچ",
                    "اپریل",
                    "مئ",
                    "جون",
                    "جولائی",
                    "اگست",
                    "ستمبر",
                    "اکتوبر",
                    "نومبر",
                    "دسمبر"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "چوتھاي پہلاں",
                    "چوتھاي دوجا",
                    "چوتھاي تيجا",
                    "چوتھاي چوتھا"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "چوتھاي پہلاں",
                    "چوتھاي دوجا",
                    "چوتھاي تيجا",
                    "چوتھاي چوتھا"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "چوتھاي پہلاں",
                    "چوتھاي دوجا",
                    "چوتھاي تيجا",
                    "چوتھاي چوتھا"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "چوتھاي پہلاں",
                    "چوتھاي دوجا",
                    "چوتھاي تيجا",
                    "چوتھاي چوتھا"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "ايساپورو",
                    "1": "سں",
                    "0-alt-variant": "ايساپورو",
                    "1-alt-variant": "سں"
                },
                abbreviated: {
                    "0": "ايساپورو",
                    "1": "سں",
                    "0-alt-variant": "ايساپورو",
                    "1-alt-variant": "سں"
                },
                narrow: {
                    "0": "ايساپورو",
                    "1": "سں",
                    "0-alt-variant": "ايساپورو",
                    "1-alt-variant": "سں"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Era",
                short: "Era",
                narrow: "Era"
            },
            year: {
                wide: "ورھا",
                short: "ورھا",
                narrow: "ورھا"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "مہينا",
                short: "مہينا",
                narrow: "مہينا"
            },
            week: {
                wide: "ہفتہ",
                short: "ہفتہ",
                narrow: "ہفتہ"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "دئن",
                short: "دئن",
                narrow: "دئن"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "ہفتے دا دن",
                short: "ہفتے دا دن",
                narrow: "ہفتے دا دن"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Dayperiod",
                wide: "Dayperiod",
                narrow: "Dayperiod"
            },
            hour: {
                wide: "گھنٹا",
                short: "گھنٹا",
                narrow: "گھنٹا"
            },
            minute: {
                wide: "منٹ",
                short: "منٹ",
                narrow: "منٹ"
            },
            second: {
                wide: "Second",
                short: "Second",
                narrow: "Second"
            },
            zone: {
                wide: "ٹپہ",
                short: "ٹپہ",
                narrow: "ٹپہ"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

