/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ps-PK",
    likelySubtags: {
        ps: "ps-Arab-AF"
    },
    identity: {
        language: "ps",
        territory: "PK"
    },
    territory: "PK",
    calendar: {
        patterns: {
            d: "y/M/d",
            D: "EEEE د y د MMMM d",
            m: "MMM d",
            M: "MMMM d",
            y: "y MMM",
            Y: "y MMMM",
            F: "EEEE د y د MMMM d h:mm:ss a",
            g: "y-MM-dd h:mm a",
            G: "y-MM-dd h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "M/d/y GGGGG",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "MM-dd",
                MEd: "MM-dd, E",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, MMM d",
                MMMMd: "MMMM d",
                "MMMMW-count-one": "اونۍ‘ W د MMMM‘",
                "MMMMW-count-other": "اونۍ W د MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "y-MM",
                yMd: "y-MM-dd",
                yMEd: "y-MM-dd, E",
                yMMM: "y MMM",
                yMMMd: "y MMM d",
                yMMMEd: "y MMM d, E",
                yMMMM: "y MMMM",
                yQQQ: "y QQQ",
                yQQQQ: "y QQQQ",
                "yw-count-one": "اونۍ w د Y",
                "yw-count-other": "اونۍ w د Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "EEEE د y د MMMM d",
            long: "د y د MMMM d",
            medium: "y MMM d",
            short: "y/M/d"
        },
        days: {
            format: {
                abbreviated: [
                    "يونۍ",
                    "دونۍ",
                    "درېنۍ",
                    "څلرنۍ",
                    "پينځنۍ",
                    "جمعه",
                    "اونۍ"
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "W",
                    "T",
                    "F",
                    "S"
                ],
                short: [
                    "يونۍ",
                    "دونۍ",
                    "درېنۍ",
                    "څلرنۍ",
                    "پينځنۍ",
                    "جمعه",
                    "اونۍ"
                ],
                wide: [
                    "يونۍ",
                    "دونۍ",
                    "درېنۍ",
                    "څلرنۍ",
                    "پينځنۍ",
                    "جمعه",
                    "اونۍ"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "يونۍ",
                    "دونۍ",
                    "درېنۍ",
                    "څلرنۍ",
                    "پينځنۍ",
                    "جمعه",
                    "اونۍ"
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "W",
                    "T",
                    "F",
                    "S"
                ],
                short: [
                    "يونۍ",
                    "دونۍ",
                    "درېنۍ",
                    "څلرنۍ",
                    "پينځنۍ",
                    "جمعه",
                    "اونۍ"
                ],
                wide: [
                    "يونۍ",
                    "دونۍ",
                    "درېنۍ",
                    "څلرنۍ",
                    "پينځنۍ",
                    "جمعه",
                    "اونۍ"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "جنوري",
                    "فبروري",
                    "مارچ",
                    "اپریل",
                    "مۍ",
                    "جون",
                    "جولای",
                    "اګست",
                    "سېپتمبر",
                    "اکتوبر",
                    "نومبر",
                    "دسمبر"
                ],
                narrow: [
                    "ج",
                    "ف",
                    "م",
                    "ا",
                    "م",
                    "ج",
                    "ج",
                    "ا",
                    "س",
                    "ا",
                    "ن",
                    "د"
                ],
                wide: [
                    "جنوري",
                    "فبروري",
                    "مارچ",
                    "اپریل",
                    "مۍ",
                    "جون",
                    "جولای",
                    "اګست",
                    "سېپتمبر",
                    "اکتوبر",
                    "نومبر",
                    "دسمبر"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "جنوري",
                    "فبروري",
                    "مارچ",
                    "اپریل",
                    "مۍ",
                    "جون",
                    "جولای",
                    "اګست",
                    "سپتمبر",
                    "اکتوبر",
                    "نومبر",
                    "دسمبر"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "جنوري",
                    "فېبروري",
                    "مارچ",
                    "اپریل",
                    "مۍ",
                    "جون",
                    "جولای",
                    "اګست",
                    "سپتمبر",
                    "اکتوبر",
                    "نومبر",
                    "دسمبر"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "لومړۍ ربعه",
                    "۲مه ربعه",
                    "۳مه ربعه",
                    "۴مه ربعه"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "لومړۍ ربعه",
                    "۲مه ربعه",
                    "۳مه ربعه",
                    "۴مه ربعه"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "لومړۍ ربعه",
                    "۲مه ربعه",
                    "۳مه ربعه",
                    "۴مه ربعه"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "لومړۍ ربعه",
                    "۲مه ربعه",
                    "۳مه ربعه",
                    "۴مه ربعه"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "غ.م.",
                    pm: "غ.و."
                },
                narrow: {
                    am: "غ.م.",
                    pm: "غ.و."
                },
                wide: {
                    am: "غ.م.",
                    pm: "غ.و."
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "غ.م.",
                    pm: "غ.و."
                },
                narrow: {
                    am: "غ.م.",
                    pm: "غ.و."
                },
                wide: {
                    am: "غ.م.",
                    pm: "غ.و."
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "له میلاد څخه وړاندې",
                    "1": "له میلاد څخه وروسته",
                    "0-alt-variant": "له عام پېر دمخه",
                    "1-alt-variant": "عام پېر"
                },
                abbreviated: {
                    "0": "له میلاد وړاندې",
                    "1": "م.",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "ع.پ"
                },
                narrow: {
                    "0": "له میلاد وړاندې",
                    "1": "م.",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "ع.پ"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "پېر",
                short: "پېر",
                narrow: "پېر"
            },
            year: {
                wide: "کال",
                short: "کال",
                narrow: "کال"
            },
            quarter: {
                wide: "څلورمه برخه",
                short: "څلورمه برخه",
                narrow: "څلورمه برخه"
            },
            month: {
                wide: "مياشت",
                short: "مياشت",
                narrow: "مياشت"
            },
            week: {
                wide: "اونۍ",
                short: "اونۍ",
                narrow: "اونۍ"
            },
            weekOfMonth: {
                wide: "د مياشتے اونۍ",
                short: "د مياشتے اونۍ",
                narrow: "د مياشتے اونۍ"
            },
            day: {
                wide: "ورځ",
                short: "ورځ",
                narrow: "ورځ"
            },
            dayOfYear: {
                wide: "د کال ورځ",
                short: "د کال ورځ",
                narrow: "د کال ورځ"
            },
            weekday: {
                wide: "د اونۍ ورځ",
                short: "د اونۍ ورځ",
                narrow: "د اونۍ ورځ"
            },
            weekdayOfMonth: {
                wide: "د مياشتے اونۍ ورځ",
                short: "د مياشتے اونۍ ورځ",
                narrow: "د مياشتے اونۍ ورځ"
            },
            dayperiod: {
                short: "ورځ شېبه",
                wide: "ورځ شېبه",
                narrow: "ورځ شېبه"
            },
            hour: {
                wide: "ساعت",
                short: "ساعت",
                narrow: "ساعت"
            },
            minute: {
                wide: "دقيقه",
                short: "دقيقه",
                narrow: "دقيقه"
            },
            second: {
                wide: "ثانيه",
                short: "ثانيه",
                narrow: "ثانيه"
            },
            zone: {
                wide: "وخت سيمه",
                short: "وخت سيمه",
                narrow: "وخت سيمه"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

