/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "rn",
    likelySubtags: {
        rn: "rn-Latn-BI"
    },
    identity: {
        language: "rn"
    },
    territory: "BI",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE d MMMM y",
            m: "d MMM",
            M: "MMMM d",
            y: "MMM y",
            Y: "y MMMM",
            F: "EEEE d MMMM y HH:mm:ss",
            g: "d/M/y HH:mm",
            G: "d/M/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E d/M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E d MMM",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "m:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E d/M/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E d MMM y",
                yMMMM: "y MMMM",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "d/M/y"
        },
        days: {
            format: {
                abbreviated: [
                    "cu.",
                    "mbe.",
                    "kab.",
                    "gtu.",
                    "kan.",
                    "gnu.",
                    "gnd."
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "W",
                    "T",
                    "F",
                    "S"
                ],
                short: [
                    "cu.",
                    "mbe.",
                    "kab.",
                    "gtu.",
                    "kan.",
                    "gnu.",
                    "gnd."
                ],
                wide: [
                    "Ku w’indwi",
                    "Ku wa mbere",
                    "Ku wa kabiri",
                    "Ku wa gatatu",
                    "Ku wa kane",
                    "Ku wa gatanu",
                    "Ku wa gatandatu"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "cu.",
                    "mbe.",
                    "kab.",
                    "gtu.",
                    "kan.",
                    "gnu.",
                    "gnd."
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "W",
                    "T",
                    "F",
                    "S"
                ],
                short: [
                    "cu.",
                    "mbe.",
                    "kab.",
                    "gtu.",
                    "kan.",
                    "gnu.",
                    "gnd."
                ],
                wide: [
                    "Ku w’indwi",
                    "Ku wa mbere",
                    "Ku wa kabiri",
                    "Ku wa gatatu",
                    "Ku wa kane",
                    "Ku wa gatanu",
                    "Ku wa gatandatu"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Mut.",
                    "Gas.",
                    "Wer.",
                    "Mat.",
                    "Gic.",
                    "Kam.",
                    "Nya.",
                    "Kan.",
                    "Nze.",
                    "Ukw.",
                    "Ugu.",
                    "Uku."
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "Nzero",
                    "Ruhuhuma",
                    "Ntwarante",
                    "Ndamukiza",
                    "Rusama",
                    "Ruheshi",
                    "Mukakaro",
                    "Nyandagaro",
                    "Nyakanga",
                    "Gitugutu",
                    "Munyonyo",
                    "Kigarama"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Mut.",
                    "Gas.",
                    "Wer.",
                    "Mat.",
                    "Gic.",
                    "Kam.",
                    "Nya.",
                    "Kan.",
                    "Nze.",
                    "Ukw.",
                    "Ugu.",
                    "Uku."
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "Nzero",
                    "Ruhuhuma",
                    "Ntwarante",
                    "Ndamukiza",
                    "Rusama",
                    "Ruheshi",
                    "Mukakaro",
                    "Nyandagaro",
                    "Nyakanga",
                    "Gitugutu",
                    "Munyonyo",
                    "Kigarama"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "I1",
                    "I2",
                    "I3",
                    "I4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Igice ca mbere c’umwaka",
                    "Igice ca kabiri c’umwaka",
                    "Igice ca gatatu c’umwaka",
                    "Igice ca kane c’umwaka"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "I1",
                    "I2",
                    "I3",
                    "I4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Igice ca mbere c’umwaka",
                    "Igice ca kabiri c’umwaka",
                    "Igice ca gatatu c’umwaka",
                    "Igice ca kane c’umwaka"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "Z.MU.",
                    pm: "Z.MW."
                },
                narrow: {
                    am: "Z.MU.",
                    pm: "Z.MW."
                },
                wide: {
                    am: "Z.MU.",
                    pm: "Z.MW."
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "Z.MU.",
                    pm: "Z.MW."
                },
                narrow: {
                    am: "Z.MU.",
                    pm: "Z.MW."
                },
                wide: {
                    am: "Z.MU.",
                    pm: "Z.MW."
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Mbere ya Yezu",
                    "1": "Nyuma ya Yezu",
                    "0-alt-variant": "Mb.Y.",
                    "1-alt-variant": "Ny.Y"
                },
                abbreviated: {
                    "0": "Mb.Y.",
                    "1": "Ny.Y",
                    "0-alt-variant": "Mb.Y.",
                    "1-alt-variant": "Ny.Y"
                },
                narrow: {
                    "0": "Mb.Y.",
                    "1": "Ny.Y",
                    "0-alt-variant": "Mb.Y.",
                    "1-alt-variant": "Ny.Y"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Igihe",
                short: "Igihe",
                narrow: "Igihe"
            },
            year: {
                wide: "Umwaka",
                short: "Umwaka",
                narrow: "Umwaka"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Ukwezi",
                short: "Ukwezi",
                narrow: "Ukwezi"
            },
            week: {
                wide: "Indwi, Iyinga",
                short: "Indwi, Iyinga",
                narrow: "Indwi, Iyinga"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Umusi",
                short: "Umusi",
                narrow: "Umusi"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Iminsi y’iyinga",
                short: "Iminsi y’iyinga",
                narrow: "Iminsi y’iyinga"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "M.s/N.s",
                wide: "M.s/N.s",
                narrow: "M.s/N.s"
            },
            hour: {
                wide: "Isaha",
                short: "Isaha",
                narrow: "Isaha"
            },
            minute: {
                wide: "Umunota",
                short: "Umunota",
                narrow: "Umunota"
            },
            second: {
                wide: "Isegonda",
                short: "Isegonda",
                narrow: "Isegonda"
            },
            zone: {
                wide: "Isaha yo mukarere",
                short: "Isaha yo mukarere",
                narrow: "Isaha yo mukarere"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

