/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ro-MD",
    identity: {
        language: "ro",
        territory: "MD"
    },
    territory: "MD",
    numbers: {
        symbols: {
            decimal: ",",
            group: ".",
            list: ";",
            percentSign: "%",
            plusSign: "+",
            minusSign: "-",
            approximatelySign: "~",
            exponential: "E",
            superscriptingExponent: "×",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "n %"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-one": "n $",
            "unitPattern-count-few": "n $",
            "unitPattern-count-other": "n de $"
        },
        accounting: {
            patterns: [
                "n $",
                "(n $)"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "pesetă andorrană",
                "displayName-count-one": "pesetă andorrană",
                "displayName-count-few": "pesete andorrane",
                "displayName-count-other": "pesete andorrane",
                symbol: "ADP"
            },
            AED: {
                displayName: "dirham din Emiratele Arabe Unite",
                "displayName-count-one": "dirham din Emiratele Arabe Unite",
                "displayName-count-few": "dirhami din Emiratele Arabe Unite",
                "displayName-count-other": "dirhami din Emiratele Arabe Unite",
                symbol: "AED"
            },
            AFA: {
                displayName: "AFA",
                symbol: "AFA"
            },
            AFN: {
                displayName: "afgani afgan",
                "displayName-count-one": "afgani afgan",
                "displayName-count-few": "afgani afgani",
                "displayName-count-other": "afgani afgani",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "ALK",
                symbol: "ALK"
            },
            ALL: {
                displayName: "lek",
                "displayName-count-one": "lek",
                "displayName-count-few": "lek",
                "displayName-count-other": "lek",
                symbol: "ALL"
            },
            AMD: {
                displayName: "dram armenesc",
                "displayName-count-one": "dram armenesc",
                "displayName-count-few": "drami armenești",
                "displayName-count-other": "drami armenești",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "gulden neerlandez antilez",
                "displayName-count-one": "gulden neerlandez antilez",
                "displayName-count-few": "guldeni neerlandezi antilezi",
                "displayName-count-other": "guldeni neerlandezi antilezi",
                symbol: "ANG"
            },
            AOA: {
                displayName: "kwanza angoleză",
                "displayName-count-one": "kwanza angoleză",
                "displayName-count-few": "kwanze angoleze",
                "displayName-count-other": "kwanze angoleze",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "AOK",
                symbol: "AOK"
            },
            AON: {
                displayName: "AON",
                symbol: "AON"
            },
            AOR: {
                displayName: "AOR",
                symbol: "AOR"
            },
            ARA: {
                displayName: "ARA",
                symbol: "ARA"
            },
            ARL: {
                displayName: "ARL",
                symbol: "ARL"
            },
            ARM: {
                displayName: "ARM",
                symbol: "ARM"
            },
            ARP: {
                displayName: "peso argentinian (1983–1985)",
                "displayName-count-one": "peso argentinian (1983–1985)",
                "displayName-count-few": "pesos argentinieni (1983–1985)",
                "displayName-count-other": "pesos argentinieni (1983–1985)",
                symbol: "ARP"
            },
            ARS: {
                displayName: "peso argentinian",
                "displayName-count-one": "peso argentinian",
                "displayName-count-few": "pesos argentinieni",
                "displayName-count-other": "pesos argentinieni",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "șiling austriac",
                "displayName-count-one": "șiling austriac",
                "displayName-count-few": "șilingi austrieci",
                "displayName-count-other": "șilingi austrieci",
                symbol: "ATS"
            },
            AUD: {
                displayName: "dolar australian",
                "displayName-count-one": "dolar australian",
                "displayName-count-few": "dolari australieni",
                "displayName-count-other": "dolari australieni",
                symbol: "AUD",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "florin aruban",
                "displayName-count-one": "florin aruban",
                "displayName-count-few": "florini arubani",
                "displayName-count-other": "florini arubani",
                symbol: "AWG"
            },
            AZM: {
                displayName: "manat azer (1993–2006)",
                symbol: "AZM"
            },
            AZN: {
                displayName: "manat azer",
                "displayName-count-one": "manat azer",
                "displayName-count-few": "manați azeri",
                "displayName-count-other": "manați azeri",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "dinar Bosnia-Herțegovina (1992–1994)",
                "displayName-count-one": "dinar Bosnia-Herțegovina (1992–1994)",
                "displayName-count-few": "dinari Bosnia-Herțegovina",
                "displayName-count-other": "dinari Bosnia-Herțegovina (1992–1994)",
                symbol: "BAD"
            },
            BAM: {
                displayName: "marcă convertibilă",
                "displayName-count-one": "marcă convertibilă",
                "displayName-count-few": "mărci convertibile",
                "displayName-count-other": "mărci convertibile",
                symbol: "BAM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "BAN",
                symbol: "BAN"
            },
            BBD: {
                displayName: "dolar din Barbados",
                "displayName-count-one": "dolar din Barbados",
                "displayName-count-few": "dolari din Barbados",
                "displayName-count-other": "dolari din Barbados",
                symbol: "BBD",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "taka din Bangladesh",
                "displayName-count-one": "taka din Bangladesh",
                "displayName-count-few": "taka din Bangladesh",
                "displayName-count-other": "taka din Bangladesh",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "franc belgian (convertibil)",
                "displayName-count-one": "franc belgian (convertibil)",
                "displayName-count-few": "franci belgieni (convertibili)",
                "displayName-count-other": "franci belgieni (convertibili)",
                symbol: "BEC"
            },
            BEF: {
                displayName: "franc belgian",
                "displayName-count-one": "franc belgian",
                "displayName-count-few": "franci belgieni",
                "displayName-count-other": "franci belgieni",
                symbol: "BEF"
            },
            BEL: {
                displayName: "franc belgian (financiar)",
                "displayName-count-one": "franc belgian (financiar)",
                "displayName-count-few": "franci belgieni (financiari)",
                "displayName-count-other": "franci belgieni (financiari)",
                symbol: "BEL"
            },
            BGL: {
                displayName: "BGL",
                symbol: "BGL"
            },
            BGM: {
                displayName: "BGM",
                symbol: "BGM"
            },
            BGN: {
                displayName: "leva",
                "displayName-count-one": "leva",
                "displayName-count-few": "leve",
                "displayName-count-other": "leve",
                symbol: "BGN"
            },
            BGO: {
                displayName: "BGO",
                symbol: "BGO"
            },
            BHD: {
                displayName: "dinar din Bahrain",
                "displayName-count-one": "dinar din Bahrain",
                "displayName-count-few": "dinari din Bahrain",
                "displayName-count-other": "dinari din Bahrain",
                symbol: "BHD"
            },
            BIF: {
                displayName: "franc burundez",
                "displayName-count-one": "franc burundez",
                "displayName-count-few": "franci burundezi",
                "displayName-count-other": "franci burundezi",
                symbol: "BIF"
            },
            BMD: {
                displayName: "dolar din Bermuda",
                "displayName-count-one": "dolar din Bermuda",
                "displayName-count-few": "dolari din Bermuda",
                "displayName-count-other": "dolari din Bermuda",
                symbol: "BMD",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "dolar din Brunei",
                "displayName-count-one": "dolar din Brunei",
                "displayName-count-few": "dolari din Brunei",
                "displayName-count-other": "dolari Brunei",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "boliviano",
                "displayName-count-one": "boliviano",
                "displayName-count-few": "boliviano",
                "displayName-count-other": "boliviano",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "BOL",
                symbol: "BOL"
            },
            BOP: {
                displayName: "peso bolivian",
                "displayName-count-one": "peso bolivian",
                "displayName-count-few": "pesos bolivieni",
                "displayName-count-other": "pesos bolivieni",
                symbol: "BOP"
            },
            BOV: {
                displayName: "mvdol bolivian",
                symbol: "BOV"
            },
            BRB: {
                displayName: "BRB",
                symbol: "BRB"
            },
            BRC: {
                displayName: "BRC",
                symbol: "BRC"
            },
            BRE: {
                displayName: "cruzeiro brazilian (1990–1993)",
                symbol: "BRE"
            },
            BRL: {
                displayName: "real",
                "displayName-count-one": "real",
                "displayName-count-few": "reali",
                "displayName-count-other": "reali",
                symbol: "BRL",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "BRN",
                symbol: "BRN"
            },
            BRR: {
                displayName: "cruzeiro brazilian (1993–1994)",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "BRZ",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "dolar din Bahamas",
                "displayName-count-one": "dolar din Bahamas",
                "displayName-count-few": "dolari din Bahamas",
                "displayName-count-other": "dolari din Bahamas",
                symbol: "BSD",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "ngultrum din Bhutan",
                "displayName-count-one": "ngultrum din Bhutan",
                "displayName-count-few": "ngultrum din Bhutan",
                "displayName-count-other": "ngultrum din Bhutan",
                symbol: "BTN"
            },
            BUK: {
                displayName: "kyat birman",
                symbol: "BUK"
            },
            BWP: {
                displayName: "pula Botswana",
                "displayName-count-one": "pula Botswana",
                "displayName-count-few": "pula Botswana",
                "displayName-count-other": "pula Botswana",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "BYB",
                symbol: "BYB"
            },
            BYN: {
                displayName: "rublă belarusă",
                "displayName-count-one": "rublă belarusă",
                "displayName-count-few": "ruble belaruse",
                "displayName-count-other": "ruble belaruse",
                symbol: "BYN",
                "symbol-alt-narrow": "р."
            },
            BYR: {
                displayName: "rublă belarusă (2000–2016)",
                "displayName-count-one": "rublă belarusă (2000–2016)",
                "displayName-count-few": "ruble belaruse (2000–2016)",
                "displayName-count-other": "ruble belaruse (2000–2016)",
                symbol: "BYR"
            },
            BZD: {
                displayName: "dolar din Belize",
                "displayName-count-one": "dolar din Belize",
                "displayName-count-few": "dolari din Belize",
                "displayName-count-other": "dolari din Belize",
                symbol: "BZD",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "dolar canadian",
                "displayName-count-one": "dolar canadian",
                "displayName-count-few": "dolari canadieni",
                "displayName-count-other": "dolari canadieni",
                symbol: "CAD",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "franc congolez",
                "displayName-count-one": "franc congolez",
                "displayName-count-few": "franci congolezi",
                "displayName-count-other": "franci congolezi",
                symbol: "CDF"
            },
            CHE: {
                displayName: "CHE",
                symbol: "CHE"
            },
            CHF: {
                displayName: "franc elvețian",
                "displayName-count-one": "franc elvețian",
                "displayName-count-few": "franci elvețieni",
                "displayName-count-other": "franci elvețieni",
                symbol: "CHF"
            },
            CHW: {
                displayName: "CHW",
                symbol: "CHW"
            },
            CLE: {
                displayName: "CLE",
                symbol: "CLE"
            },
            CLF: {
                displayName: "CLF",
                symbol: "CLF"
            },
            CLP: {
                displayName: "peso chilian",
                "displayName-count-one": "peso chilian",
                "displayName-count-few": "pesos chilieni",
                "displayName-count-other": "pesos chilieni",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "yuan chinezesc (offshore)",
                "displayName-count-one": "yuan chinezesc (offshore)",
                "displayName-count-few": "yuani chinezești (offshore)",
                "displayName-count-other": "yuani chinezești (offshore)",
                symbol: "CNH"
            },
            CNX: {
                displayName: "CNX",
                symbol: "CNX"
            },
            CNY: {
                displayName: "yuan chinezesc",
                "displayName-count-one": "yuan chinezesc",
                "displayName-count-few": "yuani chinezești",
                "displayName-count-other": "yuani chinezești",
                symbol: "CNY",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "peso columbian",
                "displayName-count-one": "peso columbian",
                "displayName-count-few": "pesos columbieni",
                "displayName-count-other": "pesos columbieni",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "COU",
                symbol: "COU"
            },
            CRC: {
                displayName: "colón costarican",
                "displayName-count-one": "colón costarican",
                "displayName-count-few": "colóni costaricani",
                "displayName-count-other": "colóni costaricani",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "dinar Serbia și Muntenegru (2002–2006)",
                "displayName-count-one": "dinar Serbia și Muntenegru (2002–2006)",
                "displayName-count-few": "dinari Serbia și Muntenegru (2002–2006)",
                "displayName-count-other": "dinari Serbia și Muntenegru (2002–2006)",
                symbol: "CSD"
            },
            CSK: {
                displayName: "CSK",
                symbol: "CSK"
            },
            CUC: {
                displayName: "peso cubanez convertibil",
                "displayName-count-one": "peso cubanez convertibil",
                "displayName-count-few": "pesos cubanezi convertibili",
                "displayName-count-other": "pesos cubanezi convertibili",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "peso cubanez",
                "displayName-count-one": "peso cubanez",
                "displayName-count-few": "pesos cubanezi",
                "displayName-count-other": "pesos cubanezi",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "escudo din Capul Verde",
                "displayName-count-one": "escudo din Capul Verde",
                "displayName-count-few": "escudo din Capul Verde",
                "displayName-count-other": "escudo din Capul Verde",
                symbol: "CVE"
            },
            CYP: {
                displayName: "liră cipriotă",
                "displayName-count-one": "liră cipriotă",
                "displayName-count-few": "lire cipriote",
                "displayName-count-other": "lire cipriote",
                symbol: "CYP"
            },
            CZK: {
                displayName: "coroană cehă",
                "displayName-count-one": "coroană cehă",
                "displayName-count-few": "coroane cehe",
                "displayName-count-other": "coroane cehe",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "marcă est-germană",
                "displayName-count-one": "marcă est-germană",
                "displayName-count-few": "mărci est-germane",
                "displayName-count-other": "mărci est-germane",
                symbol: "DDM"
            },
            DEM: {
                displayName: "marcă germană",
                "displayName-count-one": "marcă germană",
                "displayName-count-few": "mărci germane",
                "displayName-count-other": "mărci germane",
                symbol: "DEM"
            },
            DJF: {
                displayName: "franc djiboutian",
                "displayName-count-one": "franc djiboutian",
                "displayName-count-few": "franci djiboutieni",
                "displayName-count-other": "franci djiboutieni",
                symbol: "DJF"
            },
            DKK: {
                displayName: "coroană daneză",
                "displayName-count-one": "coroană daneză",
                "displayName-count-few": "coroane daneze",
                "displayName-count-other": "coroane daneze",
                symbol: "DKK",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "peso dominican",
                "displayName-count-one": "peso dominican",
                "displayName-count-few": "pesos dominicani",
                "displayName-count-other": "pesos dominicani",
                symbol: "DOP",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "dinar algerian",
                "displayName-count-one": "dinar algerian",
                "displayName-count-few": "dinari algerieni",
                "displayName-count-other": "dinari algerieni",
                symbol: "DZD"
            },
            ECS: {
                displayName: "sucre Ecuador",
                symbol: "ECS"
            },
            ECV: {
                displayName: "ECV",
                symbol: "ECV"
            },
            EEK: {
                displayName: "coroană estoniană",
                "displayName-count-one": "coroană estoniană",
                "displayName-count-few": "coroane estoniene",
                "displayName-count-other": "coroane estoniene",
                symbol: "EEK"
            },
            EGP: {
                displayName: "liră egipteană",
                "displayName-count-one": "liră egipteană",
                "displayName-count-few": "lire egiptene",
                "displayName-count-other": "lire egiptene",
                symbol: "EGP",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "nakfa eritreeană",
                "displayName-count-one": "nakfa eritreeană",
                "displayName-count-few": "nakfa eritreene",
                "displayName-count-other": "nakfa eritreene",
                symbol: "ERN"
            },
            ESA: {
                displayName: "peseta spaniolă (cont A)",
                symbol: "ESA"
            },
            ESB: {
                displayName: "peseta spaniolă (cont convertibil)",
                symbol: "ESB"
            },
            ESP: {
                displayName: "pesetă spaniolă",
                "displayName-count-one": "pesetă spaniolă",
                "displayName-count-few": "pesete spaniole",
                "displayName-count-other": "pesete spaniole",
                symbol: "ESP",
                "symbol-alt-narrow": "₧"
            },
            ETB: {
                displayName: "birr etiopian",
                "displayName-count-one": "birr etiopian",
                "displayName-count-few": "birri etiopieni",
                "displayName-count-other": "birri etiopieni",
                symbol: "ETB"
            },
            EUR: {
                displayName: "euro",
                "displayName-count-one": "euro",
                "displayName-count-few": "euro",
                "displayName-count-other": "euro",
                symbol: "EUR",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "marcă finlandeză",
                "displayName-count-one": "mărci finlandeze",
                "displayName-count-few": "mărci finlandeze",
                "displayName-count-other": "mărci finlandeze",
                symbol: "FIM"
            },
            FJD: {
                displayName: "dolar fijian",
                "displayName-count-one": "dolar fijian",
                "displayName-count-few": "dolari fijieni",
                "displayName-count-other": "dolari fijieni",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "liră din Insulele Falkland",
                "displayName-count-one": "liră din Insulele Falkland",
                "displayName-count-few": "lire din Insulele Falkland",
                "displayName-count-other": "lire din Insulele Falkland",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "franc francez",
                "displayName-count-one": "franc francez",
                "displayName-count-few": "franci francezi",
                "displayName-count-other": "franci francezi",
                symbol: "FRF"
            },
            GBP: {
                displayName: "liră sterlină",
                "displayName-count-one": "liră sterlină",
                "displayName-count-few": "lire sterline",
                "displayName-count-other": "lire sterline",
                symbol: "GBP",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "GEK",
                symbol: "GEK"
            },
            GEL: {
                displayName: "lari georgian",
                "displayName-count-one": "lari georgian",
                "displayName-count-few": "lari georgieni",
                "displayName-count-other": "lari georgieni",
                symbol: "GEL",
                "symbol-alt-narrow": "₾"
            },
            GHC: {
                displayName: "cedi Ghana (1979–2007)",
                symbol: "GHC"
            },
            GHS: {
                displayName: "cedi ghanez",
                "displayName-count-one": "cedi ghanez",
                "displayName-count-few": "cedi ghanezi",
                "displayName-count-other": "cedi ghanezi",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "liră din Gibraltar",
                "displayName-count-one": "liră din Gibraltar",
                "displayName-count-few": "lire din Gibraltar",
                "displayName-count-other": "lire Gibraltar",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "dalasi din Gambia",
                "displayName-count-one": "dalasi din Gambia",
                "displayName-count-few": "dalasi din Gambia",
                "displayName-count-other": "dalasi din Gambia",
                symbol: "GMD"
            },
            GNF: {
                displayName: "franc guineean",
                "displayName-count-one": "franc guineean",
                "displayName-count-few": "franci guineeni",
                "displayName-count-other": "franci guineeni",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "GNS",
                symbol: "GNS"
            },
            GQE: {
                displayName: "GQE",
                symbol: "GQE"
            },
            GRD: {
                displayName: "drahmă grecească",
                "displayName-count-one": "drahmă grecească",
                "displayName-count-few": "drahme grecești",
                "displayName-count-other": "drahme grecești",
                symbol: "GRD"
            },
            GTQ: {
                displayName: "quetzal guatemalez",
                "displayName-count-one": "quetzal guatemalez",
                "displayName-count-few": "quetzali guatemalezi",
                "displayName-count-other": "quetzali guatemalezi",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "GWE",
                symbol: "GWE"
            },
            GWP: {
                displayName: "peso Guineea-Bissau",
                "displayName-count-one": "peso Guineea-Bissau",
                "displayName-count-few": "pesos Guineea-Bissau",
                "displayName-count-other": "pesos Guineea-Bissau",
                symbol: "GWP"
            },
            GYD: {
                displayName: "dolar guyanez",
                "displayName-count-one": "dolar guyanez",
                "displayName-count-few": "dolari guyanezi",
                "displayName-count-other": "dolari guyanezi",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "dolar din Hong Kong",
                "displayName-count-one": "dolar din Hong Kong",
                "displayName-count-few": "dolari din Hong Kong",
                "displayName-count-other": "dolari din Hong Kong",
                symbol: "HKD",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "lempira honduriană",
                "displayName-count-one": "lempiră honduriană",
                "displayName-count-few": "lempire honduriene",
                "displayName-count-other": "lempire honduriene",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "dinar croat",
                "displayName-count-one": "dinar croat",
                "displayName-count-few": "dinari croați",
                "displayName-count-other": "dinari croați",
                symbol: "HRD"
            },
            HRK: {
                displayName: "kuna",
                "displayName-count-one": "kuna",
                "displayName-count-few": "kuna",
                "displayName-count-other": "kuna",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "gourde din Haiti",
                "displayName-count-one": "gourde din Haiti",
                "displayName-count-few": "gourde din Haiti",
                "displayName-count-other": "gourde din Haiti",
                symbol: "HTG"
            },
            HUF: {
                displayName: "forint",
                "displayName-count-one": "forint",
                "displayName-count-few": "forinți",
                "displayName-count-other": "forinți",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "rupie indoneziană",
                "displayName-count-one": "rupie indoneziană",
                "displayName-count-few": "rupii indoneziene",
                "displayName-count-other": "rupii indoneziene",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "liră irlandeză",
                "displayName-count-one": "liră irlandeză",
                "displayName-count-few": "lire irlandeze",
                "displayName-count-other": "lire irlandeze",
                symbol: "IEP"
            },
            ILP: {
                displayName: "liră israeliană",
                "displayName-count-one": "liră israeliană",
                "displayName-count-few": "lire israeliene",
                "displayName-count-other": "lire israeliene",
                symbol: "ILP"
            },
            ILR: {
                displayName: "ILR",
                symbol: "ILR"
            },
            ILS: {
                displayName: "șechel israelian nou",
                "displayName-count-one": "șechel israelian nou",
                "displayName-count-few": "șecheli israelieni noi",
                "displayName-count-other": "șecheli israelieni noi",
                symbol: "ILS",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "rupie indiană",
                "displayName-count-one": "rupie indiană",
                "displayName-count-few": "rupii indiene",
                "displayName-count-other": "rupii indiene",
                symbol: "INR",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "dinar irakian",
                "displayName-count-one": "dinar irakian",
                "displayName-count-few": "dinari irakieni",
                "displayName-count-other": "dinari irakieni",
                symbol: "IQD"
            },
            IRR: {
                displayName: "rial iranian",
                "displayName-count-one": "rial iranian",
                "displayName-count-few": "riali iranieni",
                "displayName-count-other": "riali iranieni",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "ISJ",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "coroană islandeză",
                "displayName-count-one": "coroană islandeză",
                "displayName-count-few": "coroane islandeze",
                "displayName-count-other": "coroane islandeze",
                symbol: "ISK",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "liră italiană",
                "displayName-count-one": "liră italiană",
                "displayName-count-few": "lire italiene",
                "displayName-count-other": "lire italiene",
                symbol: "ITL"
            },
            JMD: {
                displayName: "dolar jamaican",
                "displayName-count-one": "dolar jamaican",
                "displayName-count-few": "dolari jamaicani",
                "displayName-count-other": "dolari jamaicani",
                symbol: "JMD",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "dinar iordanian",
                "displayName-count-one": "dinar iordanian",
                "displayName-count-few": "dinari iordanieni",
                "displayName-count-other": "dinari iordanieni",
                symbol: "JOD"
            },
            JPY: {
                displayName: "yen japonez",
                "displayName-count-one": "yen japonez",
                "displayName-count-few": "yeni japonezi",
                "displayName-count-other": "yeni japonezi",
                symbol: "JPY",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "șiling kenyan",
                "displayName-count-one": "șiling kenyan",
                "displayName-count-few": "șilingi kenyeni",
                "displayName-count-other": "șilingi kenyeni",
                symbol: "KES"
            },
            KGS: {
                displayName: "som kârgâz",
                "displayName-count-one": "som kârgâz",
                "displayName-count-few": "somi kârgâzi",
                "displayName-count-other": "somi kârgâzi",
                symbol: "KGS"
            },
            KHR: {
                displayName: "riel cambodgian",
                "displayName-count-one": "riel cambodgian",
                "displayName-count-few": "rieli cambodgieni",
                "displayName-count-other": "rieli cambodgieni",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "franc comorian",
                "displayName-count-one": "franc comorian",
                "displayName-count-few": "franci comorieni",
                "displayName-count-other": "franci comorieni",
                symbol: "KMF",
                "symbol-alt-narrow": "CF"
            },
            KPW: {
                displayName: "won nord-coreean",
                "displayName-count-one": "won nord-coreean",
                "displayName-count-few": "woni nord-coreeni",
                "displayName-count-other": "woni nord-coreeni",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "KRH",
                symbol: "KRH"
            },
            KRO: {
                displayName: "KRO",
                symbol: "KRO"
            },
            KRW: {
                displayName: "won sud-coreean",
                "displayName-count-one": "won sud-coreean",
                "displayName-count-few": "woni sud-coreeni",
                "displayName-count-other": "woni sud-coreeni",
                symbol: "KRW",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "dinar kuweitian",
                "displayName-count-one": "dinar kuweitian",
                "displayName-count-few": "dinari kuweitieni",
                "displayName-count-other": "dinari kuweitieni",
                symbol: "KWD"
            },
            KYD: {
                displayName: "dolar din Insulele Cayman",
                "displayName-count-one": "dolar din Insulele Cayman",
                "displayName-count-few": "dolari din Insulele Cayman",
                "displayName-count-other": "dolari din Insulele Cayman",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "tenge kazahă",
                "displayName-count-one": "tenge kazahă",
                "displayName-count-few": "tenge kazahe",
                "displayName-count-other": "tenge kazahe",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "kip laoțian",
                "displayName-count-one": "kip laoțian",
                "displayName-count-few": "kipi laoțieni",
                "displayName-count-other": "kipi laoțieni",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "liră libaneză",
                "displayName-count-one": "liră libaneză",
                "displayName-count-few": "lire libaneze",
                "displayName-count-other": "lire libaneze",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "rupie srilankeză",
                "displayName-count-one": "rupie srilankeză",
                "displayName-count-few": "rupii srilankeze",
                "displayName-count-other": "rupii srilankeze",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "dolar liberian",
                "displayName-count-one": "dolar liberian",
                "displayName-count-few": "dolari liberieni",
                "displayName-count-other": "dolari liberieni",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "loti lesothian",
                "displayName-count-one": "maloti leshotieni",
                "displayName-count-few": "maloti leshotieni",
                "displayName-count-other": "maloti leshotieni",
                symbol: "LSL"
            },
            LTL: {
                displayName: "litu lituanian",
                "displayName-count-one": "litu lituanian",
                "displayName-count-few": "lite lituaniene",
                "displayName-count-other": "lite lituaniene",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "LTT",
                symbol: "LTT"
            },
            LUC: {
                displayName: "franc convertibil luxemburghez",
                "displayName-count-one": "franc convertibil luxemburghez",
                "displayName-count-few": "franci convertibili luxemburghezi",
                "displayName-count-other": "franci convertibili luxemburghezi",
                symbol: "LUC"
            },
            LUF: {
                displayName: "franc luxemburghez",
                "displayName-count-one": "franc luxemburghez",
                "displayName-count-few": "franci luxemburghezi",
                "displayName-count-other": "franci luxemburghezi",
                symbol: "LUF"
            },
            LUL: {
                displayName: "franc financiar luxemburghez",
                "displayName-count-one": "franc financiar luxemburghez",
                "displayName-count-few": "franci financiari luxemburghezi",
                "displayName-count-other": "franci financiari luxemburghezi",
                symbol: "LUL"
            },
            LVL: {
                displayName: "lats letonian",
                "displayName-count-one": "lats letonian",
                "displayName-count-few": "lats letonieni",
                "displayName-count-other": "lats letonieni",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "rublă Letonia",
                "displayName-count-one": "rublă Letonia",
                "displayName-count-few": "ruble Letonia",
                "displayName-count-other": "ruble Letonia",
                symbol: "LVR"
            },
            LYD: {
                displayName: "dinar libian",
                "displayName-count-one": "dinar libian",
                "displayName-count-few": "dinari libieni",
                "displayName-count-other": "dinari libieni",
                symbol: "LYD"
            },
            MAD: {
                displayName: "dirham marocan",
                "displayName-count-one": "dirham marocan",
                "displayName-count-few": "dirhami marocani",
                "displayName-count-other": "dirhami marocani",
                symbol: "MAD"
            },
            MAF: {
                displayName: "franc marocan",
                "displayName-count-one": "franc marocan",
                "displayName-count-few": "franci marocani",
                "displayName-count-other": "franci marocani",
                symbol: "MAF"
            },
            MCF: {
                displayName: "MCF",
                symbol: "MCF"
            },
            MDC: {
                displayName: "MDC",
                symbol: "MDC"
            },
            MDL: {
                displayName: "leu moldovenesc",
                "displayName-count-one": "leu moldovenesc",
                "displayName-count-few": "lei moldovenești",
                "displayName-count-other": "lei moldovenești",
                symbol: "L"
            },
            MGA: {
                displayName: "ariary malgaș",
                "displayName-count-one": "ariary malgaș",
                "displayName-count-few": "ariary malgași",
                "displayName-count-other": "ariary malgași",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "franc Madagascar",
                "displayName-count-one": "franc Madagascar",
                "displayName-count-few": "franci Madagascar",
                "displayName-count-other": "franci Madagascar",
                symbol: "MGF"
            },
            MKD: {
                displayName: "denar",
                "displayName-count-one": "denar",
                "displayName-count-few": "denari",
                "displayName-count-other": "denari",
                symbol: "MKD"
            },
            MKN: {
                displayName: "MKN",
                symbol: "MKN"
            },
            MLF: {
                displayName: "franc Mali",
                "displayName-count-one": "franc Mali",
                "displayName-count-few": "franci Mali",
                "displayName-count-other": "franci Mali",
                symbol: "MLF"
            },
            MMK: {
                displayName: "kyat din Myanmar",
                "displayName-count-one": "kyat din Myanmar",
                "displayName-count-few": "kyați din Myanmar",
                "displayName-count-other": "kyați din Myanmar",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "tugrik mongol",
                "displayName-count-one": "tugrik mongol",
                "displayName-count-few": "tugrici mongoli",
                "displayName-count-other": "tugrici mongoli",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "pataca din Macao",
                "displayName-count-one": "pataca din Macao",
                "displayName-count-few": "pataca din Macao",
                "displayName-count-other": "pataca din Macao",
                symbol: "MOP"
            },
            MRO: {
                displayName: "ouguiya mauritană (1973–2017)",
                "displayName-count-one": "ouguiya mauritană (1973–2017)",
                "displayName-count-few": "ouguiya mauritane (1973–2017)",
                "displayName-count-other": "ouguiya mauritane (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "ouguiya mauritană",
                "displayName-count-one": "ouguiya mauritană",
                "displayName-count-few": "ouguiya mauritane",
                "displayName-count-other": "ouguiya mauritane",
                symbol: "MRU"
            },
            MTL: {
                displayName: "liră malteză",
                "displayName-count-one": "liră malteză",
                "displayName-count-few": "lire malteze",
                "displayName-count-other": "lire malteze",
                symbol: "MTL"
            },
            MTP: {
                displayName: "MTP",
                symbol: "MTP"
            },
            MUR: {
                displayName: "rupie mauritiană",
                "displayName-count-one": "rupie mauritiană",
                "displayName-count-few": "rupii mauritiene",
                "displayName-count-other": "rupii mauritiene",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "MVP",
                symbol: "MVP"
            },
            MVR: {
                displayName: "rufiyaa maldiviană",
                "displayName-count-one": "rufiyaa maldiviană",
                "displayName-count-few": "rufiyaa maldiviene",
                "displayName-count-other": "rufiyaa maldiviene",
                symbol: "MVR"
            },
            MWK: {
                displayName: "kwacha malawiană",
                "displayName-count-one": "kwacha malawiană",
                "displayName-count-few": "kwache malawiene",
                "displayName-count-other": "kwache malawiene",
                symbol: "MWK"
            },
            MXN: {
                displayName: "peso mexican",
                "displayName-count-one": "peso mexican",
                "displayName-count-few": "pesos mexicani",
                "displayName-count-other": "pesos mexicani",
                symbol: "MXN",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "peso mexican de argint (1861–1992)",
                "displayName-count-one": "peso mexican de argint (1861–1992)",
                "displayName-count-few": "pesos mexicani de argint (1861–1992",
                "displayName-count-other": "pesos mexicani de argint (1861–1992)",
                symbol: "MXP"
            },
            MXV: {
                displayName: "MXV",
                symbol: "MXV"
            },
            MYR: {
                displayName: "ringgit malaiezian",
                "displayName-count-one": "ringgit malaiezian",
                "displayName-count-few": "ringgit malaiezieni",
                "displayName-count-other": "ringgit malaiezieni",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "escudo Mozambic",
                symbol: "MZE"
            },
            MZM: {
                displayName: "metical Mozambic vechi",
                symbol: "MZM"
            },
            MZN: {
                displayName: "metical mozambican",
                "displayName-count-one": "metical mozambican",
                "displayName-count-few": "metical mozambicani",
                "displayName-count-other": "metical mozambicani",
                symbol: "MZN"
            },
            NAD: {
                displayName: "dolar namibian",
                "displayName-count-one": "dolar namibian",
                "displayName-count-few": "dolari namibieni",
                "displayName-count-other": "dolari namibieni",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "naira nigeriană",
                "displayName-count-one": "naira nigeriană",
                "displayName-count-few": "naire nigeriene",
                "displayName-count-other": "naire nigeriene",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "cordoba nicaraguană (1988–1991)",
                symbol: "NIC"
            },
            NIO: {
                displayName: "córdoba oro",
                "displayName-count-one": "córdoba oro",
                "displayName-count-few": "córdobe oro",
                "displayName-count-other": "córdobe oro",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "gulden olandez",
                "displayName-count-one": "gulden olandez",
                "displayName-count-few": "guldeni olandezi",
                "displayName-count-other": "guldeni olandezi",
                symbol: "NLG"
            },
            NOK: {
                displayName: "coroană norvegiană",
                "displayName-count-one": "coroană norvegiană",
                "displayName-count-few": "coroane norvegiene",
                "displayName-count-other": "coroane norvegiene",
                symbol: "NOK",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "rupie nepaleză",
                "displayName-count-one": "rupie nepaleză",
                "displayName-count-few": "rupii nepaleze",
                "displayName-count-other": "rupii nepaleze",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "dolar neozeelandez",
                "displayName-count-one": "dolar neozeelandez",
                "displayName-count-few": "dolari neozeelandezi",
                "displayName-count-other": "dolari neozeelandezi",
                symbol: "NZD",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "rial omanez",
                "displayName-count-one": "rial omanez",
                "displayName-count-few": "riali omanezi",
                "displayName-count-other": "riali omanezi",
                symbol: "OMR"
            },
            PAB: {
                displayName: "balboa panameză",
                "displayName-count-one": "balboa panameză",
                "displayName-count-few": "balboa panameze",
                "displayName-count-other": "balboa panameze",
                symbol: "PAB"
            },
            PEI: {
                displayName: "inti peruvian",
                symbol: "PEI"
            },
            PEN: {
                displayName: "sol",
                "displayName-count-one": "sol",
                "displayName-count-few": "soli",
                "displayName-count-other": "soli",
                symbol: "PEN"
            },
            PES: {
                displayName: "sol peruvian (1863–1965)",
                "displayName-count-one": "sol peruvian (1863–1965)",
                "displayName-count-few": "soli peruvieni (1863–1965)",
                "displayName-count-other": "soli peruvieni (1863–1965)",
                symbol: "PES"
            },
            PGK: {
                displayName: "kina din Papua-Noua Guinee",
                "displayName-count-one": "kina din Papua-Noua Guinee",
                "displayName-count-few": "kina din Papua-Noua Guinee",
                "displayName-count-other": "kina din Papua-Noua Guinee",
                symbol: "PGK"
            },
            PHP: {
                displayName: "peso filipinez",
                "displayName-count-one": "peso filipinez",
                "displayName-count-few": "pesos filipinezi",
                "displayName-count-other": "pesos filipinezi",
                symbol: "PHP",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "rupie pakistaneză",
                "displayName-count-one": "rupie pakistaneză",
                "displayName-count-few": "rupii pakistaneze",
                "displayName-count-other": "rupii pakistaneze",
                symbol: "PKR",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "zlot",
                "displayName-count-one": "zlot",
                "displayName-count-few": "zloți",
                "displayName-count-other": "zloți",
                symbol: "PLN",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "zlot polonez (1950–1995)",
                "displayName-count-one": "zlot polonez (1950–1995)",
                "displayName-count-few": "zloți polonezi (1950–1995)",
                "displayName-count-other": "zloți polonezi (1950–1995)",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "PTE",
                symbol: "PTE"
            },
            PYG: {
                displayName: "guarani",
                "displayName-count-one": "guarani",
                "displayName-count-few": "guarani",
                "displayName-count-other": "guarani",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "rial qatarian",
                "displayName-count-one": "rial qatarian",
                "displayName-count-few": "riali qatarieni",
                "displayName-count-other": "riali qatarieni",
                symbol: "QAR"
            },
            RHD: {
                displayName: "dolar rhodesian",
                "displayName-count-one": "dolar rhodesian",
                "displayName-count-few": "dolari rhodesieni",
                "displayName-count-other": "dolari rhodesieni",
                symbol: "RHD"
            },
            ROL: {
                displayName: "leu românesc (1952–2006)",
                "displayName-count-one": "leu românesc (1952–2006)",
                "displayName-count-few": "lei românești (1952–2006)",
                "displayName-count-other": "lei românești (1952–2006)",
                symbol: "ROL"
            },
            RON: {
                displayName: "leu românesc",
                "displayName-count-one": "leu românesc",
                "displayName-count-few": "lei românești",
                "displayName-count-other": "lei românești",
                symbol: "RON",
                "symbol-alt-narrow": "lei"
            },
            RSD: {
                displayName: "dinar sârbesc",
                "displayName-count-one": "dinar sârbesc",
                "displayName-count-few": "dinari sârbești",
                "displayName-count-other": "dinari sârbești",
                symbol: "RSD"
            },
            RUB: {
                displayName: "rublă rusească",
                "displayName-count-one": "rublă rusească",
                "displayName-count-few": "ruble rusești",
                "displayName-count-other": "ruble rusești",
                symbol: "RUB",
                "symbol-alt-narrow": "₽"
            },
            RUR: {
                displayName: "RUR",
                symbol: "RUR"
            },
            RWF: {
                displayName: "franc rwandez",
                "displayName-count-one": "franc rwandez",
                "displayName-count-few": "franci rwandezi",
                "displayName-count-other": "franci rwandezi",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "rial saudit",
                "displayName-count-one": "rial saudit",
                "displayName-count-few": "riali saudiți",
                "displayName-count-other": "riali saudiți",
                symbol: "SAR"
            },
            SBD: {
                displayName: "dolar din Insulele Solomon",
                "displayName-count-one": "dolar din Insulele Solomon",
                "displayName-count-few": "dolari din Insulele Solomon",
                "displayName-count-other": "dolari din Insulele Solomon",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "rupie din Seychelles",
                "displayName-count-one": "rupie din Seychelles",
                "displayName-count-few": "rupii din Seychelles",
                "displayName-count-other": "rupii din Seychelles",
                symbol: "SCR"
            },
            SDD: {
                displayName: "dinar sudanez",
                "displayName-count-one": "dinar sudanez",
                "displayName-count-few": "dinari sudanezi",
                "displayName-count-other": "dinari sudanezi",
                symbol: "SDD"
            },
            SDG: {
                displayName: "liră sudaneză",
                "displayName-count-one": "liră sudaneză",
                "displayName-count-few": "lire sudaneze",
                "displayName-count-other": "lire sudaneze",
                symbol: "SDG"
            },
            SDP: {
                displayName: "liră sudaneză (1957–1998)",
                "displayName-count-one": "liră sudaneză (1957–1998)",
                "displayName-count-few": "lire sudaneze (1957–1998)",
                "displayName-count-other": "lire sudaneze (1957–1998)",
                symbol: "SDP"
            },
            SEK: {
                displayName: "coroană suedeză",
                "displayName-count-one": "coroană suedeză",
                "displayName-count-few": "coroane suedeze",
                "displayName-count-other": "coroane suedeze",
                symbol: "SEK",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "dolar singaporez",
                "displayName-count-one": "dolar singaporez",
                "displayName-count-few": "dolari singaporezi",
                "displayName-count-other": "dolari singaporezi",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "liră Insula Sf. Elena",
                "displayName-count-one": "liră Insula Sf. Elena",
                "displayName-count-few": "lire Insula Sf. Elena",
                "displayName-count-other": "lire Insula Sf. Elena",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "tolar sloven",
                "displayName-count-one": "tolar sloven",
                "displayName-count-few": "tolari sloveni",
                "displayName-count-other": "tolari sloveni",
                symbol: "SIT"
            },
            SKK: {
                displayName: "coroană slovacă",
                "displayName-count-one": "coroană slovacă",
                "displayName-count-few": "coroane slovace",
                "displayName-count-other": "coroane slovace",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "leone din Sierra Leone",
                "displayName-count-one": "leone din Sierra Leone",
                "displayName-count-few": "leoni din Sierra Leone",
                "displayName-count-other": "leoni din Sierra Leone",
                symbol: "SLL"
            },
            SOS: {
                displayName: "șiling somalez",
                "displayName-count-one": "șiling somalez",
                "displayName-count-few": "șilingi somalezi",
                "displayName-count-other": "șilingi somalezi",
                symbol: "SOS"
            },
            SRD: {
                displayName: "dolar surinamez",
                "displayName-count-one": "dolar surinamez",
                "displayName-count-few": "dolari surinamezi",
                "displayName-count-other": "dolari surinamezi",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "gulden Surinam",
                "displayName-count-one": "gulden Surinam",
                "displayName-count-few": "guldeni Surinam",
                "displayName-count-other": "guldeni Surinam",
                symbol: "SRG"
            },
            SSP: {
                displayName: "liră din Sudanul de Sud",
                "displayName-count-one": "liră din Sudanul de Sud",
                "displayName-count-few": "lire din Sudanul de Sud",
                "displayName-count-other": "lire din Sudanul de Sud",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "dobra Sao Tome și Principe (1977–2017)",
                "displayName-count-one": "dobra Sao Tome și Principe (1977–2017)",
                "displayName-count-few": "dobre Sao Tome și Principe (1977–2017)",
                "displayName-count-other": "dobre Sao Tome și Principe (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "dobra Sao Tome și Principe",
                "displayName-count-one": "dobra Sao Tome și Principe",
                "displayName-count-few": "dobre Sao Tome și Principe",
                "displayName-count-other": "dobre Sao Tome și Principe",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "rublă sovietică",
                "displayName-count-one": "rublă sovietică",
                "displayName-count-few": "ruble sovietice",
                "displayName-count-other": "ruble sovietice",
                symbol: "SUR"
            },
            SVC: {
                displayName: "colon El Salvador",
                "displayName-count-one": "colon El Salvador",
                "displayName-count-few": "coloni El Salvador",
                "displayName-count-other": "coloni El Salvador",
                symbol: "SVC"
            },
            SYP: {
                displayName: "liră siriană",
                "displayName-count-one": "liră siriană",
                "displayName-count-few": "lire siriene",
                "displayName-count-other": "lire siriene",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "lilangeni din Swaziland",
                "displayName-count-one": "lilangeni din Swaziland",
                "displayName-count-few": "emalangeni din Swaziland",
                "displayName-count-other": "emalangeni din Swaziland",
                symbol: "SZL"
            },
            THB: {
                displayName: "baht thailandez",
                "displayName-count-one": "baht thailandez",
                "displayName-count-few": "bahți thailandezi",
                "displayName-count-other": "bahți thailandezi",
                symbol: "THB",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "rublă Tadjikistan",
                "displayName-count-one": "rublă Tadjikistan",
                "displayName-count-few": "ruble Tadjikistan",
                "displayName-count-other": "ruble Tadjikistan",
                symbol: "TJR"
            },
            TJS: {
                displayName: "somoni tadjic",
                "displayName-count-one": "somoni tajdic",
                "displayName-count-few": "somoni tadjici",
                "displayName-count-other": "somoni tadjici",
                symbol: "TJS"
            },
            TMM: {
                displayName: "manat turkmen (1993–2009)",
                "displayName-count-one": "manat turkmen (1993–2009)",
                "displayName-count-few": "manat turkmeni (1993–2009)",
                "displayName-count-other": "manat turkmeni (1993–2009)",
                symbol: "TMM"
            },
            TMT: {
                displayName: "manat turkmen",
                "displayName-count-one": "manat turkmen",
                "displayName-count-few": "manat turkmeni",
                "displayName-count-other": "manat turkmeni",
                symbol: "TMT"
            },
            TND: {
                displayName: "dinar tunisian",
                "displayName-count-one": "dinar tunisian",
                "displayName-count-few": "dinari tunisieni",
                "displayName-count-other": "dinari tunisieni",
                symbol: "TND"
            },
            TOP: {
                displayName: "pa’anga tongană",
                "displayName-count-one": "pa’anga tongană",
                "displayName-count-few": "pa’anga tongane",
                "displayName-count-other": "pa’anga tongane",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "TPE",
                symbol: "TPE"
            },
            TRL: {
                displayName: "liră turcească (1922–2005)",
                "displayName-count-one": "liră turcească (1922–2005)",
                "displayName-count-few": "liră turcească (1922–2005)",
                "displayName-count-other": "lire turcești (1922–2005)",
                symbol: "TRL"
            },
            TRY: {
                displayName: "liră turcească",
                "displayName-count-one": "liră turcească",
                "displayName-count-few": "lire turcești",
                "displayName-count-other": "lire turcești",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "dolar din Trinidad și Tobago",
                "displayName-count-one": "dolar din Trinidad și Tobago",
                "displayName-count-few": "dolari din Trinidad și Tobago",
                "displayName-count-other": "dolari din Trinidad și Tobago",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "dolar nou din Taiwan",
                "displayName-count-one": "dolar nou din Taiwan",
                "displayName-count-few": "dolari noi din Taiwan",
                "displayName-count-other": "dolari noi Taiwan",
                symbol: "TWD",
                "symbol-alt-narrow": "NT$"
            },
            TZS: {
                displayName: "șiling tanzanian",
                "displayName-count-one": "șiling tanzanian",
                "displayName-count-few": "șilingi tanzanieni",
                "displayName-count-other": "șilingi tanzanieni",
                symbol: "TZS"
            },
            UAH: {
                displayName: "grivnă",
                "displayName-count-one": "grivnă",
                "displayName-count-few": "grivne",
                "displayName-count-other": "grivne",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "carboavă ucraineană",
                "displayName-count-one": "carboavă ucraineană",
                "displayName-count-few": "carboave ucrainiene",
                "displayName-count-other": "carboave ucrainiene",
                symbol: "UAK"
            },
            UGS: {
                displayName: "șiling ugandez (1966–1987)",
                "displayName-count-one": "șiling ugandez (1966–1987)",
                "displayName-count-few": "șilingi ugandezi (1966–1987)",
                "displayName-count-other": "șilingi ugandezi (1966–1987)",
                symbol: "UGS"
            },
            UGX: {
                displayName: "șiling ugandez",
                "displayName-count-one": "șiling ugandez",
                "displayName-count-few": "șilingi ugandezi",
                "displayName-count-other": "șilingi ugandezi",
                symbol: "UGX"
            },
            USD: {
                displayName: "dolar american",
                "displayName-count-one": "dolar american",
                "displayName-count-few": "dolari americani",
                "displayName-count-other": "dolari americani",
                symbol: "USD",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "dolar american (ziua următoare)",
                "displayName-count-one": "dolar american (ziua următoare)",
                "displayName-count-few": "dolari americani (ziua următoare)",
                "displayName-count-other": "dolari americani (ziua următoare)",
                symbol: "USN"
            },
            USS: {
                displayName: "dolar american (aceeași zi)",
                "displayName-count-one": "dolar american (aceeași zi)",
                "displayName-count-few": "dolari americani (aceeași zi)",
                "displayName-count-other": "dolari americani (aceeași zi)",
                symbol: "USS"
            },
            UYI: {
                displayName: "UYI",
                symbol: "UYI"
            },
            UYP: {
                displayName: "peso Uruguay (1975–1993)",
                "displayName-count-one": "peso Uruguay (1975–1993)",
                "displayName-count-few": "pesos Uruguay (1975–1993)",
                "displayName-count-other": "pesos Uruguay (1975–1993)",
                symbol: "UYP"
            },
            UYU: {
                displayName: "peso uruguayan",
                "displayName-count-one": "peso uruguayan",
                "displayName-count-few": "pesos uruguayeni",
                "displayName-count-other": "pesos uruguayeni",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "UYW",
                symbol: "UYW"
            },
            UZS: {
                displayName: "sum Uzbekistan",
                "displayName-count-one": "sum Uzbekistan",
                "displayName-count-few": "sum Uzbekistan",
                "displayName-count-other": "sum Uzbekistan",
                symbol: "UZS"
            },
            VEB: {
                displayName: "bolivar Venezuela (1871–2008)",
                "displayName-count-one": "bolivar Venezuela (1871–2008)",
                "displayName-count-few": "bolivari Venezuela (1871–2008)",
                "displayName-count-other": "bolivari Venezuela (1871–2008)",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "bolivar venezuelean (2008–2018)",
                "displayName-count-one": "bolivar venezuelean (2008–2018)",
                "displayName-count-few": "bolivari venezueleni (2008–2018)",
                "displayName-count-other": "bolivari venezueleni (2008–2018)",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs"
            },
            VES: {
                displayName: "bolívar soberano",
                "displayName-count-one": "bolívar soberano",
                "displayName-count-few": "bolívari soberano",
                "displayName-count-other": "bolívari soberano",
                symbol: "VES"
            },
            VND: {
                displayName: "dong vietnamez",
                "displayName-count-one": "dong vietnamez",
                "displayName-count-few": "dongi vietnamezi",
                "displayName-count-other": "dongi vietnamezi",
                symbol: "VND",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "VNN",
                symbol: "VNN"
            },
            VUV: {
                displayName: "vatu din Vanuatu",
                "displayName-count-one": "vatu din Vanuatu",
                "displayName-count-few": "vatu din Vanuatu",
                "displayName-count-other": "vatu din Vanuatu",
                symbol: "VUV"
            },
            WST: {
                displayName: "tala samoană",
                "displayName-count-one": "tala samoană",
                "displayName-count-few": "tala samoane",
                "displayName-count-other": "tala samoană",
                symbol: "WST"
            },
            XAF: {
                displayName: "franc CFA BEAC",
                "displayName-count-one": "franc CFA BEAC",
                "displayName-count-few": "franci CFA BEAC",
                "displayName-count-other": "franci CFA central-africani",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "argint",
                symbol: "XAG"
            },
            XAU: {
                displayName: "aur",
                symbol: "XAU"
            },
            XBA: {
                displayName: "unitate compusă europeană",
                symbol: "XBA"
            },
            XBB: {
                displayName: "unitate monetară europeană",
                symbol: "XBB"
            },
            XBC: {
                displayName: "unitate de cont europeană (XBC)",
                symbol: "XBC"
            },
            XBD: {
                displayName: "unitate de cont europeană (XBD)",
                symbol: "XBD"
            },
            XCD: {
                displayName: "dolar est-caraib",
                "displayName-count-one": "dolar est-caraib",
                "displayName-count-few": "dolari est-caraibi",
                "displayName-count-other": "dolari est-caraibi",
                symbol: "XCD",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "drepturi speciale de tragere",
                symbol: "XDR"
            },
            XEU: {
                displayName: "unitate de monedă europeană",
                symbol: "XEU"
            },
            XFO: {
                displayName: "franc francez de aur",
                "displayName-count-one": "franc francez de aur",
                "displayName-count-few": "franci francezi de aur",
                "displayName-count-other": "franci francezi de aur",
                symbol: "XFO"
            },
            XFU: {
                displayName: "franc UIC francez",
                symbol: "XFU"
            },
            XOF: {
                displayName: "franc CFA BCEAO",
                "displayName-count-one": "franc CFA BCEAO",
                "displayName-count-few": "franci CFA BCEAO",
                "displayName-count-other": "franci CFA BCEAO",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "paladiu",
                symbol: "XPD"
            },
            XPF: {
                displayName: "franc CFP",
                "displayName-count-one": "franc CFP",
                "displayName-count-few": "franci CFP",
                "displayName-count-other": "franci CFP",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "platină",
                symbol: "XPT"
            },
            XRE: {
                displayName: "XRE",
                symbol: "XRE"
            },
            XSU: {
                displayName: "XSU",
                symbol: "XSU"
            },
            XTS: {
                displayName: "cod monetar de test",
                symbol: "XTS"
            },
            XUA: {
                displayName: "XUA",
                symbol: "XUA"
            },
            XXX: {
                displayName: "monedă necunoscută",
                "displayName-count-one": "(unitate monetară necunoscută)",
                "displayName-count-few": "(monedă necunoscută)",
                "displayName-count-other": "(monedă necunoscută)",
                symbol: "¤"
            },
            YDD: {
                displayName: "dinar Yemen",
                "displayName-count-one": "dinar Yemen",
                "displayName-count-few": "dinari Yemen",
                "displayName-count-other": "dinari Yemen",
                symbol: "YDD"
            },
            YER: {
                displayName: "rial yemenit",
                "displayName-count-one": "rial yemenit",
                "displayName-count-few": "riali yemeniți",
                "displayName-count-other": "riali yemeniți",
                symbol: "YER"
            },
            YUD: {
                displayName: "dinar iugoslav greu",
                "displayName-count-one": "dinar iugoslav greu",
                "displayName-count-few": "dinari iugoslavi grei",
                "displayName-count-other": "dinari iugoslavi grei",
                symbol: "YUD"
            },
            YUM: {
                displayName: "dinar iugoslav nou",
                "displayName-count-one": "dinar iugoslav nou",
                "displayName-count-few": "dinari iugoslavi noi",
                "displayName-count-other": "dinari iugoslavi noi",
                symbol: "YUM"
            },
            YUN: {
                displayName: "dinar iugoslav convertibil",
                "displayName-count-one": "dinar iugoslav convertibil",
                "displayName-count-few": "dinari iugoslavi convertibili",
                "displayName-count-other": "dinari iugoslavi convertibili",
                symbol: "YUN"
            },
            YUR: {
                displayName: "YUR",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "rand sud-african (financiar)",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "rand sud-african",
                "displayName-count-one": "rand sud-african",
                "displayName-count-few": "ranzi sud-africani",
                "displayName-count-other": "ranzi sud-africani",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "kwacha zambian (1968–2012)",
                "displayName-count-one": "kwacha zambiană (1968–2012)",
                "displayName-count-few": "kwache zambiene (1968–2012)",
                "displayName-count-other": "kwache zambiene (1968–2012)",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "kwacha zambian",
                "displayName-count-one": "kwacha zambian",
                "displayName-count-few": "kwache zambiene",
                "displayName-count-other": "kwache zambiene",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "zair nou",
                "displayName-count-one": "zair nou",
                "displayName-count-few": "zairi noi",
                "displayName-count-other": "zairi noi",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "ZRZ",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "dolar Zimbabwe (1980–2008)",
                "displayName-count-one": "dolar Zimbabwe (1980–2008)",
                "displayName-count-few": "dolari Zimbabwe (1980–2008)",
                "displayName-count-other": "dolari Zimbabwe (1980–2008)",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "dolar Zimbabwe (2009)",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "dolar Zimbabwe (2008)",
                symbol: "ZWR"
            }
        },
        localeCurrency: "MDL"
    },
    calendar: {
        patterns: {
            d: "dd.MM.y",
            D: "EEEE, d MMMM y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d MMMM y HH:mm:ss",
            g: "dd.MM.y HH:mm",
            G: "dd.MM.y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1}, {0}",
            long: "{1}, {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "dd.MM.y G",
                GyMMM: "MMM y G",
                GyMMMd: "d MMM y G",
                GyMMMEd: "E, d MMM y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "dd.MM",
                MEd: "E, dd.MM",
                MMdd: "dd.MM",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E, d MMM",
                MMMMd: "d MMMM",
                MMMMEd: "E, d MMMM",
                "MMMMW-count-one": "'săptămâna' W 'din' MMMM",
                "MMMMW-count-few": "'săptămâna' W 'din' MMMM",
                "MMMMW-count-other": "'săptămâna' W 'din' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "MM.y",
                yMd: "dd.MM.y",
                yMEd: "E, dd.MM.y",
                yMM: "MM.y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E, d MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "'săptămâna' w 'din' Y",
                "yw-count-few": "'săptămâna' w 'din' Y",
                "yw-count-other": "'săptămâna' w 'din' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "dd.MM.y"
        },
        days: {
            format: {
                abbreviated: [
                    "Dum",
                    "Lun",
                    "Mar",
                    "Mie",
                    "Joi",
                    "Vin",
                    "Sâm"
                ],
                narrow: [
                    "D",
                    "L",
                    "Ma",
                    "Mi",
                    "J",
                    "V",
                    "S"
                ],
                short: [
                    "Du",
                    "Lu",
                    "Ma",
                    "Mi",
                    "Jo",
                    "Vi",
                    "Sâ"
                ],
                wide: [
                    "duminică",
                    "luni",
                    "marți",
                    "miercuri",
                    "joi",
                    "vineri",
                    "sâmbătă"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Dum",
                    "Lun",
                    "Mar",
                    "Mie",
                    "Joi",
                    "Vin",
                    "Sâm"
                ],
                narrow: [
                    "D",
                    "L",
                    "Ma",
                    "Mi",
                    "J",
                    "V",
                    "S"
                ],
                short: [
                    "Du",
                    "Lu",
                    "Ma",
                    "Mi",
                    "Jo",
                    "Vi",
                    "Sâ"
                ],
                wide: [
                    "duminică",
                    "luni",
                    "marți",
                    "miercuri",
                    "joi",
                    "vineri",
                    "sâmbătă"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "ian.",
                    "feb.",
                    "mar.",
                    "apr.",
                    "mai",
                    "iun.",
                    "iul.",
                    "aug.",
                    "sept.",
                    "oct.",
                    "nov.",
                    "dec."
                ],
                narrow: [
                    "I",
                    "F",
                    "M",
                    "A",
                    "M",
                    "I",
                    "I",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "ianuarie",
                    "februarie",
                    "martie",
                    "aprilie",
                    "mai",
                    "iunie",
                    "iulie",
                    "august",
                    "septembrie",
                    "octombrie",
                    "noiembrie",
                    "decembrie"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ian.",
                    "feb.",
                    "mar.",
                    "apr.",
                    "mai",
                    "iun.",
                    "iul.",
                    "aug.",
                    "sept.",
                    "oct.",
                    "nov.",
                    "dec."
                ],
                narrow: [
                    "I",
                    "F",
                    "M",
                    "A",
                    "M",
                    "I",
                    "I",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "ianuarie",
                    "februarie",
                    "martie",
                    "aprilie",
                    "mai",
                    "iunie",
                    "iulie",
                    "august",
                    "septembrie",
                    "octombrie",
                    "noiembrie",
                    "decembrie"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "trim. 1",
                    "trim. 2",
                    "trim. 3",
                    "trim. 4"
                ],
                narrow: [
                    "I",
                    "II",
                    "III",
                    "IV"
                ],
                wide: [
                    "trimestrul 1",
                    "trimestrul 2",
                    "trimestrul 3",
                    "trimestrul 4"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Trim. 1",
                    "Trim. 2",
                    "Trim. 3",
                    "Trim. 4"
                ],
                narrow: [
                    "I",
                    "II",
                    "III",
                    "IV"
                ],
                wide: [
                    "Trimestrul 1",
                    "Trimestrul 2",
                    "Trimestrul 3",
                    "Trimestrul 4"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "miezul nopții",
                    am: "a.m.",
                    noon: "amiază",
                    pm: "p.m.",
                    morning1: "dimineața",
                    afternoon1: "după-amiaza",
                    evening1: "seara",
                    night1: "noaptea"
                },
                narrow: {
                    midnight: "miezul nopții",
                    am: "a.m.",
                    noon: "amiază",
                    pm: "p.m.",
                    morning1: "dimineață",
                    afternoon1: "după-amiază",
                    evening1: "seară",
                    night1: "noapte"
                },
                wide: {
                    midnight: "miezul nopții",
                    am: "a.m.",
                    noon: "amiază",
                    pm: "p.m.",
                    morning1: "dimineața",
                    afternoon1: "după-amiaza",
                    evening1: "seara",
                    night1: "noaptea"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "miezul nopții",
                    am: "a.m.",
                    noon: "amiază",
                    pm: "p.m.",
                    morning1: "dimineața",
                    afternoon1: "după-amiaza",
                    evening1: "seara",
                    night1: "noaptea"
                },
                narrow: {
                    midnight: "miezul nopții",
                    am: "a.m.",
                    noon: "amiază",
                    pm: "p.m.",
                    morning1: "dimineață",
                    afternoon1: "după-amiază",
                    evening1: "seară",
                    night1: "noapte"
                },
                wide: {
                    midnight: "miezul nopții",
                    am: "a.m.",
                    noon: "amiază",
                    pm: "p.m.",
                    morning1: "dimineața",
                    afternoon1: "după-amiaza",
                    evening1: "seara",
                    night1: "noaptea"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "înainte de Hristos",
                    "1": "după Hristos",
                    "0-alt-variant": "înaintea erei noastre",
                    "1-alt-variant": "era noastră"
                },
                abbreviated: {
                    "0": "î.Hr.",
                    "1": "d.Hr.",
                    "0-alt-variant": "î.e.n.",
                    "1-alt-variant": "e.n."
                },
                narrow: {
                    "0": "î.Hr.",
                    "1": "d.Hr.",
                    "0-alt-variant": "î.e.n",
                    "1-alt-variant": "e.n."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "eră",
                short: "eră",
                narrow: "eră"
            },
            year: {
                wide: "an",
                short: "an",
                narrow: "an"
            },
            quarter: {
                wide: "trimestru",
                short: "trim.",
                narrow: "trim."
            },
            month: {
                wide: "lună",
                short: "lună",
                narrow: "lună"
            },
            week: {
                wide: "săptămână",
                short: "săpt.",
                narrow: "săpt."
            },
            weekOfMonth: {
                wide: "săptămâna din lună",
                short: "săpt. din lună",
                narrow: "săpt. din lună"
            },
            day: {
                wide: "zi",
                short: "zi",
                narrow: "zi"
            },
            dayOfYear: {
                wide: "ziua din an",
                short: "ziua din an",
                narrow: "ziua din an"
            },
            weekday: {
                wide: "ziua din săptămână",
                short: "ziua din săpt.",
                narrow: "ziua din săpt."
            },
            weekdayOfMonth: {
                wide: "ziua săptămânii din lună",
                short: "ziua săpt. din lună",
                narrow: "ziua săpt. din lună"
            },
            dayperiod: {
                short: "a.m/p.m.",
                wide: "a.m/p.m.",
                narrow: "a.m/p.m."
            },
            hour: {
                wide: "oră",
                short: "h",
                narrow: "h"
            },
            minute: {
                wide: "minut",
                short: "min.",
                narrow: "m"
            },
            second: {
                wide: "secundă",
                short: "sec.",
                narrow: "s"
            },
            zone: {
                wide: "fus orar",
                short: "fus",
                narrow: "fus"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "milisecundă"
            }
        }
    },
    firstDay: 1,
    weekendRange: {
        start: 6,
        end: 0
    },
    likelySubtags: {
        ro: "ro-Latn-RO"
    }
});

