/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ro",
    likelySubtags: {
        ro: "ro-Latn-RO"
    },
    identity: {
        language: "ro"
    },
    territory: "RO",
    calendar: {
        patterns: {
            d: "dd.MM.y",
            D: "EEEE, d MMMM y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d MMMM y HH:mm:ss",
            g: "dd.MM.y HH:mm",
            G: "dd.MM.y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1}, {0}",
            long: "{1}, {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "dd.MM.y G",
                GyMMM: "MMM y G",
                GyMMMd: "d MMM y G",
                GyMMMEd: "E, d MMM y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "dd.MM",
                MEd: "E, dd.MM",
                MMdd: "dd.MM",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E, d MMM",
                MMMMd: "d MMMM",
                MMMMEd: "E, d MMMM",
                "MMMMW-count-one": "'săptămâna' W 'din' MMMM",
                "MMMMW-count-few": "'săptămâna' W 'din' MMMM",
                "MMMMW-count-other": "'săptămâna' W 'din' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "MM.y",
                yMd: "dd.MM.y",
                yMEd: "E, dd.MM.y",
                yMM: "MM.y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E, d MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "'săptămâna' w 'din' Y",
                "yw-count-few": "'săptămâna' w 'din' Y",
                "yw-count-other": "'săptămâna' w 'din' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "dd.MM.y"
        },
        days: {
            format: {
                abbreviated: [
                    "dum.",
                    "lun.",
                    "mar.",
                    "mie.",
                    "joi",
                    "vin.",
                    "sâm."
                ],
                narrow: [
                    "D",
                    "L",
                    "M",
                    "M",
                    "J",
                    "V",
                    "S"
                ],
                short: [
                    "du.",
                    "lu.",
                    "ma.",
                    "mi.",
                    "joi",
                    "vi.",
                    "sâ."
                ],
                wide: [
                    "duminică",
                    "luni",
                    "marți",
                    "miercuri",
                    "joi",
                    "vineri",
                    "sâmbătă"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "dum.",
                    "lun.",
                    "mar.",
                    "mie.",
                    "joi",
                    "vin.",
                    "sâm."
                ],
                narrow: [
                    "D",
                    "L",
                    "M",
                    "M",
                    "J",
                    "V",
                    "S"
                ],
                short: [
                    "du.",
                    "lu.",
                    "ma.",
                    "mi.",
                    "joi",
                    "vi.",
                    "sâ."
                ],
                wide: [
                    "duminică",
                    "luni",
                    "marți",
                    "miercuri",
                    "joi",
                    "vineri",
                    "sâmbătă"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "ian.",
                    "feb.",
                    "mar.",
                    "apr.",
                    "mai",
                    "iun.",
                    "iul.",
                    "aug.",
                    "sept.",
                    "oct.",
                    "nov.",
                    "dec."
                ],
                narrow: [
                    "I",
                    "F",
                    "M",
                    "A",
                    "M",
                    "I",
                    "I",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "ianuarie",
                    "februarie",
                    "martie",
                    "aprilie",
                    "mai",
                    "iunie",
                    "iulie",
                    "august",
                    "septembrie",
                    "octombrie",
                    "noiembrie",
                    "decembrie"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ian.",
                    "feb.",
                    "mar.",
                    "apr.",
                    "mai",
                    "iun.",
                    "iul.",
                    "aug.",
                    "sept.",
                    "oct.",
                    "nov.",
                    "dec."
                ],
                narrow: [
                    "I",
                    "F",
                    "M",
                    "A",
                    "M",
                    "I",
                    "I",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "ianuarie",
                    "februarie",
                    "martie",
                    "aprilie",
                    "mai",
                    "iunie",
                    "iulie",
                    "august",
                    "septembrie",
                    "octombrie",
                    "noiembrie",
                    "decembrie"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "trim. I",
                    "trim. II",
                    "trim. III",
                    "trim. IV"
                ],
                narrow: [
                    "I",
                    "II",
                    "III",
                    "IV"
                ],
                wide: [
                    "trimestrul I",
                    "trimestrul al II-lea",
                    "trimestrul al III-lea",
                    "trimestrul al IV-lea"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "trim. I",
                    "trim. II",
                    "trim. III",
                    "trim. IV"
                ],
                narrow: [
                    "I",
                    "II",
                    "III",
                    "IV"
                ],
                wide: [
                    "trimestrul I",
                    "trimestrul al II-lea",
                    "trimestrul al III-lea",
                    "trimestrul al IV-lea"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "miezul nopții",
                    am: "a.m.",
                    noon: "amiază",
                    pm: "p.m.",
                    morning1: "dimineața",
                    afternoon1: "după-amiaza",
                    evening1: "seara",
                    night1: "noaptea"
                },
                narrow: {
                    midnight: "miezul nopții",
                    am: "a.m.",
                    noon: "la amiază",
                    pm: "p.m.",
                    morning1: "dimineața",
                    afternoon1: "după-amiaza",
                    evening1: "seara",
                    night1: "noaptea"
                },
                wide: {
                    midnight: "la miezul nopții",
                    am: "a.m.",
                    noon: "la amiază",
                    pm: "p.m.",
                    morning1: "dimineața",
                    afternoon1: "după-amiaza",
                    evening1: "seara",
                    night1: "noaptea"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "miezul nopții",
                    am: "a.m.",
                    noon: "amiază",
                    pm: "p.m.",
                    morning1: "dimineața",
                    afternoon1: "după-amiaza",
                    evening1: "seara",
                    night1: "noaptea"
                },
                narrow: {
                    midnight: "miezul nopții",
                    am: "a.m.",
                    noon: "amiază",
                    pm: "p.m.",
                    morning1: "dimineața",
                    afternoon1: "după-amiaza",
                    evening1: "seara",
                    night1: "noaptea"
                },
                wide: {
                    midnight: "la miezul nopții",
                    am: "a.m.",
                    noon: "la amiază",
                    pm: "p.m.",
                    morning1: "dimineața",
                    afternoon1: "după-amiaza",
                    evening1: "seara",
                    night1: "noaptea"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "înainte de Hristos",
                    "1": "după Hristos",
                    "0-alt-variant": "înaintea erei noastre",
                    "1-alt-variant": "era noastră"
                },
                abbreviated: {
                    "0": "î.Hr.",
                    "1": "d.Hr.",
                    "0-alt-variant": "î.e.n",
                    "1-alt-variant": "e.n."
                },
                narrow: {
                    "0": "î.Hr.",
                    "1": "d.Hr.",
                    "0-alt-variant": "î.e.n",
                    "1-alt-variant": "e.n."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "eră",
                short: "eră",
                narrow: "eră"
            },
            year: {
                wide: "an",
                short: "an",
                narrow: "an"
            },
            quarter: {
                wide: "trimestru",
                short: "trim.",
                narrow: "trim."
            },
            month: {
                wide: "lună",
                short: "lună",
                narrow: "lună"
            },
            week: {
                wide: "săptămână",
                short: "săpt.",
                narrow: "săpt."
            },
            weekOfMonth: {
                wide: "săptămâna din lună",
                short: "săpt. din lună",
                narrow: "săpt. din lună"
            },
            day: {
                wide: "zi",
                short: "zi",
                narrow: "zi"
            },
            dayOfYear: {
                wide: "ziua din an",
                short: "ziua din an",
                narrow: "ziua din an"
            },
            weekday: {
                wide: "ziua din săptămână",
                short: "ziua din săpt.",
                narrow: "ziua din săpt."
            },
            weekdayOfMonth: {
                wide: "ziua săptămânii din lună",
                short: "ziua săpt. din lună",
                narrow: "ziua săpt. din lună"
            },
            dayperiod: {
                short: "a.m/p.m.",
                wide: "a.m/p.m.",
                narrow: "a.m/p.m."
            },
            hour: {
                wide: "oră",
                short: "h",
                narrow: "h"
            },
            minute: {
                wide: "minut",
                short: "min.",
                narrow: "m"
            },
            second: {
                wide: "secundă",
                short: "sec.",
                narrow: "s"
            },
            zone: {
                wide: "fus orar",
                short: "fus",
                narrow: "fus"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "milisecundă"
            }
        }
    },
    firstDay: 1
});

