/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ru-KG",
    likelySubtags: {
        ru: "ru-Cyrl-RU"
    },
    identity: {
        language: "ru",
        territory: "KG"
    },
    territory: "KG",
    calendar: {
        patterns: {
            d: "dd.MM.y",
            D: "EEEE, d MMMM y 'г'.",
            m: "d MMM",
            M: "d MMMM",
            y: "LLL y 'г'.",
            Y: "LLLL y 'г'.",
            F: "EEEE, d MMMM y 'г'. HH:mm:ss",
            g: "dd.MM.y HH:mm",
            G: "dd.MM.y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1}, {0}",
            long: "{1}, {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "ccc, h:mm B",
                EBhms: "ccc, h:mm:ss B",
                Ed: "ccc, d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y 'г'. G",
                GyMd: "dd.MM.y GGGGG",
                GyMMM: "LLL y 'г'. G",
                GyMMMd: "d MMM y 'г'. G",
                GyMMMEd: "E, d MMM y 'г'. G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "dd.MM",
                MEd: "E, dd.MM",
                MMdd: "dd.MM",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "ccc, d MMM",
                MMMMd: "d MMMM",
                "MMMMW-count-one": "W-'я' 'неделя' MMMM",
                "MMMMW-count-few": "W-'я' 'неделя' MMMM",
                "MMMMW-count-many": "W-'я' 'неделя' MMMM",
                "MMMMW-count-other": "W-'я' 'неделя' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "MM.y",
                yMd: "dd.MM.y",
                yMEd: "ccc, dd.MM.y 'г'.",
                yMM: "MM.y",
                yMMM: "LLL y 'г'.",
                yMMMd: "d MMM y 'г'.",
                yMMMEd: "E, d MMM y 'г'.",
                yMMMM: "LLLL y 'г'.",
                yQQQ: "QQQ y 'г'.",
                yQQQQ: "QQQQ y 'г'.",
                "yw-count-one": "w-'я' 'неделя' Y 'г'.",
                "yw-count-few": "w-'я' 'неделя' Y 'г'.",
                "yw-count-many": "w-'я' 'неделя' Y 'г'.",
                "yw-count-other": "w-'я' 'неделя' Y 'г'."
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM y 'г'.",
            long: "d MMMM y 'г'.",
            medium: "d MMM y 'г'.",
            short: "dd.MM.y"
        },
        days: {
            format: {
                abbreviated: [
                    "вс",
                    "пн",
                    "вт",
                    "ср",
                    "чт",
                    "пт",
                    "сб"
                ],
                narrow: [
                    "В",
                    "П",
                    "В",
                    "С",
                    "Ч",
                    "П",
                    "С"
                ],
                short: [
                    "вс",
                    "пн",
                    "вт",
                    "ср",
                    "чт",
                    "пт",
                    "сб"
                ],
                wide: [
                    "воскресенье",
                    "понедельник",
                    "вторник",
                    "среда",
                    "четверг",
                    "пятница",
                    "суббота"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "вс",
                    "пн",
                    "вт",
                    "ср",
                    "чт",
                    "пт",
                    "сб"
                ],
                narrow: [
                    "В",
                    "П",
                    "В",
                    "С",
                    "Ч",
                    "П",
                    "С"
                ],
                short: [
                    "вс",
                    "пн",
                    "вт",
                    "ср",
                    "чт",
                    "пт",
                    "сб"
                ],
                wide: [
                    "воскресенье",
                    "понедельник",
                    "вторник",
                    "среда",
                    "четверг",
                    "пятница",
                    "суббота"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "янв.",
                    "февр.",
                    "мар.",
                    "апр.",
                    "мая",
                    "июн.",
                    "июл.",
                    "авг.",
                    "сент.",
                    "окт.",
                    "нояб.",
                    "дек."
                ],
                narrow: [
                    "Я",
                    "Ф",
                    "М",
                    "А",
                    "М",
                    "И",
                    "И",
                    "А",
                    "С",
                    "О",
                    "Н",
                    "Д"
                ],
                wide: [
                    "января",
                    "февраля",
                    "марта",
                    "апреля",
                    "мая",
                    "июня",
                    "июля",
                    "августа",
                    "сентября",
                    "октября",
                    "ноября",
                    "декабря"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "янв.",
                    "февр.",
                    "март",
                    "апр.",
                    "май",
                    "июнь",
                    "июль",
                    "авг.",
                    "сент.",
                    "окт.",
                    "нояб.",
                    "дек."
                ],
                narrow: [
                    "Я",
                    "Ф",
                    "М",
                    "А",
                    "М",
                    "И",
                    "И",
                    "А",
                    "С",
                    "О",
                    "Н",
                    "Д"
                ],
                wide: [
                    "январь",
                    "февраль",
                    "март",
                    "апрель",
                    "май",
                    "июнь",
                    "июль",
                    "август",
                    "сентябрь",
                    "октябрь",
                    "ноябрь",
                    "декабрь"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1-й кв.",
                    "2-й кв.",
                    "3-й кв.",
                    "4-й кв."
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1-й квартал",
                    "2-й квартал",
                    "3-й квартал",
                    "4-й квартал"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1-й кв.",
                    "2-й кв.",
                    "3-й кв.",
                    "4-й кв."
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1-й квартал",
                    "2-й квартал",
                    "3-й квартал",
                    "4-й квартал"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "полн.",
                    am: "AM",
                    noon: "полд.",
                    pm: "PM",
                    morning1: "утра",
                    afternoon1: "дня",
                    evening1: "вечера",
                    night1: "ночи"
                },
                narrow: {
                    midnight: "полн.",
                    am: "AM",
                    noon: "полд.",
                    pm: "PM",
                    morning1: "утра",
                    afternoon1: "дня",
                    evening1: "веч.",
                    night1: "ночи"
                },
                wide: {
                    midnight: "полночь",
                    am: "AM",
                    noon: "полдень",
                    pm: "PM",
                    morning1: "утра",
                    afternoon1: "дня",
                    evening1: "вечера",
                    night1: "ночи"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "полн.",
                    am: "AM",
                    noon: "полд.",
                    pm: "PM",
                    morning1: "утро",
                    afternoon1: "день",
                    evening1: "веч.",
                    night1: "ночь"
                },
                narrow: {
                    midnight: "полн.",
                    am: "AM",
                    noon: "полд.",
                    pm: "PM",
                    morning1: "утро",
                    afternoon1: "день",
                    evening1: "веч.",
                    night1: "ночь"
                },
                wide: {
                    midnight: "полночь",
                    am: "AM",
                    noon: "полдень",
                    pm: "PM",
                    morning1: "утро",
                    afternoon1: "день",
                    evening1: "вечер",
                    night1: "ночь"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "до Рождества Христова",
                    "1": "от Рождества Христова",
                    "0-alt-variant": "до нашей эры",
                    "1-alt-variant": "нашей эры"
                },
                abbreviated: {
                    "0": "до н. э.",
                    "1": "н. э.",
                    "0-alt-variant": "до н. э.",
                    "1-alt-variant": "н. э."
                },
                narrow: {
                    "0": "до н.э.",
                    "1": "н.э.",
                    "0-alt-variant": "до н. э.",
                    "1-alt-variant": "н. э."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "эра",
                short: "эра",
                narrow: "эра"
            },
            year: {
                wide: "год",
                short: "г.",
                narrow: "г."
            },
            quarter: {
                wide: "квартал",
                short: "кв.",
                narrow: "кв."
            },
            month: {
                wide: "месяц",
                short: "мес.",
                narrow: "мес."
            },
            week: {
                wide: "неделя",
                short: "нед.",
                narrow: "нед."
            },
            weekOfMonth: {
                wide: "неделя месяца",
                short: "нед. месяца",
                narrow: "нед. мес."
            },
            day: {
                wide: "день",
                short: "дн.",
                narrow: "дн."
            },
            dayOfYear: {
                wide: "день года",
                short: "дн. года",
                narrow: "дн. года"
            },
            weekday: {
                wide: "день недели",
                short: "дн. недели",
                narrow: "дн. нед."
            },
            weekdayOfMonth: {
                wide: "день недели в месяце",
                short: "дн. нед. в месяце",
                narrow: "дн. нед. в мес."
            },
            dayperiod: {
                short: "AM/PM",
                wide: "AM/PM",
                narrow: "AM/PM"
            },
            hour: {
                wide: "час",
                short: "ч",
                narrow: "ч"
            },
            minute: {
                wide: "минута",
                short: "мин.",
                narrow: "мин"
            },
            second: {
                wide: "секунда",
                short: "сек.",
                narrow: "с"
            },
            zone: {
                wide: "часовой пояс",
                short: "час. пояс",
                narrow: "час. пояс"
            },
            millisecond: {
                narrow: "мс",
                short: "мс",
                wide: "миллисекунда"
            }
        }
    },
    firstDay: 1
});

