/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "sa",
    likelySubtags: {
        sa: "sa-Deva-IN"
    },
    identity: {
        language: "sa"
    },
    territory: "IN",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE, d MMMM y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d MMMM y h:mm:ss a",
            g: "d/M/y h:mm a",
            G: "d/M/y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} तदा {0}",
            long: "{1} तदा {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "B h",
                Bhm: "B h:mm",
                Bhms: "B h:mm:ss",
                d: "d",
                E: "ccc",
                EBhm: "E B h:mm",
                EBhms: "E B h:mm:ss",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "MMM G y",
                GyMMMd: "d MMM y G",
                GyMMMEd: "E, d MMM y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E, d/M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E, d MMM",
                MMMMd: "d MMMM",
                "MMMMW-count-other": "'week' W 'of' MMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E, d/M/y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E, d MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "EEEE, d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "d/M/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "रवि",
                    "सोम",
                    "मंगल",
                    "बुध",
                    "गुरु",
                    "शुक्र",
                    "शनि"
                ],
                narrow: [
                    "र",
                    "सो",
                    "मं",
                    "बु",
                    "गु",
                    "शु",
                    "श"
                ],
                short: [
                    "Sun",
                    "Mon",
                    "Tue",
                    "Wed",
                    "Thu",
                    "Fri",
                    "Sat"
                ],
                wide: [
                    "रविवासरः",
                    "सोमवासरः",
                    "मंगलवासरः",
                    "बुधवासरः",
                    "गुरुवासर:",
                    "शुक्रवासरः",
                    "शनिवासरः"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "रवि",
                    "सोम",
                    "मंगल",
                    "बुध",
                    "गुरु",
                    "शुक्र",
                    "शनि"
                ],
                narrow: [
                    "र",
                    "सो",
                    "मं",
                    "बु",
                    "गु",
                    "शु",
                    "श"
                ],
                short: [
                    "Sun",
                    "Mon",
                    "Tue",
                    "Wed",
                    "Thu",
                    "Fri",
                    "Sat"
                ],
                wide: [
                    "रविवासरः",
                    "सोमवासरः",
                    "मंगलवासरः",
                    "बुधवासरः",
                    "गुरुवासर:",
                    "शुक्रवासरः",
                    "शनिवासरः"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "जनवरी:",
                    "फरवरी:",
                    "मार्च:",
                    "अप्रैल:",
                    "मई",
                    "जून:",
                    "जुलाई:",
                    "अगस्त:",
                    "सितंबर:",
                    "अक्तूबर:",
                    "नवंबर:",
                    "दिसंबर:"
                ],
                narrow: [
                    "ज",
                    "फ",
                    "मा",
                    "अ",
                    "म",
                    "जू",
                    "जु",
                    "अ",
                    "सि",
                    "अ",
                    "न",
                    "दि"
                ],
                wide: [
                    "जनवरीमासः",
                    "फरवरीमासः",
                    "मार्चमासः",
                    "अप्रैलमासः",
                    "मईमासः",
                    "जूनमासः",
                    "जुलाईमासः",
                    "अगस्तमासः",
                    "सितंबरमासः",
                    "अक्तूबरमासः",
                    "नवंबरमासः",
                    "दिसंबरमासः"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "जनवरी:",
                    "फरवरी:",
                    "मार्च:",
                    "अप्रैल:",
                    "मई",
                    "जून:",
                    "जुलाई:",
                    "अगस्त:",
                    "सितंबर:",
                    "अक्तूबर:",
                    "नवंबर:",
                    "दिसंबर:"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "जनवरीमासः",
                    "फरवरीमासः",
                    "मार्चमासः",
                    "अप्रैलमासः",
                    "मईमासः",
                    "जूनमासः",
                    "जुलाईमासः",
                    "अगस्तमासः",
                    "सितंबरमासः",
                    "अक्तूबरमासः",
                    "नवंबरमासः",
                    "दिसंबरमासः"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "त्रैमासिक1",
                    "त्रैमासिक2",
                    "त्रैमासिक3",
                    "त्रैमासिक4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "प्रथम त्रैमासिक",
                    "द्वितीय त्रैमासिक",
                    "तृतीय त्रैमासिक",
                    "चतुर्थ त्रैमासिक"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "त्रैमासिक1",
                    "त्रैमासिक2",
                    "त्रैमासिक3",
                    "त्रैमासिक4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "प्रथम त्रैमासिक",
                    "द्वितीय त्रैमासिक",
                    "तृतीय त्रैमासिक",
                    "चतुर्थ त्रैमासिक"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "पूर्वाह्न",
                    pm: "अपराह्न"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "BCE",
                    "1": "CE",
                    "0-alt-variant": "इ.स.पू.",
                    "1-alt-variant": "संवत्"
                },
                abbreviated: {
                    "0": "BCE",
                    "1": "CE",
                    "0-alt-variant": "इ.स.पू.",
                    "1-alt-variant": "संवत्"
                },
                narrow: {
                    "0": "BCE",
                    "1": "CE",
                    "0-alt-variant": "इ.स.पू.",
                    "1-alt-variant": "संवत्"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "युग",
                short: "युग",
                narrow: "युग"
            },
            year: {
                wide: "वर्ष:",
                short: "वर्ष:",
                narrow: "वर्ष"
            },
            quarter: {
                wide: "त्रेमासिक",
                short: "त्रेमासिक",
                narrow: "त्रेमासिक"
            },
            month: {
                wide: "मास:",
                short: "मास",
                narrow: "मास"
            },
            week: {
                wide: "सप्ताह:",
                short: "सप्ताह",
                narrow: "सप्ताह"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "वासर:",
                short: "वासर:",
                narrow: "दिनम्"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "सप्ताहस्य दिनं",
                short: "सप्ताहस्य दिनं",
                narrow: "सप्ताहस्य दिनं"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "पूर्वाह्न/अपराह्न",
                wide: "पूर्वाह्न/अपराह्न",
                narrow: "पूर्वाह्न/अपराह्न"
            },
            hour: {
                wide: "होरा",
                short: "होरा",
                narrow: "होरा"
            },
            minute: {
                wide: "निमेष",
                short: "निमेष",
                narrow: "निमेष"
            },
            second: {
                wide: "क्षण",
                short: "पल",
                narrow: "पल"
            },
            zone: {
                wide: "समय मण्डल",
                short: "समय मण्डल",
                narrow: "समय मण्डल"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

