/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "sah",
    likelySubtags: {
        sah: "sah-Cyrl-RU"
    },
    identity: {
        language: "sah"
    },
    territory: "RU",
    calendar: {
        patterns: {
            d: "y/M/d",
            D: "y 'сыл' MMMM d 'күнэ', EEEE",
            m: "MMM d",
            M: "MMMM d",
            y: "y MMM",
            Y: "y MMMM",
            F: "y 'сыл' MMMM d 'күнэ', EEEE HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y 'с'. G",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "MM-dd",
                MEd: "MM-dd, E",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "MMM d, E",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "MMMM W 'нэдиэлэтэ'",
                ms: "mm:ss",
                y: "y",
                yM: "y-MM",
                yMd: "y-MM-dd",
                yMEd: "y-MM-dd, E",
                yMMM: "y MMM",
                yMMMd: "y MMM d",
                yMMMEd: "y MMM d, E",
                yMMMM: "y MMMM",
                yQQQ: "y QQQ",
                yQQQQ: "y QQQQ",
                "yw-count-other": "Y 'сыл' w 'нэдиэлэтэ'"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "y 'сыл' MMMM d 'күнэ', EEEE",
            long: "y, MMMM d",
            medium: "y, MMM d",
            short: "yy/M/d"
        },
        days: {
            format: {
                abbreviated: [
                    "бс",
                    "бн",
                    "оп",
                    "сэ",
                    "чп",
                    "бэ",
                    "сб"
                ],
                narrow: [
                    "Б",
                    "Б",
                    "О",
                    "С",
                    "Ч",
                    "Б",
                    "С"
                ],
                short: [
                    "бс",
                    "бн",
                    "оп",
                    "сэ",
                    "чп",
                    "бэ",
                    "сб"
                ],
                wide: [
                    "баскыһыанньа",
                    "бэнидиэнньик",
                    "оптуорунньук",
                    "сэрэдэ",
                    "чэппиэр",
                    "Бээтиҥсэ",
                    "субуота"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "бс",
                    "бн",
                    "оп",
                    "сэ",
                    "чп",
                    "бэ",
                    "сб"
                ],
                narrow: [
                    "Б",
                    "Б",
                    "О",
                    "С",
                    "Ч",
                    "Б",
                    "С"
                ],
                short: [
                    "бс",
                    "бн",
                    "оп",
                    "сэ",
                    "чп",
                    "бэ",
                    "сб"
                ],
                wide: [
                    "баскыһыанньа",
                    "бэнидиэнньик",
                    "оптуорунньук",
                    "сэрэдэ",
                    "чэппиэр",
                    "Бээтиҥсэ",
                    "субуота"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Тохс",
                    "Олун",
                    "Клн",
                    "Мсу",
                    "Ыам",
                    "Бэс",
                    "Отй",
                    "Атр",
                    "Блҕ",
                    "Алт",
                    "Сэт",
                    "Ахс"
                ],
                narrow: [
                    "Т",
                    "О",
                    "К",
                    "М",
                    "Ы",
                    "Б",
                    "О",
                    "А",
                    "Б",
                    "А",
                    "С",
                    "А"
                ],
                wide: [
                    "Тохсунньу",
                    "Олунньу",
                    "Кулун тутар",
                    "Муус устар",
                    "Ыам ыйын",
                    "Бэс ыйын",
                    "От ыйын",
                    "Атырдьых ыйын",
                    "Балаҕан ыйын",
                    "Алтынньы",
                    "Сэтинньи",
                    "ахсынньы"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Тохс",
                    "Олун",
                    "Клн",
                    "Мсу",
                    "Ыам",
                    "Бэс",
                    "Отй",
                    "Атр",
                    "Блҕ",
                    "Алт",
                    "Сэт",
                    "Ахс"
                ],
                narrow: [
                    "Т",
                    "О",
                    "К",
                    "М",
                    "Ы",
                    "Б",
                    "О",
                    "А",
                    "Б",
                    "А",
                    "С",
                    "А"
                ],
                wide: [
                    "тохсунньу",
                    "олунньу",
                    "кулун тутар",
                    "муус устар",
                    "ыам ыйа",
                    "бэс ыйа",
                    "от ыйа",
                    "атырдьых ыйа",
                    "балаҕан ыйа",
                    "алтынньы",
                    "сэтинньи",
                    "ахсынньы"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1-кы кб",
                    "2-с кб",
                    "3-с кб",
                    "4-с кб"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1-кы кыбаартал",
                    "2-с кыбаартал",
                    "3-с кыбаартал",
                    "4-с кыбаартал"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1-кы кб",
                    "2-с кб",
                    "3-с кб",
                    "4-с кб"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1-кы кыбаартал",
                    "2-с кыбаартал",
                    "3-с кыбаартал",
                    "4-с кыбаартал"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "ЭИ",
                    pm: "ЭК"
                },
                narrow: {
                    am: "ЭИ",
                    pm: "ЭК"
                },
                wide: {
                    am: "ЭИ",
                    pm: "ЭК"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "ЭИ",
                    pm: "ЭК"
                },
                narrow: {
                    am: "ЭИ",
                    pm: "ЭК"
                },
                wide: {
                    am: "ЭИ",
                    pm: "ЭК"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "б. э. и.",
                    "1": "б. э",
                    "0-alt-variant": "биһиги ээрэбит иннинэ",
                    "1-alt-variant": "биһиги ээрэбит"
                },
                abbreviated: {
                    "0": "б. э. и.",
                    "1": "б. э",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                narrow: {
                    "0": "б. э. и.",
                    "1": "б. э",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Ээрэ",
                short: "Ээрэ",
                narrow: "Ээрэ"
            },
            year: {
                wide: "Сыл",
                short: "Сыл",
                narrow: "Сыл"
            },
            quarter: {
                wide: "Чиэппэр",
                short: "чпр.",
                narrow: "чпр."
            },
            month: {
                wide: "Ый",
                short: "Ый",
                narrow: "Ый"
            },
            week: {
                wide: "Нэдиэлэ",
                short: "Нэдиэлэ",
                narrow: "Нэдиэлэ"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Күн",
                short: "Күн",
                narrow: "Күн"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Нэдиэлэ күнэ",
                short: "Нэдиэлэ күнэ",
                narrow: "Нэдиэлэ күнэ"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "ЭИ/ЭК",
                wide: "ЭИ/ЭК",
                narrow: "ЭИ/ЭК"
            },
            hour: {
                wide: "Чаас",
                short: "Чаас",
                narrow: "Чаас"
            },
            minute: {
                wide: "Мүнүүтэ",
                short: "Мүнүүтэ",
                narrow: "Мүнүүтэ"
            },
            second: {
                wide: "Сөкүүндэ",
                short: "Сөкүүндэ",
                narrow: "Сөкүүндэ"
            },
            zone: {
                wide: "Кэм балаһата",
                short: "Кэм балаһата",
                narrow: "Кэм балаһата"
            },
            millisecond: {
                narrow: "мс",
                short: "мс",
                wide: "миллисөкүүндэ"
            }
        }
    },
    firstDay: 1
});

