/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "sbp",
    likelySubtags: {
        sbp: "sbp-Latn-TZ"
    },
    identity: {
        language: "sbp"
    },
    territory: "TZ",
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, d MMMM y",
            m: "MMM d",
            M: "MMMM d",
            y: "MMM y",
            Y: "y MMMM",
            F: "EEEE, d MMMM y HH:mm:ss",
            g: "M/d/y HH:mm",
            G: "M/d/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "M/d",
                MEd: "E, M/d",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, MMM d",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "m:ss",
                y: "y",
                yM: "M/y",
                yMd: "M/d/y",
                yMEd: "E, M/d/y",
                yMMM: "MMM y",
                yMMMd: "MMM d y",
                yMMMEd: "E, MMM d, y",
                yMMMM: "y MMMM",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "dd/MM/y"
        },
        days: {
            format: {
                abbreviated: [
                    "Mul",
                    "Jtt",
                    "Jnn",
                    "Jtn",
                    "Alh",
                    "Iju",
                    "Jmo"
                ],
                narrow: [
                    "M",
                    "J",
                    "J",
                    "J",
                    "A",
                    "I",
                    "J"
                ],
                short: [
                    "Mul",
                    "Jtt",
                    "Jnn",
                    "Jtn",
                    "Alh",
                    "Iju",
                    "Jmo"
                ],
                wide: [
                    "Mulungu",
                    "Jumatatu",
                    "Jumanne",
                    "Jumatano",
                    "Alahamisi",
                    "Ijumaa",
                    "Jumamosi"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Mul",
                    "Jtt",
                    "Jnn",
                    "Jtn",
                    "Alh",
                    "Iju",
                    "Jmo"
                ],
                narrow: [
                    "M",
                    "J",
                    "J",
                    "J",
                    "A",
                    "I",
                    "J"
                ],
                short: [
                    "Mul",
                    "Jtt",
                    "Jnn",
                    "Jtn",
                    "Alh",
                    "Iju",
                    "Jmo"
                ],
                wide: [
                    "Mulungu",
                    "Jumatatu",
                    "Jumanne",
                    "Jumatano",
                    "Alahamisi",
                    "Ijumaa",
                    "Jumamosi"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Mup",
                    "Mwi",
                    "Msh",
                    "Mun",
                    "Mag",
                    "Muj",
                    "Msp",
                    "Mpg",
                    "Mye",
                    "Mok",
                    "Mus",
                    "Muh"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "Mupalangulwa",
                    "Mwitope",
                    "Mushende",
                    "Munyi",
                    "Mushende Magali",
                    "Mujimbi",
                    "Mushipepo",
                    "Mupuguto",
                    "Munyense",
                    "Mokhu",
                    "Musongandembwe",
                    "Muhaano"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Mup",
                    "Mwi",
                    "Msh",
                    "Mun",
                    "Mag",
                    "Muj",
                    "Msp",
                    "Mpg",
                    "Mye",
                    "Mok",
                    "Mus",
                    "Muh"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "Mupalangulwa",
                    "Mwitope",
                    "Mushende",
                    "Munyi",
                    "Mushende Magali",
                    "Mujimbi",
                    "Mushipepo",
                    "Mupuguto",
                    "Munyense",
                    "Mokhu",
                    "Musongandembwe",
                    "Muhaano"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "L1",
                    "L2",
                    "L3",
                    "L4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Lobo 1",
                    "Lobo 2",
                    "Lobo 3",
                    "Lobo 4"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "L1",
                    "L2",
                    "L3",
                    "L4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Lobo 1",
                    "Lobo 2",
                    "Lobo 3",
                    "Lobo 4"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "Lwamilawu",
                    pm: "Pashamihe"
                },
                narrow: {
                    am: "Lwamilawu",
                    pm: "Pashamihe"
                },
                wide: {
                    am: "Lwamilawu",
                    pm: "Pashamihe"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "Lwamilawu",
                    pm: "Pashamihe"
                },
                narrow: {
                    am: "Lwamilawu",
                    pm: "Pashamihe"
                },
                wide: {
                    am: "Lwamilawu",
                    pm: "Pashamihe"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Ashanali uKilisito",
                    "1": "Pamwandi ya Kilisto",
                    "0-alt-variant": "AK",
                    "1-alt-variant": "PK"
                },
                abbreviated: {
                    "0": "AK",
                    "1": "PK",
                    "0-alt-variant": "AK",
                    "1-alt-variant": "PK"
                },
                narrow: {
                    "0": "AK",
                    "1": "PK",
                    "0-alt-variant": "AK",
                    "1-alt-variant": "PK"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Uluhaavi lwa",
                short: "Uluhaavi lwa",
                narrow: "Uluhaavi lwa"
            },
            year: {
                wide: "Mwakha",
                short: "Mwakha",
                narrow: "Mwakha"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Mwesi",
                short: "Mwesi",
                narrow: "Mwesi"
            },
            week: {
                wide: "Ilijuma",
                short: "Ilijuma",
                narrow: "Ilijuma"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Lusiku",
                short: "Lusiku",
                narrow: "Lusiku"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Ulusiku lwa Lijuma",
                short: "Ulusiku lwa Lijuma",
                narrow: "Ulusiku lwa Lijuma"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Uluhaavi lwa lusiku",
                wide: "Uluhaavi lwa lusiku",
                narrow: "Uluhaavi lwa lusiku"
            },
            hour: {
                wide: "Ilisala",
                short: "Ilisala",
                narrow: "Ilisala"
            },
            minute: {
                wide: "Idakika",
                short: "Idakika",
                narrow: "Idakika"
            },
            second: {
                wide: "Isekunde",
                short: "Isekunde",
                narrow: "Isekunde"
            },
            zone: {
                wide: "Uluhaavi lwa lisaa",
                short: "Uluhaavi lwa lisaa",
                narrow: "Uluhaavi lwa lisaa"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

