/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "sd-Arab",
    identity: {
        language: "sd",
        script: "Arab"
    },
    territory: "PK",
    numbers: {
        symbols: {
            decimal: ".",
            group: ",",
            list: ";",
            percentSign: "%",
            plusSign: "+",
            minusSign: "-",
            approximatelySign: "~",
            exponential: "E",
            superscriptingExponent: "×",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "n%"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "$ n"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-one": "n $",
            "unitPattern-count-other": "n $"
        },
        accounting: {
            patterns: [
                "$ n"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "ADP",
                symbol: "ADP"
            },
            AED: {
                displayName: "گڏيل عرب امارات درهم",
                "displayName-count-one": "گڏيل عرب امارات درهم",
                "displayName-count-other": "گڏيل عرب امارات درهم",
                symbol: "AED"
            },
            AFA: {
                displayName: "AFA",
                symbol: "AFA"
            },
            AFN: {
                displayName: "افغاني افغاني",
                "displayName-count-one": "افغاني افغاني",
                "displayName-count-other": "افغاني افغاني",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "ALK",
                symbol: "ALK"
            },
            ALL: {
                displayName: "الباني ليڪ",
                "displayName-count-one": "الباني ليڪ",
                "displayName-count-other": "الباني ليڪ",
                symbol: "ALL"
            },
            AMD: {
                displayName: "ارماني ڊرم",
                "displayName-count-one": "ارماني ڊرم",
                "displayName-count-other": "ارماني ڊرم",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "نيڌرلينڊ انٽليئن گلڊر",
                "displayName-count-one": "نيڌرلينڊ انٽليئن گلڊر",
                "displayName-count-other": "نيڌرلينڊ انٽليئن گلڊر",
                symbol: "ANG"
            },
            AOA: {
                displayName: "انگوليائي ڪوانزا",
                "displayName-count-one": "انگوليائي ڪوانزا",
                "displayName-count-other": "انگوليائي ڪوانزا",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "AOK",
                symbol: "AOK"
            },
            AON: {
                displayName: "AON",
                symbol: "AON"
            },
            AOR: {
                displayName: "AOR",
                symbol: "AOR"
            },
            ARA: {
                displayName: "ARA",
                symbol: "ARA"
            },
            ARL: {
                displayName: "ARL",
                symbol: "ARL"
            },
            ARM: {
                displayName: "ARM",
                symbol: "ARM"
            },
            ARP: {
                displayName: "ARP",
                symbol: "ARP"
            },
            ARS: {
                displayName: "ارجنٽائن پيسو",
                "displayName-count-one": "ارجنٽائن پيسو",
                "displayName-count-other": "ارجنٽائن پيسو",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "ATS",
                symbol: "ATS"
            },
            AUD: {
                displayName: "آسٽريلوي ڊالر",
                "displayName-count-one": "آسٽريلوي ڊالر",
                "displayName-count-other": "آسٽريلوي ڊالر",
                symbol: "A$",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "اروبن فلورن",
                "displayName-count-one": "اروبن فلورن",
                "displayName-count-other": "اروبن فلورن",
                symbol: "AWG"
            },
            AZM: {
                displayName: "AZM",
                symbol: "AZM"
            },
            AZN: {
                displayName: "آذربائيجاني منت",
                "displayName-count-one": "آذربائيجاني منت",
                "displayName-count-other": "آذربائيجاني منت",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "BAD",
                symbol: "BAD"
            },
            BAM: {
                displayName: "بوسنيا هرزگوينا ڪنورٽبل مارڪ",
                "displayName-count-one": "بوسنيا هرزگوينا ڪنورٽبل مارڪ",
                "displayName-count-other": "بوسنيا هرزگوينا ڪنورٽبل مارڪ",
                symbol: "BAM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "BAN",
                symbol: "BAN"
            },
            BBD: {
                displayName: "باربيڊين ڊالر",
                "displayName-count-one": "باربيڊين ڊالر",
                "displayName-count-other": "باربيڊين ڊالر",
                symbol: "BBD",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "بنگلاديشي ٽڪا",
                "displayName-count-one": "بنگلاديشي ٽڪا",
                "displayName-count-other": "بنگلاديشي ٽڪا",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "BEC",
                symbol: "BEC"
            },
            BEF: {
                displayName: "BEF",
                symbol: "BEF"
            },
            BEL: {
                displayName: "BEL",
                symbol: "BEL"
            },
            BGL: {
                displayName: "BGL",
                symbol: "BGL"
            },
            BGM: {
                displayName: "BGM",
                symbol: "BGM"
            },
            BGN: {
                displayName: "بلغارین لیو",
                "displayName-count-one": "بلغارین لیو",
                "displayName-count-other": "بلغارین لیو",
                symbol: "BGN"
            },
            BGO: {
                displayName: "BGO",
                symbol: "BGO"
            },
            BHD: {
                displayName: "بحريني دينار",
                "displayName-count-one": "بحريني دينار",
                "displayName-count-other": "بحريني دينار",
                symbol: "BHD"
            },
            BIF: {
                displayName: "برونڊي فرينڪ",
                "displayName-count-one": "برونڊي فرينڪ",
                "displayName-count-other": "برونڊي فرينڪ",
                symbol: "BIF"
            },
            BMD: {
                displayName: "برمودي ڊالر",
                "displayName-count-one": "برمودي ڊالر",
                "displayName-count-other": "برمودي ڊالر",
                symbol: "BMD",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "برونائي ڊالر",
                "displayName-count-one": "برونائي ڊالر",
                "displayName-count-other": "برونائي ڊالر",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "بولیوین بولیویانو",
                "displayName-count-one": "بولیوین بولیویانو",
                "displayName-count-other": "بولیوین بولیویانو",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "BOL",
                symbol: "BOL"
            },
            BOP: {
                displayName: "BOP",
                symbol: "BOP"
            },
            BOV: {
                displayName: "BOV",
                symbol: "BOV"
            },
            BRB: {
                displayName: "BRB",
                symbol: "BRB"
            },
            BRC: {
                displayName: "BRC",
                symbol: "BRC"
            },
            BRE: {
                displayName: "BRE",
                symbol: "BRE"
            },
            BRL: {
                displayName: "برازيلي ريل",
                "displayName-count-one": "برازيلي ريل",
                "displayName-count-other": "برازيلي ريل",
                symbol: "R$",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "BRN",
                symbol: "BRN"
            },
            BRR: {
                displayName: "BRR",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "BRZ",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "بهاماني ڊادلر",
                "displayName-count-one": "بهاماني ڊادلر",
                "displayName-count-other": "بهاماني ڊادلر",
                symbol: "BSD",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "ڀوٽاني گلٽرم",
                "displayName-count-one": "ڀوٽاني گلٽرم",
                "displayName-count-other": "ڀوٽاني گلٽرم",
                symbol: "BTN"
            },
            BUK: {
                displayName: "BUK",
                symbol: "BUK"
            },
            BWP: {
                displayName: "بوستواني پولا",
                "displayName-count-one": "بوٽسواني پولا",
                "displayName-count-other": "بوستواني پولا",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "BYB",
                symbol: "BYB"
            },
            BYN: {
                displayName: "بیلاروسی ربل",
                "displayName-count-one": "بیلاروسی ربل",
                "displayName-count-other": "بیلاروسی ربل",
                symbol: "BYN",
                "symbol-alt-narrow": "р."
            },
            BYR: {
                displayName: "BYR",
                symbol: "BYR"
            },
            BZD: {
                displayName: "بيليز ڊالر",
                "displayName-count-one": "بيليز ڊالر",
                "displayName-count-other": "بيليز ڊالر",
                symbol: "BZD",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "ڪئينڊيائي ڊالر",
                "displayName-count-one": "ڪئينڊيائي ڊالر",
                "displayName-count-other": "ڪئينڊيائي ڊالر",
                symbol: "CA$",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "ڪانگو فرينڪ",
                "displayName-count-one": "ڪانگو فرينڪ",
                "displayName-count-other": "ڪانگو فرينڪ",
                symbol: "CDF"
            },
            CHE: {
                displayName: "CHE",
                symbol: "CHE"
            },
            CHF: {
                displayName: "سوئس فرينڪ",
                "displayName-count-one": "سوئس فرينڪ",
                "displayName-count-other": "سوئس فرينڪ",
                symbol: "CHF"
            },
            CHW: {
                displayName: "CHW",
                symbol: "CHW"
            },
            CLE: {
                displayName: "CLE",
                symbol: "CLE"
            },
            CLF: {
                displayName: "CLF",
                symbol: "CLF"
            },
            CLP: {
                displayName: "چلي پيسو",
                "displayName-count-one": "چلي پيسو",
                "displayName-count-other": "چلي پيسو",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "چيني يوآن (غير ملڪي)",
                "displayName-count-one": "چيني يوآن (غير ملڪي)",
                "displayName-count-other": "چيني يوآن (غير ملڪي)",
                symbol: "CNH"
            },
            CNX: {
                displayName: "CNX",
                symbol: "CNX"
            },
            CNY: {
                displayName: "چيني يوآن",
                "displayName-count-one": "چيني يوآن",
                "displayName-count-other": "چيني يوآن",
                symbol: "CN¥",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "ڪولمبيائي پيسو",
                "displayName-count-one": "ڪولمبيائي پيسو",
                "displayName-count-other": "ڪولمبيائي پيسو",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "COU",
                symbol: "COU"
            },
            CRC: {
                displayName: "ڪوسٽا ريڪا ڪولن",
                "displayName-count-one": "ڪوسٽا ريڪا ڪولن",
                "displayName-count-other": "ڪوسٽا ريڪا ڪولن",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "CSD",
                symbol: "CSD"
            },
            CSK: {
                displayName: "CSK",
                symbol: "CSK"
            },
            CUC: {
                displayName: "ڪيوبن ڪنورٽيبل پيسو",
                "displayName-count-one": "ڪيوبن ڪنورٽيبل پيسو",
                "displayName-count-other": "ڪيوبن ڪنورٽيبل پيسو",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "ڪيوبن پيسو",
                "displayName-count-one": "ڪيوبن پيسو",
                "displayName-count-other": "ڪيوبن پيسو",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "ڪيپ وردي ايسڪوڊو",
                "displayName-count-one": "ڪيپ وردي ايسڪوڊو",
                "displayName-count-other": "ڪيپ وردي ايسڪوڊو",
                symbol: "CVE"
            },
            CYP: {
                displayName: "CYP",
                symbol: "CYP"
            },
            CZK: {
                displayName: "چيڪ ڪرونا",
                "displayName-count-one": "چيڪ ڪرونا",
                "displayName-count-other": "چيڪ ڪرونا",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "DDM",
                symbol: "DDM"
            },
            DEM: {
                displayName: "DEM",
                symbol: "DEM"
            },
            DJF: {
                displayName: "جبوتي فرينڪ",
                "displayName-count-one": "جبوتي فرينڪ",
                "displayName-count-other": "جبوتي فرينڪ",
                symbol: "DJF"
            },
            DKK: {
                displayName: "دانش ڪرون",
                "displayName-count-one": "ڊينش ڪرون",
                "displayName-count-other": "دانش ڪرون",
                symbol: "DKK",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "ڊومينيڪن پيسو",
                "displayName-count-one": "ڊومينيڪن پيسو",
                "displayName-count-other": "ڊومينيڪن پيسو",
                symbol: "DOP",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "الجيريائي دينار",
                "displayName-count-one": "الجيريائي دينار",
                "displayName-count-other": "الجيريائي دينار",
                symbol: "DZD"
            },
            ECS: {
                displayName: "ECS",
                symbol: "ECS"
            },
            ECV: {
                displayName: "ECV",
                symbol: "ECV"
            },
            EEK: {
                displayName: "EEK",
                symbol: "EEK"
            },
            EGP: {
                displayName: "مصري پائونڊ",
                "displayName-count-one": "مصري پائونڊ",
                "displayName-count-other": "مصري پائونڊ",
                symbol: "EGP",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "ايريٽيريائي ناڪفا",
                "displayName-count-one": "ايريٽيريائي ناڪفا",
                "displayName-count-other": "ايريٽيريائي ناڪفا",
                symbol: "ERN"
            },
            ESA: {
                displayName: "ESA",
                symbol: "ESA"
            },
            ESB: {
                displayName: "ESB",
                symbol: "ESB"
            },
            ESP: {
                displayName: "ESP",
                symbol: "ESP",
                "symbol-alt-narrow": "₧"
            },
            ETB: {
                displayName: "ايٿوپيائي بر",
                "displayName-count-one": "ايٿوپيائي بر",
                "displayName-count-other": "ايٿوپيائي بر",
                symbol: "ETB"
            },
            EUR: {
                displayName: "يورو",
                "displayName-count-one": "يورو",
                "displayName-count-other": "يورو",
                symbol: "€",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "FIM",
                symbol: "FIM"
            },
            FJD: {
                displayName: "فجي ڊالر",
                "displayName-count-one": "فجي ڊالر",
                "displayName-count-other": "فجي ڊالر",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "فاڪلينڊ ٻيٽ پائونڊ",
                "displayName-count-one": "فاڪلينڊ ٻيٽ پائونڊ",
                "displayName-count-other": "فاڪلينڊ ٻيٽ پائونڊ",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "FRF",
                symbol: "FRF"
            },
            GBP: {
                displayName: "برطانوي پائونڊ",
                "displayName-count-one": "برطانوي پائونڊ",
                "displayName-count-other": "برطانوي پائونڊ",
                symbol: "£",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "GEK",
                symbol: "GEK"
            },
            GEL: {
                displayName: "جارجيائي لاري",
                "displayName-count-one": "جارجيائي لاري",
                "displayName-count-other": "جارجيائي لاري",
                symbol: "GEL",
                "symbol-alt-narrow": "₾"
            },
            GHC: {
                displayName: "GHC",
                symbol: "GHC"
            },
            GHS: {
                displayName: "گهانين سيدي",
                "displayName-count-one": "گهانين سيدي",
                "displayName-count-other": "گهانين سيدي",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "جبرالٽر پائونڊ",
                "displayName-count-one": "جبرالٽر پائونڊ",
                "displayName-count-other": "جبرالٽر پائونڊ",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "گيمبيا دلاسائي",
                "displayName-count-one": "گيمبيا دلاسائي",
                "displayName-count-other": "گيمبيا دلاسائي",
                symbol: "GMD"
            },
            GNF: {
                displayName: "گني فرينڪ",
                "displayName-count-one": "گني فرينڪ",
                "displayName-count-other": "گني فرينڪ",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "GNS",
                symbol: "GNS"
            },
            GQE: {
                displayName: "GQE",
                symbol: "GQE"
            },
            GRD: {
                displayName: "GRD",
                symbol: "GRD"
            },
            GTQ: {
                displayName: "گوئٽي مالا ڪٽزل",
                "displayName-count-one": "گوئٽي مالا ڪٽزل",
                "displayName-count-other": "گوئٽي مالا ڪٽزل",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "GWE",
                symbol: "GWE"
            },
            GWP: {
                displayName: "GWP",
                symbol: "GWP"
            },
            GYD: {
                displayName: "گيانا ڊالر",
                "displayName-count-one": "گيانا ڊالر",
                "displayName-count-other": "گيانا ڊالر",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "هانگ ڪانگ ڊالر",
                "displayName-count-one": "هانگ ڪانگ ڊالر",
                "displayName-count-other": "هانگ ڪانگ ڊالر",
                symbol: "HK$",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "هونڊوراس ليمپرا",
                "displayName-count-one": "هونڊوراس ليمپرا",
                "displayName-count-other": "هونڊوراس ليمپرا",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "HRD",
                symbol: "HRD"
            },
            HRK: {
                displayName: "ڪروشيائي ڪونا",
                "displayName-count-one": "ڪروشيائي ڪونا",
                "displayName-count-other": "ڪروشيائي ڪونا",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "هيٽي گورڊي",
                "displayName-count-one": "هيٽي گورڊي",
                "displayName-count-other": "هيٽي گورڊي",
                symbol: "HTG"
            },
            HUF: {
                displayName: "هنگيرين فورنٽ",
                "displayName-count-one": "هنگيرين فورنٽ",
                "displayName-count-other": "هنگيرين فورنٽ",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "انڊونيشيائي رپيه",
                "displayName-count-one": "انڊونيشيائي رپيه",
                "displayName-count-other": "انڊونيشيائي رپيو",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "IEP",
                symbol: "IEP"
            },
            ILP: {
                displayName: "ILP",
                symbol: "ILP"
            },
            ILR: {
                displayName: "ILR",
                symbol: "ILR"
            },
            ILS: {
                displayName: "اسرائيلي نيو شيڪل",
                "displayName-count-one": "اسرائيلي نيو شيڪل",
                "displayName-count-other": "اسرائيلي نيو شيڪل",
                symbol: "₪",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "انڊين رپي",
                "displayName-count-one": "انڊين رپي",
                "displayName-count-other": "انڊين رپي",
                symbol: "₹",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "عراقي دينار",
                "displayName-count-one": "عراقي دينار",
                "displayName-count-other": "عراقي دينار",
                symbol: "IQD"
            },
            IRR: {
                displayName: "ايراني ريال",
                "displayName-count-one": "ايراني ريال",
                "displayName-count-other": "ايراني ريال",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "ISJ",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "آئيس لينڊي ڪرونا",
                "displayName-count-one": "آئيس لينڊي ڪرونا",
                "displayName-count-other": "آئيس لينڊي ڪرونا",
                symbol: "ISK",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "ITL",
                symbol: "ITL"
            },
            JMD: {
                displayName: "جميڪائي ڊالر",
                "displayName-count-one": "جميڪائي ڊالر",
                "displayName-count-other": "جميڪائي ڊالر",
                symbol: "JMD",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "اردني دينار",
                "displayName-count-one": "اردني دينار",
                "displayName-count-other": "اردني دينار",
                symbol: "JOD"
            },
            JPY: {
                displayName: "جاپاني يين",
                "displayName-count-one": "جاپاني يين",
                "displayName-count-other": "جاپاني يين",
                symbol: "JP¥",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "ڪينيائي سلنگ",
                "displayName-count-one": "ڪينيائي شلنگ",
                "displayName-count-other": "ڪينيائي سلنگ",
                symbol: "KES"
            },
            KGS: {
                displayName: "ڪرغزستاني سوم",
                "displayName-count-one": "ڪرغزستاني سوم",
                "displayName-count-other": "ڪرغزستاني سوم",
                symbol: "KGS"
            },
            KHR: {
                displayName: "ڪمبوڊيائي ريال",
                "displayName-count-one": "ڪمبوڊيائي ريال",
                "displayName-count-other": "ڪمبوڊيائي ريال",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "ڪوموريائي فرينڪ",
                "displayName-count-one": "ڪوموريائي فرينڪ",
                "displayName-count-other": "ڪوموريائي فرينڪ",
                symbol: "KMF",
                "symbol-alt-narrow": "CF"
            },
            KPW: {
                displayName: "اتر ڪوريائي ون",
                "displayName-count-one": "اتر ڪوريائي ون",
                "displayName-count-other": "اتر ڪوريائي ون",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "KRH",
                symbol: "KRH"
            },
            KRO: {
                displayName: "KRO",
                symbol: "KRO"
            },
            KRW: {
                displayName: "ڏکڻ ڪوريائي ون",
                "displayName-count-one": "ڏکڻ ڪوريائي ون",
                "displayName-count-other": "ڏکڻ ڪوريائي ون",
                symbol: "₩",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "ڪويتي دينار",
                "displayName-count-one": "ڪويتي دينار",
                "displayName-count-other": "ڪويتي دينار",
                symbol: "KWD"
            },
            KYD: {
                displayName: "ڪيمين ٻيٽ ڊالر",
                "displayName-count-one": "ڪيمين ٻيٽ ڊالر",
                "displayName-count-other": "ڪيمين ٻيٽ ڊالر",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "قازقستان ٽينگا",
                "displayName-count-one": "قازقستان ٽينگا",
                "displayName-count-other": "قازقستان ٽينگا",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "لائوشيائي ڪپ",
                "displayName-count-one": "لائوشيائي ڪپ",
                "displayName-count-other": "لائوشيائي ڪپ",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "لبناني پائونڊ",
                "displayName-count-one": "لبناني پائونڊ",
                "displayName-count-other": "لبناني پائونڊ",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "سري لنڪن رپي",
                "displayName-count-one": "سري لنڪن رپي",
                "displayName-count-other": "سري لنڪن رپي",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "لائبیریائی ڊالر",
                "displayName-count-one": "لائبیریائی ڊالر",
                "displayName-count-other": "لائبیریائی ڊالر",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "LSL",
                symbol: "LSL"
            },
            LTL: {
                displayName: "LTL",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "LTT",
                symbol: "LTT"
            },
            LUC: {
                displayName: "LUC",
                symbol: "LUC"
            },
            LUF: {
                displayName: "LUF",
                symbol: "LUF"
            },
            LUL: {
                displayName: "LUL",
                symbol: "LUL"
            },
            LVL: {
                displayName: "LVL",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "LVR",
                symbol: "LVR"
            },
            LYD: {
                displayName: "لبيائي دينار",
                "displayName-count-one": "لبيائي دينار",
                "displayName-count-other": "لبيائي دينار",
                symbol: "LYD"
            },
            MAD: {
                displayName: "موروڪيائي درهم",
                "displayName-count-one": "موروڪيائي درهم",
                "displayName-count-other": "موروڪيائي درهم",
                symbol: "MAD"
            },
            MAF: {
                displayName: "MAF",
                symbol: "MAF"
            },
            MCF: {
                displayName: "MCF",
                symbol: "MCF"
            },
            MDC: {
                displayName: "MDC",
                symbol: "MDC"
            },
            MDL: {
                displayName: "مالديپ ليو",
                "displayName-count-one": "مالديپ ليو",
                "displayName-count-other": "مالديپ ليو",
                symbol: "MDL"
            },
            MGA: {
                displayName: "ملاگاسي اریاری",
                "displayName-count-one": "ملاگاسي اریاری",
                "displayName-count-other": "ملاگاسي اریاری",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "MGF",
                symbol: "MGF"
            },
            MKD: {
                displayName: "ميسي ڊوني دينار",
                "displayName-count-one": "ميسي ڊوني دينار",
                "displayName-count-other": "ميسي ڊوني دينار",
                symbol: "MKD"
            },
            MKN: {
                displayName: "MKN",
                symbol: "MKN"
            },
            MLF: {
                displayName: "MLF",
                symbol: "MLF"
            },
            MMK: {
                displayName: "ميانمار ڪياٽ",
                "displayName-count-one": "ميانمار ڪياٽ",
                "displayName-count-other": "ميانمار ڪياٽ",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "منگولي تجرڪ",
                "displayName-count-one": "منگولي تجرڪ",
                "displayName-count-other": "منگولي تجرڪ",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "ميڪانيز پٽاڪا",
                "displayName-count-one": "ميڪانيز پٽاڪا",
                "displayName-count-other": "ميڪانيز پٽاڪا",
                symbol: "MOP"
            },
            MRO: {
                displayName: "موريشيائي اوگوئیا (1973–2017)",
                "displayName-count-one": "موريشيائي اوگوئیا (1973–2017)",
                "displayName-count-other": "موريشيائي اوگوئیا (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "موريشيائي اوگوئیا",
                "displayName-count-one": "موريشيائي اوگوئیا",
                "displayName-count-other": "موريشيائي اوگوئیا",
                symbol: "MRU"
            },
            MTL: {
                displayName: "MTL",
                symbol: "MTL"
            },
            MTP: {
                displayName: "MTP",
                symbol: "MTP"
            },
            MUR: {
                displayName: "ماريشيائي رپي",
                "displayName-count-one": "ماريشين روپي",
                "displayName-count-other": "ماريشيائي رپي",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "MVP",
                symbol: "MVP"
            },
            MVR: {
                displayName: "مالديپ روفيا",
                "displayName-count-one": "مالديپ روفيا",
                "displayName-count-other": "مالديپ روفيا",
                symbol: "MVR"
            },
            MWK: {
                displayName: "ملاوي ڪواچا",
                "displayName-count-one": "ملاوي ڪواچا",
                "displayName-count-other": "ملاوي ڪواچا",
                symbol: "MWK"
            },
            MXN: {
                displayName: "ميڪسيڪو پيسو",
                "displayName-count-one": "ميڪسيڪو پيسو",
                "displayName-count-other": "ميڪسيڪو پيسو",
                symbol: "MX$",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "MXP",
                symbol: "MXP"
            },
            MXV: {
                displayName: "MXV",
                symbol: "MXV"
            },
            MYR: {
                displayName: "ملائيشيائي رنگٽ",
                "displayName-count-one": "ملائيشيائي رنگٽ",
                "displayName-count-other": "ملائيشيائي رنگٽ",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "MZE",
                symbol: "MZE"
            },
            MZM: {
                displayName: "MZM",
                symbol: "MZM"
            },
            MZN: {
                displayName: "موزمبيق ميٽيڪل",
                "displayName-count-one": "موزمبيق ميٽيڪل",
                "displayName-count-other": "موزمبيق ميٽيڪل",
                symbol: "MZN"
            },
            NAD: {
                displayName: "نميبائي ڊالر",
                "displayName-count-one": "نميبيائي ڊالر",
                "displayName-count-other": "نميبائي ڊالر",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "نائجريائي نائرا",
                "displayName-count-one": "نائجيريائي نائرا",
                "displayName-count-other": "نائجريائي نائرا",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "NIC",
                symbol: "NIC"
            },
            NIO: {
                displayName: "نڪارا گوا ڪارڊوبا",
                "displayName-count-one": "نڪارا گوا ڪارڊوبا",
                "displayName-count-other": "نڪارا گوا ڪارڊوبا",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "NLG",
                symbol: "NLG"
            },
            NOK: {
                displayName: "نارويائي ڪرون",
                "displayName-count-one": "نارويائي ڪرون",
                "displayName-count-other": "نارويائي ڪرون",
                symbol: "NOK",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "نيپالي رپي",
                "displayName-count-one": "نيپالي رپي",
                "displayName-count-other": "نيپالي رپي",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "نيوزي لينڊي ڊالر",
                "displayName-count-one": "نيوزي لينڊي ڊالر",
                "displayName-count-other": "نيوزي لينڊي ڊالر",
                symbol: "NZ$",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "عماني ريال",
                "displayName-count-one": "عماني ريال",
                "displayName-count-other": "عماني ريال",
                symbol: "OMR"
            },
            PAB: {
                displayName: "پاناما پالبوا",
                "displayName-count-one": "پاناما پالبوا",
                "displayName-count-other": "پاناما پالبوا",
                symbol: "PAB"
            },
            PEI: {
                displayName: "PEI",
                symbol: "PEI"
            },
            PEN: {
                displayName: "پيرو سول",
                "displayName-count-one": "پيرو سول",
                "displayName-count-other": "پيرو سول",
                symbol: "PEN"
            },
            PES: {
                displayName: "PES",
                symbol: "PES"
            },
            PGK: {
                displayName: "پاپوا نيو گني ڪنا",
                "displayName-count-one": "پاپوا نيو گني ڪنا",
                "displayName-count-other": "پاپوا نيو گني ڪنا",
                symbol: "PGK"
            },
            PHP: {
                displayName: "فلپائني پيسو",
                "displayName-count-one": "فلپائني پيسو",
                "displayName-count-other": "فلپائني پيسو",
                symbol: "PHP",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "پاڪستاني رپي",
                "displayName-count-one": "پاڪستاني رپي",
                "displayName-count-other": "پاڪستاني رپي",
                symbol: "Rs",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "پولش زلاٽي",
                "displayName-count-one": "پولش زلاٽي",
                "displayName-count-other": "پولش زلاٽي",
                symbol: "PLN",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "PLZ",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "PTE",
                symbol: "PTE"
            },
            PYG: {
                displayName: "پيراگوئي گاراني",
                "displayName-count-one": "پيراگوئي گاراني",
                "displayName-count-other": "پيراگوئي گاراني",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "قطري ريال",
                "displayName-count-one": "قطري ريال",
                "displayName-count-other": "قطري ريال",
                symbol: "QAR"
            },
            RHD: {
                displayName: "RHD",
                symbol: "RHD"
            },
            ROL: {
                displayName: "ROL",
                symbol: "ROL"
            },
            RON: {
                displayName: "رومانیائي لیو",
                "displayName-count-one": "رومانیائي لیو",
                "displayName-count-other": "رومانیائي لیو",
                symbol: "RON",
                "symbol-alt-narrow": "lei"
            },
            RSD: {
                displayName: "سربيا دينار",
                "displayName-count-one": "سربيا دينار",
                "displayName-count-other": "سربيا دينار",
                symbol: "RSD"
            },
            RUB: {
                displayName: "روسي ربل",
                "displayName-count-one": "روسي ربل",
                "displayName-count-other": "روسي ربل",
                symbol: "RUB",
                "symbol-alt-narrow": "₽"
            },
            RUR: {
                displayName: "RUR",
                symbol: "RUR"
            },
            RWF: {
                displayName: "روانڊا فرينڪ",
                "displayName-count-one": "روانڊا فرينڪ",
                "displayName-count-other": "روانڊا فرينڪ",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "سعودي ريال",
                "displayName-count-one": "سعودي ريال",
                "displayName-count-other": "سعودي ريال",
                symbol: "SAR"
            },
            SBD: {
                displayName: "سولومان ٻيٽ ڊالر",
                "displayName-count-one": "سولومان ٻيٽ ڊالر",
                "displayName-count-other": "سولومان ٻيٽ ڊالر",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "سشلي رپي",
                "displayName-count-one": "سشلي رپي",
                "displayName-count-other": "سشلي رپي",
                symbol: "SCR"
            },
            SDD: {
                displayName: "SDD",
                symbol: "SDD"
            },
            SDG: {
                displayName: "سوڊاني پائونڊ",
                "displayName-count-one": "سوڊاني پائونڊ",
                "displayName-count-other": "سوڊاني پائونڊ",
                symbol: "SDG"
            },
            SDP: {
                displayName: "SDP",
                symbol: "SDP"
            },
            SEK: {
                displayName: "سويڊني ڪرونا",
                "displayName-count-one": "سويڊني ڪرونا",
                "displayName-count-other": "سويڊني ڪرونا",
                symbol: "SEK",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "سنگاپوري ڊالر",
                "displayName-count-one": "سنگاپوري ڊالر",
                "displayName-count-other": "سنگاپوري ڊالر",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "سينٽ هيلنا پائونڊ",
                "displayName-count-one": "سينٽ هيلنا پائونڊ",
                "displayName-count-other": "سينٽ هيلنا پائونڊ",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "SIT",
                symbol: "SIT"
            },
            SKK: {
                displayName: "SKK",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "سیرا لیونيائي لیون",
                "displayName-count-one": "سیرا لیونيائي لیون",
                "displayName-count-other": "سیرا لیونيائي لیون",
                symbol: "SLL"
            },
            SOS: {
                displayName: "سومالي شلنگ",
                "displayName-count-one": "سومالي شلنگ",
                "displayName-count-other": "سومالي شلنگ",
                symbol: "SOS"
            },
            SRD: {
                displayName: "سرينامي ڊالر",
                "displayName-count-one": "سرينامي ڊالر",
                "displayName-count-other": "سرينامي ڊالر",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "SRG",
                symbol: "SRG"
            },
            SSP: {
                displayName: "ڏکڻ سوڊاني پائونڊ",
                "displayName-count-one": "ڏکڻ سوڊاني پائونڊ",
                "displayName-count-other": "ڏکڻ سوڊاني پائونڊ",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "سائو ٽوم ۽ پرنسپي دوبرا (1977–2017)",
                "displayName-count-one": "سائو ٽوم ۽ پرنسپي دوبرا (1977–2017)",
                "displayName-count-other": "سائو ٽوم ۽ پرنسپي دوبرا (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "سائو ٽوم ۽ پرنسپي دوبرا",
                "displayName-count-one": "سائو ٽوم ۽ پرنسپي دوبرا",
                "displayName-count-other": "سائو ٽوم ۽ پرنسپي دوبرا",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "SUR",
                symbol: "SUR"
            },
            SVC: {
                displayName: "SVC",
                symbol: "SVC"
            },
            SYP: {
                displayName: "سيريائي پائونڊ",
                "displayName-count-one": "شامي پائونڊ",
                "displayName-count-other": "سيريائي پائونڊ",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "سوازي للانگيني",
                "displayName-count-one": "سوازي للانگيني",
                "displayName-count-other": "سوازي للانگيني",
                symbol: "SZL"
            },
            THB: {
                displayName: "ٿائي باهت",
                "displayName-count-one": "ٿائي باهت",
                "displayName-count-other": "ٿائي باهت",
                symbol: "THB",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "TJR",
                symbol: "TJR"
            },
            TJS: {
                displayName: "تاجڪستاني سوموني",
                "displayName-count-one": "تاجڪستاني سوموني",
                "displayName-count-other": "تاجڪستاني سوموني",
                symbol: "TJS"
            },
            TMM: {
                displayName: "TMM",
                symbol: "TMM"
            },
            TMT: {
                displayName: "ترڪمانستان منت",
                "displayName-count-one": "ترڪمانستاني منت",
                "displayName-count-other": "ترڪمانستان منت",
                symbol: "TMT"
            },
            TND: {
                displayName: "تیونس دینار",
                "displayName-count-one": "تیونس دینار",
                "displayName-count-other": "تیونس دینار",
                symbol: "TND"
            },
            TOP: {
                displayName: "تونگن پانگا",
                "displayName-count-one": "تونگن پانگا",
                "displayName-count-other": "تونگن پانگا",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "TPE",
                symbol: "TPE"
            },
            TRL: {
                displayName: "TRL",
                symbol: "TRL"
            },
            TRY: {
                displayName: "ترڪي لرا",
                "displayName-count-one": "ترڪي لرا",
                "displayName-count-other": "ترڪي لرا",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "ٽرينڊيڊ ۽ ٽوباگو ڊالر",
                "displayName-count-one": "ٽرينڊيڊ ۽ ٽوباگو ڊالر",
                "displayName-count-other": "ٽرينڊيڊ ۽ ٽوباگو ڊالر",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "نيو تائيوان ڊالر",
                "displayName-count-one": "نيو تائيوان ڊالر",
                "displayName-count-other": "نيو تائيوان ڊالر",
                symbol: "NT$",
                "symbol-alt-narrow": "$"
            },
            TZS: {
                displayName: "تنزانيائي شلنگ",
                "displayName-count-one": "تنزانيائي شلنگ",
                "displayName-count-other": "تنزانيائي شلنگ",
                symbol: "TZS"
            },
            UAH: {
                displayName: "یوڪرائن هریونیا",
                "displayName-count-one": "یوڪرائن هریونیا",
                "displayName-count-other": "یوڪرائن هریونیا",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "UAK",
                symbol: "UAK"
            },
            UGS: {
                displayName: "UGS",
                symbol: "UGS"
            },
            UGX: {
                displayName: "يگانڊا شلنگ",
                "displayName-count-one": "يگانڊا شلنگ",
                "displayName-count-other": "يگانڊا شلنگ",
                symbol: "UGX"
            },
            USD: {
                displayName: "آمريڪي ڊالر",
                "displayName-count-one": "آمريڪي ڊالر",
                "displayName-count-other": "آمريڪي ڊالر",
                symbol: "US$",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "USN",
                symbol: "USN"
            },
            USS: {
                displayName: "USS",
                symbol: "USS"
            },
            UYI: {
                displayName: "UYI",
                symbol: "UYI"
            },
            UYP: {
                displayName: "UYP",
                symbol: "UYP"
            },
            UYU: {
                displayName: "يوروگوئي پيسو",
                "displayName-count-one": "يوروگوئي پيسو",
                "displayName-count-other": "يوروگوئي پيسو",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "UYW",
                symbol: "UYW"
            },
            UZS: {
                displayName: "ازبڪستاني سوم",
                "displayName-count-one": "ازبڪستاني سوم",
                "displayName-count-other": "ازبڪستاني سوم",
                symbol: "UZS"
            },
            VEB: {
                displayName: "VEB",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "Venezuelan Bolívar (2008–2018)",
                "displayName-count-one": "وینزویلا بولیور (2008–2018)",
                "displayName-count-other": "وینزویلا بولیور (2008–2018)",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs"
            },
            VES: {
                displayName: "وینزویلا بولیور",
                "displayName-count-one": "وینزویلا بولیور",
                "displayName-count-other": "وینزویلا بولیور",
                symbol: "VES"
            },
            VND: {
                displayName: "ويٽنامي ڊونگ",
                "displayName-count-one": "ويٽنامي ڊونگ",
                "displayName-count-other": "ويٽنامي ڊونگ",
                symbol: "₫",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "VNN",
                symbol: "VNN"
            },
            VUV: {
                displayName: "وانواتو واتو",
                "displayName-count-one": "وانواتو واتو",
                "displayName-count-other": "وانواتو واتو",
                symbol: "VUV"
            },
            WST: {
                displayName: "ساموآن ٽالا",
                "displayName-count-one": "ساموآن ٽالا",
                "displayName-count-other": "ساموآن ٽالا",
                symbol: "WST"
            },
            XAF: {
                displayName: "وچ آفريڪا فرينڪ",
                "displayName-count-one": "وچ آفريڪا فرينڪ",
                "displayName-count-other": "وچ آفريڪا فرينڪ",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "XAG",
                symbol: "XAG"
            },
            XAU: {
                displayName: "XAU",
                symbol: "XAU"
            },
            XBA: {
                displayName: "XBA",
                symbol: "XBA"
            },
            XBB: {
                displayName: "XBB",
                symbol: "XBB"
            },
            XBC: {
                displayName: "XBC",
                symbol: "XBC"
            },
            XBD: {
                displayName: "XBD",
                symbol: "XBD"
            },
            XCD: {
                displayName: "اوڀر ڪيريبين ڊالر",
                "displayName-count-one": "اوڀر ڪيريبين ڊالر",
                "displayName-count-other": "اوڀر ڪيريبين ڊالر",
                symbol: "EC$",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "XDR",
                symbol: "XDR"
            },
            XEU: {
                displayName: "XEU",
                symbol: "XEU"
            },
            XFO: {
                displayName: "XFO",
                symbol: "XFO"
            },
            XFU: {
                displayName: "XFU",
                symbol: "XFU"
            },
            XOF: {
                displayName: "اولهه آفريڪا فرينڪ",
                "displayName-count-one": "اولهه آفريڪا فرينڪ",
                "displayName-count-other": "اولهه آفريڪا فرينڪ",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "XPD",
                symbol: "XPD"
            },
            XPF: {
                displayName: "CFP فرينڪ",
                "displayName-count-one": "CFP فرينڪ",
                "displayName-count-other": "CFP فرينڪ",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "XPT",
                symbol: "XPT"
            },
            XRE: {
                displayName: "XRE",
                symbol: "XRE"
            },
            XSU: {
                displayName: "XSU",
                symbol: "XSU"
            },
            XTS: {
                displayName: "XTS",
                symbol: "XTS"
            },
            XUA: {
                displayName: "XUA",
                symbol: "XUA"
            },
            XXX: {
                displayName: "اڻڄاتل سڪو",
                "displayName-count-one": "اڻڄاتل سڪو",
                "displayName-count-other": "اڻڄاتل سڪو",
                symbol: "¤"
            },
            YDD: {
                displayName: "YDD",
                symbol: "YDD"
            },
            YER: {
                displayName: "يمني ريال",
                "displayName-count-one": "يمني ريال",
                "displayName-count-other": "يمني ريال",
                symbol: "YER"
            },
            YUD: {
                displayName: "YUD",
                symbol: "YUD"
            },
            YUM: {
                displayName: "YUM",
                symbol: "YUM"
            },
            YUN: {
                displayName: "YUN",
                symbol: "YUN"
            },
            YUR: {
                displayName: "YUR",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "ZAL",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "ڏکڻ آفريقي رانڊ",
                "displayName-count-one": "ڏکڻ آفريقي رانڊ",
                "displayName-count-other": "ڏکڻ آفريقي رانڊ",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "ZMK",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "زمبائي ڪواچا",
                "displayName-count-one": "زمبائي ڪواچا",
                "displayName-count-other": "زمبائي ڪواچا",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "ZRN",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "ZRZ",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "ZWD",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "ZWL",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "ZWR",
                symbol: "ZWR"
            }
        },
        localeCurrency: "PKR"
    },
    calendar: {
        patterns: {
            d: "y-MM-dd",
            D: "y MMMM d, EEEE",
            m: "MMM d",
            M: "MMMM d",
            y: "y MMM",
            Y: "y MMMM",
            F: "y MMMM d, EEEE h:mm:ss a",
            g: "y-MM-dd h:mm a",
            G: "y-MM-dd h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "M/d/y GGGGG",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "MM-dd",
                MEd: "MM-dd, E",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "MMM d, E",
                MMMMd: "MMMM d",
                "MMMMW-count-one": "ھفتو W جو MMMM",
                "MMMMW-count-other": "ھفتو W جو MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "y-MM",
                yMd: "y-MM-dd",
                yMEd: "y-MM-dd, E",
                yMMM: "y MMM",
                yMMMd: "y MMM d",
                yMMMEd: "y MMM d, E",
                yMMMM: "y MMMM",
                yQQQ: "y QQQ",
                yQQQQ: "y QQQQ",
                "yw-count-one": "ھفتو w جو Y",
                "yw-count-other": "ھفتو w جو Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "y MMMM d, EEEE",
            long: "y MMMM d",
            medium: "y MMM d",
            short: "y-MM-dd"
        },
        days: {
            format: {
                abbreviated: [
                    "آچر",
                    "سومر",
                    "اڱارو",
                    "اربع",
                    "خميس",
                    "جمعو",
                    "ڇنڇر"
                ],
                narrow: [
                    "آچر",
                    "سو",
                    "اڱارو",
                    "اربع",
                    "خم",
                    "جمعو",
                    "ڇنڇر"
                ],
                short: [
                    "آچر",
                    "سومر",
                    "اڱارو",
                    "اربع",
                    "خميس",
                    "جمعو",
                    "ڇنڇر"
                ],
                wide: [
                    "آچر",
                    "سومر",
                    "اڱارو",
                    "اربع",
                    "خميس",
                    "جمعو",
                    "ڇنڇر"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "آچر",
                    "سومر",
                    "اڱارو",
                    "اربع",
                    "خميس",
                    "جمعو",
                    "ڇنڇر"
                ],
                narrow: [
                    "آچر",
                    "سو",
                    "اڱارو",
                    "اربع",
                    "خم",
                    "جمعو",
                    "ڇنڇر"
                ],
                short: [
                    "آچر",
                    "سومر",
                    "اڱارو",
                    "اربع",
                    "خميس",
                    "جمعو",
                    "ڇنڇر"
                ],
                wide: [
                    "آچر",
                    "سومر",
                    "اڱارو",
                    "اربع",
                    "خميس",
                    "جمعو",
                    "ڇنڇر"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "جنوري",
                    "فيبروري",
                    "مارچ",
                    "اپريل",
                    "مئي",
                    "جون",
                    "جولاءِ",
                    "آگسٽ",
                    "سيپٽمبر",
                    "آڪٽوبر",
                    "نومبر",
                    "ڊسمبر"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "جنوري",
                    "فيبروري",
                    "مارچ",
                    "اپريل",
                    "مئي",
                    "جون",
                    "جولاءِ",
                    "آگسٽ",
                    "سيپٽمبر",
                    "آڪٽوبر",
                    "نومبر",
                    "ڊسمبر"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "جنوري",
                    "فيبروري",
                    "مارچ",
                    "اپريل",
                    "مئي",
                    "جون",
                    "جولاءِ",
                    "آگسٽ",
                    "سيپٽمبر",
                    "آڪٽوبر",
                    "نومبر",
                    "ڊسمبر"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "جنوري",
                    "فيبروري",
                    "مارچ",
                    "اپريل",
                    "مئي",
                    "جون",
                    "جولاءِ",
                    "آگسٽ",
                    "سيپٽمبر",
                    "آڪٽوبر",
                    "نومبر",
                    "ڊسمبر"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q5"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "پهرين ٽي ماهي",
                    "ٻين ٽي ماهي",
                    "ٽين ٽي ماهي",
                    "چوٿين ٽي ماهي"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "پهرين ٽي ماهي",
                    "ٻين ٽي ماهي",
                    "ٽين ٽي ماهي",
                    "چوٿين ٽي ماهي"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "صبح، منجهند",
                    pm: "شام، منجهند"
                },
                narrow: {
                    am: "صبح، منجهند",
                    pm: "منجهند، شام"
                },
                wide: {
                    am: "صبح، منجهند",
                    pm: "منجهند، شام"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "صبح، منجهند",
                    pm: "منجهند، شام"
                },
                narrow: {
                    am: "صبح، منجهند",
                    pm: "منجهند، شام"
                },
                wide: {
                    am: "صبح، منجهند",
                    pm: "منجهند، شام"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "قبل مسيح",
                    "1": "عيسوي کان پهرين",
                    "0-alt-variant": "عام دور کان پهرين",
                    "1-alt-variant": "عام دور"
                },
                abbreviated: {
                    "0": "BC",
                    "1": "CD",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                narrow: {
                    "0": "BC",
                    "1": "CD",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "دور",
                short: "دور",
                narrow: "دور"
            },
            year: {
                wide: "سال",
                short: "سال",
                narrow: "سال"
            },
            quarter: {
                wide: "ٽي ماهي",
                short: "ٽي ماهي",
                narrow: "ٽي ماهي"
            },
            month: {
                wide: "مهينو",
                short: "مهينو",
                narrow: "مهينو"
            },
            week: {
                wide: "هفتو",
                short: "هفتو",
                narrow: "هفتو"
            },
            weekOfMonth: {
                wide: "مهيني جي هفتي",
                short: "مهيني جي هفتي",
                narrow: "مهيني جي هفتي"
            },
            day: {
                wide: "ڏينهن",
                short: "ڏينهن",
                narrow: "ڏينهن"
            },
            dayOfYear: {
                wide: "سال جو ڏينهن",
                short: "سال جو ڏينهن",
                narrow: "سال جو ڏينهن"
            },
            weekday: {
                wide: "هفتي جو ڏينهن",
                short: "هفتي جو ڏينهن",
                narrow: "هفتي جو ڏينهن"
            },
            weekdayOfMonth: {
                wide: "مهيني جي موڪل جو ڏينهن",
                short: "مهيني جي موڪل جو ڏينهن",
                narrow: "مهيني جي موڪل جو ڏينهن"
            },
            dayperiod: {
                short: "صبح، منجهند/منجهند، شام",
                wide: "صبح/شام",
                narrow: "صبح، منجهند/منجهند، شام"
            },
            hour: {
                wide: "ڪلاڪ",
                short: "ڪلاڪ",
                narrow: "ڪلاڪ"
            },
            minute: {
                wide: "منٽ",
                short: "منٽ",
                narrow: "منٽ"
            },
            second: {
                wide: "سيڪنڊ",
                short: "سيڪنڊ",
                narrow: "سيڪنڊ"
            },
            zone: {
                wide: "ٽائيم زون",
                short: "ٽائيم زون",
                narrow: "ٽائيم زون"
            },
            millisecond: {
                narrow: "ms",
                short: "ملي سيڪنڊ",
                wide: "ملي سيڪنڊ"
            }
        }
    },
    firstDay: 0,
    weekendRange: {
        start: 6,
        end: 0
    },
    likelySubtags: {
        sd: "sd-Arab-PK"
    },
    currencyData: {
        PKR: {
            _rounding: "0",
            _digits: "2",
            _cashRounding: "0",
            _cashDigits: "0"
        }
    }
});

