/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "sd-Deva",
    likelySubtags: {
        sd: "sd-Arab-PK",
        "sd-Deva": "sd-Deva-IN"
    },
    identity: {
        language: "sd",
        script: "Deva"
    },
    territory: "IN",
    calendar: {
        patterns: {
            d: "M/d/y",
            D: "EEEE, MMMM d, y",
            m: "MMM d",
            M: "MMMM d",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, MMMM d, y h:mm:ss a",
            g: "M/d/y h:mm a",
            G: "M/d/y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} ते {0}",
            long: "{1} ते {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "M/d/y GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "MMM d, y G",
                GyMMMEd: "E, MMM d, y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "M/d",
                MEd: "E, M/d",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, MMM d",
                MMMMd: "MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "M/d/y",
                yMEd: "E, M/d/y",
                yMMM: "MMM y",
                yMMMd: "MMM d, y",
                yMMMEd: "E, MMM d, y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "EEEE, MMMM d, y",
            long: "MMMM d, y",
            medium: "MMM d, y",
            short: "M/d/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "आर्त",
                    "सू",
                    "मंग",
                    "बु॒ध",
                    "विस",
                    "जुम",
                    "छंछ"
                ],
                narrow: [
                    "आ",
                    "सू",
                    "मं",
                    "बु॒",
                    "वि",
                    "जु",
                    "छं"
                ],
                short: [
                    "आर्त",
                    "सू",
                    "मंग",
                    "बु॒ध",
                    "विस",
                    "जुम",
                    "छंछ"
                ],
                wide: [
                    "आर्तवार",
                    "सूमर",
                    "मंगलु",
                    "बु॒धर",
                    "विस्पत",
                    "जुमो",
                    "छंछर"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "आ",
                    "सू",
                    "मं",
                    "बुध",
                    "विस",
                    "जु",
                    "छंछ"
                ],
                narrow: [
                    "आ",
                    "सू",
                    "मं",
                    "बु॒",
                    "वि",
                    "जु",
                    "छं"
                ],
                short: [
                    "आर्त",
                    "सू",
                    "मंग",
                    "बु॒ध",
                    "विस",
                    "जुम",
                    "छंछ"
                ],
                wide: [
                    "आर्त",
                    "सू",
                    "मं",
                    "बु॒ध",
                    "विस",
                    "जुम",
                    "छंछ"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "जन",
                    "फर",
                    "मार्च",
                    "अप्रै",
                    "मई",
                    "जून",
                    "जु",
                    "अग",
                    "सप्टे",
                    "ऑक्टो",
                    "नवं",
                    "डिसं"
                ],
                narrow: [
                    "ज",
                    "फ़",
                    "मा",
                    "अ",
                    "मा",
                    "जू",
                    "जु",
                    "अग",
                    "स",
                    "ऑ",
                    "न",
                    "डि"
                ],
                wide: [
                    "जनवरी",
                    "फरवरी",
                    "मार्चु",
                    "अप्रैल",
                    "मई",
                    "जून",
                    "जुलाई",
                    "अगस्ट",
                    "सप्टेंबर",
                    "ऑक्टोबर",
                    "नवंबर",
                    "डिसंबर"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "जन",
                    "फर",
                    "मार्च",
                    "अप्रै",
                    "मई",
                    "जून",
                    "जुला",
                    "अग",
                    "सप्टे",
                    "ऑक्टो",
                    "नवं",
                    "डिसं"
                ],
                narrow: [
                    "ज",
                    "फ़",
                    "म",
                    "अ",
                    "मा",
                    "जू",
                    "जु",
                    "अग",
                    "स",
                    "ऑ",
                    "न",
                    "डि"
                ],
                wide: [
                    "जनवरी",
                    "फरवरी",
                    "मार्चु",
                    "अप्रैल",
                    "मई",
                    "जून",
                    "जुलाई",
                    "अगस्ट",
                    "सप्टेंबर",
                    "ऑक्टोबर",
                    "नवंबर",
                    "डिसंबर"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "पहिंरी टिमाही",
                    "बीं॒ टिमाही",
                    "टीं टिमाही",
                    "चोथीं टिमाही"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "पहिंरी टिमाही",
                    "बीं॒ टिमाही",
                    "टीं टिमाही",
                    "चोथीं टिमाही"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "पहिरीं टिमाही",
                    "बीं॒ टिमाही",
                    "टीं टिमाही",
                    "चोथीं टिमाही"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "पहिंरी टिमाही",
                    "बीं॒ टिमाही",
                    "टीं टिमाही",
                    "चोथीं टिमाही"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "मंझंदि खां पहिंरियों",
                    pm: "मंझंदि खां पोइ"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "बीसी",
                    "1": "एडी",
                    "0-alt-variant": "बीसीई",
                    "1-alt-variant": "सीई"
                },
                abbreviated: {
                    "0": "बीसी",
                    "1": "एडी",
                    "0-alt-variant": "बीसीई",
                    "1-alt-variant": "सीई"
                },
                narrow: {
                    "0": "बीसी",
                    "1": "एडी",
                    "0-alt-variant": "बीसीई",
                    "1-alt-variant": "सीई"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "दौर",
                short: "दौर",
                narrow: "दौर"
            },
            year: {
                wide: "साल",
                short: "साल",
                narrow: "साल"
            },
            quarter: {
                wide: "टिमाही",
                short: "टिमाही",
                narrow: "टिमाही"
            },
            month: {
                wide: "महिनो",
                short: "महिनो",
                narrow: "महिनो"
            },
            week: {
                wide: "हफ्तो",
                short: "हफ्तो",
                narrow: "हफ्तो"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "दीं॒हुं",
                short: "दीं॒हुं",
                narrow: "दीं॒हुं"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "हफ्ते जो दीं॒हुं",
                short: "हफ्ते जो दीं॒हुं",
                narrow: "हफ्ते जो दीं॒हुं"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "दीं॒हुं/ रातु",
                wide: "दीं॒हुं/ रातु",
                narrow: "दीं॒हुं/ रातु"
            },
            hour: {
                wide: "कलाक",
                short: "कलाक",
                narrow: "कलाक"
            },
            minute: {
                wide: "मिंटु",
                short: "मिंटु",
                narrow: "मिंटु"
            },
            second: {
                wide: "सेकिंडु",
                short: "सेकिंडु",
                narrow: "सेकिंडु"
            },
            zone: {
                wide: "वक्तु जो दायरो",
                short: "वक्तु जो दायरो",
                narrow: "वक्तु जो दायरो"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

