/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "seh",
    likelySubtags: {
        seh: "seh-Latn-MZ"
    },
    identity: {
        language: "seh"
    },
    territory: "MZ",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE, d 'de' MMMM 'de' y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM 'de' y",
            Y: "MMMM 'de' y",
            F: "EEEE, d 'de' MMMM 'de' y HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                HHmm: "HH:mm",
                HHmmss: "HH:mm:ss",
                hm: "h:mm a",
                Hm: "H:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E, dd/MM",
                MMdd: "dd/MM",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E, d MMM",
                MMMMd: "d MMMM",
                MMMMEd: "E, d MMMM",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                mmss: "mm:ss",
                ms: "mm:ss",
                y: "y",
                yM: "MM/y",
                yMd: "y-MM-dd",
                yMEd: "E, dd/MM/y",
                yMM: "MM/y",
                yMMM: "MMM 'de' y",
                yMMMd: "d 'de' MMM 'de' y",
                yMMMEd: "E, d 'de' MMM 'de' y",
                yMMMM: "MMMM 'de' y",
                yQQQ: "y QQQ",
                yQQQQ: "y QQQQ",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d 'de' MMMM 'de' y",
            long: "d 'de' MMMM 'de' y",
            medium: "d 'de' MMM 'de' y",
            short: "d/M/y"
        },
        days: {
            format: {
                abbreviated: [
                    "Dim",
                    "Pos",
                    "Pir",
                    "Tat",
                    "Nai",
                    "Sha",
                    "Sab"
                ],
                narrow: [
                    "D",
                    "P",
                    "C",
                    "T",
                    "N",
                    "S",
                    "S"
                ],
                short: [
                    "Dim",
                    "Pos",
                    "Pir",
                    "Tat",
                    "Nai",
                    "Sha",
                    "Sab"
                ],
                wide: [
                    "Dimingu",
                    "Chiposi",
                    "Chipiri",
                    "Chitatu",
                    "Chinai",
                    "Chishanu",
                    "Sabudu"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Dim",
                    "Pos",
                    "Pir",
                    "Tat",
                    "Nai",
                    "Sha",
                    "Sab"
                ],
                narrow: [
                    "D",
                    "P",
                    "C",
                    "T",
                    "N",
                    "S",
                    "S"
                ],
                short: [
                    "Dim",
                    "Pos",
                    "Pir",
                    "Tat",
                    "Nai",
                    "Sha",
                    "Sab"
                ],
                wide: [
                    "Dimingu",
                    "Chiposi",
                    "Chipiri",
                    "Chitatu",
                    "Chinai",
                    "Chishanu",
                    "Sabudu"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Jan",
                    "Fev",
                    "Mar",
                    "Abr",
                    "Mai",
                    "Jun",
                    "Jul",
                    "Aug",
                    "Set",
                    "Otu",
                    "Nov",
                    "Dec"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Janeiro",
                    "Fevreiro",
                    "Marco",
                    "Abril",
                    "Maio",
                    "Junho",
                    "Julho",
                    "Augusto",
                    "Setembro",
                    "Otubro",
                    "Novembro",
                    "Decembro"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Jan",
                    "Fev",
                    "Mar",
                    "Abr",
                    "Mai",
                    "Jun",
                    "Jul",
                    "Aug",
                    "Set",
                    "Otu",
                    "Nov",
                    "Dec"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Janeiro",
                    "Fevreiro",
                    "Marco",
                    "Abril",
                    "Maio",
                    "Junho",
                    "Julho",
                    "Augusto",
                    "Setembro",
                    "Otubro",
                    "Novembro",
                    "Decembro"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Antes de Cristo",
                    "1": "Anno Domini",
                    "0-alt-variant": "AC",
                    "1-alt-variant": "AD"
                },
                abbreviated: {
                    "0": "AC",
                    "1": "AD",
                    "0-alt-variant": "AC",
                    "1-alt-variant": "AD"
                },
                narrow: {
                    "0": "AC",
                    "1": "AD",
                    "0-alt-variant": "AC",
                    "1-alt-variant": "AD"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Era",
                short: "Era",
                narrow: "Era"
            },
            year: {
                wide: "Chaka",
                short: "Chaka",
                narrow: "Chaka"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Mwezi",
                short: "Mwezi",
                narrow: "Mwezi"
            },
            week: {
                wide: "Week",
                short: "Week",
                narrow: "Week"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Ntsiku",
                short: "Ntsiku",
                narrow: "Ntsiku"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Day of the Week",
                short: "Day of the Week",
                narrow: "Day of the Week"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Dayperiod",
                wide: "Dayperiod",
                narrow: "Dayperiod"
            },
            hour: {
                wide: "Hora",
                short: "Hora",
                narrow: "Hora"
            },
            minute: {
                wide: "Minuto",
                short: "Minuto",
                narrow: "Minuto"
            },
            second: {
                wide: "Segundo",
                short: "Segundo",
                narrow: "Segundo"
            },
            zone: {
                wide: "Zone",
                short: "Zone",
                narrow: "Zone"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

