/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "sk",
    identity: {
        language: "sk"
    },
    territory: "SK",
    numbers: {
        symbols: {
            decimal: ",",
            group: " ",
            list: ";",
            percentSign: "%",
            plusSign: "+",
            minusSign: "-",
            approximatelySign: "~",
            exponential: "e",
            superscriptingExponent: "×",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "n %"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-one": "n $",
            "unitPattern-count-few": "n $",
            "unitPattern-count-many": "n $",
            "unitPattern-count-other": "n $"
        },
        accounting: {
            patterns: [
                "n $",
                "(n $)"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "andorrská peseta",
                "displayName-count-one": "andorrská peseta",
                "displayName-count-few": "andorrské pesety",
                "displayName-count-many": "andorrskej pesety",
                "displayName-count-other": "andorrských pesiet",
                symbol: "ADP"
            },
            AED: {
                displayName: "SAE dirham",
                "displayName-count-one": "SAE dirham",
                "displayName-count-few": "SAE dirhamy",
                "displayName-count-many": "SAE dirhamu",
                "displayName-count-other": "SAE dirhamov",
                symbol: "AED"
            },
            AFA: {
                displayName: "afganský afgání (1927 – 2002)",
                "displayName-count-one": "afganský afgání (1927 – 2002)",
                "displayName-count-few": "afganské afgání (1927 – 2002)",
                "displayName-count-many": "afganského afgání (1927 – 2002)",
                "displayName-count-other": "afganských afgání (1927 – 2002)",
                symbol: "AFA"
            },
            AFN: {
                displayName: "afganský afgání",
                "displayName-count-one": "afganský afgání",
                "displayName-count-few": "afganské afgání",
                "displayName-count-many": "afganského afgání",
                "displayName-count-other": "afganských afgání",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "albánsky lek (1946 – 1965)",
                "displayName-count-one": "albánsky lek (1946 – 1965)",
                "displayName-count-few": "albánske leky (1946 – 1965)",
                "displayName-count-many": "albánskeho leku (1946 – 1965)",
                "displayName-count-other": "albánskych lekov (1946 – 1965)",
                symbol: "ALK"
            },
            ALL: {
                displayName: "albánsky lek",
                "displayName-count-one": "albánsky lek",
                "displayName-count-few": "albánske leky",
                "displayName-count-many": "albánskeho leku",
                "displayName-count-other": "albánskych lekov",
                symbol: "ALL"
            },
            AMD: {
                displayName: "arménsky dram",
                "displayName-count-one": "arménsky dram",
                "displayName-count-few": "arménske dramy",
                "displayName-count-many": "arménskeho dramu",
                "displayName-count-other": "arménskych dramov",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "antilský gulden",
                "displayName-count-one": "antilský gulden",
                "displayName-count-few": "antilské guldeny",
                "displayName-count-many": "antilského guldena",
                "displayName-count-other": "antilských guldenov",
                symbol: "ANG"
            },
            AOA: {
                displayName: "angolská kwanza",
                "displayName-count-one": "angolská kwanza",
                "displayName-count-few": "angolské kwanzy",
                "displayName-count-many": "angolskej kwanzy",
                "displayName-count-other": "angolských kwánz",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "angolská kwanza (1977 – 1990)",
                "displayName-count-one": "angolská kwanza (1977 – 1990)",
                "displayName-count-few": "angolské kwanzy (1977 – 1990)",
                "displayName-count-many": "angolskej kwanzy (1977 – 1990)",
                "displayName-count-other": "angolských kwánz (1977 – 1990)",
                symbol: "AOK"
            },
            AON: {
                displayName: "angolská nová kwanza (1990 – 2000)",
                "displayName-count-one": "angolská nová kwanza (1990 – 2000)",
                "displayName-count-few": "angolské nové kwanzy (1990 – 2000)",
                "displayName-count-many": "angolskej novej kwanzy (1990 – 2000)",
                "displayName-count-other": "angolských nových kwánz (1990 – 2000)",
                symbol: "AON"
            },
            AOR: {
                displayName: "angolská upravená kwanza (1995 – 1999)",
                "displayName-count-one": "angolská upravená kwanza (1995 – 1999)",
                "displayName-count-few": "angolské upravené kwanzy (1995 – 1999)",
                "displayName-count-many": "angolskej upravenej kwanzy (1995 – 1999)",
                "displayName-count-other": "angolských upravených kwánz (1995 – 1999)",
                symbol: "AOR"
            },
            ARA: {
                displayName: "argentínsky austral",
                "displayName-count-one": "argentínsky austral",
                "displayName-count-few": "argentínske australy",
                "displayName-count-many": "argentínskeho australu",
                "displayName-count-other": "argentínskych australov",
                symbol: "ARA"
            },
            ARL: {
                displayName: "argentínske peso ley (1970 – 1983)",
                "displayName-count-one": "argentínske peso ley (1970 – 1983)",
                "displayName-count-few": "argentínske pesos ley (1970 – 1983)",
                "displayName-count-many": "argentínskeho pesa ley (1970 – 1983)",
                "displayName-count-other": "argentínskych pesos ley (1970 – 1983)",
                symbol: "ARL"
            },
            ARM: {
                displayName: "argentínske peso (1881 – 1970)",
                "displayName-count-one": "argentínske peso (1881 – 1970)",
                "displayName-count-few": "argentínske pesos (1881 – 1970)",
                "displayName-count-many": "argentínskeho pesa (1881 – 1970)",
                "displayName-count-other": "argentínskych pesos (1881 – 1970)",
                symbol: "ARM"
            },
            ARP: {
                displayName: "argentínske peso (1983 – 1985)",
                "displayName-count-one": "argentínske peso (1983 – 1985)",
                "displayName-count-few": "argentínske pesos (1983 – 1985)",
                "displayName-count-many": "argentínskeho pesa (1983 – 1985)",
                "displayName-count-other": "argentínskych pesos (1983 – 1985)",
                symbol: "ARP"
            },
            ARS: {
                displayName: "argentínske peso",
                "displayName-count-one": "argentínske peso",
                "displayName-count-few": "argentínske pesos",
                "displayName-count-many": "argentínskeho pesa",
                "displayName-count-other": "argentínskych pesos",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "rakúsky šiling",
                "displayName-count-one": "rakúsky šiling",
                "displayName-count-few": "rakúske šilingy",
                "displayName-count-many": "rakúskeho šilingu",
                "displayName-count-other": "rakúskych šilingov",
                symbol: "ATS"
            },
            AUD: {
                displayName: "austrálsky dolár",
                "displayName-count-one": "austrálsky dolár",
                "displayName-count-few": "austrálske doláre",
                "displayName-count-many": "austrálskeho dolára",
                "displayName-count-other": "austrálskych dolárov",
                symbol: "AUD",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "arubský gulden",
                "displayName-count-one": "arubský gulden",
                "displayName-count-few": "arubské guldeny",
                "displayName-count-many": "arubského guldena",
                "displayName-count-other": "arubských guldenov",
                symbol: "AWG"
            },
            AZM: {
                displayName: "azerbajdžanský manat (1993–2006)",
                "displayName-count-one": "azerbajdžanský manat (1993–2006)",
                "displayName-count-few": "azerbajdžanské manaty (1993–2006)",
                "displayName-count-many": "azerbajdžanského manatu (1993–2006)",
                "displayName-count-other": "azerbajdžanských manatov (1993–2006)",
                symbol: "AZM"
            },
            AZN: {
                displayName: "azerbajdžanský manat",
                "displayName-count-one": "azerbajdžanský manat",
                "displayName-count-few": "azerbajdžanské manaty",
                "displayName-count-many": "azerbajdžanského manatu",
                "displayName-count-other": "azerbajdžanských manatov",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "bosniansko-hercegovinský dinár (1992 – 1994)",
                "displayName-count-one": "bosniansko-hercegovinský dinár (1992 – 1994)",
                "displayName-count-few": "bosniansko-hercegovinské dináre (1992 – 1994)",
                "displayName-count-many": "bosniansko-hercegovinského dinára (1992 – 1994)",
                "displayName-count-other": "bosniansko-hercegovinských dinárov (1992 – 1994)",
                symbol: "BAD"
            },
            BAM: {
                displayName: "bosniansko-hercegovinská konvertibilná marka",
                "displayName-count-one": "bosniansko-hercegovinská konvertibilná marka",
                "displayName-count-few": "bosniansko-hercegovinské konvertibilné marky",
                "displayName-count-many": "bosniansko-hercegovinskej konvertibilnej marky",
                "displayName-count-other": "bosniansko-hercegovinských konvertibilných mariek",
                symbol: "BAM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "bosniansko-hercegovinský nový dinár (1994 – 1997)",
                "displayName-count-one": "bosniansko-hercegovinský nový dinár (1994 – 1997)",
                "displayName-count-few": "bosniansko-hercegovinské nové dináre (1994 – 1997)",
                "displayName-count-many": "bosniansko-hercegovinského nového dinára (1994 – 1997)",
                "displayName-count-other": "bosniansko-hercegovinské nové dináre (1994 – 1997)",
                symbol: "BAN"
            },
            BBD: {
                displayName: "barbadoský dolár",
                "displayName-count-one": "barbadoský dolár",
                "displayName-count-few": "barbadoské doláre",
                "displayName-count-many": "barbadoského dolára",
                "displayName-count-other": "barbadoských dolárov",
                symbol: "BBD",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "bangladéšska taka",
                "displayName-count-one": "bangladéšska taka",
                "displayName-count-few": "bangladéšske taky",
                "displayName-count-many": "bangladéšskej taky",
                "displayName-count-other": "bangladéšskych ták",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "belgický frank (konvertibilný)",
                "displayName-count-one": "belgický frank (konvertibilný)",
                "displayName-count-few": "belgické franky (konvertibilné)",
                "displayName-count-many": "belgického franku (konvertibilného)",
                "displayName-count-other": "belgických frankov (konvertibilných)",
                symbol: "BEC"
            },
            BEF: {
                displayName: "belgický frank",
                "displayName-count-one": "belgický frank",
                "displayName-count-few": "belgické franky",
                "displayName-count-many": "belgického franku",
                "displayName-count-other": "belgických frankov",
                symbol: "BEF"
            },
            BEL: {
                displayName: "belgický frank (finančný)",
                "displayName-count-one": "belgický frank (finančný)",
                "displayName-count-few": "belgické franky (finančné)",
                "displayName-count-many": "belgického franku (finančného)",
                "displayName-count-other": "belgických frankov (finančných)",
                symbol: "BEL"
            },
            BGL: {
                displayName: "bulharský tvrdý lev",
                "displayName-count-one": "bulharský tvrdý lev",
                "displayName-count-few": "bulharské tvrdé leva",
                "displayName-count-many": "bulharského tvrdého leva",
                "displayName-count-other": "bulharských tvrdých leva",
                symbol: "BGL"
            },
            BGM: {
                displayName: "bulharský socialistický lev",
                "displayName-count-one": "bulharský socialistický lev",
                "displayName-count-few": "bulharské socialistické leva",
                "displayName-count-many": "bulharského socialistického leva",
                "displayName-count-other": "bulharských socialistických leva",
                symbol: "BGM"
            },
            BGN: {
                displayName: "bulharský lev",
                "displayName-count-one": "bulharský lev",
                "displayName-count-few": "bulharské leva",
                "displayName-count-many": "bulharského leva",
                "displayName-count-other": "bulharských leva",
                symbol: "BGN"
            },
            BGO: {
                displayName: "bulharský lev (1879 – 1952)",
                "displayName-count-one": "bulharský lev (1879 – 1952)",
                "displayName-count-few": "bulharské leva (1879 – 1952)",
                "displayName-count-many": "bulharského leva (1879 – 1952)",
                "displayName-count-other": "bulharských leva (1879 – 1952)",
                symbol: "BGO"
            },
            BHD: {
                displayName: "bahrajnský dinár",
                "displayName-count-one": "bahrajnský dinár",
                "displayName-count-few": "bahrajnské dináre",
                "displayName-count-many": "bahrajnského dinára",
                "displayName-count-other": "bahrajnských dinárov",
                symbol: "BHD"
            },
            BIF: {
                displayName: "burundský frank",
                "displayName-count-one": "burundský frank",
                "displayName-count-few": "burundské franky",
                "displayName-count-many": "burundského franku",
                "displayName-count-other": "burundských frankov",
                symbol: "BIF"
            },
            BMD: {
                displayName: "bermudský dolár",
                "displayName-count-one": "bermudský dolár",
                "displayName-count-few": "bermudské doláre",
                "displayName-count-many": "bermudského dolára",
                "displayName-count-other": "bermudských dolárov",
                symbol: "BMD",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "brunejský dolár",
                "displayName-count-one": "brunejský dolár",
                "displayName-count-few": "brunejské doláre",
                "displayName-count-many": "brunejského dolára",
                "displayName-count-other": "brunejských dolárov",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "bolívijské boliviano",
                "displayName-count-one": "bolívijské boliviano",
                "displayName-count-few": "bolívijské boliviana",
                "displayName-count-many": "bolívijského boliviana",
                "displayName-count-other": "bolívijských bolivian",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "bolívijské boliviano (1863 – 1963)",
                "displayName-count-one": "bolívijské boliviano (1863 – 1963)",
                "displayName-count-few": "bolívijské boliviana (1863 – 1963)",
                "displayName-count-many": "bolívijského boliviana (1863 – 1963)",
                "displayName-count-other": "bolívijských bolivian (1863 – 1963)",
                symbol: "BOL"
            },
            BOP: {
                displayName: "bolívijské peso",
                "displayName-count-one": "bolívijské peso",
                "displayName-count-few": "bolívijské pesos",
                "displayName-count-many": "bolívijského pesa",
                "displayName-count-other": "bolívijských pesos",
                symbol: "BOP"
            },
            BOV: {
                displayName: "bolívijské MVDOL",
                "displayName-count-one": "bolívijský mvdol",
                "displayName-count-few": "bolívijské mvdoly",
                "displayName-count-many": "bolívijského mvdolu",
                "displayName-count-other": "bolívijských mvdolov",
                symbol: "BOV"
            },
            BRB: {
                displayName: "brazílske nové cruzeiro (1967 – 1986)",
                "displayName-count-one": "brazílske nové cruzeiro (1967 – 1986)",
                "displayName-count-few": "brazílske nové cruzeirá (1967 – 1986)",
                "displayName-count-many": "brazílskeho nového cruzeira (1967 – 1986)",
                "displayName-count-other": "brazílskych nových cruzeir (1967 – 1986)",
                symbol: "BRB"
            },
            BRC: {
                displayName: "brazílske cruzado (1986 – 1989)",
                "displayName-count-one": "brazílske cruzado (1986 – 1989)",
                "displayName-count-few": "brazílske cruzadá (1986 – 1989)",
                "displayName-count-many": "brazílskeho cruzada (1986 – 1989)",
                "displayName-count-other": "brazílskych cruzad (1986 – 1989)",
                symbol: "BRC"
            },
            BRE: {
                displayName: "brazílske cruzeiro (1990 – 1993)",
                "displayName-count-one": "brazílske cruzeiro (1990 – 1993)",
                "displayName-count-few": "brazílske cruzeirá (1990 – 1993)",
                "displayName-count-many": "brazílskeho cruzeira (1990 – 1993)",
                "displayName-count-other": "brazílskych cruzeir (1990 – 1993)",
                symbol: "BRE"
            },
            BRL: {
                displayName: "brazílsky real",
                "displayName-count-one": "brazílsky real",
                "displayName-count-few": "brazílske realy",
                "displayName-count-many": "brazílskeho realu",
                "displayName-count-other": "brazílskych realov",
                symbol: "BRL",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "brazílske nové cruzado (1989 – 1990)",
                "displayName-count-one": "brazílske nové cruzado (1989 – 1990)",
                "displayName-count-few": "brazílske nové cruzadá (1989 – 1990)",
                "displayName-count-many": "brazílskeho nového cruzada (1989 – 1990)",
                "displayName-count-other": "brazílskych nových cruzad (1989 – 1990)",
                symbol: "BRN"
            },
            BRR: {
                displayName: "Brazílske cruzeiro",
                "displayName-count-one": "brazílske cruzeiro (1993 – 1994)",
                "displayName-count-few": "brazílske cruzeirá (1993 – 1994)",
                "displayName-count-many": "brazílskeho cruzeira (1993 – 1994)",
                "displayName-count-other": "brazílskych cruzeir (1993 – 1994)",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "brazílske cruzeiro (1942 – 1967)",
                "displayName-count-one": "brazílske cruzeiro (1942 – 1967)",
                "displayName-count-few": "brazílske cruzeirá (1942 – 1967)",
                "displayName-count-many": "brazílskeho cruzeira (1942 – 1967)",
                "displayName-count-other": "brazílskych cruzeir (1942 – 1967)",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "bahamský dolár",
                "displayName-count-one": "bahamský dolár",
                "displayName-count-few": "bahamské doláre",
                "displayName-count-many": "bahamského dolára",
                "displayName-count-other": "bahamských dolárov",
                symbol: "BSD",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "bhutánsky ngultrum",
                "displayName-count-one": "bhutánsky ngultrum",
                "displayName-count-few": "bhutánske ngultrumy",
                "displayName-count-many": "bhutánskeho ngultrumu",
                "displayName-count-other": "bhutánskych ngultrumov",
                symbol: "BTN"
            },
            BUK: {
                displayName: "barmský kyat",
                "displayName-count-one": "barmský kyat",
                "displayName-count-few": "barmské kyaty",
                "displayName-count-many": "barmského kyatu",
                "displayName-count-other": "barmských kyatov",
                symbol: "BUK"
            },
            BWP: {
                displayName: "botswanská pula",
                "displayName-count-one": "botswanská pula",
                "displayName-count-few": "botswanské puly",
                "displayName-count-many": "botswanskej puly",
                "displayName-count-other": "botswanských púl",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "bieloruský rubeľ (1994 – 1999)",
                "displayName-count-one": "bieloruský rubeľ (1994 – 1999)",
                "displayName-count-few": "bieloruské ruble (1994 – 1999)",
                "displayName-count-many": "bieloruského rubľa (1994 – 1999)",
                "displayName-count-other": "bieloruských rubľov (1994 – 1999)",
                symbol: "BYB"
            },
            BYN: {
                displayName: "bieloruský rubeľ",
                "displayName-count-one": "bieloruský rubeľ",
                "displayName-count-few": "bieloruské ruble",
                "displayName-count-many": "bieloruského rubľa",
                "displayName-count-other": "bieloruských rubľov",
                symbol: "BYN",
                "symbol-alt-narrow": "р."
            },
            BYR: {
                displayName: "bieloruský rubeľ (2000–2016)",
                "displayName-count-one": "bieloruský rubeľ (2000–2016)",
                "displayName-count-few": "bieloruské ruble (2000–2016)",
                "displayName-count-many": "bieloruského rubľa (2000–2016)",
                "displayName-count-other": "bieloruských rubľov (2000–2016)",
                symbol: "BYR"
            },
            BZD: {
                displayName: "belizský dolár",
                "displayName-count-one": "belizský dolár",
                "displayName-count-few": "belizské doláre",
                "displayName-count-many": "belizského dolára",
                "displayName-count-other": "belizských dolárov",
                symbol: "BZD",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "kanadský dolár",
                "displayName-count-one": "kanadský dolár",
                "displayName-count-few": "kanadské doláre",
                "displayName-count-many": "kanadského dolára",
                "displayName-count-other": "kanadských dolárov",
                symbol: "CAD",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "konžský frank",
                "displayName-count-one": "konžský frank",
                "displayName-count-few": "konžské franky",
                "displayName-count-many": "konžského franku",
                "displayName-count-other": "konžských frankov",
                symbol: "CDF"
            },
            CHE: {
                displayName: "švajčiarske WIR euro",
                "displayName-count-one": "švajčiarske WIR euro",
                "displayName-count-few": "švajčiarske WIR eurá",
                "displayName-count-many": "švajčiarskeho WIR eura",
                "displayName-count-other": "švajčiarskych WIR eur",
                symbol: "CHE"
            },
            CHF: {
                displayName: "švajčiarsky frank",
                "displayName-count-one": "švajčiarsky frank",
                "displayName-count-few": "švajčiarske franky",
                "displayName-count-many": "švajčiarskeho franku",
                "displayName-count-other": "švajčiarskych frankov",
                symbol: "CHF"
            },
            CHW: {
                displayName: "švajčiarsky WIR frank",
                "displayName-count-one": "švajčiarsky WIR frank",
                "displayName-count-few": "švajčiarske WIR franky",
                "displayName-count-many": "švajčiarskeho WIR franku",
                "displayName-count-other": "švajčiarskych WIR frankov",
                symbol: "CHW"
            },
            CLE: {
                displayName: "čilské escudo",
                "displayName-count-one": "čilské escudo",
                "displayName-count-few": "čilské escudá",
                "displayName-count-many": "čilského escuda",
                "displayName-count-other": "čilských escúd",
                symbol: "CLE"
            },
            CLF: {
                displayName: "čilská účtovná jednotka (UF)",
                "displayName-count-one": "čilská účtovná jednotka (UF)",
                "displayName-count-few": "čilské účtovné jednotky (UF)",
                "displayName-count-many": "čilskej účtovnej jednotky (UF)",
                "displayName-count-other": "čilských účtovných jednotiek (UF)",
                symbol: "CLF"
            },
            CLP: {
                displayName: "čilské peso",
                "displayName-count-one": "čilské peso",
                "displayName-count-few": "čilské pesos",
                "displayName-count-many": "čilského pesa",
                "displayName-count-other": "čilských pesos",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "čínsky jüan (pobrežný)",
                "displayName-count-one": "čínsky jüan (pobrežný)",
                "displayName-count-few": "čínske jüany (pobrežné)",
                "displayName-count-many": "čínskeho jüana (pobrežného)",
                "displayName-count-other": "čínskych jüanov (pobrežných)",
                symbol: "CNH"
            },
            CNX: {
                displayName: "čínsky dolár ČĽB",
                "displayName-count-one": "čínsky dolár ČĽB",
                "displayName-count-few": "čínske doláre ČĽB",
                "displayName-count-many": "čínskeho dolára ČĽB",
                "displayName-count-other": "čínskych dolárov ČĽB",
                symbol: "CNX"
            },
            CNY: {
                displayName: "čínsky jüan",
                "displayName-count-one": "čínsky jüan",
                "displayName-count-few": "čínske jüany",
                "displayName-count-many": "čínskeho jüana",
                "displayName-count-other": "čínskych jüanov",
                symbol: "CNY",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "kolumbijské peso",
                "displayName-count-one": "kolumbijské peso",
                "displayName-count-few": "kolumbijské pesos",
                "displayName-count-many": "kolumbijského pesa",
                "displayName-count-other": "kolumbijských pesos",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "kolumbijská jednotka reálnej hodnoty",
                "displayName-count-one": "kolumbijská jednotka reálnej hodnoty",
                "displayName-count-few": "kolumbijské jednotky reálnej hodnoty",
                "displayName-count-many": "kolumbijskej jednotky reálnej hodnoty",
                "displayName-count-other": "kolumbijských jednotiek reálnej hodnoty",
                symbol: "COU"
            },
            CRC: {
                displayName: "kostarický colón",
                "displayName-count-one": "kostarický colón",
                "displayName-count-few": "kostarické colóny",
                "displayName-count-many": "kostarického colóna",
                "displayName-count-other": "kostarických colónov",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "srbský dinár (2002 – 2006)",
                "displayName-count-one": "srbský dinár (2002 – 2006)",
                "displayName-count-few": "srbské dináre (2002 – 2006)",
                "displayName-count-many": "srbského dinára (2002 – 2006)",
                "displayName-count-other": "srbských dinárov (2002 – 2006)",
                symbol: "CSD"
            },
            CSK: {
                displayName: "československá koruna",
                "displayName-count-one": "československá koruna",
                "displayName-count-few": "československé koruny",
                "displayName-count-many": "československej koruny",
                "displayName-count-other": "československých korún",
                symbol: "CSK"
            },
            CUC: {
                displayName: "kubánske konvertibilné peso",
                "displayName-count-one": "kubánske konvertibilné peso",
                "displayName-count-few": "kubánske konvertibilné pesos",
                "displayName-count-many": "kubánskeho konvertibilného pesa",
                "displayName-count-other": "kubánskych konvertibilných pesos",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "kubánske peso",
                "displayName-count-one": "kubánske peso",
                "displayName-count-few": "kubánske pesos",
                "displayName-count-many": "kubánskeho pesa",
                "displayName-count-other": "kubánskych pesos",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "kapverdské escudo",
                "displayName-count-one": "kapverdské escudo",
                "displayName-count-few": "kapverdské escudá",
                "displayName-count-many": "kapverdského escuda",
                "displayName-count-other": "kapverdských escúd",
                symbol: "CVE"
            },
            CYP: {
                displayName: "cyperská libra",
                "displayName-count-one": "cyperská libra",
                "displayName-count-few": "cyperské libry",
                "displayName-count-many": "cyperskej libry",
                "displayName-count-other": "cyperských libier",
                symbol: "CYP"
            },
            CZK: {
                displayName: "česká koruna",
                "displayName-count-one": "česká koruna",
                "displayName-count-few": "české koruny",
                "displayName-count-many": "českej koruny",
                "displayName-count-other": "českých korún",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "východonemecká marka",
                "displayName-count-one": "východonemecká marka",
                "displayName-count-few": "východonemecké marky",
                "displayName-count-many": "východonemeckej marky",
                "displayName-count-other": "východonemeckých mariek",
                symbol: "DDM"
            },
            DEM: {
                displayName: "nemecká marka",
                "displayName-count-one": "nemecká marka",
                "displayName-count-few": "nemecké marky",
                "displayName-count-many": "nemeckej marky",
                "displayName-count-other": "nemeckých mariek",
                symbol: "DEM"
            },
            DJF: {
                displayName: "džibutský frank",
                "displayName-count-one": "džibutský frank",
                "displayName-count-few": "džibutské franky",
                "displayName-count-many": "džibutského franku",
                "displayName-count-other": "džibutských frankov",
                symbol: "DJF"
            },
            DKK: {
                displayName: "dánska koruna",
                "displayName-count-one": "dánska koruna",
                "displayName-count-few": "dánske koruny",
                "displayName-count-many": "dánskej koruny",
                "displayName-count-other": "dánskych korún",
                symbol: "DKK",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "dominikánske peso",
                "displayName-count-one": "dominikánske peso",
                "displayName-count-few": "dominikánske pesos",
                "displayName-count-many": "dominikánskeho pesa",
                "displayName-count-other": "dominikánske pesos",
                symbol: "DOP",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "alžírsky dinár",
                "displayName-count-one": "alžírsky dinár",
                "displayName-count-few": "alžírske dináre",
                "displayName-count-many": "alžírskeho dinára",
                "displayName-count-other": "alžírskych dinárov",
                symbol: "DZD"
            },
            ECS: {
                displayName: "ekvádorský sucre",
                "displayName-count-one": "ekvádorský sucre",
                "displayName-count-few": "ekvádorské sucre",
                "displayName-count-many": "ekvádorského sucre",
                "displayName-count-other": "ekvádorských sucre",
                symbol: "ECS"
            },
            ECV: {
                displayName: "ekvádorská jednotka konštantnej hodnoty",
                "displayName-count-one": "ekvádorská jednotka konštantnej hodnoty",
                "displayName-count-few": "ekvádorské jednotky konštantnej hodnoty",
                "displayName-count-many": "ekvádorskej jednotky konštantnej hodnoty",
                "displayName-count-other": "ekvádorských jednotiek konštantnej hodnoty",
                symbol: "ECV"
            },
            EEK: {
                displayName: "estónska koruna",
                "displayName-count-one": "estónska koruna",
                "displayName-count-few": "estónske koruny",
                "displayName-count-many": "estónskej koruny",
                "displayName-count-other": "estónskych korún",
                symbol: "EEK"
            },
            EGP: {
                displayName: "egyptská libra",
                "displayName-count-one": "egyptská libra",
                "displayName-count-few": "egyptské libry",
                "displayName-count-many": "egyptskej libry",
                "displayName-count-other": "egyptských libier",
                symbol: "EGP",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "eritrejská nakfa",
                "displayName-count-one": "eritrejská nakfa",
                "displayName-count-few": "eritrejské nakfy",
                "displayName-count-many": "eritrejskej nakfy",
                "displayName-count-other": "eritrejských nakief",
                symbol: "ERN"
            },
            ESA: {
                displayName: "španielska peseta (účet A)",
                "displayName-count-one": "španielska peseta (účet A)",
                "displayName-count-few": "španielske pesety (účet A)",
                "displayName-count-many": "španielskej pesety (účet A)",
                "displayName-count-other": "španielskych pesiet (účet A)",
                symbol: "ESA"
            },
            ESB: {
                displayName: "španielska peseta (konvertibilný účet)",
                "displayName-count-one": "španielska peseta (konvertibilný účet)",
                "displayName-count-few": "španielske pesety (konvertibilný účet)",
                "displayName-count-many": "španielskej pesety (konvertibilný účet)",
                "displayName-count-other": "španielskych pesiet (konvertibilný účet)",
                symbol: "ESB"
            },
            ESP: {
                displayName: "španielska peseta",
                "displayName-count-one": "španielska peseta",
                "displayName-count-few": "španielske pesety",
                "displayName-count-many": "španielskej pesety",
                "displayName-count-other": "španielskych pesiet",
                symbol: "ESP",
                "symbol-alt-narrow": "₧"
            },
            ETB: {
                displayName: "etiópsky birr",
                "displayName-count-one": "etiópsky birr",
                "displayName-count-few": "etiópske birry",
                "displayName-count-many": "etiópskeho birru",
                "displayName-count-other": "etiópskych birrov",
                symbol: "ETB"
            },
            EUR: {
                displayName: "euro",
                "displayName-count-one": "euro",
                "displayName-count-few": "eurá",
                "displayName-count-many": "eura",
                "displayName-count-other": "eur",
                symbol: "€",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "fínska marka",
                "displayName-count-one": "fínska marka",
                "displayName-count-few": "fínske marky",
                "displayName-count-many": "fínskej marky",
                "displayName-count-other": "fínskych mariek",
                symbol: "FIM"
            },
            FJD: {
                displayName: "fidžijský dolár",
                "displayName-count-one": "fidžijský dolár",
                "displayName-count-few": "fidžijské doláre",
                "displayName-count-many": "fidžijského dolára",
                "displayName-count-other": "fidžijských dolárov",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "falklandská libra",
                "displayName-count-one": "falklandská libra",
                "displayName-count-few": "falklandské libry",
                "displayName-count-many": "falklandskej libry",
                "displayName-count-other": "falklandských libier",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "francúzsky frank",
                "displayName-count-one": "francúzsky frank",
                "displayName-count-few": "francúzske franky",
                "displayName-count-many": "francúzskeho franku",
                "displayName-count-other": "francúzskych frankov",
                symbol: "FRF"
            },
            GBP: {
                displayName: "britská libra",
                "displayName-count-one": "britská libra",
                "displayName-count-few": "britské libry",
                "displayName-count-many": "britskej libry",
                "displayName-count-other": "britských libier",
                symbol: "GBP",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "gruzínske kupónové lari",
                "displayName-count-one": "gruzínske kupónové lari",
                "displayName-count-few": "gruzínske kupónové lari",
                "displayName-count-many": "gruzínskeho kupónového lari",
                "displayName-count-other": "gruzínskych kupónových lari",
                symbol: "GEK"
            },
            GEL: {
                displayName: "gruzínske lari",
                "displayName-count-one": "gruzínske lari",
                "displayName-count-few": "gruzínske lari",
                "displayName-count-many": "gruzínskeho lari",
                "displayName-count-other": "gruzínskych lari",
                symbol: "GEL",
                "symbol-alt-narrow": "₾"
            },
            GHC: {
                displayName: "ghanské cedi (1979 – 2007)",
                "displayName-count-one": "ghanské cedi (1979 – 2007)",
                "displayName-count-few": "ghanské cedi (1979 – 2007)",
                "displayName-count-many": "ghanského cedi (1979 – 2007)",
                "displayName-count-other": "ghanských cedi (1979 – 2007)",
                symbol: "GHC"
            },
            GHS: {
                displayName: "ghanské cedi",
                "displayName-count-one": "ghanské cedi",
                "displayName-count-few": "ghanské cedi",
                "displayName-count-many": "ghanského cedi",
                "displayName-count-other": "ghanských cedi",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "gibraltárska libra",
                "displayName-count-one": "gibraltárska libra",
                "displayName-count-few": "gibraltárske libry",
                "displayName-count-many": "gibraltárskej libry",
                "displayName-count-other": "gibraltárskych libier",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "gambijské dalasi",
                "displayName-count-one": "gambijské dalasi",
                "displayName-count-few": "gambijské dalasi",
                "displayName-count-many": "gambijského dalasi",
                "displayName-count-other": "gambijských dalasi",
                symbol: "GMD"
            },
            GNF: {
                displayName: "guinejský frank",
                "displayName-count-one": "guinejský frank",
                "displayName-count-few": "guinejské franky",
                "displayName-count-many": "guinejského franku",
                "displayName-count-other": "guinejských frankov",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "guinejské syli",
                "displayName-count-one": "guinejské syli",
                "displayName-count-few": "guinejské syli",
                "displayName-count-many": "guinejského syli",
                "displayName-count-other": "guinejských syli",
                symbol: "GNS"
            },
            GQE: {
                displayName: "rovníkovoguinejský ekwele",
                "displayName-count-one": "rovníkovoguinejský ekwele",
                "displayName-count-few": "rovníkovoguinejské ekwele",
                "displayName-count-many": "rovníkovoguinejského ekwele",
                "displayName-count-other": "rovníkovoguinejských ekwele",
                symbol: "GQE"
            },
            GRD: {
                displayName: "grécka drachma",
                "displayName-count-one": "grécka drachma",
                "displayName-count-few": "grécke drachmy",
                "displayName-count-many": "gréckej drachmy",
                "displayName-count-other": "gréckych drachiem",
                symbol: "GRD"
            },
            GTQ: {
                displayName: "guatemalský quetzal",
                "displayName-count-one": "guatemalský quetzal",
                "displayName-count-few": "guatemalské quetzaly",
                "displayName-count-many": "guatemalského quetzala",
                "displayName-count-other": "guatemalských quetzalov",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "portugalsko-guinejské escudo",
                "displayName-count-one": "portugalsko-guinejské escudo",
                "displayName-count-few": "portugalsko-guinejské escudá",
                "displayName-count-many": "portugalsko-guinejského escuda",
                "displayName-count-other": "portugalsko-guinejských escúd",
                symbol: "GWE"
            },
            GWP: {
                displayName: "guinejsko-bissauské peso",
                "displayName-count-one": "guinejsko-bissauské peso",
                "displayName-count-few": "guinejsko-bissauské pesos",
                "displayName-count-many": "guinejsko-bissauského pesa",
                "displayName-count-other": "guinejsko-bissauských pesos",
                symbol: "GWP"
            },
            GYD: {
                displayName: "guyanský dolár",
                "displayName-count-one": "guyanský dolár",
                "displayName-count-few": "guyanské doláre",
                "displayName-count-many": "guyanského dolára",
                "displayName-count-other": "guyanských dolárov",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "hongkonský dolár",
                "displayName-count-one": "hongkonský dolár",
                "displayName-count-few": "hongkonské doláre",
                "displayName-count-many": "hongkonského dolára",
                "displayName-count-other": "hongkonských dolárov",
                symbol: "HKD",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "honduraská lempira",
                "displayName-count-one": "honduraská lempira",
                "displayName-count-few": "honduraské lempiry",
                "displayName-count-many": "honduraskej lempiry",
                "displayName-count-other": "honduraských lempír",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "chorvátsky dinár",
                "displayName-count-one": "chorvátsky dinár",
                "displayName-count-few": "chorvátske dináre",
                "displayName-count-many": "chorvátskeho dinára",
                "displayName-count-other": "chorvátskych dinárov",
                symbol: "HRD"
            },
            HRK: {
                displayName: "chorvátska kuna",
                "displayName-count-one": "chorvátska kuna",
                "displayName-count-few": "chorvátske kuny",
                "displayName-count-many": "chorvátskej kuny",
                "displayName-count-other": "chorvátskych kún",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "haitské gourde",
                "displayName-count-one": "haitské gourde",
                "displayName-count-few": "haitské gourde",
                "displayName-count-many": "haitského gourde",
                "displayName-count-other": "haitských gourde",
                symbol: "HTG"
            },
            HUF: {
                displayName: "maďarský forint",
                "displayName-count-one": "maďarský forint",
                "displayName-count-few": "maďarské forinty",
                "displayName-count-many": "maďarského forinta",
                "displayName-count-other": "maďarských forintov",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "indonézska rupia",
                "displayName-count-one": "indonézska rupia",
                "displayName-count-few": "indonézske rupie",
                "displayName-count-many": "indonézskej rupie",
                "displayName-count-other": "indonézskych rupií",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "írska libra",
                "displayName-count-one": "írska libra",
                "displayName-count-few": "írske libry",
                "displayName-count-many": "írskej libry",
                "displayName-count-other": "írskych libier",
                symbol: "IEP"
            },
            ILP: {
                displayName: "izraelská libra",
                "displayName-count-one": "izraelská libra",
                "displayName-count-few": "izraelské libry",
                "displayName-count-many": "izraelskej libry",
                "displayName-count-other": "izraelských libier",
                symbol: "ILP"
            },
            ILR: {
                displayName: "izraelský šekel (1980 – 1985)",
                "displayName-count-one": "izraelský šekel (1980 – 1985)",
                "displayName-count-few": "izraelské šekely (1980 – 1985)",
                "displayName-count-many": "izraelského šekela (1980 – 1985)",
                "displayName-count-other": "izraelských šekelov (1980 – 1985)",
                symbol: "ILR"
            },
            ILS: {
                displayName: "izraelský šekel",
                "displayName-count-one": "izraelský šekel",
                "displayName-count-few": "izraelské šekely",
                "displayName-count-many": "izraelského šekela",
                "displayName-count-other": "izraelských šekelov",
                symbol: "NIS",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "indická rupia",
                "displayName-count-one": "indická rupia",
                "displayName-count-few": "indické rupie",
                "displayName-count-many": "indickej rupie",
                "displayName-count-other": "indických rupií",
                symbol: "INR",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "iracký dinár",
                "displayName-count-one": "iracký dinár",
                "displayName-count-few": "iracké dináre",
                "displayName-count-many": "irackého dinára",
                "displayName-count-other": "irackých dinárov",
                symbol: "IQD"
            },
            IRR: {
                displayName: "iránsky rial",
                "displayName-count-one": "iránsky rial",
                "displayName-count-few": "iránske rialy",
                "displayName-count-many": "iránskeho rialu",
                "displayName-count-other": "iránskych rialov",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "islandská koruna (1918 – 1981)",
                "displayName-count-one": "islandská koruna (1918 – 1981)",
                "displayName-count-few": "islandské koruny (1918 – 1981)",
                "displayName-count-many": "islandskej koruny (1918 – 1981)",
                "displayName-count-other": "islandských korún (1918 – 1981)",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "islandská koruna",
                "displayName-count-one": "islandská koruna",
                "displayName-count-few": "islandské koruny",
                "displayName-count-many": "islandskej koruny",
                "displayName-count-other": "islandských korún",
                symbol: "ISK",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "talianska líra",
                "displayName-count-one": "talianska líra",
                "displayName-count-few": "talianske líry",
                "displayName-count-many": "talianskej líry",
                "displayName-count-other": "talianskych lír",
                symbol: "ITL"
            },
            JMD: {
                displayName: "jamajský dolár",
                "displayName-count-one": "jamajský dolár",
                "displayName-count-few": "jamajské doláre",
                "displayName-count-many": "jamajského dolára",
                "displayName-count-other": "jamajských dolárov",
                symbol: "JMD",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "jordánsky dinár",
                "displayName-count-one": "jordánsky dinár",
                "displayName-count-few": "jordánske dináre",
                "displayName-count-many": "jordánskeho dinára",
                "displayName-count-other": "jordánskych dinárov",
                symbol: "JOD"
            },
            JPY: {
                displayName: "japonský jen",
                "displayName-count-one": "japonský jen",
                "displayName-count-few": "japonské jeny",
                "displayName-count-many": "japonského jenu",
                "displayName-count-other": "japonských jenov",
                symbol: "JPY",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "kenský šiling",
                "displayName-count-one": "kenský šiling",
                "displayName-count-few": "kenské šilingy",
                "displayName-count-many": "kenského šilingu",
                "displayName-count-other": "kenských šilingov",
                symbol: "KES"
            },
            KGS: {
                displayName: "kirgizský som",
                "displayName-count-one": "kirgizský som",
                "displayName-count-few": "kirgizské somy",
                "displayName-count-many": "kirgizského somu",
                "displayName-count-other": "kirgizských somov",
                symbol: "KGS"
            },
            KHR: {
                displayName: "kambodžský riel",
                "displayName-count-one": "kambodžský riel",
                "displayName-count-few": "kambodžské riely",
                "displayName-count-many": "kambodžského rielu",
                "displayName-count-other": "kambodžských rielov",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "komorský frank",
                "displayName-count-one": "komorský frank",
                "displayName-count-few": "komorské franky",
                "displayName-count-many": "komorského franku",
                "displayName-count-other": "komorských frankov",
                symbol: "KMF",
                "symbol-alt-narrow": "CF"
            },
            KPW: {
                displayName: "severokórejský won",
                "displayName-count-one": "severokórejský won",
                "displayName-count-few": "severokórejské wony",
                "displayName-count-many": "severokórejskeho wonu",
                "displayName-count-other": "severokórejských wonov",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "juhokórejský hwan (1953 – 1962)",
                "displayName-count-one": "juhokórejský hwan (1953 – 1962)",
                "displayName-count-few": "juhokórejské hwany (1953 – 1962)",
                "displayName-count-many": "juhokórejského hwanu (1953 – 1962)",
                "displayName-count-other": "juhokórejských hwanov (1953 – 1962)",
                symbol: "KRH"
            },
            KRO: {
                displayName: "juhokórejský won (1945 – 1953)",
                "displayName-count-one": "juhokórejský won (1945 – 1953)",
                "displayName-count-few": "juhokórejské wony (1945 – 1953)",
                "displayName-count-many": "juhokórejského wonu (1945 – 1953)",
                "displayName-count-other": "juhokórejských wonov (1945 – 1953)",
                symbol: "KRO"
            },
            KRW: {
                displayName: "juhokórejský won",
                "displayName-count-one": "juhokórejský won",
                "displayName-count-few": "juhokórejské wony",
                "displayName-count-many": "juhokórejského wonu",
                "displayName-count-other": "juhokórejských wonov",
                symbol: "KRW",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "kuvajtský dinár",
                "displayName-count-one": "kuvajtský dinár",
                "displayName-count-few": "kuvajtské dináre",
                "displayName-count-many": "kuvajtského dinára",
                "displayName-count-other": "kuvajtských dinárov",
                symbol: "KWD"
            },
            KYD: {
                displayName: "kajmanský dolár",
                "displayName-count-one": "kajmanský dolár",
                "displayName-count-few": "kajmanské doláre",
                "displayName-count-many": "kajmanského dolára",
                "displayName-count-other": "kajmanských dolárov",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "kazašské tenge",
                "displayName-count-one": "kazašské tenge",
                "displayName-count-few": "kazašské tenge",
                "displayName-count-many": "kazašského tenge",
                "displayName-count-other": "kazašských tenge",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "laoský kip",
                "displayName-count-one": "laoský kip",
                "displayName-count-few": "laoské kipy",
                "displayName-count-many": "laoského kipu",
                "displayName-count-other": "laoských kipov",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "libanonská libra",
                "displayName-count-one": "libanonská libra",
                "displayName-count-few": "libanonské libry",
                "displayName-count-many": "libanonskej libry",
                "displayName-count-other": "libanonských libier",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "srílanská rupia",
                "displayName-count-one": "srílanská rupia",
                "displayName-count-few": "srílanské rupie",
                "displayName-count-many": "srílanskej rupie",
                "displayName-count-other": "srílanských rupií",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "libérijský dolár",
                "displayName-count-one": "libérijský dolár",
                "displayName-count-few": "libérijské doláre",
                "displayName-count-many": "libérijského dolára",
                "displayName-count-other": "libérijských dolárov",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "lesothský loti",
                "displayName-count-one": "lesothský loti",
                "displayName-count-few": "lesothské loti",
                "displayName-count-many": "lesothského loti",
                "displayName-count-other": "lesothských loti",
                symbol: "LSL"
            },
            LTL: {
                displayName: "litovský litas",
                "displayName-count-one": "litovský litas",
                "displayName-count-few": "litovské lity",
                "displayName-count-many": "litovského litu",
                "displayName-count-other": "litovských litov",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "litovský talonas",
                "displayName-count-one": "litovský talonas",
                "displayName-count-few": "litovské talony",
                "displayName-count-many": "litovského talonu",
                "displayName-count-other": "litovských talonov",
                symbol: "LTT"
            },
            LUC: {
                displayName: "luxemburský frank (konvertibilný)",
                "displayName-count-one": "luxemburský frank (konvertibilný)",
                "displayName-count-few": "luxemburské franky (konvertibilné)",
                "displayName-count-many": "luxemburského franku (konvertibilného)",
                "displayName-count-other": "luxemburských frankov (konvertibilných)",
                symbol: "LUC"
            },
            LUF: {
                displayName: "luxemburský frank",
                "displayName-count-one": "luxemburský frank",
                "displayName-count-few": "luxemburské franky",
                "displayName-count-many": "luxemburského franku",
                "displayName-count-other": "luxemburských frankov",
                symbol: "LUF"
            },
            LUL: {
                displayName: "luxemburský frank (finančný)",
                "displayName-count-one": "luxemburský frank (finančný)",
                "displayName-count-few": "luxemburské franky (finančné)",
                "displayName-count-many": "luxemburského franku (finančného)",
                "displayName-count-other": "luxemburských frankov (finančných)",
                symbol: "LUL"
            },
            LVL: {
                displayName: "lotyšský lat",
                "displayName-count-one": "lotyšský lat",
                "displayName-count-few": "lotyšské laty",
                "displayName-count-many": "lotyšského latu",
                "displayName-count-other": "lotyšských latov",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "lotyšský rubeľ",
                "displayName-count-one": "lotyšský rubeľ",
                "displayName-count-few": "lotyšské ruble",
                "displayName-count-many": "lotyšského rubľa",
                "displayName-count-other": "lotyšských rubľov",
                symbol: "LVR"
            },
            LYD: {
                displayName: "líbyjský dinár",
                "displayName-count-one": "líbyjský dinár",
                "displayName-count-few": "líbyjské dináre",
                "displayName-count-many": "líbyjského dinára",
                "displayName-count-other": "líbyjských dinárov",
                symbol: "LYD"
            },
            MAD: {
                displayName: "marocký dirham",
                "displayName-count-one": "marocký dirham",
                "displayName-count-few": "marocké dirhamy",
                "displayName-count-many": "marockého dirhamu",
                "displayName-count-other": "marockých dirhamov",
                symbol: "MAD"
            },
            MAF: {
                displayName: "marocký frank",
                "displayName-count-one": "marocký frank",
                "displayName-count-few": "marocké franky",
                "displayName-count-many": "marockého franku",
                "displayName-count-other": "marockých frankov",
                symbol: "MAF"
            },
            MCF: {
                displayName: "monacký frank",
                "displayName-count-one": "monacký frank",
                "displayName-count-few": "monacké franky",
                "displayName-count-many": "monackého franku",
                "displayName-count-other": "monackých frankov",
                symbol: "MCF"
            },
            MDC: {
                displayName: "moldavský kupón",
                "displayName-count-one": "moldavský kupón",
                "displayName-count-few": "moldavské kupóny",
                "displayName-count-many": "moldavského kupónu",
                "displayName-count-other": "moldavských kupónov",
                symbol: "MDC"
            },
            MDL: {
                displayName: "moldavský lei",
                "displayName-count-one": "moldavský lei",
                "displayName-count-few": "moldavské lei",
                "displayName-count-many": "moldavského lei",
                "displayName-count-other": "moldavských lei",
                symbol: "MDL"
            },
            MGA: {
                displayName: "malgašský ariary",
                "displayName-count-one": "malgašský ariary",
                "displayName-count-few": "malgašské ariary",
                "displayName-count-many": "malgašského ariary",
                "displayName-count-other": "malgašských ariary",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "madagaskarský frank",
                "displayName-count-one": "madagaskarský frank",
                "displayName-count-few": "madagaskarské franky",
                "displayName-count-many": "madagaskarského franku",
                "displayName-count-other": "madagaskarských frankov",
                symbol: "MGF"
            },
            MKD: {
                displayName: "macedónsky denár",
                "displayName-count-one": "macedónsky denár",
                "displayName-count-few": "macedónske denáre",
                "displayName-count-many": "macedónskeho denára",
                "displayName-count-other": "macedónskych denárov",
                symbol: "MKD"
            },
            MKN: {
                displayName: "macedónsky denár (1992 – 1993)",
                "displayName-count-one": "macedónsky denár (1992 – 1993)",
                "displayName-count-few": "macedónske denáre (1992 – 1993)",
                "displayName-count-many": "macedónskeho denára (1992 – 1993)",
                "displayName-count-other": "macedónskych denárov (1992 – 1993)",
                symbol: "MKN"
            },
            MLF: {
                displayName: "malijský frank",
                "displayName-count-one": "malijský frank",
                "displayName-count-few": "malijské franky",
                "displayName-count-many": "malijského franku",
                "displayName-count-other": "malijské franky",
                symbol: "MLF"
            },
            MMK: {
                displayName: "mjanmarský kyat",
                "displayName-count-one": "mjanmarský kyat",
                "displayName-count-few": "mjanmarské kyaty",
                "displayName-count-many": "mjanmarského kyatu",
                "displayName-count-other": "mjanmarských kyatov",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "mongolský tugrik",
                "displayName-count-one": "mongolský tugrik",
                "displayName-count-few": "mongolské tugriky",
                "displayName-count-many": "mongolského tugrika",
                "displayName-count-other": "mongolských tugrikov",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "macajská pataca",
                "displayName-count-one": "macajská pataca",
                "displayName-count-few": "macajské patacy",
                "displayName-count-many": "macajskej patacy",
                "displayName-count-other": "macajských patác",
                symbol: "MOP"
            },
            MRO: {
                displayName: "mauritánska ukija (1973–2017)",
                "displayName-count-one": "mauritánska ukija (1973–2017)",
                "displayName-count-few": "mauritánske ukije (1973–2017)",
                "displayName-count-many": "mauritánskej ukije (1973–2017)",
                "displayName-count-other": "mauritánskych ukijí (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "mauritánska ukija",
                "displayName-count-one": "mauritánska ukija",
                "displayName-count-few": "mauritánske ukije",
                "displayName-count-many": "mauritánskej ukije",
                "displayName-count-other": "mauritánskych ukijí",
                symbol: "MRU"
            },
            MTL: {
                displayName: "maltská líra",
                "displayName-count-one": "maltská líra",
                "displayName-count-few": "maltské líry",
                "displayName-count-many": "maltskej líry",
                "displayName-count-other": "maltských lír",
                symbol: "MTL"
            },
            MTP: {
                displayName: "maltská libra",
                "displayName-count-one": "maltská libra",
                "displayName-count-few": "maltské libry",
                "displayName-count-many": "maltskej libry",
                "displayName-count-other": "maltských libier",
                symbol: "MTP"
            },
            MUR: {
                displayName: "maurícijská rupia",
                "displayName-count-one": "maurícijská rupia",
                "displayName-count-few": "maurícijské rupie",
                "displayName-count-many": "maurícijskej rupie",
                "displayName-count-other": "maurícijských rupií",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "maldivská rupia (1947 – 1981)",
                "displayName-count-one": "maldivská rupia (1947 – 1981)",
                "displayName-count-few": "maldivské rupie (1947 – 1981)",
                "displayName-count-many": "maldivskej rupie (1947 – 1981)",
                "displayName-count-other": "maldivských rupií (1947 – 1981)",
                symbol: "MVP"
            },
            MVR: {
                displayName: "maldivská rupia",
                "displayName-count-one": "maldivská rupia",
                "displayName-count-few": "maldivské rupie",
                "displayName-count-many": "maldivskej rupie",
                "displayName-count-other": "maldivských rupií",
                symbol: "MVR"
            },
            MWK: {
                displayName: "malawijská kwacha",
                "displayName-count-one": "malawijská kwacha",
                "displayName-count-few": "malawijské kwachy",
                "displayName-count-many": "malawijskej kwachy",
                "displayName-count-other": "malawijských kwách",
                symbol: "MWK"
            },
            MXN: {
                displayName: "mexické peso",
                "displayName-count-one": "mexické peso",
                "displayName-count-few": "mexické pesos",
                "displayName-count-many": "mexického pesa",
                "displayName-count-other": "mexických pesos",
                symbol: "MX$",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "mexické strieborné peso (1861 – 1992)",
                "displayName-count-one": "mexické strieborné peso (1861 – 1992)",
                "displayName-count-few": "mexické strieborné pesos (1861 – 1992)",
                "displayName-count-many": "mexického strieborného pesa (1861 – 1992)",
                "displayName-count-other": "mexických strieborných pesos (1861 – 1992)",
                symbol: "MXP"
            },
            MXV: {
                displayName: "mexická investičná jednotka",
                "displayName-count-one": "mexická investičná jednotka",
                "displayName-count-few": "mexické investičné jednotky",
                "displayName-count-many": "mexickej investičnej jednotky",
                "displayName-count-other": "mexických investičných jednotiek",
                symbol: "MXV"
            },
            MYR: {
                displayName: "malajzijský ringgit",
                "displayName-count-one": "malajzijský ringgit",
                "displayName-count-few": "malajzijské ringgity",
                "displayName-count-many": "malajzijského ringgitu",
                "displayName-count-other": "malajzijských ringgitov",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "mozambické escudo",
                "displayName-count-one": "mozambické escudo",
                "displayName-count-few": "mozambické escudá",
                "displayName-count-many": "mozambického escuda",
                "displayName-count-other": "mozambických escúd",
                symbol: "MZE"
            },
            MZM: {
                displayName: "mozambický metical (1980 – 2006)",
                "displayName-count-one": "mozambický metical (1980–2006)",
                "displayName-count-few": "mozambické meticaly (1980–2006)",
                "displayName-count-many": "mozambického meticalu (1980–2006)",
                "displayName-count-other": "mozambických meticalov (1980–2006)",
                symbol: "MZM"
            },
            MZN: {
                displayName: "mozambický metical",
                "displayName-count-one": "mozambický metical",
                "displayName-count-few": "mozambické meticaly",
                "displayName-count-many": "mozambického meticalu",
                "displayName-count-other": "mozambických meticalov",
                symbol: "MZN"
            },
            NAD: {
                displayName: "namíbijský dolár",
                "displayName-count-one": "namíbijský dolár",
                "displayName-count-few": "namíbijské doláre",
                "displayName-count-many": "namíbijského dolára",
                "displayName-count-other": "namíbijských dolárov",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "nigérijská naira",
                "displayName-count-one": "nigérijská naira",
                "displayName-count-few": "nigérijské nairy",
                "displayName-count-many": "nigérijskej nairy",
                "displayName-count-other": "nigérijských nair",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "nikaragujská córdoba (1988 – 1991)",
                "displayName-count-one": "nikaragujská córdoba (1988–1991)",
                "displayName-count-few": "nikaragujské córdoby (1988–1991)",
                "displayName-count-many": "nikaragujskej córdoby (1988–1991)",
                "displayName-count-other": "nikaragujských córdob (1988–1991)",
                symbol: "NIC"
            },
            NIO: {
                displayName: "nikaragujská córdoba",
                "displayName-count-one": "nikaragujská córdoba",
                "displayName-count-few": "nikaragujské córdoby",
                "displayName-count-many": "nikaragujskej córdoby",
                "displayName-count-other": "nikaragujských córdob",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "holandský gulden",
                "displayName-count-one": "holandský gulden",
                "displayName-count-few": "holandské guldeny",
                "displayName-count-many": "holandského guldena",
                "displayName-count-other": "holandských guldenov",
                symbol: "NLG"
            },
            NOK: {
                displayName: "nórska koruna",
                "displayName-count-one": "nórska koruna",
                "displayName-count-few": "nórske koruny",
                "displayName-count-many": "nórskej koruny",
                "displayName-count-other": "nórskych korún",
                symbol: "NOK",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "nepálska rupia",
                "displayName-count-one": "nepálska rupia",
                "displayName-count-few": "nepálske rupie",
                "displayName-count-many": "nepálskej rupie",
                "displayName-count-other": "nepálskych rupií",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "novozélandský dolár",
                "displayName-count-one": "novozélandský dolár",
                "displayName-count-few": "novozélandské doláre",
                "displayName-count-many": "novozélandského dolára",
                "displayName-count-other": "novozélandských dolárov",
                symbol: "NZD",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "ománsky rial",
                "displayName-count-one": "ománsky rial",
                "displayName-count-few": "ománske rialy",
                "displayName-count-many": "ománskeho rialu",
                "displayName-count-other": "ománskych rialov",
                symbol: "OMR"
            },
            PAB: {
                displayName: "panamská balboa",
                "displayName-count-one": "panamská balboa",
                "displayName-count-few": "panamské balboy",
                "displayName-count-many": "panamskej balboy",
                "displayName-count-other": "panamských balboí",
                symbol: "PAB"
            },
            PEI: {
                displayName: "peruánsky inti",
                "displayName-count-one": "peruánsky inti",
                "displayName-count-few": "peruánske inti",
                "displayName-count-many": "peruánskeho inti",
                "displayName-count-other": "peruánskych inti",
                symbol: "PEI"
            },
            PEN: {
                displayName: "peruánsky sol",
                "displayName-count-one": "peruánsky sol",
                "displayName-count-few": "peruánske soly",
                "displayName-count-many": "peruánskeho sola",
                "displayName-count-other": "peruánskych solov",
                symbol: "PEN"
            },
            PES: {
                displayName: "peruánsky sol (1863 – 1965)",
                "displayName-count-one": "peruánsky sol (1863–1965)",
                "displayName-count-few": "peruánske soly (1863–1965)",
                "displayName-count-many": "peruánskeho sola (1863–1965)",
                "displayName-count-other": "peruánskych solov (1863–1965)",
                symbol: "PES"
            },
            PGK: {
                displayName: "papuánska kina",
                "displayName-count-one": "papuánska kina",
                "displayName-count-few": "papuánske kiny",
                "displayName-count-many": "papuánskej kiny",
                "displayName-count-other": "papuánskych kín",
                symbol: "PGK"
            },
            PHP: {
                displayName: "filipínske peso",
                "displayName-count-one": "filipínske peso",
                "displayName-count-few": "filipínske pesos",
                "displayName-count-many": "filipínskeho pesa",
                "displayName-count-other": "filipínskych pesos",
                symbol: "PHP",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "pakistanská rupia",
                "displayName-count-one": "pakistanská rupia",
                "displayName-count-few": "pakistanské rupie",
                "displayName-count-many": "pakistanskej rupie",
                "displayName-count-other": "pakistanských rupií",
                symbol: "PKR",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "poľský zlotý",
                "displayName-count-one": "poľský zlotý",
                "displayName-count-few": "poľské zloté",
                "displayName-count-many": "poľského zlotého",
                "displayName-count-other": "poľských zlotých",
                symbol: "PLN",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "poľský zlotý (1950 – 1995)",
                "displayName-count-one": "poľský zlotý (1950 – 1995)",
                "displayName-count-few": "poľské zloté (1950 – 1995)",
                "displayName-count-many": "poľského zlotého (1950 – 1995)",
                "displayName-count-other": "poľských zlotých (1950 – 1995)",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "portugalské escudo",
                "displayName-count-one": "portugalské escudo",
                "displayName-count-few": "portugalské escudá",
                "displayName-count-many": "portugalského escuda",
                "displayName-count-other": "portugalských escúd",
                symbol: "PTE"
            },
            PYG: {
                displayName: "paraguajské guaraní",
                "displayName-count-one": "paraguajské guaraní",
                "displayName-count-few": "paraguajské guaraní",
                "displayName-count-many": "paraguajského guaraní",
                "displayName-count-other": "paraguajských guaraní",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "katarský rial",
                "displayName-count-one": "katarský rial",
                "displayName-count-few": "katarské rialy",
                "displayName-count-many": "katarského rialu",
                "displayName-count-other": "katarských rialov",
                symbol: "QAR"
            },
            RHD: {
                displayName: "rodézsky dolár",
                "displayName-count-one": "rodézsky dolár",
                "displayName-count-few": "rodézske doláre",
                "displayName-count-many": "rodézskeho dolára",
                "displayName-count-other": "rodézskych dolárov",
                symbol: "RHD"
            },
            ROL: {
                displayName: "rumunský lei (1952 – 2006)",
                "displayName-count-one": "rumunský lei (1952 – 2006)",
                "displayName-count-few": "rumunské lei (1952 – 2006)",
                "displayName-count-many": "rumunského lei (1952 – 2006)",
                "displayName-count-other": "rumunských lei (1952 – 2006)",
                symbol: "ROL"
            },
            RON: {
                displayName: "rumunský lei",
                "displayName-count-one": "rumunský lei",
                "displayName-count-few": "rumunské lei",
                "displayName-count-many": "rumunského lei",
                "displayName-count-other": "rumunských lei",
                symbol: "RON",
                "symbol-alt-narrow": "lei"
            },
            RSD: {
                displayName: "srbský dinár",
                "displayName-count-one": "srbský dinár",
                "displayName-count-few": "srbské dináre",
                "displayName-count-many": "srbského dinára",
                "displayName-count-other": "srbských dinárov",
                symbol: "RSD"
            },
            RUB: {
                displayName: "ruský rubeľ",
                "displayName-count-one": "ruský rubeľ",
                "displayName-count-few": "ruské ruble",
                "displayName-count-many": "ruského rubľa",
                "displayName-count-other": "ruských rubľov",
                symbol: "RUB",
                "symbol-alt-narrow": "₽",
                "symbol-alt-variant": "₽"
            },
            RUR: {
                displayName: "ruský rubeľ (1991 – 1998)",
                "displayName-count-one": "ruský rubeľ (1991 – 1998)",
                "displayName-count-few": "ruské ruble (1991 – 1998)",
                "displayName-count-many": "ruského rubľa (1991 – 1998)",
                "displayName-count-other": "ruských rubľov (1991 – 1998)",
                symbol: "RUR",
                "symbol-alt-narrow": "р."
            },
            RWF: {
                displayName: "rwandský frank",
                "displayName-count-one": "rwandský frank",
                "displayName-count-few": "rwandské franky",
                "displayName-count-many": "rwandského franku",
                "displayName-count-other": "rwandských frankov",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "saudskoarabský rial",
                "displayName-count-one": "saudskoarabský rial",
                "displayName-count-few": "saudskoarabské rialy",
                "displayName-count-many": "saudskoarabského rialu",
                "displayName-count-other": "saudskoarabských rialov",
                symbol: "SAR"
            },
            SBD: {
                displayName: "šalamúnsky dolár",
                "displayName-count-one": "šalamúnsky dolár",
                "displayName-count-few": "šalamúnske doláre",
                "displayName-count-many": "šalamúnskeho dolára",
                "displayName-count-other": "šalamúnskych dolárov",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "seychelská rupia",
                "displayName-count-one": "seychelská rupia",
                "displayName-count-few": "seychelské rupie",
                "displayName-count-many": "seychelskej rupie",
                "displayName-count-other": "seychelských rupií",
                symbol: "SCR"
            },
            SDD: {
                displayName: "sudánsky dinár (1992 – 2007)",
                "displayName-count-one": "sudánsky dinár (1992 – 2007)",
                "displayName-count-few": "sudánske dináre (1992 – 2007)",
                "displayName-count-many": "sudánskeho dinára (1992 – 2007)",
                "displayName-count-other": "sudánskych dinárov (1992 – 2007)",
                symbol: "SDD"
            },
            SDG: {
                displayName: "sudánska libra",
                "displayName-count-one": "sudánska libra",
                "displayName-count-few": "sudánske libry",
                "displayName-count-many": "sudánskej libry",
                "displayName-count-other": "sudánskych libier",
                symbol: "SDG"
            },
            SDP: {
                displayName: "sudánska libra (1957 – 1998)",
                "displayName-count-one": "sudánska libra (1957 – 1998)",
                "displayName-count-few": "sudánske libry (1957 – 1998)",
                "displayName-count-many": "sudánskej libry (1957 – 1998)",
                "displayName-count-other": "sudánskych libier (1957 – 1998)",
                symbol: "SDP"
            },
            SEK: {
                displayName: "švédska koruna",
                "displayName-count-one": "švédska koruna",
                "displayName-count-few": "švédske koruny",
                "displayName-count-many": "švédskej koruny",
                "displayName-count-other": "švédskych korún",
                symbol: "SEK",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "singapurský dolár",
                "displayName-count-one": "singapurský dolár",
                "displayName-count-few": "singapurské doláre",
                "displayName-count-many": "singapurského dolára",
                "displayName-count-other": "singapurských dolárov",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "svätohelenská libra",
                "displayName-count-one": "svätohelenská libra",
                "displayName-count-few": "svätohelenské libry",
                "displayName-count-many": "svätohelenskej libry",
                "displayName-count-other": "svätohelenských libier",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "slovinský toliar",
                "displayName-count-one": "slovinský toliar",
                "displayName-count-few": "slovinské toliare",
                "displayName-count-many": "slovinského toliara",
                "displayName-count-other": "slovinských toliarov",
                symbol: "SIT"
            },
            SKK: {
                displayName: "slovenská koruna",
                "displayName-count-one": "slovenská koruna",
                "displayName-count-few": "slovenské koruny",
                "displayName-count-many": "slovenskej koruny",
                "displayName-count-other": "slovenských korún",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "sierraleonský leone",
                "displayName-count-one": "sierraleonský leone",
                "displayName-count-few": "sierraleonské leone",
                "displayName-count-many": "sierraleonského leone",
                "displayName-count-other": "sierraleonských leone",
                symbol: "SLL"
            },
            SOS: {
                displayName: "somálsky šiling",
                "displayName-count-one": "somálsky šiling",
                "displayName-count-few": "somálske šilingy",
                "displayName-count-many": "somálskeho šilingu",
                "displayName-count-other": "somálskych šilingov",
                symbol: "SOS"
            },
            SRD: {
                displayName: "surinamský dolár",
                "displayName-count-one": "surinamský dolár",
                "displayName-count-few": "surinamské doláre",
                "displayName-count-many": "surinamského dolára",
                "displayName-count-other": "surinamských dolárov",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "surinamský zlatý",
                "displayName-count-one": "surinamský zlatý",
                "displayName-count-few": "surinamské zlaté",
                "displayName-count-many": "surinamského zlatého",
                "displayName-count-other": "surinamských zlatých",
                symbol: "SRG"
            },
            SSP: {
                displayName: "juhosudánska libra",
                "displayName-count-one": "juhosudánska libra",
                "displayName-count-few": "juhosudánske libry",
                "displayName-count-many": "juhosudánskej libry",
                "displayName-count-other": "juhosudánskych libier",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "svätotomášska dobra (1977–2017)",
                "displayName-count-one": "svätotomášska dobra (1977–2017)",
                "displayName-count-few": "svätotomášske dobry (1977–2017)",
                "displayName-count-many": "svätotomášskej dobry (1977–2017)",
                "displayName-count-other": "svätotomášskych dobier (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "svätotomášska dobra",
                "displayName-count-one": "svätotomášska dobra",
                "displayName-count-few": "svätotomášske dobry",
                "displayName-count-many": "svätotomášskej dobry",
                "displayName-count-other": "svätotomášskych dobier",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "sovietsky rubeľ",
                "displayName-count-one": "sovietsky rubeľ",
                "displayName-count-few": "sovietske ruble",
                "displayName-count-many": "sovietskeho rubľa",
                "displayName-count-other": "sovietskych rubľov",
                symbol: "SUR"
            },
            SVC: {
                displayName: "salvádorský colón",
                "displayName-count-one": "salvádorský colón",
                "displayName-count-few": "salvádorské colóny",
                "displayName-count-many": "salvádorského colóna",
                "displayName-count-other": "salvádorských colónov",
                symbol: "SVC"
            },
            SYP: {
                displayName: "sýrska libra",
                "displayName-count-one": "sýrska libra",
                "displayName-count-few": "sýrske libry",
                "displayName-count-many": "sýrskej libry",
                "displayName-count-other": "sýrskych libier",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "svazijské lilangeni",
                "displayName-count-one": "svazijské lilangeni",
                "displayName-count-few": "svazijské lilangeni",
                "displayName-count-many": "svazijského lilangeni",
                "displayName-count-other": "svazijských lilangeni",
                symbol: "SZL"
            },
            THB: {
                displayName: "thajský baht",
                "displayName-count-one": "thajský baht",
                "displayName-count-few": "thajské bahty",
                "displayName-count-many": "thajského bahtu",
                "displayName-count-other": "thajských bahtov",
                symbol: "THB",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "tadžický rubeľ",
                "displayName-count-one": "tadžický rubeľ",
                "displayName-count-few": "tadžické ruble",
                "displayName-count-many": "tadžického rubľa",
                "displayName-count-other": "tadžických rubľov",
                symbol: "TJR"
            },
            TJS: {
                displayName: "tadžické somoni",
                "displayName-count-one": "tadžické somoni",
                "displayName-count-few": "tadžické somoni",
                "displayName-count-many": "tadžického somoni",
                "displayName-count-other": "tadžických somoni",
                symbol: "TJS"
            },
            TMM: {
                displayName: "turkménsky manat (1993 – 2009)",
                "displayName-count-one": "turkménsky manat (1993 – 2009)",
                "displayName-count-few": "turkménske manaty (1993 – 2009)",
                "displayName-count-many": "turkménskeho manatu (1993 – 2009)",
                "displayName-count-other": "turkménskych manatov (1993 – 2009)",
                symbol: "TMM"
            },
            TMT: {
                displayName: "turkménsky manat",
                "displayName-count-one": "turkménsky manat",
                "displayName-count-few": "turkménske manaty",
                "displayName-count-many": "turkménskeho manatu",
                "displayName-count-other": "turkménskych manatov",
                symbol: "TMT"
            },
            TND: {
                displayName: "tuniský dinár",
                "displayName-count-one": "tuniský dinár",
                "displayName-count-few": "tuniské dináre",
                "displayName-count-many": "tuniského dinára",
                "displayName-count-other": "tuniských dinárov",
                symbol: "TND"
            },
            TOP: {
                displayName: "tongská paʻanga",
                "displayName-count-one": "tongská pa’anga",
                "displayName-count-few": "tongské pa’anga",
                "displayName-count-many": "tongského pa’anga",
                "displayName-count-other": "tongských pa’anga",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "timorské escudo",
                "displayName-count-one": "timorské escudo",
                "displayName-count-few": "timorské escudá",
                "displayName-count-many": "timorského escuda",
                "displayName-count-other": "timorských escúd",
                symbol: "TPE"
            },
            TRL: {
                displayName: "turecká líra (1922 – 2005)",
                "displayName-count-one": "turecká líra (1922 – 2005)",
                "displayName-count-few": "turecké líry (1922 – 2005)",
                "displayName-count-many": "tureckej líry (1922 – 2005)",
                "displayName-count-other": "tureckých lír (1922 – 2005)",
                symbol: "TRL"
            },
            TRY: {
                displayName: "turecká líra",
                "displayName-count-one": "turecká líra",
                "displayName-count-few": "turecké líry",
                "displayName-count-many": "tureckej líry",
                "displayName-count-other": "tureckých lír",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "trinidadsko-tobažský dolár",
                "displayName-count-one": "trinidadsko-tobažský dolár",
                "displayName-count-few": "trinidadsko-tobažské doláre",
                "displayName-count-many": "trinidadsko-tobažského dolára",
                "displayName-count-other": "trinidadsko-tobažských dolárov",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "nový taiwanský dolár",
                "displayName-count-one": "nový taiwanský dolár",
                "displayName-count-few": "nové taiwanské doláre",
                "displayName-count-many": "nového taiwanského dolára",
                "displayName-count-other": "nových taiwanských dolárov",
                symbol: "TWD",
                "symbol-alt-narrow": "NT$"
            },
            TZS: {
                displayName: "tanzánsky šiling",
                "displayName-count-one": "tanzánsky šiling",
                "displayName-count-few": "tanzánske šilingy",
                "displayName-count-many": "tanzánskeho šilingu",
                "displayName-count-other": "tanzánskych šilingov",
                symbol: "TZS"
            },
            UAH: {
                displayName: "ukrajinská hrivna",
                "displayName-count-one": "ukrajinská hrivna",
                "displayName-count-few": "ukrajinské hrivny",
                "displayName-count-many": "ukrajinskej hrivny",
                "displayName-count-other": "ukrajinských hrivien",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "ukrajinský karbovanec",
                "displayName-count-one": "ukrajinský karbovanec",
                "displayName-count-few": "ukrajinské karbovance",
                "displayName-count-many": "ukrajinského karbovanca",
                "displayName-count-other": "ukrajinských karbovancov",
                symbol: "UAK"
            },
            UGS: {
                displayName: "ugandský šiling (1966 – 1987)",
                "displayName-count-one": "ugandský šiling (1966 – 1987)",
                "displayName-count-few": "ugandské šilingy (1966 – 1987)",
                "displayName-count-many": "ugandského šilingu (1966 – 1987)",
                "displayName-count-other": "ugandských šilingov (1966 – 1987)",
                symbol: "UGS"
            },
            UGX: {
                displayName: "ugandský šiling",
                "displayName-count-one": "ugandský šiling",
                "displayName-count-few": "ugandské šilingy",
                "displayName-count-many": "ugandského šilingu",
                "displayName-count-other": "ugandských šilingov",
                symbol: "UGX"
            },
            USD: {
                displayName: "americký dolár",
                "displayName-count-one": "americký dolár",
                "displayName-count-few": "americké doláre",
                "displayName-count-many": "amerického dolára",
                "displayName-count-other": "amerických dolárov",
                symbol: "USD",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "americký dolár (ďalší deň)",
                "displayName-count-one": "americký dolár (ďalší deň)",
                "displayName-count-few": "americké doláre (ďalší deň)",
                "displayName-count-many": "amerického dolára (ďalší deň)",
                "displayName-count-other": "amerických dolárov (ďalší deň)",
                symbol: "USN"
            },
            USS: {
                displayName: "americký dolár (rovnaký deň)",
                "displayName-count-one": "americký dolár (rovnaký deň)",
                "displayName-count-few": "americké doláre (rovnaký deň)",
                "displayName-count-many": "amerického dolára (rovnaký deň)",
                "displayName-count-other": "amerických dolárov (rovnaký deň)",
                symbol: "USS"
            },
            UYI: {
                displayName: "uruguajské peso (v indexovaných jednotkách)",
                "displayName-count-one": "uruguajské peso (v indexovaných jednotkách)",
                "displayName-count-few": "uruguajské pesos (v indexovaných jednotkách)",
                "displayName-count-many": "uruguajského pesa (v indexovaných jednotkách)",
                "displayName-count-other": "uruguajských pesos (v indexovaných jednotkách)",
                symbol: "UYI"
            },
            UYP: {
                displayName: "uruguajské peso (1975 – 1993)",
                "displayName-count-one": "uruguajské peso (1975 – 1993)",
                "displayName-count-few": "uruguajské pesos (1975 – 1993)",
                "displayName-count-many": "uruguajského pesa (1975 – 1993)",
                "displayName-count-other": "uruguajských pesos (1975 – 1993)",
                symbol: "UYP"
            },
            UYU: {
                displayName: "uruguajské peso",
                "displayName-count-one": "uruguajské peso",
                "displayName-count-few": "uruguajské pesos",
                "displayName-count-many": "uruguajského pesa",
                "displayName-count-other": "uruguajských pesos",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "UYW",
                symbol: "UYW"
            },
            UZS: {
                displayName: "uzbecký sum",
                "displayName-count-one": "uzbecký sum",
                "displayName-count-few": "uzbecké sumy",
                "displayName-count-many": "uzbeckého sumu",
                "displayName-count-other": "uzbeckých sumov",
                symbol: "UZS"
            },
            VEB: {
                displayName: "venezuelský bolívar (1871 – 2008)",
                "displayName-count-one": "venezuelský bolívar (1871 – 2008)",
                "displayName-count-few": "venezuelské bolívary (1871 – 2008)",
                "displayName-count-many": "venezuelského bolívaru (1871 – 2008)",
                "displayName-count-other": "venezuelských bolívarov (1871 – 2008)",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "venezuelský bolívar (2008–2018)",
                "displayName-count-one": "venezuelský bolívar (2008–2018)",
                "displayName-count-few": "venezuelské bolívary (2008–2018)",
                "displayName-count-many": "venezuelského bolívaru (2008–2018)",
                "displayName-count-other": "venezuelských bolívarov (2008–2018)",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs"
            },
            VES: {
                displayName: "venezuelský bolívar",
                "displayName-count-one": "venezuelský bolívar",
                "displayName-count-few": "venezuelské bolívary",
                "displayName-count-many": "venezuelského bolívaru",
                "displayName-count-other": "venezuelských bolívarov",
                symbol: "VES"
            },
            VND: {
                displayName: "vietnamský dong",
                "displayName-count-one": "vietnamský dong",
                "displayName-count-few": "vietnamské dongy",
                "displayName-count-many": "vietnamského dongu",
                "displayName-count-other": "vietnamských dongov",
                symbol: "VND",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "vietnamský dong (1978 – 1985)",
                "displayName-count-one": "vietnamský dong (1978 – 1985)",
                "displayName-count-few": "vietnamské dongy (1978 – 1985)",
                "displayName-count-many": "vietnamského dongu (1978 – 1985)",
                "displayName-count-other": "vietnamských dongov (1978 – 1985)",
                symbol: "VNN"
            },
            VUV: {
                displayName: "vanuatské vatu",
                "displayName-count-one": "vanuatské vatu",
                "displayName-count-few": "vanuatské vatu",
                "displayName-count-many": "vanuatského vatu",
                "displayName-count-other": "vanuatských vatu",
                symbol: "VUV"
            },
            WST: {
                displayName: "samojská tala",
                "displayName-count-one": "samojská tala",
                "displayName-count-few": "samojské taly",
                "displayName-count-many": "samojskej taly",
                "displayName-count-other": "samojských tál",
                symbol: "WST"
            },
            XAF: {
                displayName: "stredoafrický frank",
                "displayName-count-one": "stredoafrický frank",
                "displayName-count-few": "stredoafrické franky",
                "displayName-count-many": "stredoafrického franku",
                "displayName-count-other": "stredoafrických frankov",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "striebro",
                "displayName-count-one": "trójska unca striebra",
                "displayName-count-few": "trójske unce striebra",
                "displayName-count-many": "trójskej unce striebra",
                "displayName-count-other": "trójskych uncí striebra",
                symbol: "XAG"
            },
            XAU: {
                displayName: "zlato",
                "displayName-count-one": "trójska unca zlata",
                "displayName-count-few": "trójske unce zlata",
                "displayName-count-many": "trójskej unce zlata",
                "displayName-count-other": "trójskych uncí zlata",
                symbol: "XAU"
            },
            XBA: {
                displayName: "európska zmiešaná jednotka",
                "displayName-count-one": "európska zmiešaná jednotka",
                "displayName-count-few": "európske zmiešané jednotky",
                "displayName-count-many": "európskej zmiešanej jednotky",
                "displayName-count-other": "európskych zmiešaných jednotiek",
                symbol: "XBA"
            },
            XBB: {
                displayName: "európska peňažná jednotka",
                "displayName-count-one": "európska peňažná jednotka",
                "displayName-count-few": "európske peňažné jednotky",
                "displayName-count-many": "európskej peňažnek jednotky",
                "displayName-count-other": "európskych peňažných jednotiek",
                symbol: "XBB"
            },
            XBC: {
                displayName: "európska jednotka účtu 9 (XBC)",
                "displayName-count-one": "európska jednotka účtu 9 (XBC)",
                "displayName-count-few": "európske jednotky účtu 9 (XBC)",
                "displayName-count-many": "európskej jednotky účtu 9 (XBC)",
                "displayName-count-other": "európskych jednotiek účtu 9 (XBC)",
                symbol: "XBC"
            },
            XBD: {
                displayName: "európska jednotka účtu 17 (XBC)",
                "displayName-count-one": "európska jednotka účtu 17 (XBC)",
                "displayName-count-few": "európske jednotky účtu 17 (XBC)",
                "displayName-count-many": "európskej jednotky účtu 17 (XBC)",
                "displayName-count-other": "európskych jednotiek účtu 17 (XBC)",
                symbol: "XBD"
            },
            XCD: {
                displayName: "východokaribský dolár",
                "displayName-count-one": "východokaribský dolár",
                "displayName-count-few": "východokaribské doláre",
                "displayName-count-many": "východokaribského dolára",
                "displayName-count-other": "východokaribských dolárov",
                symbol: "EC$",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "SDR",
                "displayName-count-one": "SDR",
                "displayName-count-few": "SDR",
                "displayName-count-many": "SDR",
                "displayName-count-other": "SDR",
                symbol: "XDR"
            },
            XEU: {
                displayName: "európska menová jednotka",
                "displayName-count-one": "európska menová jednotka",
                "displayName-count-few": "európske menové jednotky",
                "displayName-count-many": "európskej menovej jednotky",
                "displayName-count-other": "európskych menových jednotiek",
                symbol: "XEU"
            },
            XFO: {
                displayName: "francúzsky zlatý frank",
                "displayName-count-one": "francúzsky zlatý frank",
                "displayName-count-few": "francúzske zlaté franky",
                "displayName-count-many": "francúzskeho zlatého franku",
                "displayName-count-other": "francúzskych zlatých frankov",
                symbol: "XFO"
            },
            XFU: {
                displayName: "francúzsky UIC frank",
                "displayName-count-one": "francúzsky UIC frank",
                "displayName-count-few": "francúzske UIC franky",
                "displayName-count-many": "francúzskeho UIC franku",
                "displayName-count-other": "francúzskych UIC frankov",
                symbol: "XFU"
            },
            XOF: {
                displayName: "západoafrický frank",
                "displayName-count-one": "západoafrický frank",
                "displayName-count-few": "západoafrické franky",
                "displayName-count-many": "západoafrického franku",
                "displayName-count-other": "západoafrických frankov",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "paládium",
                "displayName-count-one": "trójska unca paládia",
                "displayName-count-few": "trójske unce paládia",
                "displayName-count-many": "trójskej unce paládia",
                "displayName-count-other": "trójskych uncí paládia",
                symbol: "XPD"
            },
            XPF: {
                displayName: "CFP frank",
                "displayName-count-one": "CFP frank",
                "displayName-count-few": "CFP franky",
                "displayName-count-many": "CFP franku",
                "displayName-count-other": "CFP frankov",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "platina",
                "displayName-count-one": "trójska unca platiny",
                "displayName-count-few": "trójske unce platiny",
                "displayName-count-many": "trójskej unce platiny",
                "displayName-count-other": "trójskej unce platiny",
                symbol: "XPT"
            },
            XRE: {
                displayName: "fondy RINET",
                "displayName-count-one": "jednotka fondov RINET",
                "displayName-count-few": "jednotky fondov RINET",
                "displayName-count-many": "jednotky fondov RINET",
                "displayName-count-other": "jednotiek fondov RINET",
                symbol: "XRE"
            },
            XSU: {
                displayName: "sucre",
                "displayName-count-one": "sucre",
                "displayName-count-few": "sucre",
                "displayName-count-many": "sucre",
                "displayName-count-other": "sucre",
                symbol: "XSU"
            },
            XTS: {
                displayName: "kód testovacej meny",
                "displayName-count-one": "jednotka testovacej meny",
                "displayName-count-few": "jednotky testovacej meny",
                "displayName-count-many": "jednotky testovacej meny",
                "displayName-count-other": "jednotiek testovacej meny",
                symbol: "XTS"
            },
            XUA: {
                displayName: "jednotka účtu ADB",
                "displayName-count-one": "jednotka účtu ADB",
                "displayName-count-few": "jednotky účtu ADB",
                "displayName-count-many": "jednotky účtu ADB",
                "displayName-count-other": "jednotiek účtu ADB",
                symbol: "XUA"
            },
            XXX: {
                displayName: "neznáma mena",
                "displayName-count-one": "(neznáma mena)",
                "displayName-count-few": "(neznáma mena)",
                "displayName-count-many": "(neznáma mena)",
                "displayName-count-other": "(neznáma mena)",
                symbol: "XXX"
            },
            YDD: {
                displayName: "jemenský dinár",
                "displayName-count-one": "jemenský dinár",
                "displayName-count-few": "jemenské dináre",
                "displayName-count-many": "jemenského dinára",
                "displayName-count-other": "jemenských dinárov",
                symbol: "YDD"
            },
            YER: {
                displayName: "jemenský rial",
                "displayName-count-one": "jemenský rial",
                "displayName-count-few": "jemenské rialy",
                "displayName-count-many": "jemenského rialu",
                "displayName-count-other": "jemenských rialov",
                symbol: "YER"
            },
            YUD: {
                displayName: "Juhoslávsky dinár [YUD]",
                "displayName-count-one": "juhoslovanský dinár (1966 – 1990)",
                "displayName-count-few": "juhoslovanské dináre (1966 – 1990)",
                "displayName-count-many": "juhoslovanského dinára (1966 – 1990)",
                "displayName-count-other": "juhoslovanských dinárov (1966 – 1990)",
                symbol: "YUD"
            },
            YUM: {
                displayName: "juhoslovanský nový dinár (1994 – 2002)",
                "displayName-count-one": "juhoslovanský nový dinár (1994 – 2002)",
                "displayName-count-few": "juhoslovanské nové dináre (1994 – 2002)",
                "displayName-count-many": "juhoslovanského nového dinára (1994 – 2002)",
                "displayName-count-other": "juhoslovanských nových dinárov (1994 – 2002)",
                symbol: "YUM"
            },
            YUN: {
                displayName: "juhoslovanský konvertibilný dinár (1990 – 1992)",
                "displayName-count-one": "juhoslovanský konvertibilný dinár (1990 – 1992)",
                "displayName-count-few": "juhoslovanské konvertibilné dináre (1990 – 1992)",
                "displayName-count-many": "juhoslovanského konvertibilného dinára (1990 – 1992)",
                "displayName-count-other": "juhoslovanských konvertibilných dinárov (1990 – 1992)",
                symbol: "YUN"
            },
            YUR: {
                displayName: "juhoslovanský reformovaný dinár (1992 – 1993)",
                "displayName-count-one": "juhoslovanský reformovaný dinár (1992 – 1993)",
                "displayName-count-few": "juhoslovanské reformované dináre (1992 – 1993)",
                "displayName-count-many": "juhoslovanského reformovaného dinára (1992 – 1993)",
                "displayName-count-other": "juhoslovanských reformovaných dinárov (1992 – 1993)",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "juhoafrický rand (finančný)",
                "displayName-count-one": "juhoafrický rand (finančný)",
                "displayName-count-few": "juhoafrické randy (finančné)",
                "displayName-count-many": "juhoafrického randu (finančného)",
                "displayName-count-other": "juhoafrických randov (finančných)",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "juhoafrický rand",
                "displayName-count-one": "juhoafrický rand",
                "displayName-count-few": "juhoafrické randy",
                "displayName-count-many": "juhoafrického randu",
                "displayName-count-other": "juhoafrických randov",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "zambijská kwacha (1968 – 2012)",
                "displayName-count-one": "zambijská kwacha (1968 – 2012)",
                "displayName-count-few": "zambijské kwachy (1968 – 2012)",
                "displayName-count-many": "zambijskej kwachy (1968 – 2012)",
                "displayName-count-other": "zambijských kwách (1968 – 2012)",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "zambijská kwacha",
                "displayName-count-one": "zambijská kwacha",
                "displayName-count-few": "zambijské kwachy",
                "displayName-count-many": "zambijskej kwachy",
                "displayName-count-other": "zambijských kwách",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "zairský nový zaire (1993 – 1998)",
                "displayName-count-one": "zairský nový zaire (1993 – 1998)",
                "displayName-count-few": "zairské nové zairy (1993 – 1998)",
                "displayName-count-many": "zairského nového zairu (1993 – 1998)",
                "displayName-count-other": "zairských nových zairov (1993 – 1998)",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "zairský zaire (1971 – 1993)",
                "displayName-count-one": "zairský zaire (1971 – 1993)",
                "displayName-count-few": "zairské zairy (1971 – 1993)",
                "displayName-count-many": "zairského zairu (1971 – 1993)",
                "displayName-count-other": "zairských zairov (1971 – 1993)",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "zimbabwiansky dolár (1980 – 2008)",
                "displayName-count-one": "zimbabwiansky dolár (1980 – 2008)",
                "displayName-count-few": "zimbabwianske doláre (1980 – 2008)",
                "displayName-count-many": "zimbabwianskeho dolára (1980 – 2008)",
                "displayName-count-other": "zimbabwianskych dolárov (1980 – 2008)",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "zimbabwiansky dolár (2009)",
                "displayName-count-one": "zimbabwiansky dolár (2009)",
                "displayName-count-few": "zimbabwianske doláre (2009)",
                "displayName-count-many": "zimbabwianskeho dolára (2009)",
                "displayName-count-other": "zimbabwianskych dolárov (2009)",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "zimbabwiansky dolár (2008)",
                "displayName-count-one": "zimbabwiansky dolár (2008)",
                "displayName-count-few": "zimbabwianske doláre (2008)",
                "displayName-count-many": "zimbabwianskeho dolára (2008)",
                "displayName-count-other": "zimbabwianskych dolárov (2008)",
                symbol: "ZWR"
            }
        },
        localeCurrency: "EUR"
    },
    calendar: {
        patterns: {
            d: "d. M. y",
            D: "EEEE d. MMMM y",
            m: "d. M.",
            M: "d. MMMM",
            y: "M/y",
            Y: "LLLL y",
            F: "EEEE d. MMMM y H:mm:ss",
            g: "d. M. y H:mm",
            G: "d. M. y H:mm:ss",
            t: "H:mm",
            T: "H:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1}, {0}",
            long: "{1}, {0}",
            medium: "{1}, {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d.",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d.",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "d. M. y GGGGG",
                GyMMM: "LLLL y G",
                GyMMMd: "d. M. y G",
                GyMMMEd: "E d. M. y G",
                GyMMMMd: "d. M. y G",
                h: "h a",
                H: "H",
                hm: "h:mm a",
                Hm: "H:mm",
                hms: "h:mm:ss a",
                Hms: "H:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "H:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "H:mm v",
                M: "L.",
                Md: "d. M.",
                MEd: "E d. M.",
                MMM: "LLL",
                MMMd: "d. M.",
                MMMEd: "E d. M.",
                MMMMd: "d. MMMM",
                MMMMEd: "E d. MMMM",
                "MMMMW-count-one": "W. 'týždeň' MMMM",
                "MMMMW-count-few": "W. 'týždeň' MMMM",
                "MMMMW-count-many": "W. 'týždeň' MMMM",
                "MMMMW-count-other": "W. 'týždeň' MMMM",
                mmss: "mm:ss",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d. M. y",
                yMEd: "E d. M. y",
                yMMM: "M/y",
                yMMMd: "d. M. y",
                yMMMEd: "E d. M. y",
                yMMMM: "LLLL y",
                yMMMMd: "d. MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "w. 'týždeň' 'roka' Y",
                "yw-count-few": "w. 'týždeň' 'roka' Y",
                "yw-count-many": "w. 'týždeň' 'roka' Y",
                "yw-count-other": "w. 'týždeň' 'roka' Y"
            }
        },
        timeFormats: {
            full: "H:mm:ss zzzz",
            long: "H:mm:ss z",
            medium: "H:mm:ss",
            short: "H:mm"
        },
        dateFormats: {
            full: "EEEE d. MMMM y",
            long: "d. MMMM y",
            medium: "d. M. y",
            short: "d. M. y"
        },
        days: {
            format: {
                abbreviated: [
                    "ne",
                    "po",
                    "ut",
                    "st",
                    "št",
                    "pi",
                    "so"
                ],
                narrow: [
                    "n",
                    "p",
                    "u",
                    "s",
                    "š",
                    "p",
                    "s"
                ],
                short: [
                    "ne",
                    "po",
                    "ut",
                    "st",
                    "št",
                    "pi",
                    "so"
                ],
                wide: [
                    "nedeľa",
                    "pondelok",
                    "utorok",
                    "streda",
                    "štvrtok",
                    "piatok",
                    "sobota"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ne",
                    "po",
                    "ut",
                    "st",
                    "št",
                    "pi",
                    "so"
                ],
                narrow: [
                    "n",
                    "p",
                    "u",
                    "s",
                    "š",
                    "p",
                    "s"
                ],
                short: [
                    "ne",
                    "po",
                    "ut",
                    "st",
                    "št",
                    "pi",
                    "so"
                ],
                wide: [
                    "nedeľa",
                    "pondelok",
                    "utorok",
                    "streda",
                    "štvrtok",
                    "piatok",
                    "sobota"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "jan",
                    "feb",
                    "mar",
                    "apr",
                    "máj",
                    "jún",
                    "júl",
                    "aug",
                    "sep",
                    "okt",
                    "nov",
                    "dec"
                ],
                narrow: [
                    "j",
                    "f",
                    "m",
                    "a",
                    "m",
                    "j",
                    "j",
                    "a",
                    "s",
                    "o",
                    "n",
                    "d"
                ],
                wide: [
                    "januára",
                    "februára",
                    "marca",
                    "apríla",
                    "mája",
                    "júna",
                    "júla",
                    "augusta",
                    "septembra",
                    "októbra",
                    "novembra",
                    "decembra"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "jan",
                    "feb",
                    "mar",
                    "apr",
                    "máj",
                    "jún",
                    "júl",
                    "aug",
                    "sep",
                    "okt",
                    "nov",
                    "dec"
                ],
                narrow: [
                    "j",
                    "f",
                    "m",
                    "a",
                    "m",
                    "j",
                    "j",
                    "a",
                    "s",
                    "o",
                    "n",
                    "d"
                ],
                wide: [
                    "január",
                    "február",
                    "marec",
                    "apríl",
                    "máj",
                    "jún",
                    "júl",
                    "august",
                    "september",
                    "október",
                    "november",
                    "december"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. štvrťrok",
                    "2. štvrťrok",
                    "3. štvrťrok",
                    "4. štvrťrok"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. štvrťrok",
                    "2. štvrťrok",
                    "3. štvrťrok",
                    "4. štvrťrok"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "o poln.",
                    am: "AM",
                    noon: "napol.",
                    pm: "PM",
                    morning1: "ráno",
                    morning2: "dopol.",
                    afternoon1: "popol.",
                    evening1: "večer",
                    night1: "v noci"
                },
                narrow: {
                    midnight: "o poln.",
                    am: "AM",
                    noon: "nap.",
                    pm: "PM",
                    morning1: "ráno",
                    morning2: "dop.",
                    afternoon1: "pop.",
                    evening1: "več.",
                    night1: "v n."
                },
                wide: {
                    midnight: "o polnoci",
                    am: "AM",
                    noon: "napoludnie",
                    pm: "PM",
                    morning1: "ráno",
                    morning2: "dopoludnia",
                    afternoon1: "popoludní",
                    evening1: "večer",
                    night1: "v noci"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "poln.",
                    am: "AM",
                    noon: "pol.",
                    pm: "PM",
                    morning1: "ráno",
                    morning2: "dopol.",
                    afternoon1: "popol.",
                    evening1: "večer",
                    night1: "noc"
                },
                narrow: {
                    midnight: "poln.",
                    am: "AM",
                    noon: "pol.",
                    pm: "PM",
                    morning1: "ráno",
                    morning2: "dop.",
                    afternoon1: "pop.",
                    evening1: "več.",
                    night1: "noc"
                },
                wide: {
                    midnight: "polnoc",
                    am: "AM",
                    noon: "poludnie",
                    pm: "PM",
                    morning1: "ráno",
                    morning2: "dopoludnie",
                    afternoon1: "popoludnie",
                    evening1: "večer",
                    night1: "noc"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "pred Kristom",
                    "1": "po Kristovi",
                    "0-alt-variant": "pred naším letopočtom",
                    "1-alt-variant": "nášho letopočtu"
                },
                abbreviated: {
                    "0": "pred Kr.",
                    "1": "po Kr.",
                    "0-alt-variant": "pred n. l.",
                    "1-alt-variant": "n. l."
                },
                narrow: {
                    "0": "pred Kr.",
                    "1": "po Kr.",
                    "0-alt-variant": "pred n. l.",
                    "1-alt-variant": "n. l."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "letopočet",
                short: "letop.",
                narrow: "letop."
            },
            year: {
                wide: "rok",
                short: "r.",
                narrow: "r."
            },
            quarter: {
                wide: "štvrťrok",
                short: "Q",
                narrow: "Q"
            },
            month: {
                wide: "mesiac",
                short: "mes.",
                narrow: "mes."
            },
            week: {
                wide: "týždeň",
                short: "týž.",
                narrow: "týž."
            },
            weekOfMonth: {
                wide: "týždeň mesiaca",
                short: "týž. mes.",
                narrow: "týž. mes."
            },
            day: {
                wide: "deň",
                short: "d.",
                narrow: "d."
            },
            dayOfYear: {
                wide: "deň roka",
                short: "deň r.",
                narrow: "deň r."
            },
            weekday: {
                wide: "deň týždňa",
                short: "deň týž.",
                narrow: "deň týž."
            },
            weekdayOfMonth: {
                wide: "deň týždňa v mesiaci",
                short: "d. týž. v mes.",
                narrow: "d. týž. v mes."
            },
            dayperiod: {
                short: "AM/PM",
                wide: "AM/PM",
                narrow: "AM/PM"
            },
            hour: {
                wide: "hodina",
                short: "h",
                narrow: "h"
            },
            minute: {
                wide: "minúta",
                short: "min",
                narrow: "min"
            },
            second: {
                wide: "sekunda",
                short: "s",
                narrow: "s"
            },
            zone: {
                wide: "časové pásmo",
                short: "pásmo",
                narrow: "pásmo"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "milisekunda"
            }
        }
    },
    firstDay: 1,
    weekendRange: {
        start: 6,
        end: 0
    },
    likelySubtags: {
        sk: "sk-Latn-SK"
    }
});

