/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "sk",
    likelySubtags: {
        sk: "sk-Latn-SK"
    },
    identity: {
        language: "sk"
    },
    territory: "SK",
    calendar: {
        patterns: {
            d: "d. M. y",
            D: "EEEE d. MMMM y",
            m: "d. M.",
            M: "d. MMMM",
            y: "M/y",
            Y: "LLLL y",
            F: "EEEE d. MMMM y H:mm:ss",
            g: "d. M. y H:mm",
            G: "d. M. y H:mm:ss",
            t: "H:mm",
            T: "H:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1}, {0}",
            long: "{1}, {0}",
            medium: "{1}, {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d.",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d.",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "d. M. y GGGGG",
                GyMMM: "LLLL y G",
                GyMMMd: "d. M. y G",
                GyMMMEd: "E d. M. y G",
                GyMMMMd: "d. M. y G",
                h: "h a",
                H: "H",
                hm: "h:mm a",
                Hm: "H:mm",
                hms: "h:mm:ss a",
                Hms: "H:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "H:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "H:mm v",
                M: "L.",
                Md: "d. M.",
                MEd: "E d. M.",
                MMM: "LLL",
                MMMd: "d. M.",
                MMMEd: "E d. M.",
                MMMMd: "d. MMMM",
                MMMMEd: "E d. MMMM",
                "MMMMW-count-one": "W. 'týždeň' MMMM",
                "MMMMW-count-few": "W. 'týždeň' MMMM",
                "MMMMW-count-many": "W. 'týždeň' MMMM",
                "MMMMW-count-other": "W. 'týždeň' MMMM",
                mmss: "mm:ss",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d. M. y",
                yMEd: "E d. M. y",
                yMMM: "M/y",
                yMMMd: "d. M. y",
                yMMMEd: "E d. M. y",
                yMMMM: "LLLL y",
                yMMMMd: "d. MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "w. 'týždeň' 'roka' Y",
                "yw-count-few": "w. 'týždeň' 'roka' Y",
                "yw-count-many": "w. 'týždeň' 'roka' Y",
                "yw-count-other": "w. 'týždeň' 'roka' Y"
            }
        },
        timeFormats: {
            full: "H:mm:ss zzzz",
            long: "H:mm:ss z",
            medium: "H:mm:ss",
            short: "H:mm"
        },
        dateFormats: {
            full: "EEEE d. MMMM y",
            long: "d. MMMM y",
            medium: "d. M. y",
            short: "d. M. y"
        },
        days: {
            format: {
                abbreviated: [
                    "ne",
                    "po",
                    "ut",
                    "st",
                    "št",
                    "pi",
                    "so"
                ],
                narrow: [
                    "n",
                    "p",
                    "u",
                    "s",
                    "š",
                    "p",
                    "s"
                ],
                short: [
                    "ne",
                    "po",
                    "ut",
                    "st",
                    "št",
                    "pi",
                    "so"
                ],
                wide: [
                    "nedeľa",
                    "pondelok",
                    "utorok",
                    "streda",
                    "štvrtok",
                    "piatok",
                    "sobota"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ne",
                    "po",
                    "ut",
                    "st",
                    "št",
                    "pi",
                    "so"
                ],
                narrow: [
                    "n",
                    "p",
                    "u",
                    "s",
                    "š",
                    "p",
                    "s"
                ],
                short: [
                    "ne",
                    "po",
                    "ut",
                    "st",
                    "št",
                    "pi",
                    "so"
                ],
                wide: [
                    "nedeľa",
                    "pondelok",
                    "utorok",
                    "streda",
                    "štvrtok",
                    "piatok",
                    "sobota"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "jan",
                    "feb",
                    "mar",
                    "apr",
                    "máj",
                    "jún",
                    "júl",
                    "aug",
                    "sep",
                    "okt",
                    "nov",
                    "dec"
                ],
                narrow: [
                    "j",
                    "f",
                    "m",
                    "a",
                    "m",
                    "j",
                    "j",
                    "a",
                    "s",
                    "o",
                    "n",
                    "d"
                ],
                wide: [
                    "januára",
                    "februára",
                    "marca",
                    "apríla",
                    "mája",
                    "júna",
                    "júla",
                    "augusta",
                    "septembra",
                    "októbra",
                    "novembra",
                    "decembra"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "jan",
                    "feb",
                    "mar",
                    "apr",
                    "máj",
                    "jún",
                    "júl",
                    "aug",
                    "sep",
                    "okt",
                    "nov",
                    "dec"
                ],
                narrow: [
                    "j",
                    "f",
                    "m",
                    "a",
                    "m",
                    "j",
                    "j",
                    "a",
                    "s",
                    "o",
                    "n",
                    "d"
                ],
                wide: [
                    "január",
                    "február",
                    "marec",
                    "apríl",
                    "máj",
                    "jún",
                    "júl",
                    "august",
                    "september",
                    "október",
                    "november",
                    "december"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. štvrťrok",
                    "2. štvrťrok",
                    "3. štvrťrok",
                    "4. štvrťrok"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. štvrťrok",
                    "2. štvrťrok",
                    "3. štvrťrok",
                    "4. štvrťrok"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "o poln.",
                    am: "AM",
                    noon: "napol.",
                    pm: "PM",
                    morning1: "ráno",
                    morning2: "dopol.",
                    afternoon1: "popol.",
                    evening1: "večer",
                    night1: "v noci"
                },
                narrow: {
                    midnight: "o poln.",
                    am: "AM",
                    noon: "nap.",
                    pm: "PM",
                    morning1: "ráno",
                    morning2: "dop.",
                    afternoon1: "pop.",
                    evening1: "več.",
                    night1: "v n."
                },
                wide: {
                    midnight: "o polnoci",
                    am: "AM",
                    noon: "napoludnie",
                    pm: "PM",
                    morning1: "ráno",
                    morning2: "dopoludnia",
                    afternoon1: "popoludní",
                    evening1: "večer",
                    night1: "v noci"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "poln.",
                    am: "AM",
                    noon: "pol.",
                    pm: "PM",
                    morning1: "ráno",
                    morning2: "dopol.",
                    afternoon1: "popol.",
                    evening1: "večer",
                    night1: "noc"
                },
                narrow: {
                    midnight: "poln.",
                    am: "AM",
                    noon: "pol.",
                    pm: "PM",
                    morning1: "ráno",
                    morning2: "dop.",
                    afternoon1: "pop.",
                    evening1: "več.",
                    night1: "noc"
                },
                wide: {
                    midnight: "polnoc",
                    am: "AM",
                    noon: "poludnie",
                    pm: "PM",
                    morning1: "ráno",
                    morning2: "dopoludnie",
                    afternoon1: "popoludnie",
                    evening1: "večer",
                    night1: "noc"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "pred Kristom",
                    "1": "po Kristovi",
                    "0-alt-variant": "pred naším letopočtom",
                    "1-alt-variant": "nášho letopočtu"
                },
                abbreviated: {
                    "0": "pred Kr.",
                    "1": "po Kr.",
                    "0-alt-variant": "pred n. l.",
                    "1-alt-variant": "n. l."
                },
                narrow: {
                    "0": "pred Kr.",
                    "1": "po Kr.",
                    "0-alt-variant": "pred n. l.",
                    "1-alt-variant": "n. l."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "letopočet",
                short: "letop.",
                narrow: "letop."
            },
            year: {
                wide: "rok",
                short: "r.",
                narrow: "r."
            },
            quarter: {
                wide: "štvrťrok",
                short: "Q",
                narrow: "Q"
            },
            month: {
                wide: "mesiac",
                short: "mes.",
                narrow: "mes."
            },
            week: {
                wide: "týždeň",
                short: "týž.",
                narrow: "týž."
            },
            weekOfMonth: {
                wide: "týždeň mesiaca",
                short: "týž. mes.",
                narrow: "týž. mes."
            },
            day: {
                wide: "deň",
                short: "d.",
                narrow: "d."
            },
            dayOfYear: {
                wide: "deň roka",
                short: "deň r.",
                narrow: "deň r."
            },
            weekday: {
                wide: "deň týždňa",
                short: "deň týž.",
                narrow: "deň týž."
            },
            weekdayOfMonth: {
                wide: "deň týždňa v mesiaci",
                short: "d. týž. v mes.",
                narrow: "d. týž. v mes."
            },
            dayperiod: {
                short: "AM/PM",
                wide: "AM/PM",
                narrow: "AM/PM"
            },
            hour: {
                wide: "hodina",
                short: "h",
                narrow: "h"
            },
            minute: {
                wide: "minúta",
                short: "min",
                narrow: "min"
            },
            second: {
                wide: "sekunda",
                short: "s",
                narrow: "s"
            },
            zone: {
                wide: "časové pásmo",
                short: "pásmo",
                narrow: "pásmo"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "milisekunda"
            }
        }
    },
    firstDay: 1
});

