/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "smn",
    likelySubtags: {
        smn: "smn-Latn-FI"
    },
    identity: {
        language: "smn"
    },
    territory: "FI",
    calendar: {
        patterns: {
            d: "d.M.y",
            D: "cccc, MMMM d. y",
            m: "MMM d.",
            M: "MMMM d.",
            y: "LLL y",
            Y: "LLLL y",
            F: "cccc, MMMM d. y H.mm.ss",
            g: "d.M.y H.mm",
            G: "d.M.y H.mm.ss",
            t: "H.mm",
            T: "H.mm.ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} 'tme' {0}",
            long: "{1} 'tme' {0}",
            medium: "{1} 'tme' {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d.",
                Ehm: "E h.mm a",
                EHm: "E H.mm",
                Ehms: "E h.mm.ss a",
                EHms: "E H.mm.ss",
                Gy: "y G",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "LLL y G",
                GyMMMd: "MMM d. y G",
                GyMMMEd: "E, MMM d. y G",
                h: "h a",
                H: "H",
                hm: "h.mm a",
                Hm: "H.mm",
                hms: "h.mm.ss a",
                Hms: "H.mm.ss",
                hmsv: "h.mm.ss a v",
                Hmsv: "H.mm.ss v",
                hmv: "h.mm a v",
                Hmv: "H.mm v",
                M: "L",
                Md: "d.M.",
                MEd: "E d.M.",
                MMM: "LLL",
                MMMd: "MMM d.",
                MMMEd: "E, MMM d.",
                MMMMd: "MMMM d.",
                "MMMMW-count-one": "'okko' W, MMMM",
                "MMMMW-count-two": "'okko' W, MMMM",
                "MMMMW-count-other": "'okko' W, MMMM",
                ms: "m.ss.",
                y: "y",
                yM: "L.y",
                yMd: "d.M.y",
                yMEd: "E d.M.y",
                yMMM: "LLL y",
                yMMMd: "MMM d. y",
                yMMMEd: "ccc, MMM d. y",
                yMMMM: "LLLL y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "'okko' w, Y",
                "yw-count-two": "'okko' w, Y",
                "yw-count-other": "'okko' w, Y"
            }
        },
        timeFormats: {
            full: "H.mm.ss zzzz",
            long: "H.mm.ss z",
            medium: "H.mm.ss",
            short: "H.mm"
        },
        dateFormats: {
            full: "cccc, MMMM d. y",
            long: "MMMM d. y",
            medium: "MMM d. y",
            short: "d.M.y"
        },
        days: {
            format: {
                abbreviated: [
                    "pas",
                    "vuo",
                    "maj",
                    "kos",
                    "tuo",
                    "vás",
                    "láv"
                ],
                narrow: [
                    "p",
                    "V",
                    "M",
                    "K",
                    "T",
                    "V",
                    "L"
                ],
                short: [
                    "pa",
                    "vu",
                    "ma",
                    "ko",
                    "tu",
                    "vá",
                    "lá"
                ],
                wide: [
                    "pasepeeivi",
                    "vuossaargâ",
                    "majebaargâ",
                    "koskoho",
                    "tuorâstuv",
                    "vástuppeeivi",
                    "lávurduv"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "pas",
                    "vuo",
                    "maj",
                    "kos",
                    "tuo",
                    "vás",
                    "láv"
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "W",
                    "T",
                    "F",
                    "S"
                ],
                short: [
                    "pa",
                    "vu",
                    "ma",
                    "ko",
                    "tu",
                    "vá",
                    "lá"
                ],
                wide: [
                    "pasepeivi",
                    "vuossargâ",
                    "majebargâ",
                    "koskokko",
                    "tuorâstâh",
                    "vástuppeivi",
                    "lávurdâh"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "uđiv",
                    "kuovâ",
                    "njuhčâ",
                    "cuáŋui",
                    "vyesi",
                    "kesi",
                    "syeini",
                    "porge",
                    "čohčâ",
                    "roovvâd",
                    "skammâ",
                    "juovlâ"
                ],
                narrow: [
                    "U",
                    "K",
                    "NJ",
                    "C",
                    "V",
                    "K",
                    "S",
                    "P",
                    "Č",
                    "R",
                    "S",
                    "J"
                ],
                wide: [
                    "uđđâivemáánu",
                    "kuovâmáánu",
                    "njuhčâmáánu",
                    "cuáŋuimáánu",
                    "vyesimáánu",
                    "kesimáánu",
                    "syeinimáánu",
                    "porgemáánu",
                    "čohčâmáánu",
                    "roovvâdmáánu",
                    "skammâmáánu",
                    "juovlâmáánu"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "uđiv",
                    "kuovâ",
                    "njuhčâ",
                    "cuáŋui",
                    "vyesi",
                    "kesi",
                    "syeini",
                    "porge",
                    "čohčâ",
                    "roovvâd",
                    "skammâ",
                    "juovlâ"
                ],
                narrow: [
                    "U",
                    "K",
                    "NJ",
                    "C",
                    "V",
                    "K",
                    "S",
                    "P",
                    "Č",
                    "R",
                    "S",
                    "J"
                ],
                wide: [
                    "uđđâivemáánu",
                    "kuovâmáánu",
                    "njuhčâmáánu",
                    "cuáŋuimáánu",
                    "vyesimáánu",
                    "kesimáánu",
                    "syeinimáánu",
                    "porgemáánu",
                    "čohčâmáánu",
                    "roovvâdmáánu",
                    "skammâmáánu",
                    "juovlâmáánu"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1. niälj.",
                    "2. niälj.",
                    "3. niälj.",
                    "4. niälj."
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. niäljádâs",
                    "2. niäljádâs",
                    "3. niäljádâs",
                    "4. niäljádâs"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1. niälj.",
                    "2. niälj.",
                    "3. niälj.",
                    "4. niälj."
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1. niäljádâs",
                    "2. niäljádâs",
                    "3. niäljádâs",
                    "4. niäljádâs"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "ip.",
                    pm: "ep."
                },
                narrow: {
                    am: "ip.",
                    pm: "ep."
                },
                wide: {
                    am: "ip.",
                    pm: "ep."
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "ip.",
                    pm: "ep."
                },
                narrow: {
                    am: "ip.",
                    pm: "ep."
                },
                wide: {
                    am: "ip.",
                    pm: "ep."
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Ovdil Kristus šoddâm",
                    "1": "maŋa Kristus šoddâm",
                    "0-alt-variant": "Ovdil ääigirekinistem älgim",
                    "1-alt-variant": "maŋa ääigirekinistem älgim"
                },
                abbreviated: {
                    "0": "oKr.",
                    "1": "mKr.",
                    "0-alt-variant": "oää.",
                    "1-alt-variant": "mää."
                },
                narrow: {
                    "0": "oKr.",
                    "1": "mKr.",
                    "0-alt-variant": "oää.",
                    "1-alt-variant": "mää."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Era",
                short: "Era",
                narrow: "Era"
            },
            year: {
                wide: "Year",
                short: "Year",
                narrow: "Year"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Month",
                short: "Month",
                narrow: "Month"
            },
            week: {
                wide: "Week",
                short: "Week",
                narrow: "Week"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Day",
                short: "Day",
                narrow: "Day"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Day of the Week",
                short: "Day of the Week",
                narrow: "Day of the Week"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Dayperiod",
                wide: "Dayperiod",
                narrow: "Dayperiod"
            },
            hour: {
                wide: "Hour",
                short: "Hour",
                narrow: "Hour"
            },
            minute: {
                wide: "Minute",
                short: "Minute",
                narrow: "Minute"
            },
            second: {
                wide: "Second",
                short: "Second",
                narrow: "Second"
            },
            zone: {
                wide: "Zone",
                short: "Zone",
                narrow: "Zone"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

