/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "sn",
    likelySubtags: {
        sn: "sn-Latn-ZW"
    },
    identity: {
        language: "sn"
    },
    territory: "ZW",
    calendar: {
        patterns: {
            d: "y-MM-dd",
            D: "y MMMM d, EEEE",
            m: "MMM d",
            M: "MMMM d",
            y: "y MMM",
            Y: "y MMMM",
            F: "y MMMM d, EEEE HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "MM-dd",
                MEd: "MM-dd, E",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "MMM d, E",
                MMMMd: "MMMM d",
                MMMMEd: "E, MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "y-MM",
                yMd: "y-MM-dd",
                yMEd: "y-MM-dd, E",
                yMMM: "y MMM",
                yMMMd: "y MMM d",
                yMMMEd: "y MMM d, E",
                yMMMM: "y MMMM",
                yQQQ: "y QQQ",
                yQQQQ: "y QQQQ",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "y MMMM d, EEEE",
            long: "y MMMM d",
            medium: "y MMM d",
            short: "y-MM-dd"
        },
        days: {
            format: {
                abbreviated: [
                    "Svo",
                    "Muv",
                    "Chp",
                    "Cht",
                    "Chn",
                    "Chs",
                    "Mug"
                ],
                narrow: [
                    "S",
                    "M",
                    "C",
                    "C",
                    "C",
                    "C",
                    "M"
                ],
                short: [
                    "Sv",
                    "Mu",
                    "Cp",
                    "Ct",
                    "Cn",
                    "Cs",
                    "Mg"
                ],
                wide: [
                    "Svondo",
                    "Muvhuro",
                    "Chipiri",
                    "Chitatu",
                    "China",
                    "Chishanu",
                    "Mugovera"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Svo",
                    "Muv",
                    "Chp",
                    "Cht",
                    "Chn",
                    "Chs",
                    "Mug"
                ],
                narrow: [
                    "S",
                    "M",
                    "C",
                    "C",
                    "C",
                    "C",
                    "M"
                ],
                short: [
                    "Sv",
                    "Mu",
                    "Cp",
                    "Ct",
                    "Cn",
                    "Cs",
                    "Mg"
                ],
                wide: [
                    "Svondo",
                    "Muvhuro",
                    "Chipiri",
                    "Chitatu",
                    "China",
                    "Chishanu",
                    "Mugovera"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Ndi",
                    "Kuk",
                    "Kur",
                    "Kub",
                    "Chv",
                    "Chk",
                    "Chg",
                    "Nya",
                    "Gun",
                    "Gum",
                    "Mbu",
                    "Zvi"
                ],
                narrow: [
                    "N",
                    "K",
                    "K",
                    "K",
                    "C",
                    "C",
                    "C",
                    "N",
                    "G",
                    "G",
                    "M",
                    "Z"
                ],
                wide: [
                    "Ndira",
                    "Kukadzi",
                    "Kurume",
                    "Kubvumbi",
                    "Chivabvu",
                    "Chikumi",
                    "Chikunguru",
                    "Nyamavhuvhu",
                    "Gunyana",
                    "Gumiguru",
                    "Mbudzi",
                    "Zvita"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Ndi",
                    "Kuk",
                    "Kur",
                    "Kub",
                    "Chv",
                    "Chk",
                    "Chg",
                    "Nya",
                    "Gun",
                    "Gum",
                    "Mbu",
                    "Zvi"
                ],
                narrow: [
                    "N",
                    "K",
                    "K",
                    "K",
                    "C",
                    "C",
                    "C",
                    "N",
                    "G",
                    "G",
                    "M",
                    "Z"
                ],
                wide: [
                    "Ndira",
                    "Kukadzi",
                    "Kurume",
                    "Kubvumbi",
                    "Chivabvu",
                    "Chikumi",
                    "Chikunguru",
                    "Nyamavhuvhu",
                    "Gunyana",
                    "Gumiguru",
                    "Mbudzi",
                    "Zvita"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Kota 1",
                    "Kota 2",
                    "Kota 3",
                    "Kota 4"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Kota 1",
                    "Kota 2",
                    "Kota 3",
                    "Kota 4"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "a",
                    pm: "p"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM"
                },
                narrow: {
                    am: "AM",
                    pm: "PM"
                },
                wide: {
                    am: "AM",
                    pm: "PM"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Kristo asati auya",
                    "1": "mugore ramambo vedu",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                abbreviated: {
                    "0": "BC",
                    "1": "AD",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                narrow: {
                    "0": "BC",
                    "1": "AD",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Mukore",
                short: "Mukore",
                narrow: "Mukore"
            },
            year: {
                wide: "Gore",
                short: "Gore",
                narrow: "Gore"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Mwedzi",
                short: "Mwedzi",
                narrow: "Mwedzi"
            },
            week: {
                wide: "Vhiki",
                short: "Vhiki",
                narrow: "Vhiki"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Zuva",
                short: "Zuva",
                narrow: "Zuva"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Zuva revhiki",
                short: "Zuva revhiki",
                narrow: "Zuva revhiki"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Dayperiod",
                wide: "Dayperiod",
                narrow: "Dayperiod"
            },
            hour: {
                wide: "Awa",
                short: "Awa",
                narrow: "Awa"
            },
            minute: {
                wide: "Mineti",
                short: "Mineti",
                narrow: "Mineti"
            },
            second: {
                wide: "Sekondi",
                short: "Sekondi",
                narrow: "Sekondi"
            },
            zone: {
                wide: "Nguva",
                short: "Nguva",
                narrow: "Nguva"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

