/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "so-ET",
    likelySubtags: {
        so: "so-Latn-SO"
    },
    identity: {
        language: "so",
        territory: "ET"
    },
    territory: "ET",
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, MMMM d, y",
            m: "MMM d",
            M: "MMMM d",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, MMMM d, y h:mm:ss a",
            g: "M/d/y h:mm a",
            G: "M/d/y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} 'ee' {0}",
            long: "{1} 'ee' {0}",
            medium: "{1} 'ee' {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "M/d/y GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "MMM d, y G",
                GyMMMEd: "E, MMM d, y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "M/d",
                MEd: "E, M/d",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, MMM d",
                MMMMd: "MMMM d",
                MMMMEd: "E, MMMM d",
                "MMMMW-count-one": "'toddobaadka' W 'ee' MMMM",
                "MMMMW-count-other": "'toddobaadka' W 'ee' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "M/d/y",
                yMEd: "E, M/d/y",
                yMMM: "MMM y",
                yMMMd: "MMM d, y",
                yMMMEd: "E, MMM d, y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "'toddobaadka' w 'ee' Y",
                "yw-count-other": "'toddobaadka' w 'ee' Y"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "EEEE, MMMM d, y",
            long: "MMMM d, y",
            medium: "dd-MMM-y",
            short: "dd/MM/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "Axd",
                    "Isn",
                    "Tldo",
                    "Arbc",
                    "Khms",
                    "Jmc",
                    "Sbti"
                ],
                narrow: [
                    "A",
                    "I",
                    "T",
                    "A",
                    "Kh",
                    "J",
                    "S"
                ],
                short: [
                    "Axd",
                    "Isn",
                    "Tldo",
                    "Arbc",
                    "Khms",
                    "Jmc",
                    "Sbti"
                ],
                wide: [
                    "Axad",
                    "Isniin",
                    "Talaado",
                    "Arbaco",
                    "Khamiis",
                    "Jimco",
                    "Sabti"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Axd",
                    "Isn",
                    "Tldo",
                    "Arbc",
                    "Khms",
                    "Jmc",
                    "Sbti"
                ],
                narrow: [
                    "A",
                    "I",
                    "T",
                    "A",
                    "Kh",
                    "J",
                    "S"
                ],
                short: [
                    "Axd",
                    "Isn",
                    "Tldo",
                    "Arbaco",
                    "Khms",
                    "Jmc",
                    "Sbti"
                ],
                wide: [
                    "Axad",
                    "Isniin",
                    "Talaado",
                    "Arbaco",
                    "Khamiis",
                    "Jimco",
                    "Sabti"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Jan",
                    "Feb",
                    "Mar",
                    "Abr",
                    "May",
                    "Jun",
                    "Lul",
                    "Ogs",
                    "Seb",
                    "Okt",
                    "Nof",
                    "Dis"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "L",
                    "O",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Bisha Koobaad",
                    "Bisha Labaad",
                    "Bisha Saddexaad",
                    "Bisha Afraad",
                    "Bisha Shanaad",
                    "Bisha Lixaad",
                    "Bisha Todobaad",
                    "Bisha Sideedaad",
                    "Bisha Sagaalaad",
                    "Bisha Tobnaad",
                    "Bisha Kow iyo Tobnaad",
                    "Bisha Laba iyo Tobnaad"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Jan",
                    "Feb",
                    "Mar",
                    "Abr",
                    "May",
                    "Jun",
                    "Lul",
                    "Ogs",
                    "Seb",
                    "Okt",
                    "Nof",
                    "Dis"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "L",
                    "O",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Jannaayo",
                    "Febraayo",
                    "Maarso",
                    "Abriil",
                    "May",
                    "Juun",
                    "Luuliyo",
                    "Ogost",
                    "Sebtembar",
                    "Oktoobar",
                    "Nofembar",
                    "Desembar"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "R1",
                    "R2",
                    "R3",
                    "R4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Rubaca 1aad",
                    "Rubaca 2aad",
                    "Rubaca 3aad",
                    "Rubaca 4aad"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "R1",
                    "R2",
                    "R3",
                    "R4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Rubaca 1aad",
                    "Rubaca 2aad",
                    "Rubaca 3aad",
                    "Rubaca 4aad"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "GH",
                    pm: "GD"
                },
                narrow: {
                    am: "h",
                    pm: "d"
                },
                wide: {
                    am: "GH",
                    pm: "GD"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "GD"
                },
                narrow: {
                    am: "AM",
                    pm: "GD"
                },
                wide: {
                    am: "GH",
                    pm: "GD"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Ciise Hortii",
                    "1": "Ciise Dabadii",
                    "0-alt-variant": "Ka Hor Taariikhda Miilaadiga",
                    "1-alt-variant": "Taariikhda Miilaadiga"
                },
                abbreviated: {
                    "0": "BC",
                    "1": "AD",
                    "0-alt-variant": "KTM",
                    "1-alt-variant": "CE"
                },
                narrow: {
                    "0": "B",
                    "1": "A",
                    "0-alt-variant": "KTM",
                    "1-alt-variant": "CE"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "saman",
                short: "saman",
                narrow: "saman"
            },
            year: {
                wide: "Sannad",
                short: "snd",
                narrow: "Snd"
            },
            quarter: {
                wide: "Rubuc",
                short: "rbc",
                narrow: "rbc"
            },
            month: {
                wide: "Bil",
                short: "Bil",
                narrow: "bil"
            },
            week: {
                wide: "Toddobaad",
                short: "tdbd",
                narrow: "tdbd"
            },
            weekOfMonth: {
                wide: "Toddobaadka Bisha",
                short: "Toddobaadka Bisha",
                narrow: "Toddobaadka Bisha"
            },
            day: {
                wide: "maalin",
                short: "mln",
                narrow: "mln"
            },
            dayOfYear: {
                wide: "maalinta sannadka",
                short: "mlnta sndka",
                narrow: "mlnta sndka"
            },
            weekday: {
                wide: "maalinta toddobaadka",
                short: "mlnta tdbdka",
                narrow: "mlnta tdbdka"
            },
            weekdayOfMonth: {
                wide: "maalinta-toddobaadka bisha",
                short: "mlnta-tdbdka bsha",
                narrow: "mlnta-tdbdka bsha"
            },
            dayperiod: {
                short: "GH/GD",
                wide: "GH/GD",
                narrow: "GH/GD"
            },
            hour: {
                wide: "Saacad",
                short: "scd",
                narrow: "scd"
            },
            minute: {
                wide: "daqiiqad",
                short: "dqqd",
                narrow: "dqqd"
            },
            second: {
                wide: "ilbiriqsi",
                short: "ilbrqsi",
                narrow: "ilbrqsi"
            },
            zone: {
                wide: "wakhtiga aagga",
                short: "aagga",
                narrow: "Aagga"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "miliseken"
            }
        }
    },
    firstDay: 0
});

