/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "sq-XK",
    likelySubtags: {
        sq: "sq-Latn-AL"
    },
    identity: {
        language: "sq",
        territory: "XK"
    },
    territory: "XK",
    calendar: {
        patterns: {
            d: "d.M.y",
            D: "EEEE, d MMMM y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d MMMM y HH:mm:ss",
            g: "d.M.y HH:mm",
            G: "d.M.y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} 'në' {0}",
            long: "{1} 'në' {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E, d",
                Ehm: "E, h:mm a",
                EHm: "E, HH:mm",
                Ehms: "E, h:mm:ss a",
                EHms: "E, HH:mm:ss",
                Gy: "y G",
                GyMd: "d.M.y GGGG",
                GyMMM: "MMM y G",
                GyMMMd: "d MMM y G",
                GyMMMEd: "E, d MMM y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a, v",
                Hmsv: "HH:mm:ss, v",
                hmv: "h:mm a, v",
                Hmv: "HH:mm, v",
                M: "L",
                Md: "d.M",
                MEd: "E, d.M",
                MMdd: "d.M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E, d MMM",
                MMMMd: "d MMMM",
                MMMMEd: "E, d MMMM",
                "MMMMW-count-one": "'java' W 'e' MMMM",
                "MMMMW-count-other": "'java' W 'e' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M.y",
                yMd: "d.M.y",
                yMEd: "E, d.M.y",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E, d MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ, y",
                yQQQQ: "QQQQ, y",
                "yw-count-one": "'java' w 'e' Y",
                "yw-count-other": "'java' w 'e' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "d.M.yy"
        },
        days: {
            format: {
                abbreviated: [
                    "Die",
                    "Hën",
                    "Mar",
                    "Mër",
                    "Enj",
                    "Pre",
                    "Sht"
                ],
                narrow: [
                    "d",
                    "h",
                    "m",
                    "m",
                    "e",
                    "p",
                    "sh"
                ],
                short: [
                    "die",
                    "hën",
                    "mar",
                    "mër",
                    "enj",
                    "pre",
                    "sht"
                ],
                wide: [
                    "e diel",
                    "e hënë",
                    "e martë",
                    "e mërkurë",
                    "e enjte",
                    "e premte",
                    "e shtunë"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "die",
                    "hën",
                    "mar",
                    "mër",
                    "enj",
                    "pre",
                    "sht"
                ],
                narrow: [
                    "d",
                    "h",
                    "m",
                    "m",
                    "e",
                    "p",
                    "sh"
                ],
                short: [
                    "die",
                    "hën",
                    "mar",
                    "mër",
                    "enj",
                    "pre",
                    "sht"
                ],
                wide: [
                    "e diel",
                    "e hënë",
                    "e martë",
                    "e mërkurë",
                    "e enjte",
                    "e premte",
                    "e shtunë"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "jan",
                    "shk",
                    "mar",
                    "pri",
                    "maj",
                    "qer",
                    "korr",
                    "gush",
                    "sht",
                    "tet",
                    "nën",
                    "dhj"
                ],
                narrow: [
                    "j",
                    "sh",
                    "m",
                    "p",
                    "m",
                    "q",
                    "k",
                    "g",
                    "sh",
                    "t",
                    "n",
                    "dh"
                ],
                wide: [
                    "janar",
                    "shkurt",
                    "mars",
                    "prill",
                    "maj",
                    "qershor",
                    "korrik",
                    "gusht",
                    "shtator",
                    "tetor",
                    "nëntor",
                    "dhjetor"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "jan",
                    "shk",
                    "mar",
                    "pri",
                    "maj",
                    "qer",
                    "korr",
                    "gush",
                    "sht",
                    "tet",
                    "nën",
                    "dhj"
                ],
                narrow: [
                    "j",
                    "sh",
                    "m",
                    "p",
                    "m",
                    "q",
                    "k",
                    "g",
                    "sh",
                    "t",
                    "n",
                    "dh"
                ],
                wide: [
                    "janar",
                    "shkurt",
                    "mars",
                    "prill",
                    "maj",
                    "qershor",
                    "korrik",
                    "gusht",
                    "shtator",
                    "tetor",
                    "nëntor",
                    "dhjetor"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "tremujori I",
                    "tremujori II",
                    "tremujori III",
                    "tremujori IV"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "tremujori i parë",
                    "tremujori i dytë",
                    "tremujori i tretë",
                    "tremujori i katërt"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Tremujori I",
                    "Tremujori II",
                    "Tremujori III",
                    "Tremujori IV"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Tremujori i 1-rë",
                    "Tremujori i 2-të",
                    "Tremujori i 3-të",
                    "Tremujori i 4-t"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "e mesnatës",
                    am: "p.d.",
                    noon: "e mesditës",
                    pm: "m.d.",
                    morning1: "e mëngjesit",
                    morning2: "e paradites",
                    afternoon1: "e pasdites",
                    evening1: "e mbrëmjes",
                    night1: "e natës"
                },
                narrow: {
                    midnight: "e mesnatës",
                    am: "p.d.",
                    noon: "e mesditës",
                    pm: "m.d.",
                    morning1: "e mëngjesit",
                    morning2: "e paradites",
                    afternoon1: "e pasdites",
                    evening1: "e mbrëmjes",
                    night1: "e natës"
                },
                wide: {
                    midnight: "e mesnatës",
                    am: "e paradites",
                    noon: "e mesditës",
                    pm: "e pasdites",
                    morning1: "e mëngjesit",
                    morning2: "e paradites",
                    afternoon1: "e pasdites",
                    evening1: "e mbrëmjes",
                    night1: "e natës"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "mesnatë",
                    am: "p.d.",
                    noon: "mesditë",
                    pm: "m.d.",
                    morning1: "mëngjes",
                    morning2: "paradite",
                    afternoon1: "pasdite",
                    evening1: "mbrëmje",
                    night1: "natë"
                },
                narrow: {
                    midnight: "mesnatë",
                    am: "p.d.",
                    noon: "mesditë",
                    pm: "m.d.",
                    morning1: "mëngjes",
                    morning2: "paradite",
                    afternoon1: "pasdite",
                    evening1: "mbrëmje",
                    night1: "natë"
                },
                wide: {
                    midnight: "mesnatë",
                    am: "paradite",
                    noon: "mesditë",
                    pm: "pasdite",
                    morning1: "mëngjes",
                    morning2: "paradite",
                    afternoon1: "pasdite",
                    evening1: "mbrëmje",
                    night1: "natë"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "para Krishtit",
                    "1": "mbas Krishtit",
                    "0-alt-variant": "para erës sonë",
                    "1-alt-variant": "erës sonë"
                },
                abbreviated: {
                    "0": "p.K.",
                    "1": "mb.K.",
                    "0-alt-variant": "p.e.s.",
                    "1-alt-variant": "e.s."
                },
                narrow: {
                    "0": "p.K.",
                    "1": "mb.K.",
                    "0-alt-variant": "p.e.s.",
                    "1-alt-variant": "e.s."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "erë",
                short: "erë",
                narrow: "erë"
            },
            year: {
                wide: "vit",
                short: "vit",
                narrow: "vit"
            },
            quarter: {
                wide: "tremujor",
                short: "tremujor",
                narrow: "tremujor"
            },
            month: {
                wide: "muaj",
                short: "muaj",
                narrow: "muaj"
            },
            week: {
                wide: "javë",
                short: "javë",
                narrow: "javë"
            },
            weekOfMonth: {
                wide: "javë e muajit",
                short: "javë e muajit",
                narrow: "javë e muajit"
            },
            day: {
                wide: "ditë",
                short: "ditë",
                narrow: "ditë"
            },
            dayOfYear: {
                wide: "ditë e vitit",
                short: "ditë e vitit",
                narrow: "ditë e vitit"
            },
            weekday: {
                wide: "ditë e javës",
                short: "ditë e javës",
                narrow: "ditë e javës"
            },
            weekdayOfMonth: {
                wide: "ditë pune e muajit",
                short: "ditë pune e muajit",
                narrow: "ditë pune e muajit"
            },
            dayperiod: {
                short: "paradite/pasdite",
                wide: "paradite/pasdite",
                narrow: "paradite/pasdite"
            },
            hour: {
                wide: "orë",
                short: "orë",
                narrow: "orë"
            },
            minute: {
                wide: "minutë",
                short: "min",
                narrow: "min"
            },
            second: {
                wide: "sekondë",
                short: "sek",
                narrow: "sek"
            },
            zone: {
                wide: "brezi orar",
                short: "brezi orar",
                narrow: "brezi orar"
            },
            millisecond: {
                narrow: "ms",
                short: "milisek.",
                wide: "milisekondë"
            }
        }
    },
    firstDay: 1
});

