/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "sr-Latn",
    identity: {
        language: "sr",
        script: "Latn"
    },
    territory: "RS",
    numbers: {
        symbols: {
            decimal: ",",
            group: ".",
            list: ";",
            percentSign: "%",
            plusSign: "+",
            minusSign: "-",
            approximatelySign: "~",
            exponential: "E",
            superscriptingExponent: "×",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "n%"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-one": "n $",
            "unitPattern-count-few": "n $",
            "unitPattern-count-other": "n $"
        },
        accounting: {
            patterns: [
                "n $",
                "(n $)"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "Andorska pezeta",
                "displayName-count-one": "andorska pezeta",
                "displayName-count-few": "andorske pezete",
                "displayName-count-other": "andorske pezete",
                symbol: "ADP"
            },
            AED: {
                displayName: "dirham UAE",
                "displayName-count-one": "dirham UAE",
                "displayName-count-few": "dirhama UAE",
                "displayName-count-other": "dirhama UAE",
                symbol: "AED"
            },
            AFA: {
                displayName: "Avganistanski avgani (1927–2002)",
                "displayName-count-one": "avganistanski avgani (1927–2002)",
                "displayName-count-few": "avganistanska avgana (1927–2002)",
                "displayName-count-other": "avganistanskih avgana (1927–2002)",
                symbol: "AFA"
            },
            AFN: {
                displayName: "avganistanski avgani",
                "displayName-count-one": "avganistanski avgani",
                "displayName-count-few": "avganistanska avgana",
                "displayName-count-other": "avganistanskih avgana",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "ALK",
                symbol: "ALK"
            },
            ALL: {
                displayName: "albanski lek",
                "displayName-count-one": "albanski lek",
                "displayName-count-few": "albanska leka",
                "displayName-count-other": "albanskih leka",
                symbol: "ALL"
            },
            AMD: {
                displayName: "jermenski dram",
                "displayName-count-one": "jermenski dram",
                "displayName-count-few": "jermenska drama",
                "displayName-count-other": "jermenska drama",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "holandskoantilski gulden",
                "displayName-count-one": "holandskoantilski gulden",
                "displayName-count-few": "holandskoantilska guldena",
                "displayName-count-other": "holandskoantilskih guldena",
                symbol: "ANG"
            },
            AOA: {
                displayName: "angolska kvanza",
                "displayName-count-one": "angolska kvanza",
                "displayName-count-few": "angolske kvanze",
                "displayName-count-other": "angolskih kvanzi",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "Angolijska kvanza (1977–1990)",
                "displayName-count-one": "angolijska kvanza (1977–1990)",
                "displayName-count-few": "angolijske kvanze (1977–1990)",
                "displayName-count-other": "angolijskih kvanzi (1977–1990)",
                symbol: "AOK"
            },
            AON: {
                displayName: "Angolijska nova kvanza (1990–2000)",
                "displayName-count-one": "angolijska nova kvanza",
                "displayName-count-few": "angolijske nove kvanze",
                "displayName-count-other": "angolijskih novih kvanzi",
                symbol: "AON"
            },
            AOR: {
                displayName: "Angolijska kvanza reađustado (1995–1999)",
                "displayName-count-one": "angolijska kvanza reađustado (1995–1999)",
                "displayName-count-few": "angolijske kvanze reađustado (1995–1999)",
                "displayName-count-other": "angolijskih kvanzi reađustado (1995–1999)",
                symbol: "AOR"
            },
            ARA: {
                displayName: "Argentinski austral",
                "displayName-count-one": "argentinski austral",
                "displayName-count-few": "argentinska australa",
                "displayName-count-other": "argentinskih australa",
                symbol: "ARA"
            },
            ARL: {
                displayName: "ARL",
                symbol: "ARL"
            },
            ARM: {
                displayName: "ARM",
                symbol: "ARM"
            },
            ARP: {
                displayName: "Argentinski pezo (1983–1985)",
                "displayName-count-one": "argentinski pezo (1983–1985)",
                "displayName-count-few": "argentinska pezosa (1983–1985)",
                "displayName-count-other": "argentinskih pezosa (1983–1985)",
                symbol: "ARP"
            },
            ARS: {
                displayName: "argentinski pezos",
                "displayName-count-one": "argentinski pezos",
                "displayName-count-few": "argentinska pezosa",
                "displayName-count-other": "argentinskih pezosa",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "Austrijski šiling",
                "displayName-count-one": "austrijski šiling",
                "displayName-count-few": "austrijska šilinga",
                "displayName-count-other": "austrijskih šilinga",
                symbol: "ATS"
            },
            AUD: {
                displayName: "australijski dolar",
                "displayName-count-one": "australijski dolar",
                "displayName-count-few": "australijska dolara",
                "displayName-count-other": "australijskih dolara",
                symbol: "AUD",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "arubanski florin",
                "displayName-count-one": "arubanski florin",
                "displayName-count-few": "arubanska florina",
                "displayName-count-other": "arubanskih florina",
                symbol: "AWG"
            },
            AZM: {
                displayName: "Azerbejdžanski manat (1993–2006)",
                "displayName-count-one": "azerbejdžanski manat (1993–2006)",
                "displayName-count-few": "azerbejdžanska manata (1993–2006)",
                "displayName-count-other": "azerbejdžanskih manata (1993–2006)",
                symbol: "AZM"
            },
            AZN: {
                displayName: "azerbejdžanski manat",
                "displayName-count-one": "azerbejdžanski manat",
                "displayName-count-few": "azerbejdžanska manata",
                "displayName-count-other": "azerbejdžanskih manata",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "Bosansko-Hercegovački dinar",
                "displayName-count-one": "bosansko-hercegovački dinar",
                "displayName-count-few": "bosansko-hercegovačka dinara",
                "displayName-count-other": "bosansko-hercegovačkih dinara",
                symbol: "BAD"
            },
            BAM: {
                displayName: "bosansko-hercegovačka konvertibilna marka",
                "displayName-count-one": "bosansko-hercegovačka konvertibilna marka",
                "displayName-count-few": "bosansko-hercegovačke konvertibilne marke",
                "displayName-count-other": "bosansko-hercegovačkih konvertibilnih maraka",
                symbol: "KM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "BAN",
                symbol: "BAN"
            },
            BBD: {
                displayName: "barbadoški dolar",
                "displayName-count-one": "barbadoški dolar",
                "displayName-count-few": "barbadoška dolara",
                "displayName-count-other": "barbadoških dolara",
                symbol: "BBD",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "bangladeška taka",
                "displayName-count-one": "bangladeška taka",
                "displayName-count-few": "bangladeške take",
                "displayName-count-other": "bangladeških taka",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "Belgijski franak (konvertibilni)",
                "displayName-count-one": "belgijski franak (konvertibilni)",
                "displayName-count-few": "belgijska franka (konvertibilna)",
                "displayName-count-other": "belgijskih franaka (konvertibilnih)",
                symbol: "BEC"
            },
            BEF: {
                displayName: "Belgijski franak",
                "displayName-count-one": "belgijski franak",
                "displayName-count-few": "belgijska franka",
                "displayName-count-other": "belgijskih franaka",
                symbol: "BEF"
            },
            BEL: {
                displayName: "Belgijski franak (finansijski)",
                "displayName-count-one": "belgijski franak (finansijski)",
                "displayName-count-few": "belgijska franka (finansijska)",
                "displayName-count-other": "belgijskih franaka (finansijskih)",
                symbol: "BEL"
            },
            BGL: {
                displayName: "Bugarski tvrdi lev",
                "displayName-count-one": "bugarski tvrdi lev",
                "displayName-count-few": "bugarska tvrda leva",
                "displayName-count-other": "bugarskih tvrdih leva",
                symbol: "BGL"
            },
            BGM: {
                displayName: "BGM",
                symbol: "BGM"
            },
            BGN: {
                displayName: "bugarski lev",
                "displayName-count-one": "bugarski lev",
                "displayName-count-few": "bugarska leva",
                "displayName-count-other": "bugarskih leva",
                symbol: "BGN"
            },
            BGO: {
                displayName: "BGO",
                symbol: "BGO"
            },
            BHD: {
                displayName: "bahreinski dinar",
                "displayName-count-one": "bahreinski dinar",
                "displayName-count-few": "bahreinska dinara",
                "displayName-count-other": "bahreinskih dinara",
                symbol: "BHD"
            },
            BIF: {
                displayName: "burundski franak",
                "displayName-count-one": "burundski franak",
                "displayName-count-few": "burundska franka",
                "displayName-count-other": "burundskih franaka",
                symbol: "BIF"
            },
            BMD: {
                displayName: "bermudski dolar",
                "displayName-count-one": "bermudski dolar",
                "displayName-count-few": "bermudska dolara",
                "displayName-count-other": "bermudskih dolara",
                symbol: "BMD",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "brunejski dolar",
                "displayName-count-one": "brunejski dolar",
                "displayName-count-few": "brunejska dolara",
                "displayName-count-other": "brunejskih dolara",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "bolivijski bolivijano",
                "displayName-count-one": "bolivijski bolivijano",
                "displayName-count-few": "bolivijska bolivijana",
                "displayName-count-other": "bolivijskih bolivijana",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "BOL",
                symbol: "BOL"
            },
            BOP: {
                displayName: "Bolivijski pezo",
                "displayName-count-one": "bolivijski pezo",
                "displayName-count-few": "bolivijska pezosa",
                "displayName-count-other": "bolivijskih pezosa",
                symbol: "BOP"
            },
            BOV: {
                displayName: "Bolivijski mvdol",
                "displayName-count-one": "bolivijski mvdol",
                "displayName-count-few": "bolivijska mvdola",
                "displayName-count-other": "bolivijskih mvdola",
                symbol: "BOV"
            },
            BRB: {
                displayName: "Brazilski novi kruzeiro (1967–1986)",
                "displayName-count-one": "brazilski novi kruzeiro (1967–1986)",
                "displayName-count-few": "brazilska nova kruzeira (1967–1986)",
                "displayName-count-other": "brazilskih novih kruzeira (1967–1986)",
                symbol: "BRB"
            },
            BRC: {
                displayName: "Brazilijski kruzado",
                "displayName-count-one": "brazilski kruzados",
                "displayName-count-few": "brazilska kruzadosa",
                "displayName-count-other": "brazilskih kruzadosa",
                symbol: "BRC"
            },
            BRE: {
                displayName: "Brazilski kruzeiro (1990–1993)",
                "displayName-count-one": "brazilski kruzeiro (1990–1993)",
                "displayName-count-few": "brazilska kruzeira (1990–1993)",
                "displayName-count-other": "brazilskih kruzeira (1990–1993)",
                symbol: "BRE"
            },
            BRL: {
                displayName: "brazilski real",
                "displayName-count-one": "brazilski real",
                "displayName-count-few": "brazilska reala",
                "displayName-count-other": "brazilskih reala",
                symbol: "R$",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "Brazilijski novi kruzado",
                "displayName-count-one": "brazilski novi kruzado",
                "displayName-count-few": "brazilska nova kruzada",
                "displayName-count-other": "brazilskih novih kruzada",
                symbol: "BRN"
            },
            BRR: {
                displayName: "Brazilski kruzeiro",
                "displayName-count-one": "brazilski kruzeiro",
                "displayName-count-few": "brazilska kruzeira",
                "displayName-count-other": "brazilskih kruzeira",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "BRZ",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "bahamski dolar",
                "displayName-count-one": "bahamski dolar",
                "displayName-count-few": "bahamska dolara",
                "displayName-count-other": "bahamskih dolara",
                symbol: "BSD",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "butanski ngultrum",
                "displayName-count-one": "butanski ngultrum",
                "displayName-count-few": "butanska ngultruma",
                "displayName-count-other": "butanskih ngultruma",
                symbol: "BTN"
            },
            BUK: {
                displayName: "Burmanski kjat",
                "displayName-count-one": "burmanski kjat",
                "displayName-count-few": "burmanska kjata",
                "displayName-count-other": "burmanskih kjata",
                symbol: "BUK"
            },
            BWP: {
                displayName: "bocvanska pula",
                "displayName-count-one": "bocvanska pula",
                "displayName-count-few": "bocvanske pule",
                "displayName-count-other": "bocvanskih pula",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "Beloruska nova rublja (1994–1999)",
                "displayName-count-one": "beloruska nova rublja (1994–1999)",
                "displayName-count-few": "beloruske nove rublja (1994–1999)",
                "displayName-count-other": "beloruskih novih rublji (1994–1999)",
                symbol: "BYB"
            },
            BYN: {
                displayName: "beloruska rublja",
                "displayName-count-one": "beloruska rublja",
                "displayName-count-few": "beloruske rublje",
                "displayName-count-other": "beloruskih rublji",
                symbol: "BYN",
                "symbol-alt-narrow": "r."
            },
            BYR: {
                displayName: "Beloruska rublja (2000–2016)",
                "displayName-count-one": "beloruska rublja (2000–2016)",
                "displayName-count-few": "beloruske rublje (2000–2016)",
                "displayName-count-other": "beloruskih rublji (2000–2016)",
                symbol: "BYR"
            },
            BZD: {
                displayName: "beliski dolar",
                "displayName-count-one": "beliski dolar",
                "displayName-count-few": "beliska dolara",
                "displayName-count-other": "beliskih dolara",
                symbol: "BZD",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "kanadski dolar",
                "displayName-count-one": "kanadski dolar",
                "displayName-count-few": "kanadska dolara",
                "displayName-count-other": "kanadskih dolara",
                symbol: "CA$",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "kongoanski franak",
                "displayName-count-one": "kongoanski franak",
                "displayName-count-few": "kongoanska franka",
                "displayName-count-other": "kongoanskih franaka",
                symbol: "CDF"
            },
            CHE: {
                displayName: "WIR evro",
                "displayName-count-one": "WIR evro",
                "displayName-count-few": "WIR evra",
                "displayName-count-other": "WIR evra",
                symbol: "CHE"
            },
            CHF: {
                displayName: "švajcarski franak",
                "displayName-count-one": "švajcarski franak",
                "displayName-count-few": "švajcarska franka",
                "displayName-count-other": "švajcarskih franaka",
                symbol: "CHF"
            },
            CHW: {
                displayName: "WIR franak",
                "displayName-count-one": "WIR franak",
                "displayName-count-few": "WIR franka",
                "displayName-count-other": "WIR franaka",
                symbol: "CHW"
            },
            CLE: {
                displayName: "CLE",
                symbol: "CLE"
            },
            CLF: {
                displayName: "Čileovski unidades se fomento",
                "displayName-count-one": "čileanski unidades de fomento",
                "displayName-count-few": "čileanska unidades de fomenta",
                "displayName-count-other": "čileanski unidadesi de fomento",
                symbol: "CLF"
            },
            CLP: {
                displayName: "čileanski pezos",
                "displayName-count-one": "čileanski pezos",
                "displayName-count-few": "čileanska pezosa",
                "displayName-count-other": "čileanskih pezosa",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "kineski juan (ostrvski)",
                "displayName-count-one": "kineski juan (ostrvski)",
                "displayName-count-few": "kineska juana (ostrvska)",
                "displayName-count-other": "kineskih juana (ostrvskih)",
                symbol: "CNH"
            },
            CNX: {
                displayName: "CNX",
                symbol: "CNX"
            },
            CNY: {
                displayName: "kineski juan",
                "displayName-count-one": "kineski juan",
                "displayName-count-few": "kineska juana",
                "displayName-count-other": "kineskih juana",
                symbol: "CN¥",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "kolumbijski pezos",
                "displayName-count-one": "kolumbijski pezos",
                "displayName-count-few": "kolumbijska pezosa",
                "displayName-count-other": "kolumbijskih pezosa",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "Unidad de valorški real",
                "displayName-count-one": "unidad de valorški real",
                "displayName-count-few": "nidad de valor reala",
                "displayName-count-other": "unidad de valorških reala",
                symbol: "COU"
            },
            CRC: {
                displayName: "kostarikanski kolon",
                "displayName-count-one": "kostarikanski kolon",
                "displayName-count-few": "kostarikanska kolona",
                "displayName-count-other": "kostarikanskih kolona",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "Stari srpski dinar",
                "displayName-count-one": "stari srpski dinar",
                "displayName-count-few": "stara srpska dinara",
                "displayName-count-other": "starih srpskih dinara",
                symbol: "CSD"
            },
            CSK: {
                displayName: "Čehoslovačka tvrda kruna",
                "displayName-count-one": "čehoslovačka tvrda kruna",
                "displayName-count-few": "čehoslovačke tvrde krune",
                "displayName-count-other": "čehoslovačkih tvrdih kruna",
                symbol: "CSK"
            },
            CUC: {
                displayName: "kubanski konvertibilni pezos",
                "displayName-count-one": "kubanski konvertibilni pezos",
                "displayName-count-few": "kubanska konvertibilna pezosa",
                "displayName-count-other": "kubanskih konvertibilnih pezosa",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "kubanski pezos",
                "displayName-count-one": "kubanski pezos",
                "displayName-count-few": "kubanska pezosa",
                "displayName-count-other": "kubanskih pezosa",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "zelenortski eskudo",
                "displayName-count-one": "zelenortski eskudo",
                "displayName-count-few": "zelenortska eskuda",
                "displayName-count-other": "zelenortskih eskuda",
                symbol: "CVE"
            },
            CYP: {
                displayName: "Kiparska funta",
                "displayName-count-one": "kiparska funta",
                "displayName-count-few": "kiparske funte",
                "displayName-count-other": "kiparskih funti",
                symbol: "CYP"
            },
            CZK: {
                displayName: "češka kruna",
                "displayName-count-one": "češka kruna",
                "displayName-count-few": "češke krune",
                "displayName-count-other": "čeških kruna",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "Istočno-nemačka marka",
                "displayName-count-one": "istočno-nemačka marka",
                "displayName-count-few": "istočno-nemačke marke",
                "displayName-count-other": "istočno-nemačkih maraka",
                symbol: "DDM"
            },
            DEM: {
                displayName: "Nemačka marka",
                "displayName-count-one": "nemačka marka",
                "displayName-count-few": "nemačke marke",
                "displayName-count-other": "nemačkih maraka",
                symbol: "DEM"
            },
            DJF: {
                displayName: "džibutski franak",
                "displayName-count-one": "džibutski franak",
                "displayName-count-few": "džibutska franka",
                "displayName-count-other": "džibutskih franaka",
                symbol: "DJF"
            },
            DKK: {
                displayName: "danska kruna",
                "displayName-count-one": "danska kruna",
                "displayName-count-few": "danske krune",
                "displayName-count-other": "danskih kruna",
                symbol: "DKK",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "dominikanski pezos",
                "displayName-count-one": "dominikanski pezos",
                "displayName-count-few": "dominikanska pezosa",
                "displayName-count-other": "dominikanskih pezosa",
                symbol: "DOP",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "alžirski dinar",
                "displayName-count-one": "alžirski dinar",
                "displayName-count-few": "alžirska dinara",
                "displayName-count-other": "alžirskih dinara",
                symbol: "DZD"
            },
            ECS: {
                displayName: "Ekvadorski sakr",
                "displayName-count-one": "ekvadorski sakr",
                "displayName-count-few": "ekvadorska sakra",
                "displayName-count-other": "ekvadorskih sakra",
                symbol: "ECS"
            },
            ECV: {
                displayName: "Ekvadorski unidad de valor konstante",
                "displayName-count-one": "ekvadorski unidad de valor konstante",
                "displayName-count-few": "ekvadorska unidad de valor konstanta",
                "displayName-count-other": "ekvadorskih unidad de valor konstanta",
                symbol: "ECV"
            },
            EEK: {
                displayName: "Estonska kroon",
                "displayName-count-one": "estonska kruna",
                "displayName-count-few": "estonske krune",
                "displayName-count-other": "estonskih kruna",
                symbol: "EEK"
            },
            EGP: {
                displayName: "egipatska funta",
                "displayName-count-one": "egipatska funta",
                "displayName-count-few": "egipatske funte",
                "displayName-count-other": "egipatskih funti",
                symbol: "EGP",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "eritrejska nakfa",
                "displayName-count-one": "eritrejska nakfa",
                "displayName-count-few": "eritrejske nakfe",
                "displayName-count-other": "eritrejskih nakfi",
                symbol: "ERN"
            },
            ESA: {
                displayName: "Španska pezeta (račun)",
                "displayName-count-one": "španska pezeta (A račun)",
                "displayName-count-few": "španske pezete (A račun)",
                "displayName-count-other": "španskih pezeta (A račun)",
                symbol: "ESA"
            },
            ESB: {
                displayName: "Španska pezeta (konvertibilniračun)",
                "displayName-count-one": "španska pezeta (konvertibilan račun)",
                "displayName-count-few": "španske pezete (konvertibilan račun)",
                "displayName-count-other": "španskih pezeta (konvertibilan račun)",
                symbol: "ESB"
            },
            ESP: {
                displayName: "Španska pezeta",
                "displayName-count-one": "španska pezeta",
                "displayName-count-few": "španska pezeta",
                "displayName-count-other": "španske pezete",
                symbol: "ESP",
                "symbol-alt-narrow": "₧"
            },
            ETB: {
                displayName: "etiopijski bir",
                "displayName-count-one": "etiopski bir",
                "displayName-count-few": "etiopska bira",
                "displayName-count-other": "etiopskih bira",
                symbol: "ETB"
            },
            EUR: {
                displayName: "Evro",
                "displayName-count-one": "evro",
                "displayName-count-few": "evra",
                "displayName-count-other": "evra",
                symbol: "€",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "Finska marka",
                "displayName-count-one": "finska marka",
                "displayName-count-few": "finske marke",
                "displayName-count-other": "finskih maraka",
                symbol: "FIM"
            },
            FJD: {
                displayName: "fidžijski dolar",
                "displayName-count-one": "fidžijski dolar",
                "displayName-count-few": "fidžijska dolara",
                "displayName-count-other": "fidžijskih dolara",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "folklandska funta",
                "displayName-count-one": "foklandska funta",
                "displayName-count-few": "foklandske funte",
                "displayName-count-other": "foklandskih funti",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "Francuski franak",
                "displayName-count-one": "francuski franak",
                "displayName-count-few": "francuska franka",
                "displayName-count-other": "francuskih franaka",
                symbol: "FRF"
            },
            GBP: {
                displayName: "britanska funta",
                "displayName-count-one": "britanska funta",
                "displayName-count-few": "britanske funte",
                "displayName-count-other": "britanskih funti",
                symbol: "£",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "Gruzijski kupon larit",
                "displayName-count-one": "gruzijski kupon larit",
                "displayName-count-few": "gruzijska kupon larita",
                "displayName-count-other": "gruzijskih kupon larita",
                symbol: "GEK"
            },
            GEL: {
                displayName: "gruzijski lari",
                "displayName-count-one": "gruzijski lari",
                "displayName-count-few": "gruzijska larija",
                "displayName-count-other": "gruzijskih larija",
                symbol: "GEL",
                "symbol-alt-narrow": "ლ"
            },
            GHC: {
                displayName: "Ganski cedi (1979–2007)",
                "displayName-count-one": "ganski ced (1979–2007)",
                "displayName-count-few": "ganska ceda (1979–2007)",
                "displayName-count-other": "ganskih ceda (1979–2007)",
                symbol: "GHC"
            },
            GHS: {
                displayName: "ganski sedi",
                "displayName-count-one": "ganski sedi",
                "displayName-count-few": "ganska sedija",
                "displayName-count-other": "ganskih sedija",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "gibraltarska funta",
                "displayName-count-one": "gibraltarska funta",
                "displayName-count-few": "gibraltarske funte",
                "displayName-count-other": "gibraltarskih funti",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "gambijski dalasi",
                "displayName-count-one": "gambijski dalasi",
                "displayName-count-few": "gambijskih dalasija",
                "displayName-count-other": "gambijskih dalasija",
                symbol: "GMD"
            },
            GNF: {
                displayName: "gvinejski franak",
                "displayName-count-one": "gvinejski franak",
                "displayName-count-few": "gvinejska franka",
                "displayName-count-other": "gvinejskih franaka",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "Gvinejski sili",
                "displayName-count-one": "gvinejski sili",
                "displayName-count-few": "gvinejska sila",
                "displayName-count-other": "gvinejskih sila",
                symbol: "GNS"
            },
            GQE: {
                displayName: "Ekvatorijalno-gvinejski ekvele",
                "displayName-count-one": "ekvatorijalno-gvinejski ekvele",
                "displayName-count-few": "ekvatorijalno-gvinejska ekvela",
                "displayName-count-other": "ekvatorijalno-gvinejskih ekvela",
                symbol: "GQE"
            },
            GRD: {
                displayName: "Grčka drahma",
                "displayName-count-one": "grčka drahma",
                "displayName-count-few": "grčke drahme",
                "displayName-count-other": "grčkih drahmi",
                symbol: "GRD"
            },
            GTQ: {
                displayName: "gvatemalski kecal",
                "displayName-count-one": "gvatemalski kecal",
                "displayName-count-few": "gvatemalska kecala",
                "displayName-count-other": "gvatemalskih kecala",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "Portugalska gvineja eskudo",
                "displayName-count-one": "portugalsko-gvinejski eskudo",
                "displayName-count-few": "portugalsko-gvinejska eskuda",
                "displayName-count-other": "portugalsko-gvinejskih eskuda",
                symbol: "GWE"
            },
            GWP: {
                displayName: "Gvineja Bisao Pezo",
                "displayName-count-one": "gvineja-bisaoški pezo",
                "displayName-count-few": "gvineja-bisaoška pezosa",
                "displayName-count-other": "gvineja-bisaoških pezosa",
                symbol: "GWP"
            },
            GYD: {
                displayName: "gvajanski dolar",
                "displayName-count-one": "gvajanski dolar",
                "displayName-count-few": "gvajanska dolara",
                "displayName-count-other": "gvajanskih dolara",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "hongkonški dolar",
                "displayName-count-one": "hongkonški dolar",
                "displayName-count-few": "hongkonška dolara",
                "displayName-count-other": "hongkonških dolara",
                symbol: "HK$",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "honduraška lempira",
                "displayName-count-one": "honduraška lempira",
                "displayName-count-few": "honduraške lempire",
                "displayName-count-other": "honduraških lempira",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "Hrvatski dinar",
                "displayName-count-one": "hrvatski dinar",
                "displayName-count-few": "hrvatska dinara",
                "displayName-count-other": "hrvatskih dinara",
                symbol: "HRD"
            },
            HRK: {
                displayName: "hrvatska kuna",
                "displayName-count-one": "hrvatska kuna",
                "displayName-count-few": "hrvatske kune",
                "displayName-count-other": "hrvatskih kuna",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "haićanski gurd",
                "displayName-count-one": "haićanski gurd",
                "displayName-count-few": "haićanska gurda",
                "displayName-count-other": "haićanskih gurda",
                symbol: "HTG"
            },
            HUF: {
                displayName: "mađarska forinta",
                "displayName-count-one": "mađarska forinta",
                "displayName-count-few": "mađarske forinte",
                "displayName-count-other": "mađarskih forinti",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "indonežanska rupija",
                "displayName-count-one": "indonežanska rupija",
                "displayName-count-few": "indonežanske rupije",
                "displayName-count-other": "indonežanskih rupija",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "Irska funta",
                "displayName-count-one": "irska funta",
                "displayName-count-few": "irske funte",
                "displayName-count-other": "irskih funti",
                symbol: "IEP"
            },
            ILP: {
                displayName: "Izraelska funta",
                "displayName-count-one": "izraelska funta",
                "displayName-count-few": "izraelske funte",
                "displayName-count-other": "izraelskih funti",
                symbol: "ILP"
            },
            ILR: {
                displayName: "Stari izraelski šekeli",
                "displayName-count-one": "stari izraelski šekeli",
                "displayName-count-few": "stari izraelski šekeli",
                "displayName-count-other": "stari izraelski šekeli",
                symbol: "ILR"
            },
            ILS: {
                displayName: "izraelski novi šekel",
                "displayName-count-one": "izraelski novi šekel",
                "displayName-count-few": "izraelska nova šekela",
                "displayName-count-other": "izraelskih novih šekela",
                symbol: "₪",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "indijska rupija",
                "displayName-count-one": "indijska rupija",
                "displayName-count-few": "indijske rupije",
                "displayName-count-other": "indijskih rupija",
                symbol: "₹",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "irački dinar",
                "displayName-count-one": "irački dinar",
                "displayName-count-few": "iračka dinara",
                "displayName-count-other": "iračkih dinara",
                symbol: "IQD"
            },
            IRR: {
                displayName: "iranski rijal",
                "displayName-count-one": "iranski rijal",
                "displayName-count-few": "iranska rijala",
                "displayName-count-other": "iranskih rijala",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "Stara islandska kruna",
                "displayName-count-one": "stara islandska kruna",
                "displayName-count-few": "stara islandska kruna",
                "displayName-count-other": "stara islandska kruna",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "islandska kruna",
                "displayName-count-one": "islandska kruna",
                "displayName-count-few": "islandske krune",
                "displayName-count-other": "islandskih kruna",
                symbol: "ISK",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "Italijanska lira",
                "displayName-count-one": "italijanska lira",
                "displayName-count-few": "italijanske lire",
                "displayName-count-other": "italijanske lire",
                symbol: "ITL"
            },
            JMD: {
                displayName: "jamajčanski dolar",
                "displayName-count-one": "jamajčanski dolar",
                "displayName-count-few": "jamajčanska dolara",
                "displayName-count-other": "jamajčanskix dolara",
                symbol: "JMD",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "jordanski dinar",
                "displayName-count-one": "jordanski dinar",
                "displayName-count-few": "jordanska dinara",
                "displayName-count-other": "jordanskih dinara",
                symbol: "JOD"
            },
            JPY: {
                displayName: "japanski jen",
                "displayName-count-one": "japanski jen",
                "displayName-count-few": "japanska jena",
                "displayName-count-other": "japanskih jena",
                symbol: "¥",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "kenijski šiling",
                "displayName-count-one": "kenijski šiling",
                "displayName-count-few": "kenijska šilinga",
                "displayName-count-other": "kenijskih šilinga",
                symbol: "KES"
            },
            KGS: {
                displayName: "kirgistanski som",
                "displayName-count-one": "kirgistanski som",
                "displayName-count-few": "kirgistanska soma",
                "displayName-count-other": "kirgistanskih soma",
                symbol: "KGS"
            },
            KHR: {
                displayName: "kambodžanski rijel",
                "displayName-count-one": "kambodžanski rijel",
                "displayName-count-few": "kambodžanska rijela",
                "displayName-count-other": "kambodžanskih rijela",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "komorski franak",
                "displayName-count-one": "komorski franak",
                "displayName-count-few": "komorska franka",
                "displayName-count-other": "komorskih franaka",
                symbol: "KMF",
                "symbol-alt-narrow": "CF"
            },
            KPW: {
                displayName: "severnokorejski von",
                "displayName-count-one": "severnokorejski von",
                "displayName-count-few": "severnokorejska vona",
                "displayName-count-other": "severnokorejskih vona",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "KRH",
                symbol: "KRH"
            },
            KRO: {
                displayName: "KRO",
                symbol: "KRO"
            },
            KRW: {
                displayName: "južnokorejski von",
                "displayName-count-one": "južnokorejski von",
                "displayName-count-few": "južnokorejska vona",
                "displayName-count-other": "južnokorejskih vona",
                symbol: "KRW",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "kuvajtski dinar",
                "displayName-count-one": "kuvajtski dinar",
                "displayName-count-few": "kuvajtska dinara",
                "displayName-count-other": "kuvajtskih dinara",
                symbol: "KWD"
            },
            KYD: {
                displayName: "kajmanski dolar",
                "displayName-count-one": "kajmanski dolar",
                "displayName-count-few": "kajmanska dolara",
                "displayName-count-other": "kajmanskih dolara",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "kazahstanski tenge",
                "displayName-count-one": "kazahstanski tenge",
                "displayName-count-few": "kazahstanska tengea",
                "displayName-count-other": "kazahstanskih tengea",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "laoski kip",
                "displayName-count-one": "laoski kip",
                "displayName-count-few": "laoska kipa",
                "displayName-count-other": "laoskih kipa",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "libanska funta",
                "displayName-count-one": "libanska funta",
                "displayName-count-few": "libanske funte",
                "displayName-count-other": "libanskih funti",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "šrilančanska rupija",
                "displayName-count-one": "šrilančanska rupija",
                "displayName-count-few": "šrilančanske rupije",
                "displayName-count-other": "šrilančanskih rupija",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "liberijski dolar",
                "displayName-count-one": "liberijski dolar",
                "displayName-count-few": "liberijska dolara",
                "displayName-count-other": "liberijskih dolara",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "lesotski loti",
                "displayName-count-one": "lesotski loti",
                "displayName-count-few": "lesotska lotija",
                "displayName-count-other": "lesotskih lotija",
                symbol: "LSL"
            },
            LTL: {
                displayName: "Litvanski litas",
                "displayName-count-one": "litvanski litas",
                "displayName-count-few": "litvanska litasa",
                "displayName-count-other": "litvanskih litasa",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "Litvanski talonas",
                "displayName-count-one": "litvanski talonas",
                "displayName-count-few": "litvanska talonasa",
                "displayName-count-other": "litvanskih talonasa",
                symbol: "LTT"
            },
            LUC: {
                displayName: "Luksemburški konvertibilni franak",
                "displayName-count-one": "luksemburški konvertibilni franak",
                "displayName-count-few": "luksemburška konvertibilna franka",
                "displayName-count-other": "luksemburških konvertibilnih franaka",
                symbol: "LUC"
            },
            LUF: {
                displayName: "Luksemburški franak",
                "displayName-count-one": "luksemburški franak",
                "displayName-count-few": "luksemburška franka",
                "displayName-count-other": "luksemburški franci",
                symbol: "LUF"
            },
            LUL: {
                displayName: "Luksemburški finansijski franak",
                "displayName-count-one": "luksemburški finansijski franak",
                "displayName-count-few": "luksemburška finansijska franka",
                "displayName-count-other": "luksemburških finansijskih franaka",
                symbol: "LUL"
            },
            LVL: {
                displayName: "Latvijski lati",
                "displayName-count-one": "latvijski lat",
                "displayName-count-few": "latvijska lata",
                "displayName-count-other": "latvijskih lata",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "Latvijska rublja",
                "displayName-count-one": "latvijska rublja",
                "displayName-count-few": "latvijske rublje",
                "displayName-count-other": "latvijskih rublji",
                symbol: "LVR"
            },
            LYD: {
                displayName: "libijski dinar",
                "displayName-count-one": "libijski dinar",
                "displayName-count-few": "libijska dinara",
                "displayName-count-other": "libijskih dinara",
                symbol: "LYD"
            },
            MAD: {
                displayName: "marokanski dirham",
                "displayName-count-one": "marokanski dirham",
                "displayName-count-few": "marokanska dirhama",
                "displayName-count-other": "marokanskih dirhama",
                symbol: "MAD"
            },
            MAF: {
                displayName: "Marokanski franak",
                "displayName-count-one": "marokanski franak",
                "displayName-count-few": "marokanska franka",
                "displayName-count-other": "marokanskih franaka",
                symbol: "MAF"
            },
            MCF: {
                displayName: "MCF",
                symbol: "MCF"
            },
            MDC: {
                displayName: "MDC",
                symbol: "MDC"
            },
            MDL: {
                displayName: "moldavski lej",
                "displayName-count-one": "moldavski lej",
                "displayName-count-few": "moldavska leja",
                "displayName-count-other": "moldavskih leja",
                symbol: "MDL"
            },
            MGA: {
                displayName: "malgaški arijari",
                "displayName-count-one": "malgaški arijari",
                "displayName-count-few": "malgaška arijarija",
                "displayName-count-other": "malgaških arijarija",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "Malagasijski franak",
                "displayName-count-one": "malagašajski franak",
                "displayName-count-few": "malagašajska franka",
                "displayName-count-other": "malagašajski franci",
                symbol: "MGF"
            },
            MKD: {
                displayName: "makedonski denar",
                "displayName-count-one": "makedonski denar",
                "displayName-count-few": "makedonska denara",
                "displayName-count-other": "makedonskih denara",
                symbol: "MKD"
            },
            MKN: {
                displayName: "MKN",
                symbol: "MKN"
            },
            MLF: {
                displayName: "Malijanski franak",
                "displayName-count-one": "malijski franak",
                "displayName-count-few": "malijska franka",
                "displayName-count-other": "malijskih franaka",
                symbol: "MLF"
            },
            MMK: {
                displayName: "mjanmarski kjat",
                "displayName-count-one": "mjanmarski kjat",
                "displayName-count-few": "mjanmarska kjata",
                "displayName-count-other": "mjanmarskih kjata",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "mongolski tugrik",
                "displayName-count-one": "mongolski tugrik",
                "displayName-count-few": "mongolska tugrika",
                "displayName-count-other": "mongolskih tugrika",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "makaoska pataka",
                "displayName-count-one": "makaoska pataka",
                "displayName-count-few": "makaoske patake",
                "displayName-count-other": "makaoskih pataka",
                symbol: "MOP"
            },
            MRO: {
                displayName: "Mauritanijska ogija (1973–2017)",
                "displayName-count-one": "mauritanijska ogija (1973–2017)",
                "displayName-count-few": "mauritanijske ogije (1973–2017)",
                "displayName-count-other": "mauritanijskih ogija (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "mauritanska ogija",
                "displayName-count-one": "mauritanska ogija",
                "displayName-count-few": "mauritanske ogije",
                "displayName-count-other": "mauritanskih ogija",
                symbol: "MRU"
            },
            MTL: {
                displayName: "Malteška lira",
                "displayName-count-one": "malteška lira",
                "displayName-count-few": "malteške lire",
                "displayName-count-other": "malteških lira",
                symbol: "MTL"
            },
            MTP: {
                displayName: "Malteška funta",
                "displayName-count-one": "malteška funta",
                "displayName-count-few": "malteške funte",
                "displayName-count-other": "malteških funti",
                symbol: "MTP"
            },
            MUR: {
                displayName: "mauricijska rupija",
                "displayName-count-one": "mauricijska rupija",
                "displayName-count-few": "mauricijske rupije",
                "displayName-count-other": "mauricijskih rupija",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "MVP",
                symbol: "MVP"
            },
            MVR: {
                displayName: "maldivska rufija",
                "displayName-count-one": "maldivska rufija",
                "displayName-count-few": "maldivske rufije",
                "displayName-count-other": "maldivskih rufija",
                symbol: "MVR"
            },
            MWK: {
                displayName: "malavijska kvača",
                "displayName-count-one": "malavijska kvača",
                "displayName-count-few": "malavijske kvače",
                "displayName-count-other": "malavijskih kvača",
                symbol: "MWK"
            },
            MXN: {
                displayName: "meksički pezos",
                "displayName-count-one": "meksički pezos",
                "displayName-count-few": "meksička pezosa",
                "displayName-count-other": "meksičkih pezosa",
                symbol: "MX$",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "Meksički srebrni pezo (1861–1992)",
                "displayName-count-one": "meksički srebrni pezo",
                "displayName-count-few": "meksička srebrna pezosa",
                "displayName-count-other": "meksičkih srebrnih pezosa",
                symbol: "MXP"
            },
            MXV: {
                displayName: "Meksički unidad de inversion (UDI)",
                "displayName-count-one": "meksički unidads de inverzion",
                "displayName-count-few": "meksička unidads de inverziona",
                "displayName-count-other": "meksičkih unidads de inverziona",
                symbol: "MXV"
            },
            MYR: {
                displayName: "malezijski ringit",
                "displayName-count-one": "malezijski ringit",
                "displayName-count-few": "malezijska ringita",
                "displayName-count-other": "malezijskih ringita",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "Mozambijski eskudo",
                "displayName-count-one": "mozambijski eskudo",
                "displayName-count-few": "mozambijska eskuda",
                "displayName-count-other": "mozambijskih eskuda",
                symbol: "MZE"
            },
            MZM: {
                displayName: "Stari mozambijski metikal",
                "displayName-count-one": "stari mozambijski metikal",
                "displayName-count-few": "stara mozambijska metikala",
                "displayName-count-other": "starih mozambijskih metikala",
                symbol: "MZM"
            },
            MZN: {
                displayName: "mozambički metikal",
                "displayName-count-one": "mozambički metikal",
                "displayName-count-few": "mozambička metikala",
                "displayName-count-other": "mozambičkih metikala",
                symbol: "MZN"
            },
            NAD: {
                displayName: "namibijski dolar",
                "displayName-count-one": "namibijski dolar",
                "displayName-count-few": "namibijska dolara",
                "displayName-count-other": "namibijskih dolara",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "nigerijska naira",
                "displayName-count-one": "nigerijska naira",
                "displayName-count-few": "nigerijske naire",
                "displayName-count-other": "nigerijskih naira",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "nikaragvanska kordoba (1988–1991)",
                "displayName-count-one": "nikaragvanska kordoba (1988–1991)",
                "displayName-count-few": "nikaragvanske kordobe (1988–1991)",
                "displayName-count-other": "nikaragvanskih kordoba (1988–1991)",
                symbol: "NIC"
            },
            NIO: {
                displayName: "nikaragvanska kordoba",
                "displayName-count-one": "nikaragvanska kordoba",
                "displayName-count-few": "nikaragvanske kordobe",
                "displayName-count-other": "nikaragvanskih kordoba",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "Holandski gulden",
                "displayName-count-one": "holandski gulden",
                "displayName-count-few": "holandska guldena",
                "displayName-count-other": "holandskih guldena",
                symbol: "NLG"
            },
            NOK: {
                displayName: "norveška kruna",
                "displayName-count-one": "norveška kruna",
                "displayName-count-few": "norveške krune",
                "displayName-count-other": "norveških kruna",
                symbol: "NOK",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "nepalska rupija",
                "displayName-count-one": "nepalska rupija",
                "displayName-count-few": "nepalske rupije",
                "displayName-count-other": "nepalskih rupija",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "novozelandski dolar",
                "displayName-count-one": "novozelandski dolar",
                "displayName-count-few": "novozelandska dolara",
                "displayName-count-other": "novozelandskih dolara",
                symbol: "NZD",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "omanski rijal",
                "displayName-count-one": "omanski rijal",
                "displayName-count-few": "omanska rijala",
                "displayName-count-other": "omanskih rijala",
                symbol: "OMR"
            },
            PAB: {
                displayName: "panamska balboa",
                "displayName-count-one": "panamska balboa",
                "displayName-count-few": "panamske balboe",
                "displayName-count-other": "panamskih balboa",
                symbol: "PAB"
            },
            PEI: {
                displayName: "Peruanski inti",
                "displayName-count-one": "peruvijski inti",
                "displayName-count-few": "peruvijska intija",
                "displayName-count-other": "peruvijskih intija",
                symbol: "PEI"
            },
            PEN: {
                displayName: "peruanski sol",
                "displayName-count-one": "peruanski sol",
                "displayName-count-few": "peruanska sola",
                "displayName-count-other": "peruanskih sola",
                symbol: "PEN"
            },
            PES: {
                displayName: "Peruanski sol (1863–1965)",
                "displayName-count-one": "peruanski sol (1863–1965)",
                "displayName-count-few": "peruanska sola (1863–1965)",
                "displayName-count-other": "peruanskih sola (1863–1965)",
                symbol: "PES"
            },
            PGK: {
                displayName: "papuanska kina",
                "displayName-count-one": "papuanska kina",
                "displayName-count-few": "papuanske kine",
                "displayName-count-other": "papuanskih kina",
                symbol: "PGK"
            },
            PHP: {
                displayName: "filipinski pezos",
                "displayName-count-one": "filipinski pezos",
                "displayName-count-few": "filipinska pezosa",
                "displayName-count-other": "filipinskih pezosa",
                symbol: "PHP",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "pakistanska rupija",
                "displayName-count-one": "pakistanska rupija",
                "displayName-count-few": "pakistanske rupije",
                "displayName-count-other": "pakistanskih rupija",
                symbol: "PKR",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "poljski zlot",
                "displayName-count-one": "poljski zlot",
                "displayName-count-few": "poljska zlota",
                "displayName-count-other": "poljskih zlota",
                symbol: "PLN",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "Poljski zloti (1950–1995)",
                "displayName-count-one": "poljski zlot (1950–1995)",
                "displayName-count-few": "poljska zlota (1950–1995)",
                "displayName-count-other": "poljskih zlota (1950–1995)",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "Portugalski eskudo",
                "displayName-count-one": "portugalski eskudo",
                "displayName-count-few": "portugalska eskuda",
                "displayName-count-other": "portugalskih eskuda",
                symbol: "PTE"
            },
            PYG: {
                displayName: "paragvajski gvarani",
                "displayName-count-one": "paragvajski gvarani",
                "displayName-count-few": "paragvajska gvaranija",
                "displayName-count-other": "paragvajskih gvaranija",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "katarski rijal",
                "displayName-count-one": "katarski rijal",
                "displayName-count-few": "katarska rijala",
                "displayName-count-other": "katarskih rijala",
                symbol: "QAR"
            },
            RHD: {
                displayName: "Rodejskidolar",
                "displayName-count-one": "rodežanski dolar",
                "displayName-count-few": "rodežanska dolara",
                "displayName-count-other": "rodežanskih dolara",
                symbol: "RHD"
            },
            ROL: {
                displayName: "Rumunski lej (1952–2006)",
                "displayName-count-one": "rumunski lej (1952–2006)",
                "displayName-count-few": "rumunska leja (1952–2006)",
                "displayName-count-other": "rumunskih leja (1952–2006)",
                symbol: "ROL"
            },
            RON: {
                displayName: "rumunski lej",
                "displayName-count-one": "rumunski lej",
                "displayName-count-few": "rumunska leja",
                "displayName-count-other": "rumunskih leja",
                symbol: "RON",
                "symbol-alt-narrow": "lei"
            },
            RSD: {
                displayName: "srpski dinar",
                "displayName-count-one": "srpski dinar",
                "displayName-count-few": "srpska dinara",
                "displayName-count-other": "srpskih dinara",
                symbol: "RSD"
            },
            RUB: {
                displayName: "ruska rublja",
                "displayName-count-one": "ruska rublja",
                "displayName-count-few": "ruske rublje",
                "displayName-count-other": "ruskih rublji",
                symbol: "RUB",
                "symbol-alt-narrow": "₽"
            },
            RUR: {
                displayName: "Ruska rublja (1991–1998)",
                "displayName-count-one": "ruska rublja (1991–1998)",
                "displayName-count-few": "ruske rublje (1991–1998)",
                "displayName-count-other": "ruskih rublji (1991–1998)",
                symbol: "RUR"
            },
            RWF: {
                displayName: "ruandski franak",
                "displayName-count-one": "ruandski franak",
                "displayName-count-few": "ruandska franka",
                "displayName-count-other": "ruandskih franaka",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "saudijski rijal",
                "displayName-count-one": "saudijski rijal",
                "displayName-count-few": "saudijska rijala",
                "displayName-count-other": "saudijskih rijala",
                symbol: "SAR"
            },
            SBD: {
                displayName: "solomonski dolar",
                "displayName-count-one": "solomonski dolar",
                "displayName-count-few": "solomonska dolara",
                "displayName-count-other": "solomonskih dolara",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "sejšelska rupija",
                "displayName-count-one": "sejšelska rupija",
                "displayName-count-few": "sejšelske rupije",
                "displayName-count-other": "sejšelskih rupija",
                symbol: "SCR"
            },
            SDD: {
                displayName: "Stari sudanski dinar",
                "displayName-count-one": "stari sudanski dinar",
                "displayName-count-few": "stara sudanska dinara",
                "displayName-count-other": "starih sudanskih dinara",
                symbol: "SDD"
            },
            SDG: {
                displayName: "sudanska funta",
                "displayName-count-one": "sudanska funta",
                "displayName-count-few": "sudanske funte",
                "displayName-count-other": "sudanskih funti",
                symbol: "SDG"
            },
            SDP: {
                displayName: "Stara sudanska funta",
                "displayName-count-one": "stara sudanska funta",
                "displayName-count-few": "stare sudanske funte",
                "displayName-count-other": "starih sudanskih funti",
                symbol: "SDP"
            },
            SEK: {
                displayName: "švedska kruna",
                "displayName-count-one": "švedska kruna",
                "displayName-count-few": "švedske krune",
                "displayName-count-other": "švedskih kruna",
                symbol: "SEK",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "singapurski dolar",
                "displayName-count-one": "singapurski dolar",
                "displayName-count-few": "singapurska dolara",
                "displayName-count-other": "singapurskih dolara",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "funta Svete Jelene",
                "displayName-count-one": "funta Svete Jelene",
                "displayName-count-few": "funte Svete Jelene",
                "displayName-count-other": "funti Svete Jelene",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "Slovenački tolar",
                "displayName-count-one": "slovenački tolar",
                "displayName-count-few": "slovenačka tolara",
                "displayName-count-other": "slovenačkih tolara",
                symbol: "SIT"
            },
            SKK: {
                displayName: "Slovačka kruna",
                "displayName-count-one": "slovačka kruna",
                "displayName-count-few": "slovačke krune",
                "displayName-count-other": "slovačkih kruna",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "sijeraleonski leone",
                "displayName-count-one": "sijeraleonski leone",
                "displayName-count-few": "sijeraleonska leona",
                "displayName-count-other": "sijeraleonskih leona",
                symbol: "SLL"
            },
            SOS: {
                displayName: "somalijski šiling",
                "displayName-count-one": "somalijski šiling",
                "displayName-count-few": "somalijska šilinga",
                "displayName-count-other": "somalijskih šilinga",
                symbol: "SOS"
            },
            SRD: {
                displayName: "surinamski dolar",
                "displayName-count-one": "surinamski dolar",
                "displayName-count-few": "surinamska dolara",
                "displayName-count-other": "surinamskih dolara",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "Surinamski gilder",
                "displayName-count-one": "surinamski gilder",
                "displayName-count-few": "surinamska gildera",
                "displayName-count-other": "surinamskih gildera",
                symbol: "SRG"
            },
            SSP: {
                displayName: "južnosudanska funta",
                "displayName-count-one": "južnosudanska funta",
                "displayName-count-few": "južnosudanske funte",
                "displayName-count-other": "južnosudanskih funti",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "Saotomska dobra (1977–2017)",
                "displayName-count-one": "saotomska dobra (1977–2017)",
                "displayName-count-few": "saotomske dobre (1977–2017)",
                "displayName-count-other": "saotomskih dobri (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "saotomska dobra",
                "displayName-count-one": "saotomska dobra",
                "displayName-count-few": "saotomske dobre",
                "displayName-count-other": "saotomskih dobri",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "Sovjetska rublja",
                "displayName-count-one": "sovjetska rublja",
                "displayName-count-few": "sovjetske rublje",
                "displayName-count-other": "sovjetskih rublji",
                symbol: "SUR"
            },
            SVC: {
                displayName: "Salvadorski kolon",
                "displayName-count-one": "salvadorski kolon",
                "displayName-count-few": "salvadorska kolona",
                "displayName-count-other": "salvadorskih kolona",
                symbol: "SVC"
            },
            SYP: {
                displayName: "sirijska funta",
                "displayName-count-one": "sirijska funta",
                "displayName-count-few": "sirijske funte",
                "displayName-count-other": "sirijskih funti",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "svazilendski lilangeni",
                "displayName-count-one": "svazilendski lilangeni",
                "displayName-count-few": "svazilendska lilangenija",
                "displayName-count-other": "svazilendskih lilangenija",
                symbol: "SZL"
            },
            THB: {
                displayName: "tajlandski bat",
                "displayName-count-one": "tajlandski bat",
                "displayName-count-few": "tajlandska bata",
                "displayName-count-other": "tajlandskih bata",
                symbol: "THB",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "Tadžihistanska rublja",
                "displayName-count-one": "tadžihistanska rublja",
                "displayName-count-few": "tadžihistanske rublje",
                "displayName-count-other": "tadžihistanskih rublji",
                symbol: "TJR"
            },
            TJS: {
                displayName: "tadžikistanski somon",
                "displayName-count-one": "tadžikistanski somon",
                "displayName-count-few": "tadžikistanska somona",
                "displayName-count-other": "tadžikistanskih somona",
                symbol: "TJS"
            },
            TMM: {
                displayName: "Turkmenistanski manat (1993–2009)",
                "displayName-count-one": "turkmenistanski manat (1993–2009)",
                "displayName-count-few": "turkmenistanska manata (1993–2009)",
                "displayName-count-other": "turkmenistanski manat (1993–2009)",
                symbol: "TMM"
            },
            TMT: {
                displayName: "turkmenistanski manat",
                "displayName-count-one": "turkmenistanski manat",
                "displayName-count-few": "turkmenistanska manata",
                "displayName-count-other": "turkmenistanskih manata",
                symbol: "TMT"
            },
            TND: {
                displayName: "tuniski dinar",
                "displayName-count-one": "tuniski dinar",
                "displayName-count-few": "tuniska dinara",
                "displayName-count-other": "tuniskih dinara",
                symbol: "TND"
            },
            TOP: {
                displayName: "tonganska panga",
                "displayName-count-one": "tonganska panga",
                "displayName-count-few": "tonganske pange",
                "displayName-count-other": "tonganskih pangi",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "Timorški eskudo",
                "displayName-count-one": "timorški eskudo",
                "displayName-count-few": "timorška eskuda",
                "displayName-count-other": "timorških eskuda",
                symbol: "TPE"
            },
            TRL: {
                displayName: "Turska lira (1922–2005)",
                "displayName-count-one": "turska lira (1922–2005)",
                "displayName-count-few": "turske lire (1922–2005)",
                "displayName-count-other": "turskih lira (1922–2005)",
                symbol: "TRL"
            },
            TRY: {
                displayName: "turska lira",
                "displayName-count-one": "turska lira",
                "displayName-count-few": "turske lire",
                "displayName-count-other": "turskih lira",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "Trinidad-tobagoški dolar",
                "displayName-count-one": "trinidad-tobagoški dolar",
                "displayName-count-few": "trinidad-tobagoška dolara",
                "displayName-count-other": "trinidad-tobagoških dolara",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "novi tajvanski dolar",
                "displayName-count-one": "novi tajvanski dolar",
                "displayName-count-few": "nova tajvanska dolara",
                "displayName-count-other": "novih tajvanskih dolara",
                symbol: "NT$",
                "symbol-alt-narrow": "NT$"
            },
            TZS: {
                displayName: "tanzanijski šiling",
                "displayName-count-one": "tanzanijski šiling",
                "displayName-count-few": "tanzanijska šilinga",
                "displayName-count-other": "tanzanijskih šilinga",
                symbol: "TZS"
            },
            UAH: {
                displayName: "ukrajinska grivna",
                "displayName-count-one": "ukrajinska grivna",
                "displayName-count-few": "ukrajinske grivne",
                "displayName-count-other": "ukrajinskih hrivnji",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "Ukrajinski karbovaneti",
                "displayName-count-one": "ukrajinski karbovanec",
                "displayName-count-few": "ukrajinska karbovanciva",
                "displayName-count-other": "ukrajinskih karbovanciva",
                symbol: "UAK"
            },
            UGS: {
                displayName: "Ugandski šiling (1966–1987)",
                "displayName-count-one": "ugandijski šiling (1966–1987)",
                "displayName-count-few": "ugandijska šilinga (1966–1987)",
                "displayName-count-other": "ugandijskih šilinga (1966–1987)",
                symbol: "UGS"
            },
            UGX: {
                displayName: "ugandski šiling",
                "displayName-count-one": "ugandski šiling",
                "displayName-count-few": "ugandska šilinga",
                "displayName-count-other": "ugandskih šilinga",
                symbol: "UGX"
            },
            USD: {
                displayName: "američki dolar",
                "displayName-count-one": "američki dolar",
                "displayName-count-few": "američka dolara",
                "displayName-count-other": "američkih dolara",
                symbol: "US$",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "SAD dolar (sledeći dan)",
                "displayName-count-one": "SAD dolar (sledeći dan)",
                "displayName-count-few": "SAD dolara (sledeći dan)",
                "displayName-count-other": "SAD dolara (sledeći dan)",
                symbol: "USN"
            },
            USS: {
                displayName: "SAD dolar (isti dan)",
                "displayName-count-one": "SAD dolar (isti dan)",
                "displayName-count-few": "SAD dolara (isti dan)",
                "displayName-count-other": "SAD dolara (isti dan)",
                symbol: "USS"
            },
            UYI: {
                displayName: "Urugvajski pezo en unidades indeksadas",
                "displayName-count-one": "urugvajski pezo en unidades indeksades",
                "displayName-count-few": "urugvajska pezosa en unidades indeksadesa",
                "displayName-count-other": "ugvajskih pezosa en unidades indeksadesa",
                symbol: "UYI"
            },
            UYP: {
                displayName: "Urugvajski pezo (1975–1993)",
                "displayName-count-one": "urugvajski pezo (1975–1993)",
                "displayName-count-few": "urugvajska pezosa (1975–1993)",
                "displayName-count-other": "urugvajskih pezosa (1975–1993)",
                symbol: "UYP"
            },
            UYU: {
                displayName: "urugvajski pezos",
                "displayName-count-one": "urugvajski pezos",
                "displayName-count-few": "urugvajska pezosa",
                "displayName-count-other": "urugvajskih pezosa",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "UYW",
                symbol: "UYW"
            },
            UZS: {
                displayName: "uzbekistanski som",
                "displayName-count-one": "uzbekistanski som",
                "displayName-count-few": "uzbekistanska soma",
                "displayName-count-other": "uzbekistanskih soma",
                symbol: "UZS"
            },
            VEB: {
                displayName: "Venecuelanski bolivar (1871–2008)",
                "displayName-count-one": "venecuelanski bolivar (1871–2008)",
                "displayName-count-few": "venecuelanska bolivara (1871–2008)",
                "displayName-count-other": "venecuelanskih bolivara (1871–2008)",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "Venecuelanski bolivar (2008–2018)",
                "displayName-count-one": "venecuelanski bolivar (2008–2018)",
                "displayName-count-few": "venecuelanska bolivara (2008–2018)",
                "displayName-count-other": "venecuelanskih bolivara (2008–2018)",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs"
            },
            VES: {
                displayName: "venecuelanski bolivar",
                "displayName-count-one": "venecuelanski bolivar",
                "displayName-count-few": "venecuelanska bolivara",
                "displayName-count-other": "venecuelanskih bolivara",
                symbol: "VES"
            },
            VND: {
                displayName: "vijetnamski dong",
                "displayName-count-one": "vijetnamski dong",
                "displayName-count-few": "vijetnamska donga",
                "displayName-count-other": "vijetnamskih donga",
                symbol: "VND",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "Vijetnamski dong (1978–1985)",
                "displayName-count-one": "vijetnamski dong (1978–1985)",
                "displayName-count-few": "vijetnamska donga (1978–1985)",
                "displayName-count-other": "vijetnamskih donga (1978–1985)",
                symbol: "VNN"
            },
            VUV: {
                displayName: "vanuatski vatu",
                "displayName-count-one": "vanuatski vatu",
                "displayName-count-few": "vanuatska vatua",
                "displayName-count-other": "vanuatskih vatua",
                symbol: "VUV"
            },
            WST: {
                displayName: "samoanska tala",
                "displayName-count-one": "samoanska tala",
                "displayName-count-few": "samoanske tale",
                "displayName-count-other": "samoanskih tala",
                symbol: "WST"
            },
            XAF: {
                displayName: "centralnoafrički franak",
                "displayName-count-one": "centralnoafrički franak",
                "displayName-count-few": "centralnoafrička franka",
                "displayName-count-other": "centralnoafričkih franaka",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "Srebro",
                "displayName-count-one": "srebro",
                "displayName-count-few": "srebra",
                "displayName-count-other": "srebra",
                symbol: "XAG"
            },
            XAU: {
                displayName: "Zlato",
                "displayName-count-one": "zlato",
                "displayName-count-few": "zlata",
                "displayName-count-other": "zlata",
                symbol: "XAU"
            },
            XBA: {
                displayName: "Evropska kompozitna jedinica",
                "displayName-count-one": "evropska kompozitna jedinica",
                "displayName-count-few": "evropske kompozitne jedinice",
                "displayName-count-other": "evropskih kompozitnih jedinica",
                symbol: "XBA"
            },
            XBB: {
                displayName: "Evropska novčana jedinica",
                "displayName-count-one": "evropska novčana jedinica (XBB)",
                "displayName-count-few": "evropske novčane jedinice (XBB)",
                "displayName-count-other": "evropske novčane jedinice (XBB)",
                symbol: "XBB"
            },
            XBC: {
                displayName: "Evropska jedinica računa (XBC)",
                "displayName-count-one": "evropska jedinica računa (XBC)",
                "displayName-count-few": "evropske jedinice računa (XBC)",
                "displayName-count-other": "evropskih jedinica računa (XBC)",
                symbol: "XBC"
            },
            XBD: {
                displayName: "Evropska jedinica računa (XBD)",
                "displayName-count-one": "evropska jedinica računa (XBD)",
                "displayName-count-few": "evropske jedinice računa (XBD)",
                "displayName-count-other": "evropskih jedinica računa (XBD)",
                symbol: "XBD"
            },
            XCD: {
                displayName: "istočnokaripski dolar",
                "displayName-count-one": "istočnokaripski dolar",
                "displayName-count-few": "istočnokaripska dolara",
                "displayName-count-other": "istočnokaripskix dolara",
                symbol: "EC$",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "Posebna crtaća prava",
                "displayName-count-one": "posebno crtaće pravo",
                "displayName-count-few": "posebna crtaća prava",
                "displayName-count-other": "posebnih crtaćih prava",
                symbol: "XDR"
            },
            XEU: {
                displayName: "Evropska valutna jedinica",
                "displayName-count-one": "evropska novčana jedinica (XEU)",
                "displayName-count-few": "evropske novčane jedinice (XEU)",
                "displayName-count-other": "evropskih novčanih jedinica",
                symbol: "XEU"
            },
            XFO: {
                displayName: "Francuski zlatni franak",
                "displayName-count-one": "francuski zlatni franak",
                "displayName-count-few": "francuska zlatna franka",
                "displayName-count-other": "francuskih zlatnih franaka",
                symbol: "XFO"
            },
            XFU: {
                displayName: "Francuski UIC-franak",
                "displayName-count-one": "francuski UIC-franak",
                "displayName-count-few": "francuska UIC-franka",
                "displayName-count-other": "francuskih UIC-franaka",
                symbol: "XFU"
            },
            XOF: {
                displayName: "zapadnoafrički franak",
                "displayName-count-one": "zapadnoafrički franak",
                "displayName-count-few": "zapadnoafrička franka",
                "displayName-count-other": "zapadnoafričkih franaka",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "Paladijum",
                "displayName-count-one": "paladijum",
                "displayName-count-few": "paladijuma",
                "displayName-count-other": "paladijuma",
                symbol: "XPD"
            },
            XPF: {
                displayName: "CFP franak",
                "displayName-count-one": "CFP franak",
                "displayName-count-few": "CFP franka",
                "displayName-count-other": "CFP franaka",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "Platina",
                "displayName-count-one": "platina",
                "displayName-count-few": "platine",
                "displayName-count-other": "platina",
                symbol: "XPT"
            },
            XRE: {
                displayName: "RINET fond",
                "displayName-count-one": "RINET fond",
                "displayName-count-few": "RINET fonda",
                "displayName-count-other": "RINET fondova",
                symbol: "XRE"
            },
            XSU: {
                displayName: "XSU",
                symbol: "XSU"
            },
            XTS: {
                displayName: "Kod testirane valute",
                "displayName-count-one": "kod testirane valute",
                "displayName-count-few": "koda testirane valute",
                "displayName-count-other": "kodova testirane valute",
                symbol: "XTS"
            },
            XUA: {
                displayName: "XUA",
                symbol: "XUA"
            },
            XXX: {
                displayName: "Nepoznata valuta",
                "displayName-count-one": "nepoznata jedinica valute",
                "displayName-count-few": "nepoznate valute",
                "displayName-count-other": "nepoznatih valuta",
                symbol: "¤"
            },
            YDD: {
                displayName: "Jemenski dinar",
                "displayName-count-one": "jemenski dolar",
                "displayName-count-few": "jemenska dolara",
                "displayName-count-other": "jemenskih dolara",
                symbol: "YDD"
            },
            YER: {
                displayName: "jemenski rijal",
                "displayName-count-one": "jemenski rijal",
                "displayName-count-few": "jemenska rijala",
                "displayName-count-other": "jemenskih rijala",
                symbol: "YER"
            },
            YUD: {
                displayName: "Jugoslovenski tvrdi dinar",
                "displayName-count-one": "jugoslovenski tvrdi dinar",
                "displayName-count-few": "jugoslovenska tvrda dinara",
                "displayName-count-other": "jugoslovenskih tvrdih dinara",
                symbol: "YUD"
            },
            YUM: {
                displayName: "Jugoslovenski novi dinar",
                "displayName-count-one": "jugoslovenski novi dinar",
                "displayName-count-few": "jugoslovenska nova dinara",
                "displayName-count-other": "jugoslovenskih novih dinara",
                symbol: "YUM"
            },
            YUN: {
                displayName: "Jugoslovenski konvertibilni dinar",
                "displayName-count-one": "jugoslovenski konvertibilni dinar",
                "displayName-count-few": "jugoslovenska konvertibilna dinara",
                "displayName-count-other": "jugoslovenskih konvertibilnih dinara",
                symbol: "YUN"
            },
            YUR: {
                displayName: "YUR",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "Južno-afrički rand (finansijski)",
                "displayName-count-one": "južnoafrički rand (finansijski)",
                "displayName-count-few": "južnoafrička randa (finansijska)",
                "displayName-count-other": "južnoafričkih randa (finansijskih)",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "južnoafrički rand",
                "displayName-count-one": "južnoafrički rand",
                "displayName-count-few": "južnoafrička randa",
                "displayName-count-other": "južnoafričkih randa",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "Zambijska kvača (1968–2012)",
                "displayName-count-one": "zambijska kvača (1968–2012)",
                "displayName-count-few": "zambijske kvače (1968–2012)",
                "displayName-count-other": "zambijskih kvača (1968–2012)",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "zambijska kvača",
                "displayName-count-one": "zambijska kvača",
                "displayName-count-few": "zambijske kvače",
                "displayName-count-other": "zambijskih kvača",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "Zairski novi zair",
                "displayName-count-one": "zairski novi zair",
                "displayName-count-few": "zairska nova zaira",
                "displayName-count-other": "zairskih novih zaira",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "Zairski zair",
                "displayName-count-one": "zairski zair",
                "displayName-count-few": "zairska zaira",
                "displayName-count-other": "zairskih zaira",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "Zimbabveanski dolar (1980–2008)",
                "displayName-count-one": "zimbabvejski dolar (1980–2008)",
                "displayName-count-few": "zimbabvejska dolara (1980–2008)",
                "displayName-count-other": "zimbabvejskih dolara (1980–2008)",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "Zimbabveanski dolar (2009)",
                "displayName-count-one": "zimbabvejski dolar (2009)",
                "displayName-count-few": "zimbabvejska dolara (2009)",
                "displayName-count-other": "zimbabvejskih dolara (2009)",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "Zimbabveanski dolar (2008)",
                "displayName-count-one": "zimbabvejski dolar (2008)",
                "displayName-count-few": "zimbabvejska dolara (2008)",
                "displayName-count-other": "zimbabvejskih dolara (2008)",
                symbol: "ZWR"
            }
        },
        localeCurrency: "RSD"
    },
    calendar: {
        patterns: {
            d: "d.M.y.",
            D: "EEEE, d. MMMM y.",
            m: "d. MMM",
            M: "d. MMMM",
            y: "MMM y.",
            Y: "MMMM y.",
            F: "EEEE, d. MMMM y. HH:mm:ss",
            g: "d.M.y. HH:mm",
            G: "d.M.y. HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "hh:mm B",
                Bhms: "hh:mm:ss B",
                d: "d",
                E: "E",
                EBhm: "E hh:mm B",
                EBhms: "E hh:mm:ss B",
                Ed: "E d.",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y. G",
                GyMd: "d.MM.y. GGGGG",
                GyMMM: "MMM y. G",
                GyMMMd: "d. MMM y. G",
                GyMMMEd: "E, d. MMM y. G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d.M.",
                MEd: "E, d.M.",
                MMdd: "dd.MM.",
                MMM: "LLL",
                MMMd: "d. MMM",
                MMMdd: "dd.MMM",
                MMMEd: "E d. MMM",
                MMMMd: "d. MMMM",
                MMMMEd: "E, d. MMMM",
                "MMMMW-count-one": "W. 'sedmica' 'u' MMMM.",
                "MMMMW-count-few": "W. 'sedmica' 'u' MMMM.",
                "MMMMW-count-other": "W. 'sedmica' 'u' MMMM.",
                ms: "mm:ss",
                y: "y.",
                yM: "M.y.",
                yMd: "d.M.y.",
                yMEd: "E, d.M.y.",
                yMM: "MM.y.",
                yMMdd: "dd.MM.y.",
                yMMM: "MMM y.",
                yMMMd: "d. MMM y.",
                yMMMEd: "E, d. MMM y.",
                yMMMM: "MMMM y.",
                yQQQ: "QQQ y.",
                yQQQQ: "QQQQ y.",
                "yw-count-one": "w. 'sedmica' 'u' Y.",
                "yw-count-few": "w. 'sedmica' 'u' Y.",
                "yw-count-other": "w. 'sedmica' 'u' Y."
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d. MMMM y.",
            long: "d. MMMM y.",
            medium: "d. M. y.",
            short: "d.M.yy."
        },
        days: {
            format: {
                abbreviated: [
                    "ned",
                    "pon",
                    "uto",
                    "sre",
                    "čet",
                    "pet",
                    "sub"
                ],
                narrow: [
                    "n",
                    "p",
                    "u",
                    "s",
                    "č",
                    "p",
                    "s"
                ],
                short: [
                    "ne",
                    "po",
                    "ut",
                    "sr",
                    "če",
                    "pe",
                    "su"
                ],
                wide: [
                    "nedelja",
                    "ponedeljak",
                    "utorak",
                    "sreda",
                    "četvrtak",
                    "petak",
                    "subota"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ned",
                    "pon",
                    "uto",
                    "sre",
                    "čet",
                    "pet",
                    "sub"
                ],
                narrow: [
                    "n",
                    "p",
                    "u",
                    "s",
                    "č",
                    "p",
                    "s"
                ],
                short: [
                    "ne",
                    "po",
                    "ut",
                    "sr",
                    "če",
                    "pe",
                    "su"
                ],
                wide: [
                    "nedelja",
                    "ponedeljak",
                    "utorak",
                    "sreda",
                    "četvrtak",
                    "petak",
                    "subota"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "jan",
                    "feb",
                    "mar",
                    "apr",
                    "maj",
                    "jun",
                    "jul",
                    "avg",
                    "sep",
                    "okt",
                    "nov",
                    "dec"
                ],
                narrow: [
                    "j",
                    "f",
                    "m",
                    "a",
                    "m",
                    "j",
                    "j",
                    "a",
                    "s",
                    "o",
                    "n",
                    "d"
                ],
                wide: [
                    "januar",
                    "februar",
                    "mart",
                    "april",
                    "maj",
                    "jun",
                    "jul",
                    "avgust",
                    "septembar",
                    "oktobar",
                    "novembar",
                    "decembar"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "jan",
                    "feb",
                    "mar",
                    "apr",
                    "maj",
                    "jun",
                    "jul",
                    "avg",
                    "sep",
                    "okt",
                    "nov",
                    "dec"
                ],
                narrow: [
                    "j",
                    "f",
                    "m",
                    "a",
                    "m",
                    "j",
                    "j",
                    "a",
                    "s",
                    "o",
                    "n",
                    "d"
                ],
                wide: [
                    "januar",
                    "februar",
                    "mart",
                    "april",
                    "maj",
                    "jun",
                    "jul",
                    "avgust",
                    "septembar",
                    "oktobar",
                    "novembar",
                    "decembar"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1. kv.",
                    "2. kv.",
                    "3. kv.",
                    "4. kv."
                ],
                narrow: [
                    "1.",
                    "2.",
                    "3.",
                    "4."
                ],
                wide: [
                    "prvi kvartal",
                    "drugi kvartal",
                    "treći kvartal",
                    "četvrti kvartal"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1. kv.",
                    "2. kv.",
                    "3. kv.",
                    "4. kv."
                ],
                narrow: [
                    "1.",
                    "2.",
                    "3.",
                    "4."
                ],
                wide: [
                    "prvi kvartal",
                    "drugi kvartal",
                    "treći kvartal",
                    "četvrti kvartal"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "ponoć",
                    am: "AM",
                    noon: "podne",
                    pm: "PM",
                    morning1: "ujutro",
                    afternoon1: "po podne",
                    evening1: "uveče",
                    night1: "noću"
                },
                narrow: {
                    midnight: "ponoć",
                    am: "AM",
                    noon: "podne",
                    pm: "PM",
                    morning1: "ujutru",
                    afternoon1: "po podne",
                    evening1: "uveče",
                    night1: "noću"
                },
                wide: {
                    midnight: "ponoć",
                    am: "AM",
                    noon: "podne",
                    pm: "PM",
                    morning1: "ujutro",
                    afternoon1: "po podne",
                    evening1: "uveče",
                    night1: "noću"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "ponoć",
                    am: "AM",
                    noon: "podne",
                    pm: "PM",
                    morning1: "jutro",
                    afternoon1: "popodne",
                    evening1: "veče",
                    night1: "noć"
                },
                narrow: {
                    midnight: "ponoć",
                    am: "pre podne",
                    noon: "podne",
                    pm: "po podne",
                    morning1: "jutro",
                    afternoon1: "popodne",
                    evening1: "veče",
                    night1: "noć"
                },
                wide: {
                    midnight: "ponoć",
                    am: "AM",
                    noon: "podne",
                    pm: "PM",
                    morning1: "jutro",
                    afternoon1: "popodne",
                    evening1: "veče",
                    night1: "noć"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "pre nove ere",
                    "1": "nove ere",
                    "0-alt-variant": "pre naše ere",
                    "1-alt-variant": "naše ere"
                },
                abbreviated: {
                    "0": "p. n. e.",
                    "1": "n. e.",
                    "0-alt-variant": "p. n. e.",
                    "1-alt-variant": "n. e."
                },
                narrow: {
                    "0": "p.n.e.",
                    "1": "n.e.",
                    "0-alt-variant": "p. n. e.",
                    "1-alt-variant": "n. e."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "era",
                short: "era",
                narrow: "era"
            },
            year: {
                wide: "godina",
                short: "god.",
                narrow: "g."
            },
            quarter: {
                wide: "kvartal",
                short: "kv.",
                narrow: "kv."
            },
            month: {
                wide: "mesec",
                short: "mes.",
                narrow: "mes."
            },
            week: {
                wide: "nedelja",
                short: "ned.",
                narrow: "ned."
            },
            weekOfMonth: {
                wide: "nedelja u mesecu",
                short: "ned. u mes.",
                narrow: "ned. u mes."
            },
            day: {
                wide: "dan",
                short: "d.",
                narrow: "d."
            },
            dayOfYear: {
                wide: "dan u godini",
                short: "dan u god.",
                narrow: "dan u god."
            },
            weekday: {
                wide: "dan u nedelji",
                short: "dan u nedelji",
                narrow: "dan u nedelji"
            },
            weekdayOfMonth: {
                wide: "dan u mesecu",
                short: "dan u mesecu",
                narrow: "dan u mesecu"
            },
            dayperiod: {
                short: "pre podne/po podne",
                wide: "AM/PM",
                narrow: "pre podne/po podne"
            },
            hour: {
                wide: "sat",
                short: "č.",
                narrow: "č."
            },
            minute: {
                wide: "minut",
                short: "min.",
                narrow: "min."
            },
            second: {
                wide: "sekund",
                short: "sek.",
                narrow: "s"
            },
            zone: {
                wide: "vremenska zona",
                short: "vremenska zona",
                narrow: "vremenska zona"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "milisekunda"
            }
        }
    },
    firstDay: 1,
    weekendRange: {
        start: 6,
        end: 0
    },
    likelySubtags: {
        sr: "sr-Cyrl-RS"
    },
    currencyData: {
        RSD: {
            _rounding: "0",
            _digits: "0"
        }
    }
});

