/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "sv-FI",
    identity: {
        language: "sv",
        territory: "FI"
    },
    territory: "FI",
    numbers: {
        symbols: {
            decimal: ",",
            group: " ",
            list: ";",
            percentSign: "%",
            plusSign: "+",
            minusSign: "−",
            approximatelySign: "~",
            exponential: "×10^",
            superscriptingExponent: "×",
            perMille: "‰",
            infinity: "∞",
            nan: "NaN",
            timeSeparator: ".",
            "timeSeparator-alt-variant": ":"
        },
        decimal: {
            patterns: [
                "n"
            ],
            groupSize: [
                3
            ]
        },
        scientific: {
            patterns: [
                "nEn"
            ],
            groupSize: []
        },
        percent: {
            patterns: [
                "n %"
            ],
            groupSize: [
                3
            ]
        },
        currency: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ],
            "unitPattern-count-one": "n $",
            "unitPattern-count-other": "n $"
        },
        accounting: {
            patterns: [
                "n $"
            ],
            groupSize: [
                3
            ]
        },
        currencies: {
            ADP: {
                displayName: "andorransk peseta",
                "displayName-count-one": "andorransk peseta",
                "displayName-count-other": "andorranska pesetas",
                symbol: "ADP"
            },
            AED: {
                displayName: "emiratisk dirham",
                "displayName-count-one": "emiratisk dirham",
                "displayName-count-other": "emiratisk dirham",
                symbol: "AED"
            },
            AFA: {
                displayName: "afghani (1927–2002)",
                "displayName-count-one": "afghani (1927–2002)",
                "displayName-count-other": "afghani (1927–2002)",
                symbol: "AFA"
            },
            AFN: {
                displayName: "afghansk afghani",
                "displayName-count-one": "afghansk afghani",
                "displayName-count-other": "afghanska afghani",
                symbol: "AFN",
                "symbol-alt-narrow": "؋"
            },
            ALK: {
                displayName: "albansk lek (1946–1965)",
                "displayName-count-one": "albansk lek (1946–1965)",
                "displayName-count-other": "albanska lek (1946–1965)",
                symbol: "ALK"
            },
            ALL: {
                displayName: "albansk lek",
                "displayName-count-one": "albansk lek",
                "displayName-count-other": "albanska leke",
                symbol: "ALL"
            },
            AMD: {
                displayName: "armenisk dram",
                "displayName-count-one": "armenisk dram",
                "displayName-count-other": "armeniska dram",
                symbol: "AMD",
                "symbol-alt-narrow": "֏"
            },
            ANG: {
                displayName: "antillergulden",
                "displayName-count-one": "antillergulden",
                "displayName-count-other": "antillergulden",
                symbol: "ANG"
            },
            AOA: {
                displayName: "angolansk kwanza",
                "displayName-count-one": "angolansk kwanza",
                "displayName-count-other": "angolanska kwanza",
                symbol: "AOA",
                "symbol-alt-narrow": "Kz"
            },
            AOK: {
                displayName: "angolansk kwanza (1977–1990)",
                "displayName-count-one": "angolansk kwanza (1977–1990)",
                "displayName-count-other": "angolanska kwanza (1977–1990)",
                symbol: "AOK"
            },
            AON: {
                displayName: "angolansk ny kwanza (1990–2000)",
                "displayName-count-one": "angolansk kwanza (1990–2000)",
                "displayName-count-other": "angolanska nya kwanza (1990–2000)",
                symbol: "AON"
            },
            AOR: {
                displayName: "angolansk kwanza reajustado (1995–1999)",
                "displayName-count-one": "angolansk kwanza reajustado (1995–1999)",
                "displayName-count-other": "angolanska kwanza reajustado (1995–1999)",
                symbol: "AOR"
            },
            ARA: {
                displayName: "argentinsk austral",
                "displayName-count-one": "argentinsk austral",
                "displayName-count-other": "argentinska australer",
                symbol: "ARA"
            },
            ARL: {
                displayName: "argentisk peso (1970–1983)",
                "displayName-count-one": "argentisk peso (1970–1983)",
                "displayName-count-other": "argentiska pesos (1970–1983)",
                symbol: "ARL"
            },
            ARM: {
                displayName: "argentisk peso (1881–1969)",
                "displayName-count-one": "argentisk peso (1881–1969)",
                "displayName-count-other": "argentiska pesos (1881–1969)",
                symbol: "ARM"
            },
            ARP: {
                displayName: "argentinsk peso (1983–1985)",
                "displayName-count-one": "argentinsk peso (1983–1985)",
                "displayName-count-other": "argentinska pesos (1983–1985)",
                symbol: "ARP"
            },
            ARS: {
                displayName: "argentinsk peso",
                "displayName-count-one": "argentinsk peso",
                "displayName-count-other": "argentinska pesos",
                symbol: "ARS",
                "symbol-alt-narrow": "$"
            },
            ATS: {
                displayName: "österrikisk schilling",
                "displayName-count-one": "österrikisk schilling",
                "displayName-count-other": "österrikiska schilling",
                symbol: "ATS"
            },
            AUD: {
                displayName: "australisk dollar",
                "displayName-count-one": "australisk dollar",
                "displayName-count-other": "australiska dollar",
                symbol: "AUD",
                "symbol-alt-narrow": "$"
            },
            AWG: {
                displayName: "arubansk florin",
                "displayName-count-one": "arubansk florin",
                "displayName-count-other": "arubanska floriner",
                symbol: "AWG"
            },
            AZM: {
                displayName: "azerbajdzjansk manat (1993–2006)",
                "displayName-count-one": "azerbajdzjansk manat (1993–2006)",
                "displayName-count-other": "azerbajdzjanska manat (1993–2006)",
                symbol: "AZM"
            },
            AZN: {
                displayName: "azerbajdzjansk manat",
                "displayName-count-one": "azerbajdzjansk manat",
                "displayName-count-other": "azerbajdzjanska manat",
                symbol: "AZN",
                "symbol-alt-narrow": "₼"
            },
            BAD: {
                displayName: "bosnisk-hercegovinsk dinar (1992–1994)",
                "displayName-count-one": "bosnisk-hercegovinsk dinar (1992–1994)",
                "displayName-count-other": "bosnisk-hercegovinska dinarer (1992–1994)",
                symbol: "BAD"
            },
            BAM: {
                displayName: "bosnisk-hercegovinsk mark (konvertibel)",
                "displayName-count-one": "bosnisk-hercegovinsk mark (konvertibel)",
                "displayName-count-other": "bosnisk-hercegovinska mark (konvertibla)",
                symbol: "BAM",
                "symbol-alt-narrow": "KM"
            },
            BAN: {
                displayName: "bosnisk-hercegovinsk dinar (1994–1998)",
                "displayName-count-one": "bosnisk-hercegovinsk dinar (1994–1998)",
                "displayName-count-other": "bosnisk-hercegovinska dinarer (1994–1998)",
                symbol: "BAN"
            },
            BBD: {
                displayName: "barbadisk dollar",
                "displayName-count-one": "barbadisk dollar",
                "displayName-count-other": "barbadisk dollar",
                symbol: "Bds$",
                "symbol-alt-narrow": "$"
            },
            BDT: {
                displayName: "bangladeshisk taka",
                "displayName-count-one": "bangladeshisk taka",
                "displayName-count-other": "bangladeshiska taka",
                symbol: "BDT",
                "symbol-alt-narrow": "৳"
            },
            BEC: {
                displayName: "belgisk franc (konvertibel)",
                "displayName-count-one": "belgisk franc (konvertibel)",
                "displayName-count-other": "belgiska franc (konvertibla)",
                symbol: "BEC"
            },
            BEF: {
                displayName: "belgisk franc",
                "displayName-count-one": "belgisk franc",
                "displayName-count-other": "belgiska franc",
                symbol: "BEF"
            },
            BEL: {
                displayName: "belgisk franc (finansiell)",
                "displayName-count-one": "belgisk franc (finansiell)",
                "displayName-count-other": "belgiska franc (finansiella)",
                symbol: "BEL"
            },
            BGL: {
                displayName: "bulgarisk hård lev (1962–1999)",
                "displayName-count-one": "bulgarisk hård lev (1962–1999)",
                "displayName-count-other": "bulgariska hårda lev (1962–1999)",
                symbol: "BGL"
            },
            BGM: {
                displayName: "bulgarisk lev (1952–1962)",
                "displayName-count-one": "bulgarisk lev (1952–1962)",
                "displayName-count-other": "bulgariska lev (1952–1962)",
                symbol: "BGM"
            },
            BGN: {
                displayName: "bulgarisk lev",
                "displayName-count-one": "bulgarisk lev",
                "displayName-count-other": "bulgariska leva",
                symbol: "BGN"
            },
            BGO: {
                displayName: "bulgarisk lev (1881–1952)",
                "displayName-count-one": "bulgarisk lev (1881–1952)",
                "displayName-count-other": "bulgarisk lev (1881–1952)",
                symbol: "BGO"
            },
            BHD: {
                displayName: "bahrainsk dinar",
                "displayName-count-one": "bahrainsk dinar",
                "displayName-count-other": "bahrainska dinarer",
                symbol: "BHD"
            },
            BIF: {
                displayName: "burundisk franc",
                "displayName-count-one": "burundisk franc",
                "displayName-count-other": "burundiska franc",
                symbol: "BIF"
            },
            BMD: {
                displayName: "bermudisk dollar",
                "displayName-count-one": "bermudisk dollar",
                "displayName-count-other": "bermudisk dollar",
                symbol: "BM$",
                "symbol-alt-narrow": "$"
            },
            BND: {
                displayName: "bruneisk dollar",
                "displayName-count-one": "bruneisk dollar",
                "displayName-count-other": "bruneiska dollar",
                symbol: "BND",
                "symbol-alt-narrow": "$"
            },
            BOB: {
                displayName: "boliviansk boliviano",
                "displayName-count-one": "boliviansk boliviano",
                "displayName-count-other": "bolivianska bolivianos",
                symbol: "BOB",
                "symbol-alt-narrow": "Bs"
            },
            BOL: {
                displayName: "boliviansk boliviano (1864–1963)",
                "displayName-count-one": "boliviansk boliviano (1864–1963)",
                "displayName-count-other": "bolivianska bolivianos (1864–1963)",
                symbol: "BOL"
            },
            BOP: {
                displayName: "boliviansk peso",
                "displayName-count-one": "boliviansk peso",
                "displayName-count-other": "bolivianska pesos",
                symbol: "BOP"
            },
            BOV: {
                displayName: "boliviansk mvdol",
                "displayName-count-one": "boliviansk mvdol",
                "displayName-count-other": "bolivianska mvdol",
                symbol: "BOV"
            },
            BRB: {
                displayName: "brasiliansk cruzeiro novo (1967–1986)",
                "displayName-count-one": "brasiliansk cruzeiro (1967–1986)",
                "displayName-count-other": "brasilianska cruzeiro novo (1967–1986)",
                symbol: "BRB"
            },
            BRC: {
                displayName: "brasiliansk cruzado",
                "displayName-count-one": "brasiliansk cruzado",
                "displayName-count-other": "brasilianska cruzado",
                symbol: "BRC"
            },
            BRE: {
                displayName: "brasiliansk cruzeiro (1990–1993)",
                "displayName-count-one": "brasiliansk cruzeiro (1990–1993)",
                "displayName-count-other": "brasilianska cruzeiro (1990–1993)",
                symbol: "BRE"
            },
            BRL: {
                displayName: "brasiliansk real",
                "displayName-count-one": "brasiliansk real",
                "displayName-count-other": "brasilianska real",
                symbol: "BR$",
                "symbol-alt-narrow": "R$"
            },
            BRN: {
                displayName: "brasiliansk cruzado novo",
                "displayName-count-one": "brasiliansk cruzado novo",
                "displayName-count-other": "brasilianska cruzado novo",
                symbol: "BRN"
            },
            BRR: {
                displayName: "brasiliansk cruzeiro",
                "displayName-count-one": "brasiliansk cruzeiro",
                "displayName-count-other": "brasilianska cruzeiros",
                symbol: "BRR"
            },
            BRZ: {
                displayName: "brasiliansk cruzeiro (1942–1967)",
                "displayName-count-one": "brasiliansk cruzeiro (1942–1967)",
                "displayName-count-other": "brasilianska cruzeiros (1942–1967)",
                symbol: "BRZ"
            },
            BSD: {
                displayName: "bahamansk dollar",
                "displayName-count-one": "bahamansk dollar",
                "displayName-count-other": "bahamanska dollar",
                symbol: "BS$",
                "symbol-alt-narrow": "$"
            },
            BTN: {
                displayName: "bhutanesisk ngultrum",
                "displayName-count-one": "bhutanesisk ngultrum",
                "displayName-count-other": "bhutanesiska ngultrum",
                symbol: "BTN"
            },
            BUK: {
                displayName: "burmesisk kyat",
                "displayName-count-one": "burmesisk kyat",
                "displayName-count-other": "burmesiska kyat",
                symbol: "BUK"
            },
            BWP: {
                displayName: "botswansk pula",
                "displayName-count-one": "botswansk pula",
                "displayName-count-other": "botswanska pula",
                symbol: "BWP",
                "symbol-alt-narrow": "P"
            },
            BYB: {
                displayName: "vitrysk ny rubel (1994–1999)",
                "displayName-count-one": "vitrysk rubel (1994–1999)",
                "displayName-count-other": "vitryska nya rubel (1994–1999)",
                symbol: "BYB"
            },
            BYN: {
                displayName: "vitrysk rubel",
                "displayName-count-one": "vitrysk rubel",
                "displayName-count-other": "vitryska rubel",
                symbol: "BYN",
                "symbol-alt-narrow": "р."
            },
            BYR: {
                displayName: "vitrysk rubel (2000–2016)",
                "displayName-count-one": "vitrysk rubel (2000–2016)",
                "displayName-count-other": "vitryska rubel (2000–2016)",
                symbol: "BYR"
            },
            BZD: {
                displayName: "belizisk dollar",
                "displayName-count-one": "belizisk dollar",
                "displayName-count-other": "beliziska dollar",
                symbol: "BZ$",
                "symbol-alt-narrow": "$"
            },
            CAD: {
                displayName: "kanadensisk dollar",
                "displayName-count-one": "kanadensisk dollar",
                "displayName-count-other": "kanadensiska dollar",
                symbol: "CA$",
                "symbol-alt-narrow": "$"
            },
            CDF: {
                displayName: "kongolesisk franc",
                "displayName-count-one": "kongolesisk franc",
                "displayName-count-other": "kongolesiska franc",
                symbol: "CDF"
            },
            CHE: {
                displayName: "euro (konvertibelt konto, WIR Bank, Schweiz)",
                "displayName-count-one": "euro (WIR Bank)",
                "displayName-count-other": "euro (konvertibelt konto, WIR Bank, Schweiz)",
                symbol: "CHE"
            },
            CHF: {
                displayName: "schweizisk franc",
                "displayName-count-one": "schweizisk franc",
                "displayName-count-other": "schweiziska franc",
                symbol: "CHF"
            },
            CHW: {
                displayName: "franc (konvertibelt konto, WIR Bank, Schweiz)",
                "displayName-count-one": "franc (WIR Bank)",
                "displayName-count-other": "franc (konvertibelt konto, WIR Bank, Schweiz)",
                symbol: "CHW"
            },
            CLE: {
                displayName: "chilensk escudo (1960–1975)",
                "displayName-count-one": "chilensk escudo (1960–1975)",
                "displayName-count-other": "chilenska escudos (1960–1975)",
                symbol: "CLE"
            },
            CLF: {
                displayName: "chilensk unidad de fomento",
                "displayName-count-one": "chilensk unidad de fomento",
                "displayName-count-other": "chilenska unidad de fomento",
                symbol: "CLF"
            },
            CLP: {
                displayName: "chilensk peso",
                "displayName-count-one": "chilensk peso",
                "displayName-count-other": "chilenska pesos",
                symbol: "CLP",
                "symbol-alt-narrow": "$"
            },
            CNH: {
                displayName: "kinesisk yuan (offshore)",
                "displayName-count-one": "kinesisk yuan (offshore)",
                "displayName-count-other": "kinesisk yuan (offshore)",
                symbol: "CNH"
            },
            CNX: {
                displayName: "kinesisk dollar",
                "displayName-count-one": "kinesisk dollar",
                "displayName-count-other": "kinesiska dollar",
                symbol: "CNX"
            },
            CNY: {
                displayName: "kinesisk yuan",
                "displayName-count-one": "kinesisk yuan",
                "displayName-count-other": "kinesiska yuan",
                symbol: "CNY",
                "symbol-alt-narrow": "¥"
            },
            COP: {
                displayName: "colombiansk peso",
                "displayName-count-one": "colombiansk peso",
                "displayName-count-other": "colombianska pesos",
                symbol: "COP",
                "symbol-alt-narrow": "$"
            },
            COU: {
                displayName: "colombiansk unidad de valor real",
                "displayName-count-one": "colombiansk unidad de valor real",
                "displayName-count-other": "colombianska unidad de valor real",
                symbol: "COU"
            },
            CRC: {
                displayName: "costarikansk colón",
                "displayName-count-one": "costarikansk colón",
                "displayName-count-other": "costarikanska colón",
                symbol: "CRC",
                "symbol-alt-narrow": "₡"
            },
            CSD: {
                displayName: "serbisk dinar (2002–2006)",
                "displayName-count-one": "serbisk dinar (2002–2006)",
                "displayName-count-other": "serbiska dinarer (2002–2006)",
                symbol: "CSD"
            },
            CSK: {
                displayName: "tjeckoslovakisk krona (–1993)",
                "displayName-count-one": "tjeckoslovakisk hård koruna",
                "displayName-count-other": "tjeckiska hårda koruna",
                symbol: "CSK"
            },
            CUC: {
                displayName: "kubansk peso (konvertibel)",
                "displayName-count-one": "kubansk peso (konvertibel)",
                "displayName-count-other": "kubanska pesos (konvertibla)",
                symbol: "CUC",
                "symbol-alt-narrow": "$"
            },
            CUP: {
                displayName: "kubansk peso",
                "displayName-count-one": "kubansk peso",
                "displayName-count-other": "kubanska pesos",
                symbol: "CUP",
                "symbol-alt-narrow": "$"
            },
            CVE: {
                displayName: "kapverdisk escudo",
                "displayName-count-one": "kapverdisk escudo",
                "displayName-count-other": "kapverdiska escudos",
                symbol: "CVE"
            },
            CYP: {
                displayName: "cypriotiskt pund",
                "displayName-count-one": "cypriotiskt pund",
                "displayName-count-other": "cypriotiska pund",
                symbol: "CYP"
            },
            CZK: {
                displayName: "tjeckisk koruna",
                "displayName-count-one": "tjeckisk koruna",
                "displayName-count-other": "tjeckiska koruna",
                symbol: "CZK",
                "symbol-alt-narrow": "Kč"
            },
            DDM: {
                displayName: "östtysk mark",
                "displayName-count-one": "östtysk mark",
                "displayName-count-other": "östtyska mark",
                symbol: "DDM"
            },
            DEM: {
                displayName: "tysk mark",
                "displayName-count-one": "tysk mark",
                "displayName-count-other": "tyska mark",
                symbol: "DEM"
            },
            DJF: {
                displayName: "djiboutisk franc",
                "displayName-count-one": "djiboutisk franc",
                "displayName-count-other": "djiboutiska franc",
                symbol: "DJF"
            },
            DKK: {
                displayName: "dansk krona",
                "displayName-count-one": "dansk krona",
                "displayName-count-other": "danska kronor",
                symbol: "Dkr",
                "symbol-alt-narrow": "kr"
            },
            DOP: {
                displayName: "dominikansk peso",
                "displayName-count-one": "dominikansk peso",
                "displayName-count-other": "dominikanska pesos",
                symbol: "RD$",
                "symbol-alt-narrow": "$"
            },
            DZD: {
                displayName: "algerisk dinar",
                "displayName-count-one": "algerisk dinar",
                "displayName-count-other": "algeriska dinarer",
                symbol: "DZD"
            },
            ECS: {
                displayName: "ecuadoriansk sucre",
                "displayName-count-one": "ecuadoriansk sucre",
                "displayName-count-other": "ecuadorianska sucre",
                symbol: "ECS"
            },
            ECV: {
                displayName: "ecuadoriansk unidad de valor constante",
                "displayName-count-one": "ecuadoriansk unidad de valor constante",
                "displayName-count-other": "ecuadorianska unidad de valor constante",
                symbol: "ECV"
            },
            EEK: {
                displayName: "estnisk krona",
                "displayName-count-one": "estnisk krona",
                "displayName-count-other": "estniska kronor",
                symbol: "Ekr"
            },
            EGP: {
                displayName: "egyptiskt pund",
                "displayName-count-one": "egyptiskt pund",
                "displayName-count-other": "egyptiska pund",
                symbol: "EG£",
                "symbol-alt-narrow": "E£"
            },
            ERN: {
                displayName: "eritreansk nakfa",
                "displayName-count-one": "eritreansk nakfa",
                "displayName-count-other": "eritreanska nakfa",
                symbol: "ERN"
            },
            ESA: {
                displayName: "spansk peseta (konto)",
                "displayName-count-one": "spansk peseta (konto)",
                "displayName-count-other": "spanska pesetas (konto)",
                symbol: "ESA"
            },
            ESB: {
                displayName: "spansk peseta (konvertibelt konto)",
                "displayName-count-one": "spansk peseta (konvertibelt konto)",
                "displayName-count-other": "spanska pesetas (konvertibelt konto)",
                symbol: "ESB"
            },
            ESP: {
                displayName: "spansk peseta",
                "displayName-count-one": "spansk peseta",
                "displayName-count-other": "spanska pesetas",
                symbol: "ESP",
                "symbol-alt-narrow": "ESP"
            },
            ETB: {
                displayName: "etiopisk birr",
                "displayName-count-one": "etiopisk birr",
                "displayName-count-other": "etiopiska birr",
                symbol: "ETB"
            },
            EUR: {
                displayName: "euro",
                "displayName-count-one": "euro",
                "displayName-count-other": "euro",
                symbol: "€",
                "symbol-alt-narrow": "€"
            },
            FIM: {
                displayName: "finsk mark",
                "displayName-count-one": "finsk mark",
                "displayName-count-other": "finska mark",
                symbol: "FIM"
            },
            FJD: {
                displayName: "Fijidollar",
                "displayName-count-one": "Fijidollar",
                "displayName-count-other": "Fijidollar",
                symbol: "FJD",
                "symbol-alt-narrow": "$"
            },
            FKP: {
                displayName: "Falklandspund",
                "displayName-count-one": "Falklandspund",
                "displayName-count-other": "Falklandspund",
                symbol: "FKP",
                "symbol-alt-narrow": "£"
            },
            FRF: {
                displayName: "fransk franc",
                "displayName-count-one": "fransk franc",
                "displayName-count-other": "franska franc",
                symbol: "FRF"
            },
            GBP: {
                displayName: "brittiskt pund",
                "displayName-count-one": "brittiskt pund",
                "displayName-count-other": "brittiska pund",
                symbol: "GBP",
                "symbol-alt-narrow": "£"
            },
            GEK: {
                displayName: "georgisk kupon larit",
                "displayName-count-one": "georgisk kupon larit",
                "displayName-count-other": "georgiska kupon larit",
                symbol: "GEK"
            },
            GEL: {
                displayName: "georgisk lari",
                "displayName-count-one": "georgisk lari",
                "displayName-count-other": "georgiska lari",
                symbol: "GEL",
                "symbol-alt-narrow": "₾"
            },
            GHC: {
                displayName: "ghanansk cedi (1979–2007)",
                "displayName-count-one": "ghanansk cedi (1979–2007)",
                "displayName-count-other": "ghananska cedi (1979–2007)",
                symbol: "GHC"
            },
            GHS: {
                displayName: "ghanansk cedi",
                "displayName-count-one": "ghanansk cedi",
                "displayName-count-other": "ghananska cedi",
                symbol: "GHS",
                "symbol-alt-narrow": "GH₵"
            },
            GIP: {
                displayName: "gibraltiskt pund",
                "displayName-count-one": "gibraltiskt pund",
                "displayName-count-other": "gibraltiska pund",
                symbol: "GIP",
                "symbol-alt-narrow": "£"
            },
            GMD: {
                displayName: "gambisk dalasi",
                "displayName-count-one": "gambisk dalasi",
                "displayName-count-other": "gambiska dalasi",
                symbol: "GMD"
            },
            GNF: {
                displayName: "guineansk franc",
                "displayName-count-one": "guineansk franc",
                "displayName-count-other": "guineanska franc",
                symbol: "GNF",
                "symbol-alt-narrow": "FG"
            },
            GNS: {
                displayName: "guineansk syli",
                "displayName-count-one": "guineansk syli",
                "displayName-count-other": "guineanska syli",
                symbol: "GNS"
            },
            GQE: {
                displayName: "ekvatorialguineansk ekwele",
                "displayName-count-one": "ekvatorialguineansk ekwele",
                "displayName-count-other": "ekvatorialguineanska ekweler",
                symbol: "GQE"
            },
            GRD: {
                displayName: "grekisk drachma",
                "displayName-count-one": "grekisk drachma",
                "displayName-count-other": "grekiska drachmer",
                symbol: "GRD"
            },
            GTQ: {
                displayName: "guatemalansk quetzal",
                "displayName-count-one": "guatemalansk quetzal",
                "displayName-count-other": "guatemalanska quetzal",
                symbol: "GTQ",
                "symbol-alt-narrow": "Q"
            },
            GWE: {
                displayName: "Portugisiska Guinea-escudo",
                "displayName-count-one": "Portugisiska Guinea-escudo",
                "displayName-count-other": "Portugisiska Guinea-escudos",
                symbol: "GWE"
            },
            GWP: {
                displayName: "Guinea-Bissau-peso",
                "displayName-count-one": "Guinea-Bissau-peso",
                "displayName-count-other": "Guinea-Bissau-pesos",
                symbol: "GWP"
            },
            GYD: {
                displayName: "Guyanadollar",
                "displayName-count-one": "Guyanadollar",
                "displayName-count-other": "Guyanadollar",
                symbol: "GYD",
                "symbol-alt-narrow": "$"
            },
            HKD: {
                displayName: "Hongkongdollar",
                "displayName-count-one": "Hongkongdollar",
                "displayName-count-other": "Hongkongdollar",
                symbol: "HKD",
                "symbol-alt-narrow": "$"
            },
            HNL: {
                displayName: "honduransk lempira",
                "displayName-count-one": "honduransk lempira",
                "displayName-count-other": "honduranska lempira",
                symbol: "HNL",
                "symbol-alt-narrow": "L"
            },
            HRD: {
                displayName: "kroatisk dinar",
                "displayName-count-one": "kroatisk dinar",
                "displayName-count-other": "kroatiska dinarer",
                symbol: "HRD"
            },
            HRK: {
                displayName: "kroatisk kuna",
                "displayName-count-one": "kroatisk kuna",
                "displayName-count-other": "kroatiska kunor",
                symbol: "HRK",
                "symbol-alt-narrow": "kn"
            },
            HTG: {
                displayName: "haitisk gourde",
                "displayName-count-one": "haitisk gourde",
                "displayName-count-other": "haitiska gourder",
                symbol: "HTG"
            },
            HUF: {
                displayName: "ungersk forint",
                "displayName-count-one": "ungersk forint",
                "displayName-count-other": "ungerska forinter",
                symbol: "HUF",
                "symbol-alt-narrow": "Ft"
            },
            IDR: {
                displayName: "indonesisk rupie",
                "displayName-count-one": "indonesisk rupie",
                "displayName-count-other": "indonesiska rupier",
                symbol: "IDR",
                "symbol-alt-narrow": "Rp"
            },
            IEP: {
                displayName: "irländskt pund",
                "displayName-count-one": "irländskt pund",
                "displayName-count-other": "irländska pund",
                symbol: "IE£"
            },
            ILP: {
                displayName: "israeliskt pund",
                "displayName-count-one": "israeliskt pund",
                "displayName-count-other": "israeliska pund",
                symbol: "ILP"
            },
            ILR: {
                displayName: "israelisk shekel (1980–1985)",
                "displayName-count-one": "israelisk shekel (1980–1985)",
                "displayName-count-other": "israeliska shekel (1980–1985)",
                symbol: "ILR"
            },
            ILS: {
                displayName: "israelisk ny shekel",
                "displayName-count-one": "israelisk ny shekel",
                "displayName-count-other": "israeliska nya shekel",
                symbol: "₪",
                "symbol-alt-narrow": "₪"
            },
            INR: {
                displayName: "indisk rupie",
                "displayName-count-one": "indisk rupie",
                "displayName-count-other": "indiska rupier",
                symbol: "INR",
                "symbol-alt-narrow": "₹"
            },
            IQD: {
                displayName: "irakisk dinar",
                "displayName-count-one": "irakisk dinar",
                "displayName-count-other": "irakiska dinarer",
                symbol: "IQD"
            },
            IRR: {
                displayName: "iransk rial",
                "displayName-count-one": "iransk rial",
                "displayName-count-other": "iranska rial",
                symbol: "IRR"
            },
            ISJ: {
                displayName: "isländsk gammal krona",
                "displayName-count-one": "isländsk gammal krona",
                "displayName-count-other": "isländska kronor (1874–1981)",
                symbol: "ISJ"
            },
            ISK: {
                displayName: "isländsk krona",
                "displayName-count-one": "isländsk krona",
                "displayName-count-other": "isländska kronor",
                symbol: "Ikr",
                "symbol-alt-narrow": "kr"
            },
            ITL: {
                displayName: "italiensk lire",
                "displayName-count-one": "italiensk lire",
                "displayName-count-other": "italienska lire",
                symbol: "ITL"
            },
            JMD: {
                displayName: "jamaicansk dollar",
                "displayName-count-one": "Jamaica-dollar",
                "displayName-count-other": "jamaicansk dollar",
                symbol: "JM$",
                "symbol-alt-narrow": "$"
            },
            JOD: {
                displayName: "jordansk dinar",
                "displayName-count-one": "jordansk dinar",
                "displayName-count-other": "jordanska dinarer",
                symbol: "JOD"
            },
            JPY: {
                displayName: "japansk yen",
                "displayName-count-one": "japansk yen",
                "displayName-count-other": "japanska yen",
                symbol: "JPY",
                "symbol-alt-narrow": "¥"
            },
            KES: {
                displayName: "kenyansk shilling",
                "displayName-count-one": "kenyansk shilling",
                "displayName-count-other": "kenyanska shilling",
                symbol: "KES"
            },
            KGS: {
                displayName: "kirgizisk som",
                "displayName-count-one": "kirgizisk som",
                "displayName-count-other": "kirgiziska somer",
                symbol: "KGS"
            },
            KHR: {
                displayName: "kambodjansk riel",
                "displayName-count-one": "kambodjansk riel",
                "displayName-count-other": "kambodjanska riel",
                symbol: "KHR",
                "symbol-alt-narrow": "៛"
            },
            KMF: {
                displayName: "komorisk franc",
                "displayName-count-one": "komorisk franc",
                "displayName-count-other": "komoriska franc",
                symbol: "KMF",
                "symbol-alt-narrow": "CF"
            },
            KPW: {
                displayName: "nordkoreansk won",
                "displayName-count-one": "nordkoreansk won",
                "displayName-count-other": "nordkoreanska won",
                symbol: "KPW",
                "symbol-alt-narrow": "₩"
            },
            KRH: {
                displayName: "sydkoreansk hwan (1953–1962)",
                "displayName-count-one": "sydkoreansk hwan (1953–1962)",
                "displayName-count-other": "sydkoreanska hwan (1953–1962)",
                symbol: "KRH"
            },
            KRO: {
                displayName: "sydkoreansk won (1945–1953)",
                "displayName-count-one": "sydkoreansk won (1945–1953)",
                "displayName-count-other": "sydkoreanska won (1945–1953)",
                symbol: "KRO"
            },
            KRW: {
                displayName: "sydkoreansk won",
                "displayName-count-one": "sydkoreansk won",
                "displayName-count-other": "sydkoreanska won",
                symbol: "KRW",
                "symbol-alt-narrow": "₩"
            },
            KWD: {
                displayName: "kuwaitisk dinar",
                "displayName-count-one": "kuwaitisk dinar",
                "displayName-count-other": "kuwaitiska dinarer",
                symbol: "KWD"
            },
            KYD: {
                displayName: "caymansk dollar",
                "displayName-count-one": "caymansk dollar",
                "displayName-count-other": "caymansk dollar",
                symbol: "KYD",
                "symbol-alt-narrow": "$"
            },
            KZT: {
                displayName: "kazakisk tenge",
                "displayName-count-one": "kazakisk tenge",
                "displayName-count-other": "kazakiska tenge",
                symbol: "KZT",
                "symbol-alt-narrow": "₸"
            },
            LAK: {
                displayName: "laotisk kip",
                "displayName-count-one": "laotisk kip",
                "displayName-count-other": "laotiska kip",
                symbol: "LAK",
                "symbol-alt-narrow": "₭"
            },
            LBP: {
                displayName: "libanesiskt pund",
                "displayName-count-one": "libanesiskt pund",
                "displayName-count-other": "libanesiska pund",
                symbol: "LBP",
                "symbol-alt-narrow": "L£"
            },
            LKR: {
                displayName: "srilankesisk rupie",
                "displayName-count-one": "srilankesisk rupie",
                "displayName-count-other": "srilankesiska rupier",
                symbol: "LKR",
                "symbol-alt-narrow": "Rs"
            },
            LRD: {
                displayName: "liberiansk dollar",
                "displayName-count-one": "liberiansk dollar",
                "displayName-count-other": "liberianska dollar",
                symbol: "LRD",
                "symbol-alt-narrow": "$"
            },
            LSL: {
                displayName: "lesothisk loti",
                "displayName-count-one": "lesothisk loti",
                "displayName-count-other": "lesothiska lotier",
                symbol: "LSL"
            },
            LTL: {
                displayName: "litauisk litas",
                "displayName-count-one": "litauisk litas",
                "displayName-count-other": "litauiska litai",
                symbol: "LTL",
                "symbol-alt-narrow": "Lt"
            },
            LTT: {
                displayName: "litauisk talonas",
                "displayName-count-one": "litauisk talonas",
                "displayName-count-other": "litauiska talonas",
                symbol: "LTT"
            },
            LUC: {
                displayName: "luxemburgsk franc (konvertibel)",
                "displayName-count-one": "luxemburgsk franc (konvertibel)",
                "displayName-count-other": "luxemburgska franc (konvertibla)",
                symbol: "LUC"
            },
            LUF: {
                displayName: "luxemburgsk franc",
                "displayName-count-one": "luxemburgsk franc",
                "displayName-count-other": "luxemburgska franc",
                symbol: "LUF"
            },
            LUL: {
                displayName: "luxemburgsk franc (finansiell)",
                "displayName-count-one": "luxemburgsk franc (finansiell)",
                "displayName-count-other": "luxemburgska franc (finansiella)",
                symbol: "LUL"
            },
            LVL: {
                displayName: "lettisk lats",
                "displayName-count-one": "lettisk lats",
                "displayName-count-other": "lettiska lati",
                symbol: "LVL",
                "symbol-alt-narrow": "Ls"
            },
            LVR: {
                displayName: "lettisk rubel",
                "displayName-count-one": "lettisk rubel",
                "displayName-count-other": "lettiska rubel",
                symbol: "LVR"
            },
            LYD: {
                displayName: "libysk dinar",
                "displayName-count-one": "libysk dinar",
                "displayName-count-other": "libyska dinarer",
                symbol: "LYD"
            },
            MAD: {
                displayName: "marockansk dirham",
                "displayName-count-one": "marockansk dirham",
                "displayName-count-other": "marockanska dirhamer",
                symbol: "MAD"
            },
            MAF: {
                displayName: "marockansk franc",
                "displayName-count-one": "marockansk franc",
                "displayName-count-other": "marockanska franc",
                symbol: "MAF"
            },
            MCF: {
                displayName: "monegaskisk franc (–2001)",
                "displayName-count-one": "monegaskisk franc (–2001)",
                "displayName-count-other": "monegaskiska franc (–2001)",
                symbol: "MCF"
            },
            MDC: {
                displayName: "moldavisk cupon (1992–1993)",
                "displayName-count-one": "moldavisk cupon (1992–1993)",
                "displayName-count-other": "moldaviska cupon (1992–1993)",
                symbol: "MDC"
            },
            MDL: {
                displayName: "moldavisk leu",
                "displayName-count-one": "moldavisk leu",
                "displayName-count-other": "moldaviska lei",
                symbol: "MDL"
            },
            MGA: {
                displayName: "madagaskisk ariary",
                "displayName-count-one": "madagaskisk ariary",
                "displayName-count-other": "madagaskiska ariary",
                symbol: "MGA",
                "symbol-alt-narrow": "Ar"
            },
            MGF: {
                displayName: "madagaskisk franc",
                "displayName-count-one": "madagaskisk franc",
                "displayName-count-other": "madagaskiska franc",
                symbol: "MGF"
            },
            MKD: {
                displayName: "makedonisk denar",
                "displayName-count-one": "makedonisk denar",
                "displayName-count-other": "makedoniska denarer",
                symbol: "MKD"
            },
            MKN: {
                displayName: "makedonisk denar (1992–1993)",
                "displayName-count-one": "makedonisk denar (1992–1993)",
                "displayName-count-other": "makedoniska denarer (1992–1993)",
                symbol: "MKN"
            },
            MLF: {
                displayName: "malisk franc",
                "displayName-count-one": "malisk franc",
                "displayName-count-other": "maliska franc",
                symbol: "MLF"
            },
            MMK: {
                displayName: "myanmarisk kyat",
                "displayName-count-one": "myanmarisk kyat",
                "displayName-count-other": "myanmariska kyat",
                symbol: "MMK",
                "symbol-alt-narrow": "K"
            },
            MNT: {
                displayName: "mongolisk tögrög",
                "displayName-count-one": "mongolisk tögrög",
                "displayName-count-other": "mongoliska tögrög",
                symbol: "MNT",
                "symbol-alt-narrow": "₮"
            },
            MOP: {
                displayName: "makanesisk pataca",
                "displayName-count-one": "makanesisk pataca",
                "displayName-count-other": "makanesiska pataca",
                symbol: "MOP"
            },
            MRO: {
                displayName: "mauretansk ouguiya (1973–2017)",
                "displayName-count-one": "mauretansk ouguiya (1973–2017)",
                "displayName-count-other": "mauretanska ouguiya (1973–2017)",
                symbol: "MRO"
            },
            MRU: {
                displayName: "mauretansk ouguiya",
                "displayName-count-one": "mauretansk ouguiya",
                "displayName-count-other": "mauretanska ouguiya",
                symbol: "MRU"
            },
            MTL: {
                displayName: "maltesisk lire",
                "displayName-count-one": "maltesisk lire",
                "displayName-count-other": "maltesiska lire",
                symbol: "MTL"
            },
            MTP: {
                displayName: "maltesiskt pund",
                "displayName-count-one": "maltesiskt pund",
                "displayName-count-other": "maltesiska pund",
                symbol: "MTP"
            },
            MUR: {
                displayName: "mauritisk rupie",
                "displayName-count-one": "mauritisk rupie",
                "displayName-count-other": "mauritiska rupier",
                symbol: "MUR",
                "symbol-alt-narrow": "Rs"
            },
            MVP: {
                displayName: "maldivisk rupie",
                "displayName-count-one": "maldivisk rupie",
                "displayName-count-other": "maldiviska rupier",
                symbol: "MVP"
            },
            MVR: {
                displayName: "maldivisk rufiyaa",
                "displayName-count-one": "maldivisk rufiyaa",
                "displayName-count-other": "maldiviska rufiyer",
                symbol: "MVR"
            },
            MWK: {
                displayName: "malawisk kwacha",
                "displayName-count-one": "malawisk kwacha",
                "displayName-count-other": "malawiska kwacha",
                symbol: "MWK"
            },
            MXN: {
                displayName: "mexikansk peso",
                "displayName-count-one": "mexikansk peso",
                "displayName-count-other": "mexikanska pesos",
                symbol: "MX$",
                "symbol-alt-narrow": "$"
            },
            MXP: {
                displayName: "mexikansk silverpeso (1861–1992)",
                "displayName-count-one": "mexikansk silverpeso (1861–1992)",
                "displayName-count-other": "mexikanska silverpesos (1861–1992)",
                symbol: "MXP"
            },
            MXV: {
                displayName: "mexikansk unidad de inversion",
                "displayName-count-one": "mexikansk unidad de inversion",
                "displayName-count-other": "mexikanska unidad de inversion",
                symbol: "MXV"
            },
            MYR: {
                displayName: "malaysisk ringgit",
                "displayName-count-one": "malaysisk ringgit",
                "displayName-count-other": "malaysiska ringgiter",
                symbol: "MYR",
                "symbol-alt-narrow": "RM"
            },
            MZE: {
                displayName: "moçambikisk escudo",
                "displayName-count-one": "moçambikisk escudo (1914–1980)",
                "displayName-count-other": "moçambikiska escudos",
                symbol: "MZE"
            },
            MZM: {
                displayName: "gammal moçambikisk metical",
                "displayName-count-one": "moçambikisk metical (1980–2006)",
                "displayName-count-other": "gammla moçambikiska metical",
                symbol: "MZM"
            },
            MZN: {
                displayName: "moçambikisk metical",
                "displayName-count-one": "moçambikisk metical",
                "displayName-count-other": "moçambikiska metical",
                symbol: "MZN"
            },
            NAD: {
                displayName: "namibisk dollar",
                "displayName-count-one": "namibisk dollar",
                "displayName-count-other": "namibiska dollar",
                symbol: "NAD",
                "symbol-alt-narrow": "$"
            },
            NGN: {
                displayName: "nigeriansk naira",
                "displayName-count-one": "nigeriansk naira",
                "displayName-count-other": "nigerianska naira",
                symbol: "NGN",
                "symbol-alt-narrow": "₦"
            },
            NIC: {
                displayName: "nicaraguansk córdoba (1998–1991)",
                "displayName-count-one": "nicaraguansk córdoba (1998–1991)",
                "displayName-count-other": "nicaraguanska córdobas (1988–1991)",
                symbol: "NIC"
            },
            NIO: {
                displayName: "nicaraguansk córdoba",
                "displayName-count-one": "nicaraguansk córdoba",
                "displayName-count-other": "nicaraguanska córdobas",
                symbol: "NIO",
                "symbol-alt-narrow": "C$"
            },
            NLG: {
                displayName: "nederländsk gulden",
                "displayName-count-one": "nederländsk gulden",
                "displayName-count-other": "nederländska gulden",
                symbol: "NLG"
            },
            NOK: {
                displayName: "norsk krona",
                "displayName-count-one": "norsk krona",
                "displayName-count-other": "norska kronor",
                symbol: "Nkr",
                "symbol-alt-narrow": "kr"
            },
            NPR: {
                displayName: "nepalesisk rupie",
                "displayName-count-one": "nepalesisk rupie",
                "displayName-count-other": "nepalesiska rupier",
                symbol: "NPR",
                "symbol-alt-narrow": "Rs"
            },
            NZD: {
                displayName: "nyzeeländsk dollar",
                "displayName-count-one": "nyzeeländsk dollar",
                "displayName-count-other": "nyzeeländska dollar",
                symbol: "NZD",
                "symbol-alt-narrow": "$"
            },
            OMR: {
                displayName: "omansk rial",
                "displayName-count-one": "omansk rial",
                "displayName-count-other": "omanska rial",
                symbol: "OMR"
            },
            PAB: {
                displayName: "panamansk balboa",
                "displayName-count-one": "panamansk balboa",
                "displayName-count-other": "panamanska balboa",
                symbol: "PAB"
            },
            PEI: {
                displayName: "peruansk inti",
                "displayName-count-one": "peruansk inti",
                "displayName-count-other": "peruanska intier",
                symbol: "PEI"
            },
            PEN: {
                displayName: "peruansk sol",
                "displayName-count-one": "peruansk sol",
                "displayName-count-other": "peruanska sol",
                symbol: "PEN"
            },
            PES: {
                displayName: "peruansk sol (1863–1965)",
                "displayName-count-one": "peruansk sol (1863–1965)",
                "displayName-count-other": "peruanska sol (1863–1965)",
                symbol: "PES"
            },
            PGK: {
                displayName: "papuansk kina",
                "displayName-count-one": "papuansk kina",
                "displayName-count-other": "papuanska kinor",
                symbol: "PGK"
            },
            PHP: {
                displayName: "filippinsk peso",
                "displayName-count-one": "filippinsk peso",
                "displayName-count-other": "filippinska pesos",
                symbol: "PHP",
                "symbol-alt-narrow": "₱"
            },
            PKR: {
                displayName: "pakistansk rupie",
                "displayName-count-one": "pakistansk rupie",
                "displayName-count-other": "pakistanska rupier",
                symbol: "PKR",
                "symbol-alt-narrow": "Rs"
            },
            PLN: {
                displayName: "polsk zloty",
                "displayName-count-one": "polsk zloty",
                "displayName-count-other": "polska zloty",
                symbol: "PLN",
                "symbol-alt-narrow": "zł"
            },
            PLZ: {
                displayName: "polsk zloty (1950–1995)",
                "displayName-count-one": "polsk zloty (1950–1995)",
                "displayName-count-other": "polska zloty (1950–1995)",
                symbol: "PLZ"
            },
            PTE: {
                displayName: "portugisisk escudo",
                "displayName-count-one": "portugisisk escudo",
                "displayName-count-other": "portugisiska escudos",
                symbol: "PTE"
            },
            PYG: {
                displayName: "paraguayansk guarani",
                "displayName-count-one": "paraguayansk guarani",
                "displayName-count-other": "paraguayska guarani",
                symbol: "PYG",
                "symbol-alt-narrow": "₲"
            },
            QAR: {
                displayName: "qatarisk rial",
                "displayName-count-one": "qatarisk rial",
                "displayName-count-other": "qatariska rial",
                symbol: "QAR"
            },
            RHD: {
                displayName: "rhodesisk dollar",
                "displayName-count-one": "rhodesisk dollar",
                "displayName-count-other": "rhodesiska dollar",
                symbol: "RHD"
            },
            ROL: {
                displayName: "rumänsk leu (1952–2005)",
                "displayName-count-one": "rumänsk leu (1952–2005)",
                "displayName-count-other": "rumänska leu (1952–2005)",
                symbol: "ROL"
            },
            RON: {
                displayName: "rumänsk leu",
                "displayName-count-one": "rumänsk leu",
                "displayName-count-other": "rumänska lei",
                symbol: "RON",
                "symbol-alt-narrow": "L"
            },
            RSD: {
                displayName: "serbisk dinar",
                "displayName-count-one": "serbisk dinar",
                "displayName-count-other": "serbiska dinarer",
                symbol: "RSD"
            },
            RUB: {
                displayName: "rysk rubel",
                "displayName-count-one": "rysk rubel",
                "displayName-count-other": "ryska rubel",
                symbol: "RUB",
                "symbol-alt-narrow": "₽"
            },
            RUR: {
                displayName: "rysk rubel (1991–1998)",
                "displayName-count-one": "rysk rubel (1991–1998)",
                "displayName-count-other": "ryska rubel (1991–1998)",
                symbol: "RUR"
            },
            RWF: {
                displayName: "rwandisk franc",
                "displayName-count-one": "rwandisk franc",
                "displayName-count-other": "rwandiska franc",
                symbol: "RWF",
                "symbol-alt-narrow": "RF"
            },
            SAR: {
                displayName: "saudisk riyal",
                "displayName-count-one": "saudisk riyal",
                "displayName-count-other": "saudiska riyal",
                symbol: "SAR"
            },
            SBD: {
                displayName: "Salomondollar",
                "displayName-count-one": "Salomondollar",
                "displayName-count-other": "Salomondollar",
                symbol: "SBD",
                "symbol-alt-narrow": "$"
            },
            SCR: {
                displayName: "seychellisk rupie",
                "displayName-count-one": "seychellisk rupie",
                "displayName-count-other": "seychelliska rupier",
                symbol: "SCR"
            },
            SDD: {
                displayName: "sudansk dinar (1992–2007)",
                "displayName-count-one": "sudansk dinar (1992–2007)",
                "displayName-count-other": "sudanska dinarer (1992–2007)",
                symbol: "SDD"
            },
            SDG: {
                displayName: "sudanesiskt pund",
                "displayName-count-one": "sudanesiskt pund",
                "displayName-count-other": "sudanesiska pund",
                symbol: "SDG"
            },
            SDP: {
                displayName: "sudanskt pund (1916–1992)",
                "displayName-count-one": "sudanskt pund (1916–1992)",
                "displayName-count-other": "sudanska pund (1916–1992)",
                symbol: "SDP"
            },
            SEK: {
                displayName: "svensk krona",
                "displayName-count-one": "svensk krona",
                "displayName-count-other": "svenska kronor",
                symbol: "kr",
                "symbol-alt-narrow": "kr"
            },
            SGD: {
                displayName: "singaporiansk dollar",
                "displayName-count-one": "singaporiansk dollar",
                "displayName-count-other": "singaporianska dollar",
                symbol: "SGD",
                "symbol-alt-narrow": "$"
            },
            SHP: {
                displayName: "sankthelenskt pund",
                "displayName-count-one": "sankthelenskt pund",
                "displayName-count-other": "sankthelenskt pund",
                symbol: "SHP",
                "symbol-alt-narrow": "£"
            },
            SIT: {
                displayName: "slovensk tolar",
                "displayName-count-one": "slovensk tolar",
                "displayName-count-other": "slovenska tolar",
                symbol: "SIT"
            },
            SKK: {
                displayName: "slovakisk koruna",
                "displayName-count-one": "slovakisk krona",
                "displayName-count-other": "slovakiska korunor",
                symbol: "SKK"
            },
            SLE: {
                displayName: "SLE",
                symbol: "SLE"
            },
            SLL: {
                displayName: "sierraleonsk leone",
                "displayName-count-one": "sierraleonsk leone",
                "displayName-count-other": "sierraleonska leoner",
                symbol: "SLL"
            },
            SOS: {
                displayName: "somalisk shilling",
                "displayName-count-one": "somalisk shilling",
                "displayName-count-other": "somaliska shilling",
                symbol: "SOS"
            },
            SRD: {
                displayName: "surinamesisk dollar",
                "displayName-count-one": "surinamesisk dollar",
                "displayName-count-other": "surinamesiska dollar",
                symbol: "SRD",
                "symbol-alt-narrow": "$"
            },
            SRG: {
                displayName: "surinamesisk gulden",
                "displayName-count-one": "surinamesisk gulden",
                "displayName-count-other": "surinamesiska gulden",
                symbol: "SRG"
            },
            SSP: {
                displayName: "sydsudanesiskt pund",
                "displayName-count-one": "sydsudanesiskt pund",
                "displayName-count-other": "sydsudanesiska pund",
                symbol: "SSP",
                "symbol-alt-narrow": "£"
            },
            STD: {
                displayName: "saotomeansk dobra (1977–2017)",
                "displayName-count-one": "saotomeansk dobra (1977–2017)",
                "displayName-count-other": "saotomeanska dobra (1977–2017)",
                symbol: "STD"
            },
            STN: {
                displayName: "saotomeansk dobra",
                "displayName-count-one": "saotomeansk dobra",
                "displayName-count-other": "saotomeanska dobra",
                symbol: "STN",
                "symbol-alt-narrow": "Db"
            },
            SUR: {
                displayName: "sovjetisk rubel",
                "displayName-count-one": "sovjetisk rubel",
                "displayName-count-other": "sovjetiska rubler",
                symbol: "SUR"
            },
            SVC: {
                displayName: "salvadoransk colón",
                "displayName-count-one": "salvadoransk colón",
                "displayName-count-other": "salvadoranska colón",
                symbol: "SVC"
            },
            SYP: {
                displayName: "syriskt pund",
                "displayName-count-one": "syriskt pund",
                "displayName-count-other": "syriska pund",
                symbol: "SYP",
                "symbol-alt-narrow": "£"
            },
            SZL: {
                displayName: "swaziländsk lilangeni",
                "displayName-count-one": "swaziländsk lilangeni",
                "displayName-count-other": "swaziländska lilangeni",
                symbol: "SZL"
            },
            THB: {
                displayName: "thailändsk baht",
                "displayName-count-one": "thailändsk baht",
                "displayName-count-other": "thailändska baht",
                symbol: "THB",
                "symbol-alt-narrow": "฿"
            },
            TJR: {
                displayName: "tadzjikisk rubel",
                "displayName-count-one": "tadzjikisk rubel",
                "displayName-count-other": "tadzjikiska rubler",
                symbol: "TJR"
            },
            TJS: {
                displayName: "tadzjikisk somoni",
                "displayName-count-one": "tadzjikisk somoni",
                "displayName-count-other": "tadzjikiska somoni",
                symbol: "TJS"
            },
            TMM: {
                displayName: "turkmenistansk manat (1993–2009)",
                "displayName-count-one": "turkmenistansk manat (1993–2009)",
                "displayName-count-other": "turkmenistanska manat (1993–2009)",
                symbol: "TMM"
            },
            TMT: {
                displayName: "turkmenistansk manat",
                "displayName-count-one": "turkmenistansk manat",
                "displayName-count-other": "turkmenistanska manat",
                symbol: "TMT"
            },
            TND: {
                displayName: "tunisisk dinar",
                "displayName-count-one": "tunisisk dinar",
                "displayName-count-other": "tunisiska dinarer",
                symbol: "TND"
            },
            TOP: {
                displayName: "tongansk paʻanga",
                "displayName-count-one": "tongansk paʻanga",
                "displayName-count-other": "tonganska paʻanga",
                symbol: "TOP",
                "symbol-alt-narrow": "T$"
            },
            TPE: {
                displayName: "östtimoresisk escudo",
                "displayName-count-one": "östtimoresisk escudo",
                "displayName-count-other": "östtimoresiska escudos",
                symbol: "TPE"
            },
            TRL: {
                displayName: "turkisk lire (1922–2005)",
                "displayName-count-one": "turkisk lire (1922–2005)",
                "displayName-count-other": "turkiska lire (1922–2005)",
                symbol: "TRL"
            },
            TRY: {
                displayName: "turkisk lira",
                "displayName-count-one": "turkisk lira",
                "displayName-count-other": "turkiska lira",
                symbol: "TRY",
                "symbol-alt-narrow": "₺",
                "symbol-alt-variant": "TL"
            },
            TTD: {
                displayName: "Trinidaddollar",
                "displayName-count-one": "Trinidaddollar",
                "displayName-count-other": "Trinidaddollar",
                symbol: "TTD",
                "symbol-alt-narrow": "$"
            },
            TWD: {
                displayName: "taiwanesisk dollar",
                "displayName-count-one": "taiwanesisk dollar",
                "displayName-count-other": "taiwanesisk dollar",
                symbol: "TWD",
                "symbol-alt-narrow": "NT$"
            },
            TZS: {
                displayName: "tanzanisk shilling",
                "displayName-count-one": "tanzanisk shilling",
                "displayName-count-other": "tanzaniska shilling",
                symbol: "TZS"
            },
            UAH: {
                displayName: "ukrainsk hryvnia",
                "displayName-count-one": "ukrainsk hryvnia",
                "displayName-count-other": "ukrainska hryvnia",
                symbol: "UAH",
                "symbol-alt-narrow": "₴"
            },
            UAK: {
                displayName: "ukrainsk karbovanetz",
                "displayName-count-one": "ukrainsk karbovanetz (1992–1996)",
                "displayName-count-other": "ukrainska karbovanetz (1992–1996)",
                symbol: "UAK"
            },
            UGS: {
                displayName: "ugandisk shilling (1966–1987)",
                "displayName-count-one": "ugandisk shilling (1966–1987)",
                "displayName-count-other": "ugandiska shilling (1966–1987)",
                symbol: "UGS"
            },
            UGX: {
                displayName: "ugandisk shilling",
                "displayName-count-one": "ugandisk shilling",
                "displayName-count-other": "ugandiska shilling",
                symbol: "UGX"
            },
            USD: {
                displayName: "amerikansk dollar",
                "displayName-count-one": "amerikansk dollar",
                "displayName-count-other": "amerikansk dollar",
                symbol: "US$",
                "symbol-alt-narrow": "$"
            },
            USN: {
                displayName: "US-dollar (nästa dag)",
                "displayName-count-one": "US-dollar (nästa dag)",
                "displayName-count-other": "US-dollar (nästa dag)",
                symbol: "USN"
            },
            USS: {
                displayName: "US-dollar (samma dag)",
                "displayName-count-one": "US-dollar (samma dag)",
                "displayName-count-other": "US-dollar (samma dag)",
                symbol: "USS"
            },
            UYI: {
                displayName: "uruguayansk peso en unidades indexadas",
                "displayName-count-one": "uruguayansk peso en unidades indexadas",
                "displayName-count-other": "uruguayanska pesos en unidades indexadas",
                symbol: "UYI"
            },
            UYP: {
                displayName: "uruguayansk peso (1975–1993)",
                "displayName-count-one": "uruguayansk peso (1975–1993)",
                "displayName-count-other": "uruguayanska pesos (1975–1993)",
                symbol: "UYP"
            },
            UYU: {
                displayName: "uruguayansk peso",
                "displayName-count-one": "uruguayansk peso",
                "displayName-count-other": "uruguayanska pesos",
                symbol: "UYU",
                "symbol-alt-narrow": "$"
            },
            UYW: {
                displayName: "uruguayansk indexenhet för nominell lön",
                "displayName-count-one": "uruguayansk indexenhet för nominell lön",
                "displayName-count-other": "uruguayansk indexenhet för nominell lön",
                symbol: "UYW"
            },
            UZS: {
                displayName: "uzbekisk sum",
                "displayName-count-one": "uzbekisk sum",
                "displayName-count-other": "uzbekiska sum",
                symbol: "UZS"
            },
            VEB: {
                displayName: "venezuelansk bolivar (1871–2008)",
                "displayName-count-one": "venezuelansk bolivar (1871–2008)",
                "displayName-count-other": "venezuelanska bolivar (1871–2008)",
                symbol: "VEB"
            },
            VED: {
                displayName: "VED",
                symbol: "VED"
            },
            VEF: {
                displayName: "venezuelansk bolívar (2008–2018)",
                "displayName-count-one": "venezuelansk bolívar (2008–2018)",
                "displayName-count-other": "venezuelanska bolívar (2008–2018)",
                symbol: "VEF",
                "symbol-alt-narrow": "Bs"
            },
            VES: {
                displayName: "venezuelansk bolívar",
                "displayName-count-one": "venezuelansk bolívar",
                "displayName-count-other": "venezuelanska bolívar",
                symbol: "VES"
            },
            VND: {
                displayName: "vietnamesisk dong",
                "displayName-count-one": "vietnamesisk dong",
                "displayName-count-other": "vietnamesiska dong",
                symbol: "VND",
                "symbol-alt-narrow": "₫"
            },
            VNN: {
                displayName: "vietnamesisk dong (1978–1985)",
                "displayName-count-one": "vietnamesisk dong (1978–1985)",
                "displayName-count-other": "vietnamesiska dong (1978–1985)",
                symbol: "VNN"
            },
            VUV: {
                displayName: "vanuatisk vatu",
                "displayName-count-one": "vanuatisk vatu",
                "displayName-count-other": "vanuatiska vatu",
                symbol: "VUV"
            },
            WST: {
                displayName: "västsamoansk tala",
                "displayName-count-one": "västsamoansk tala",
                "displayName-count-other": "västsamoanska tala",
                symbol: "WST"
            },
            XAF: {
                displayName: "centralafrikansk franc",
                "displayName-count-one": "centralafrikansk franc",
                "displayName-count-other": "centralafrikanska franc",
                symbol: "FCFA"
            },
            XAG: {
                displayName: "silver",
                "displayName-count-one": "uns silver",
                "displayName-count-other": "silveruns",
                symbol: "XAG"
            },
            XAU: {
                displayName: "guld",
                "displayName-count-one": "uns guld",
                "displayName-count-other": "gulduns",
                symbol: "XAU"
            },
            XBA: {
                displayName: "europeisk kompositenhet",
                "displayName-count-one": "europeisk kompositenhet",
                "displayName-count-other": "europeiska kompositenheter",
                symbol: "XBA"
            },
            XBB: {
                displayName: "europeisk monetär enhet",
                "displayName-count-one": "europeisk monetär enhet",
                "displayName-count-other": "europeiska monetära enheter",
                symbol: "XBB"
            },
            XBC: {
                displayName: "europeisk kontoenhet (XBC)",
                "displayName-count-one": "europeisk kontoenhet (XBC)",
                "displayName-count-other": "europeiska kontoenheter (XBC)",
                symbol: "XBC"
            },
            XBD: {
                displayName: "europeisk kontoenhet (XBD)",
                "displayName-count-one": "europeisk kontoenhet (XBD)",
                "displayName-count-other": "europeiska kontoenheter (XBD)",
                symbol: "XBD"
            },
            XCD: {
                displayName: "östkaribisk dollar",
                "displayName-count-one": "östkaribisk dollar",
                "displayName-count-other": "östkaribiska dollar",
                symbol: "EC$",
                "symbol-alt-narrow": "$"
            },
            XDR: {
                displayName: "IMF särskild dragningsrätt",
                "displayName-count-one": "IMF särskild dragningsrätt",
                "displayName-count-other": "IMF särskilda dragningsrätter",
                symbol: "XDR"
            },
            XEU: {
                displayName: "europeisk valutaenhet",
                "displayName-count-one": "europeisk valutaenhet",
                "displayName-count-other": "europeiska valutaenheter",
                symbol: "XEU"
            },
            XFO: {
                displayName: "fransk guldfranc",
                "displayName-count-one": "fransk guldfranc",
                "displayName-count-other": "franska guldfranc",
                symbol: "XFO"
            },
            XFU: {
                displayName: "internationella järnvägsunionens franc",
                "displayName-count-one": "internationella järnvägsunionens franc",
                "displayName-count-other": "internationella järnvägsunionens franc",
                symbol: "XFU"
            },
            XOF: {
                displayName: "västafrikansk franc",
                "displayName-count-one": "västafrikansk franc",
                "displayName-count-other": "västafrikanska franc",
                symbol: "F CFA"
            },
            XPD: {
                displayName: "palladium",
                "displayName-count-one": "uns palladium",
                "displayName-count-other": "palladium",
                symbol: "XPD"
            },
            XPF: {
                displayName: "CFP-franc",
                "displayName-count-one": "CFP-franc",
                "displayName-count-other": "CFP-franc",
                symbol: "CFPF"
            },
            XPT: {
                displayName: "platina",
                "displayName-count-one": "uns platina",
                "displayName-count-other": "platina",
                symbol: "XPT"
            },
            XRE: {
                displayName: "RINET-fond",
                "displayName-count-one": "RINET-fond",
                "displayName-count-other": "RINET-fond",
                symbol: "XRE"
            },
            XSU: {
                displayName: "latinamerikansk sucre",
                "displayName-count-one": "latinamerikansk sucre",
                "displayName-count-other": "latinamerikanska sucre",
                symbol: "XSU"
            },
            XTS: {
                displayName: "testvalutaenhet",
                "displayName-count-one": "testvalutaenhet",
                "displayName-count-other": "testvalutaenheter",
                symbol: "XTS"
            },
            XUA: {
                displayName: "afrikansk kontoenhet",
                "displayName-count-one": "afrikansk kontoenhet",
                "displayName-count-other": "afrikanska kontoenheter",
                symbol: "XUA"
            },
            XXX: {
                displayName: "okänd valuta",
                "displayName-count-one": "(okänd valutaenhet)",
                "displayName-count-other": "(okända valutaenheter)",
                symbol: "¤"
            },
            YDD: {
                displayName: "jemenitisk dinar",
                "displayName-count-one": "jemenitisk dinar",
                "displayName-count-other": "jemenitiska dinarer",
                symbol: "YDD"
            },
            YER: {
                displayName: "jemenitisk rial",
                "displayName-count-one": "jemenitisk rial",
                "displayName-count-other": "jemenitiska rial",
                symbol: "YER"
            },
            YUD: {
                displayName: "jugoslavisk dinar (1966–1990)",
                "displayName-count-one": "jugoslavisk dinar (1966–1990)",
                "displayName-count-other": "jugoslaviska dinarer (1966–1990)",
                symbol: "YUD"
            },
            YUM: {
                displayName: "jugoslavisk dinar (1994–2002)",
                "displayName-count-one": "jugoslavisk dinar (1994–2002)",
                "displayName-count-other": "jugoslaviska dinarer (1994–2002)",
                symbol: "YUM"
            },
            YUN: {
                displayName: "jugoslavisk dinar (1990–1992)",
                "displayName-count-one": "jugoslavisk dinar (1990–1992)",
                "displayName-count-other": "jugoslaviska dinarer (1990–1992)",
                symbol: "YUN"
            },
            YUR: {
                displayName: "jugoslavisk dinar (1992–1993)",
                "displayName-count-one": "jugoslavisk dinar (1992–1993)",
                "displayName-count-other": "jugoslaviska dinarer (1992–1993)",
                symbol: "YUR"
            },
            ZAL: {
                displayName: "sydafrikansk rand (finansiell)",
                "displayName-count-one": "sydafrikansk rand (finansiell)",
                "displayName-count-other": "sydafrikanska rand (finansiella)",
                symbol: "ZAL"
            },
            ZAR: {
                displayName: "sydafrikansk rand",
                "displayName-count-one": "sydafrikansk rand",
                "displayName-count-other": "sydafrikanska rand",
                symbol: "ZAR",
                "symbol-alt-narrow": "R"
            },
            ZMK: {
                displayName: "zambisk kwacha (1968–2012)",
                "displayName-count-one": "zambisk kwacha (1968–2012)",
                "displayName-count-other": "zambiska kwacha (1968–2012)",
                symbol: "ZMK"
            },
            ZMW: {
                displayName: "zambisk kwacha",
                "displayName-count-one": "zambisk kwacha",
                "displayName-count-other": "zambiska kwacha",
                symbol: "ZMW",
                "symbol-alt-narrow": "ZK"
            },
            ZRN: {
                displayName: "zairisk ny zaire",
                "displayName-count-one": "zaïrisk ny zaïre",
                "displayName-count-other": "zaïriska nya zaïre",
                symbol: "ZRN"
            },
            ZRZ: {
                displayName: "zairisk zaire",
                "displayName-count-one": "zaïrisk zaïre",
                "displayName-count-other": "zaïriska zaïre",
                symbol: "ZRZ"
            },
            ZWD: {
                displayName: "Zimbabwe-dollar",
                "displayName-count-one": "Zimbabwe-dollar",
                "displayName-count-other": "Zimbabwe-dollar",
                symbol: "ZWD"
            },
            ZWL: {
                displayName: "Zimbabwe-dollar (2009)",
                "displayName-count-one": "Zimbabwe-dollar (2009)",
                "displayName-count-other": "Zimbabwe-dollar (2009)",
                symbol: "ZWL"
            },
            ZWR: {
                displayName: "Zimbabwe-dollar (2008)",
                "displayName-count-one": "Zimbabwe-dollar (2008)",
                "displayName-count-other": "Zimbabwe-dollar (2008)",
                symbol: "ZWR"
            }
        },
        localeCurrency: "EUR"
    },
    calendar: {
        patterns: {
            d: "y-MM-dd",
            D: "EEEE d MMMM y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE d MMMM y HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h.mm B",
                Bhms: "h.mm.ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h.mm B",
                EBhms: "E h.mm.ss B",
                Ed: "E d",
                Ehm: "E h.mm a",
                EHm: "E HH.mm",
                Ehms: "E h.mm.ss a",
                EHms: "E HH.mm.ss",
                Gy: "y G",
                GyMd: "y-MM-dd GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "d MMM y G",
                GyMMMEd: "E d MMM y G",
                h: "h a",
                H: "HH",
                hm: "h.mm a",
                Hm: "HH.mm",
                hms: "h.mm.ss a",
                Hms: "HH.mm.ss",
                hmsv: "h.mm.ss a v",
                Hmsv: "HH.mm.ss v",
                hmv: "h.mm a v",
                Hmv: "HH.mm v",
                M: "L",
                Md: "d.M",
                MEd: "E d.M",
                MMd: "d.M",
                MMdd: "dd.MM",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E d MMM",
                MMMMd: "d MMMM",
                MMMMEd: "E d MMMM",
                "MMMMW-count-one": "'vecka' W 'i' MMMM",
                "MMMMW-count-other": "'vecka' W 'i' MMMM",
                ms: "mm.ss",
                y: "y",
                yM: "y-MM",
                yMd: "y-MM-dd",
                yMEd: "E, y-MM-dd",
                yMM: "y-MM",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E d MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "'vecka' w, Y",
                "yw-count-other": "'vecka' w, Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            "full-alt-variant": "'kl'. HH.mm.ss zzzz",
            long: "HH:mm:ss z",
            "long-alt-variant": "HH.mm.ss z",
            medium: "HH:mm:ss",
            "medium-alt-variant": "HH.mm.ss",
            short: "HH:mm",
            "short-alt-variant": "HH.mm"
        },
        dateFormats: {
            full: "EEEE d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "y-MM-dd"
        },
        days: {
            format: {
                abbreviated: [
                    "sön",
                    "mån",
                    "tis",
                    "ons",
                    "tors",
                    "fre",
                    "lör"
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "O",
                    "T",
                    "F",
                    "L"
                ],
                short: [
                    "sö",
                    "må",
                    "ti",
                    "on",
                    "to",
                    "fr",
                    "lö"
                ],
                wide: [
                    "söndag",
                    "måndag",
                    "tisdag",
                    "onsdag",
                    "torsdag",
                    "fredag",
                    "lördag"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "sön",
                    "mån",
                    "tis",
                    "ons",
                    "tors",
                    "fre",
                    "lör"
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "O",
                    "T",
                    "F",
                    "L"
                ],
                short: [
                    "sö",
                    "må",
                    "ti",
                    "on",
                    "to",
                    "fr",
                    "lö"
                ],
                wide: [
                    "söndag",
                    "måndag",
                    "tisdag",
                    "onsdag",
                    "torsdag",
                    "fredag",
                    "lördag"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "jan.",
                    "feb.",
                    "mars",
                    "apr.",
                    "maj",
                    "juni",
                    "juli",
                    "aug.",
                    "sep.",
                    "okt.",
                    "nov.",
                    "dec."
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "januari",
                    "februari",
                    "mars",
                    "april",
                    "maj",
                    "juni",
                    "juli",
                    "augusti",
                    "september",
                    "oktober",
                    "november",
                    "december"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "jan.",
                    "feb.",
                    "mars",
                    "apr.",
                    "maj",
                    "juni",
                    "juli",
                    "aug.",
                    "sep.",
                    "okt.",
                    "nov.",
                    "dec."
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "januari",
                    "februari",
                    "mars",
                    "april",
                    "maj",
                    "juni",
                    "juli",
                    "augusti",
                    "september",
                    "oktober",
                    "november",
                    "december"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1:a kvartalet",
                    "2:a kvartalet",
                    "3:e kvartalet",
                    "4:e kvartalet"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1:a kvartalet",
                    "2:a kvartalet",
                    "3:e kvartalet",
                    "4:e kvartalet"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "midnatt",
                    am: "fm",
                    pm: "em",
                    morning1: "på morg.",
                    morning2: "på förm.",
                    afternoon1: "på efterm.",
                    evening1: "på kvällen",
                    night1: "på natten"
                },
                narrow: {
                    midnight: "midn.",
                    am: "fm",
                    pm: "em",
                    morning1: "på morg.",
                    morning2: "på förm.",
                    afternoon1: "på efterm.",
                    evening1: "på kvällen",
                    night1: "på natten"
                },
                wide: {
                    midnight: "midnatt",
                    am: "fm",
                    pm: "em",
                    morning1: "på morgonen",
                    morning2: "på förmiddagen",
                    afternoon1: "på eftermiddagen",
                    evening1: "på kvällen",
                    night1: "på natten"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "midnatt",
                    am: "f.m.",
                    pm: "e.m.",
                    morning1: "morgon",
                    morning2: "förm.",
                    afternoon1: "efterm.",
                    evening1: "kväll",
                    night1: "natt"
                },
                narrow: {
                    midnight: "midn.",
                    am: "fm",
                    pm: "em",
                    morning1: "morg.",
                    morning2: "förm.",
                    afternoon1: "efterm.",
                    evening1: "kväll",
                    night1: "natt"
                },
                wide: {
                    midnight: "midnatt",
                    am: "förmiddag",
                    pm: "eftermiddag",
                    morning1: "morgon",
                    morning2: "förmiddag",
                    afternoon1: "eftermiddag",
                    evening1: "kväll",
                    night1: "natt"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "före Kristus",
                    "1": "efter Kristus",
                    "0-alt-variant": "före västerländsk tideräkning",
                    "1-alt-variant": "västerländsk tideräkning"
                },
                abbreviated: {
                    "0": "f.Kr.",
                    "1": "e.Kr.",
                    "0-alt-variant": "f.v.t.",
                    "1-alt-variant": "v.t."
                },
                narrow: {
                    "0": "f.Kr.",
                    "1": "e.Kr.",
                    "0-alt-variant": "f.v.t.",
                    "1-alt-variant": "v.t."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "era",
                short: "era",
                narrow: "era"
            },
            year: {
                wide: "år",
                short: "år",
                narrow: "år"
            },
            quarter: {
                wide: "kvartal",
                short: "kv.",
                narrow: "kv."
            },
            month: {
                wide: "månad",
                short: "m",
                narrow: "mån"
            },
            week: {
                wide: "vecka",
                short: "v",
                narrow: "v"
            },
            weekOfMonth: {
                wide: "vecka i månaden",
                short: "vk. i mån.",
                narrow: "vk.i mån."
            },
            day: {
                wide: "dag",
                short: "dag",
                narrow: "dag"
            },
            dayOfYear: {
                wide: "dag under året",
                short: "dag under året",
                narrow: "dag under året"
            },
            weekday: {
                wide: "veckodag",
                short: "veckodag",
                narrow: "veckodag"
            },
            weekdayOfMonth: {
                wide: "veckodag i månad",
                short: "veckodag i mån.",
                narrow: "veckodag i mån."
            },
            dayperiod: {
                short: "fm/em",
                wide: "fm/em",
                narrow: "fm/em"
            },
            hour: {
                wide: "timme",
                short: "tim",
                narrow: "h"
            },
            minute: {
                wide: "minut",
                short: "min",
                narrow: "m"
            },
            second: {
                wide: "sekund",
                short: "sek",
                narrow: "s"
            },
            zone: {
                wide: "tidszon",
                short: "tidszon",
                narrow: "tidszon"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "millisekund"
            }
        }
    },
    firstDay: 1,
    weekendRange: {
        start: 6,
        end: 0
    },
    likelySubtags: {
        sv: "sv-Latn-SE"
    }
});

