/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "sv",
    likelySubtags: {
        sv: "sv-Latn-SE"
    },
    identity: {
        language: "sv"
    },
    territory: "SE",
    calendar: {
        patterns: {
            d: "y-MM-dd",
            D: "EEEE d MMMM y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE d MMMM y HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "y-MM-dd GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "d MMM y G",
                GyMMMEd: "E d MMM y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E d/M",
                MMd: "d/M",
                MMdd: "dd/MM",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E d MMM",
                MMMMd: "d MMMM",
                MMMMEd: "E d MMMM",
                "MMMMW-count-one": "'vecka' W 'i' MMMM",
                "MMMMW-count-other": "'vecka' W 'i' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "y-MM",
                yMd: "y-MM-dd",
                yMEd: "E, y-MM-dd",
                yMM: "y-MM",
                yMMM: "MMM y",
                yMMMd: "d MMM y",
                yMMMEd: "E d MMM y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "'vecka' w, Y",
                "yw-count-other": "'vecka' w, Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            "full-alt-variant": "'kl'. HH.mm.ss zzzz",
            long: "HH:mm:ss z",
            "long-alt-variant": "HH.mm.ss z",
            medium: "HH:mm:ss",
            "medium-alt-variant": "HH.mm.ss",
            short: "HH:mm",
            "short-alt-variant": "HH.mm"
        },
        dateFormats: {
            full: "EEEE d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "y-MM-dd"
        },
        days: {
            format: {
                abbreviated: [
                    "sön",
                    "mån",
                    "tis",
                    "ons",
                    "tors",
                    "fre",
                    "lör"
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "O",
                    "T",
                    "F",
                    "L"
                ],
                short: [
                    "sö",
                    "må",
                    "ti",
                    "on",
                    "to",
                    "fr",
                    "lö"
                ],
                wide: [
                    "söndag",
                    "måndag",
                    "tisdag",
                    "onsdag",
                    "torsdag",
                    "fredag",
                    "lördag"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "sön",
                    "mån",
                    "tis",
                    "ons",
                    "tors",
                    "fre",
                    "lör"
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "O",
                    "T",
                    "F",
                    "L"
                ],
                short: [
                    "sö",
                    "må",
                    "ti",
                    "on",
                    "to",
                    "fr",
                    "lö"
                ],
                wide: [
                    "söndag",
                    "måndag",
                    "tisdag",
                    "onsdag",
                    "torsdag",
                    "fredag",
                    "lördag"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "jan.",
                    "feb.",
                    "mars",
                    "apr.",
                    "maj",
                    "juni",
                    "juli",
                    "aug.",
                    "sep.",
                    "okt.",
                    "nov.",
                    "dec."
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "januari",
                    "februari",
                    "mars",
                    "april",
                    "maj",
                    "juni",
                    "juli",
                    "augusti",
                    "september",
                    "oktober",
                    "november",
                    "december"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "jan.",
                    "feb.",
                    "mars",
                    "apr.",
                    "maj",
                    "juni",
                    "juli",
                    "aug.",
                    "sep.",
                    "okt.",
                    "nov.",
                    "dec."
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "januari",
                    "februari",
                    "mars",
                    "april",
                    "maj",
                    "juni",
                    "juli",
                    "augusti",
                    "september",
                    "oktober",
                    "november",
                    "december"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1:a kvartalet",
                    "2:a kvartalet",
                    "3:e kvartalet",
                    "4:e kvartalet"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "K1",
                    "K2",
                    "K3",
                    "K4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1:a kvartalet",
                    "2:a kvartalet",
                    "3:e kvartalet",
                    "4:e kvartalet"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "midnatt",
                    am: "fm",
                    pm: "em",
                    morning1: "på morg.",
                    morning2: "på förm.",
                    afternoon1: "på efterm.",
                    evening1: "på kvällen",
                    night1: "på natten"
                },
                narrow: {
                    midnight: "midn.",
                    am: "fm",
                    pm: "em",
                    morning1: "på morg.",
                    morning2: "på förm.",
                    afternoon1: "på efterm.",
                    evening1: "på kvällen",
                    night1: "på natten"
                },
                wide: {
                    midnight: "midnatt",
                    am: "fm",
                    pm: "em",
                    morning1: "på morgonen",
                    morning2: "på förmiddagen",
                    afternoon1: "på eftermiddagen",
                    evening1: "på kvällen",
                    night1: "på natten"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "midnatt",
                    am: "f.m.",
                    pm: "e.m.",
                    morning1: "morgon",
                    morning2: "förm.",
                    afternoon1: "efterm.",
                    evening1: "kväll",
                    night1: "natt"
                },
                narrow: {
                    midnight: "midn.",
                    am: "fm",
                    pm: "em",
                    morning1: "morg.",
                    morning2: "förm.",
                    afternoon1: "efterm.",
                    evening1: "kväll",
                    night1: "natt"
                },
                wide: {
                    midnight: "midnatt",
                    am: "förmiddag",
                    pm: "eftermiddag",
                    morning1: "morgon",
                    morning2: "förmiddag",
                    afternoon1: "eftermiddag",
                    evening1: "kväll",
                    night1: "natt"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "före Kristus",
                    "1": "efter Kristus",
                    "0-alt-variant": "före västerländsk tideräkning",
                    "1-alt-variant": "västerländsk tideräkning"
                },
                abbreviated: {
                    "0": "f.Kr.",
                    "1": "e.Kr.",
                    "0-alt-variant": "f.v.t.",
                    "1-alt-variant": "v.t."
                },
                narrow: {
                    "0": "f.Kr.",
                    "1": "e.Kr.",
                    "0-alt-variant": "f.v.t.",
                    "1-alt-variant": "v.t."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "era",
                short: "era",
                narrow: "era"
            },
            year: {
                wide: "år",
                short: "år",
                narrow: "år"
            },
            quarter: {
                wide: "kvartal",
                short: "kv.",
                narrow: "kv."
            },
            month: {
                wide: "månad",
                short: "m",
                narrow: "mån"
            },
            week: {
                wide: "vecka",
                short: "v",
                narrow: "v"
            },
            weekOfMonth: {
                wide: "vecka i månaden",
                short: "vk. i mån.",
                narrow: "vk.i mån."
            },
            day: {
                wide: "dag",
                short: "dag",
                narrow: "dag"
            },
            dayOfYear: {
                wide: "dag under året",
                short: "dag under året",
                narrow: "dag under året"
            },
            weekday: {
                wide: "veckodag",
                short: "veckodag",
                narrow: "veckodag"
            },
            weekdayOfMonth: {
                wide: "veckodag i månad",
                short: "veckodag i mån.",
                narrow: "veckodag i mån."
            },
            dayperiod: {
                short: "fm/em",
                wide: "fm/em",
                narrow: "fm/em"
            },
            hour: {
                wide: "timme",
                short: "tim",
                narrow: "h"
            },
            minute: {
                wide: "minut",
                short: "min",
                narrow: "m"
            },
            second: {
                wide: "sekund",
                short: "sek",
                narrow: "s"
            },
            zone: {
                wide: "tidszon",
                short: "tidszon",
                narrow: "tidszon"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "millisekund"
            }
        }
    },
    firstDay: 1
});

