/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ta-SG",
    likelySubtags: {
        ta: "ta-Taml-IN"
    },
    identity: {
        language: "ta",
        territory: "SG"
    },
    territory: "SG",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE, d MMMM, y",
            m: "MMM d",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d MMMM, y a h:mm:ss",
            g: "d/M/y a h:mm",
            G: "d/M/y a h:mm:ss",
            t: "a h:mm",
            T: "a h:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} அன்று {0}",
            long: "{1} அன்று {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "B h",
                Bhm: "B h:mm",
                Bhms: "B h:mm:ss",
                d: "d",
                E: "ccc",
                EBhm: "E B h:mm",
                EBhms: "E B h:mm:ss",
                Ed: "d E",
                Ehm: "E a h:mm",
                EHm: "E HH:mm",
                Ehms: "E a h:mm:ss",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "a h",
                H: "HH",
                hm: "a h:mm",
                Hm: "HH:mm",
                hms: "a h:mm:ss",
                Hms: "HH:mm:ss",
                hmsv: "a h:mm:ss v",
                Hmsv: "HH:mm:ss v",
                hmv: "a h:mm v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "dd-MM, E",
                MMdd: "dd-MM",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "MMM d, E",
                MMMMd: "d MMMM",
                "MMMMW-count-one": "MMMM W -ஆம் வாரம்",
                "MMMMW-count-other": "MMMM W -ஆம் வாரம்",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E, d/M/y",
                yMM: "MM-y",
                yMMM: "MMM y",
                yMMMd: "d MMM, y",
                yMMMEd: "E, d MMM, y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "Y ஆம் ஆண்டின் w -ஆம் வாரம்",
                "yw-count-other": "Y ஆம் ஆண்டின் w -ஆம் வாரம்"
            }
        },
        timeFormats: {
            full: "a h:mm:ss zzzz",
            long: "a h:mm:ss z",
            medium: "a h:mm:ss",
            short: "a h:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM, y",
            long: "d MMMM, y",
            medium: "d MMM, y",
            short: "d/M/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "ஞாயி.",
                    "திங்.",
                    "செவ்.",
                    "புத.",
                    "வியா.",
                    "வெள்.",
                    "சனி"
                ],
                narrow: [
                    "ஞா",
                    "தி",
                    "செ",
                    "பு",
                    "வி",
                    "வெ",
                    "ச"
                ],
                short: [
                    "ஞா",
                    "தி",
                    "செ",
                    "பு",
                    "வி",
                    "வெ",
                    "ச"
                ],
                wide: [
                    "ஞாயிறு",
                    "திங்கள்",
                    "செவ்வாய்",
                    "புதன்",
                    "வியாழன்",
                    "வெள்ளி",
                    "சனி"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ஞாயி.",
                    "திங்.",
                    "செவ்.",
                    "புத.",
                    "வியா.",
                    "வெள்.",
                    "சனி"
                ],
                narrow: [
                    "ஞா",
                    "தி",
                    "செ",
                    "பு",
                    "வி",
                    "வெ",
                    "ச"
                ],
                short: [
                    "ஞா",
                    "தி",
                    "செ",
                    "பு",
                    "வி",
                    "வெ",
                    "ச"
                ],
                wide: [
                    "ஞாயிறு",
                    "திங்கள்",
                    "செவ்வாய்",
                    "புதன்",
                    "வியாழன்",
                    "வெள்ளி",
                    "சனி"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "ஜன.",
                    "பிப்.",
                    "மார்.",
                    "ஏப்.",
                    "மே",
                    "ஜூன்",
                    "ஜூலை",
                    "ஆக.",
                    "செப்.",
                    "அக்.",
                    "நவ.",
                    "டிச."
                ],
                narrow: [
                    "ஜ",
                    "பி",
                    "மா",
                    "ஏ",
                    "மே",
                    "ஜூ",
                    "ஜூ",
                    "ஆ",
                    "செ",
                    "அ",
                    "ந",
                    "டி"
                ],
                wide: [
                    "ஜனவரி",
                    "பிப்ரவரி",
                    "மார்ச்",
                    "ஏப்ரல்",
                    "மே",
                    "ஜூன்",
                    "ஜூலை",
                    "ஆகஸ்ட்",
                    "செப்டம்பர்",
                    "அக்டோபர்",
                    "நவம்பர்",
                    "டிசம்பர்"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "ஜன.",
                    "பிப்.",
                    "மார்.",
                    "ஏப்.",
                    "மே",
                    "ஜூன்",
                    "ஜூலை",
                    "ஆக.",
                    "செப்.",
                    "அக்.",
                    "நவ.",
                    "டிச."
                ],
                narrow: [
                    "ஜ",
                    "பி",
                    "மா",
                    "ஏ",
                    "மே",
                    "ஜூ",
                    "ஜூ",
                    "ஆ",
                    "செ",
                    "அ",
                    "ந",
                    "டி"
                ],
                wide: [
                    "ஜனவரி",
                    "பிப்ரவரி",
                    "மார்ச்",
                    "ஏப்ரல்",
                    "மே",
                    "ஜூன்",
                    "ஜூலை",
                    "ஆகஸ்ட்",
                    "செப்டம்பர்",
                    "அக்டோபர்",
                    "நவம்பர்",
                    "டிசம்பர்"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "காலா.1",
                    "காலா.2",
                    "காலா.3",
                    "காலா.4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "ஒன்றாம் காலாண்டு",
                    "இரண்டாம் காலாண்டு",
                    "மூன்றாம் காலாண்டு",
                    "நான்காம் காலாண்டு"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "காலா.1",
                    "காலா.2",
                    "காலா.3",
                    "காலா.4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "ஒன்றாம் காலாண்டு",
                    "இரண்டாம் காலாண்டு",
                    "மூன்றாம் காலாண்டு",
                    "நான்காம் காலாண்டு"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "நள்ளிரவு",
                    am: "முற்பகல்",
                    noon: "நண்பகல்",
                    pm: "பிற்பகல்",
                    morning1: "அதிகாலை",
                    morning2: "காலை",
                    afternoon1: "மதியம்",
                    afternoon2: "பிற்பகல்",
                    evening1: "மாலை",
                    evening2: "அந்தி மாலை",
                    night1: "இரவு"
                },
                narrow: {
                    midnight: "நள்.",
                    am: "மு.ப",
                    noon: "நண்.",
                    pm: "பி.ப",
                    morning1: "அதி.",
                    morning2: "கா.",
                    afternoon1: "மதி.",
                    afternoon2: "பிற்.",
                    evening1: "மா.",
                    evening2: "அந்தி மா.",
                    night1: "இர."
                },
                wide: {
                    midnight: "நள்ளிரவு",
                    am: "முற்பகல்",
                    noon: "நண்பகல்",
                    pm: "பிற்பகல்",
                    morning1: "அதிகாலை",
                    morning2: "காலை",
                    afternoon1: "மதியம்",
                    afternoon2: "பிற்பகல்",
                    evening1: "மாலை",
                    evening2: "அந்தி மாலை",
                    night1: "இரவு"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "நள்ளிரவு",
                    am: "முற்பகல்",
                    noon: "நண்பகல்",
                    pm: "பிற்பகல்",
                    morning1: "அதிகாலை",
                    morning2: "காலை",
                    afternoon1: "மதியம்",
                    afternoon2: "பிற்பகல்",
                    evening1: "மாலை",
                    evening2: "அந்தி மாலை",
                    night1: "இரவு"
                },
                narrow: {
                    midnight: "நள்.",
                    am: "மு.ப",
                    noon: "நண்.",
                    pm: "பி.ப",
                    morning1: "அதி.",
                    morning2: "கா.",
                    afternoon1: "மதி.",
                    afternoon2: "பிற்.",
                    evening1: "மா.",
                    evening2: "அந்தி மா.",
                    night1: "இ."
                },
                wide: {
                    midnight: "நள்ளிரவு",
                    am: "முற்பகல்",
                    noon: "நண்பகல்",
                    pm: "பிற்பகல்",
                    morning1: "அதிகாலை",
                    morning2: "காலை",
                    afternoon1: "மதியம்",
                    afternoon2: "பிற்பகல்",
                    evening1: "மாலை",
                    evening2: "அந்தி மாலை",
                    night1: "இரவு"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "கிறிஸ்துவுக்கு முன்",
                    "1": "அன்னோ டோமினி",
                    "0-alt-variant": "பொ.ச.மு",
                    "1-alt-variant": "பொ.ச"
                },
                abbreviated: {
                    "0": "கி.மு.",
                    "1": "கி.பி.",
                    "0-alt-variant": "பொ.ச.மு",
                    "1-alt-variant": "பொ.ச"
                },
                narrow: {
                    "0": "கி.மு.",
                    "1": "கி.பி.",
                    "0-alt-variant": "பொ.ச.மு",
                    "1-alt-variant": "பொ.ச"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "காலம்",
                short: "காலம்",
                narrow: "காலம்"
            },
            year: {
                wide: "ஆண்டு",
                short: "ஆண்டு",
                narrow: "ஆ."
            },
            quarter: {
                wide: "காலாண்டு",
                short: "காலா.",
                narrow: "கா."
            },
            month: {
                wide: "மாதம்",
                short: "மாத.",
                narrow: "மா."
            },
            week: {
                wide: "வாரம்",
                short: "வாரம்",
                narrow: "வா."
            },
            weekOfMonth: {
                wide: "மாதத்தின் வாரம்",
                short: "மாத. வாரம்",
                narrow: "மாத. வாரம்"
            },
            day: {
                wide: "நாள்",
                short: "நாள்",
                narrow: "நா."
            },
            dayOfYear: {
                wide: "வருடத்தின் நாள்",
                short: "வருட. நாள்",
                narrow: "வருட. நாள்"
            },
            weekday: {
                wide: "வாரத்தின் நாள்",
                short: "வார. நாள்",
                narrow: "வார. நாள்"
            },
            weekdayOfMonth: {
                wide: "மாதத்தின் வாரநாள்",
                short: "மாத. வாரநாள்",
                narrow: "மாத. வாரநாள்"
            },
            dayperiod: {
                short: "முற்./பிற்.",
                wide: "முற்பகல்/பிற்பகல்",
                narrow: "முற்./பிற்."
            },
            hour: {
                wide: "மணி",
                short: "மணி.",
                narrow: "ம."
            },
            minute: {
                wide: "நிமிடம்",
                short: "நிமி.",
                narrow: "நிமி."
            },
            second: {
                wide: "விநாடி",
                short: "விநா.",
                narrow: "வி."
            },
            zone: {
                wide: "நேர மண்டலம்",
                short: "மண்டலம்",
                narrow: "மண்டலம்"
            },
            millisecond: {
                narrow: "மி.வி.",
                short: "மி.வி.",
                wide: "மில்லிவிநாடி"
            }
        }
    },
    firstDay: 0
});

