/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "tzm",
    likelySubtags: {
        tzm: "tzm-Latn-MA"
    },
    identity: {
        language: "tzm"
    },
    territory: "MA",
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, d MMMM y",
            m: "MMM d",
            M: "MMMM d",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, d MMMM y HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d, E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "M/d",
                MEd: "E, M/d",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, MMM d",
                MMMMd: "MMMM d",
                MMMMEd: "E, MMMM d",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "y-MM-dd",
                yMEd: "E, M/d/y",
                yMMM: "MMM y",
                yMMMd: "y MMM d",
                yMMMEd: "E, MMM d, y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM y",
            long: "d MMMM y",
            medium: "d MMM y",
            short: "dd/MM/y"
        },
        days: {
            format: {
                abbreviated: [
                    "Asa",
                    "Ayn",
                    "Asn",
                    "Akr",
                    "Akw",
                    "Asm",
                    "Asḍ"
                ],
                narrow: [
                    "A",
                    "A",
                    "A",
                    "A",
                    "A",
                    "A",
                    "A"
                ],
                short: [
                    "Asa",
                    "Ayn",
                    "Asn",
                    "Akr",
                    "Akw",
                    "Asm",
                    "Asḍ"
                ],
                wide: [
                    "Asamas",
                    "Aynas",
                    "Asinas",
                    "Akras",
                    "Akwas",
                    "Asimwas",
                    "Asiḍyas"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Asa",
                    "Ayn",
                    "Asn",
                    "Akr",
                    "Akw",
                    "Asm",
                    "Asḍ"
                ],
                narrow: [
                    "A",
                    "A",
                    "A",
                    "A",
                    "A",
                    "A",
                    "A"
                ],
                short: [
                    "Asa",
                    "Ayn",
                    "Asn",
                    "Akr",
                    "Akw",
                    "Asm",
                    "Asḍ"
                ],
                wide: [
                    "Asamas",
                    "Aynas",
                    "Asinas",
                    "Akras",
                    "Akwas",
                    "Asimwas",
                    "Asiḍyas"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Yen",
                    "Yeb",
                    "Mar",
                    "Ibr",
                    "May",
                    "Yun",
                    "Yul",
                    "Ɣuc",
                    "Cut",
                    "Kṭu",
                    "Nwa",
                    "Duj"
                ],
                narrow: [
                    "Y",
                    "Y",
                    "M",
                    "I",
                    "M",
                    "Y",
                    "Y",
                    "Ɣ",
                    "C",
                    "K",
                    "N",
                    "D"
                ],
                wide: [
                    "Yennayer",
                    "Yebrayer",
                    "Mars",
                    "Ibrir",
                    "Mayyu",
                    "Yunyu",
                    "Yulyuz",
                    "Ɣuct",
                    "Cutanbir",
                    "Kṭuber",
                    "Nwanbir",
                    "Dujanbir"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Yen",
                    "Yeb",
                    "Mar",
                    "Ibr",
                    "May",
                    "Yun",
                    "Yul",
                    "Ɣuc",
                    "Cut",
                    "Kṭu",
                    "Nwa",
                    "Duj"
                ],
                narrow: [
                    "Y",
                    "Y",
                    "M",
                    "I",
                    "M",
                    "Y",
                    "Y",
                    "Ɣ",
                    "C",
                    "K",
                    "N",
                    "D"
                ],
                wide: [
                    "Yennayer",
                    "Yebrayer",
                    "Mars",
                    "Ibrir",
                    "Mayyu",
                    "Yunyu",
                    "Yulyuz",
                    "Ɣuct",
                    "Cutanbir",
                    "Kṭuber",
                    "Nwanbir",
                    "Dujanbir"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "IA1",
                    "IA2",
                    "IA3",
                    "IA4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Imir adamsan 1",
                    "Imir adamsan 2",
                    "Imir adamsan 3",
                    "Imir adamsan 4"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "IA1",
                    "IA2",
                    "IA3",
                    "IA4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Imir adamsan 1",
                    "Imir adamsan 2",
                    "Imir adamsan 3",
                    "Imir adamsan 4"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "Zdat azal",
                    pm: "Ḍeffir aza"
                },
                narrow: {
                    am: "Zdat azal",
                    pm: "Ḍeffir aza"
                },
                wide: {
                    am: "Zdat azal",
                    pm: "Ḍeffir aza"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "Zdat azal",
                    pm: "Ḍeffir aza"
                },
                narrow: {
                    am: "Zdat azal",
                    pm: "Ḍeffir aza"
                },
                wide: {
                    am: "Zdat azal",
                    pm: "Ḍeffir aza"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Zdat Ɛisa (TAƔ)",
                    "1": "Ḍeffir Ɛisa (TAƔ)",
                    "0-alt-variant": "ZƐ",
                    "1-alt-variant": "ḌƐ"
                },
                abbreviated: {
                    "0": "ZƐ",
                    "1": "ḌƐ",
                    "0-alt-variant": "ZƐ",
                    "1-alt-variant": "ḌƐ"
                },
                narrow: {
                    "0": "ZƐ",
                    "1": "ḌƐ",
                    "0-alt-variant": "ZƐ",
                    "1-alt-variant": "ḌƐ"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Tallit",
                short: "Tallit",
                narrow: "Tallit"
            },
            year: {
                wide: "Asseggas",
                short: "Asseggas",
                narrow: "Asseggas"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "Ayur",
                short: "Ayur",
                narrow: "Ayur"
            },
            week: {
                wide: "Imalass",
                short: "Imalass",
                narrow: "Imalass"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "Ass",
                short: "Ass",
                narrow: "Ass"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "Ass n Imalass",
                short: "Ass n Imalass",
                narrow: "Ass n Imalass"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "Zdat azal/Deffir azal",
                wide: "Zdat azal/Deffir azal",
                narrow: "Zdat azal/Deffir azal"
            },
            hour: {
                wide: "Tasragt",
                short: "Tasragt",
                narrow: "Tasragt"
            },
            minute: {
                wide: "Tusdat",
                short: "Tusdat",
                narrow: "Tusdat"
            },
            second: {
                wide: "Tusnat",
                short: "Tusnat",
                narrow: "Tusnat"
            },
            zone: {
                wide: "Aseglem asergan",
                short: "Aseglem asergan",
                narrow: "Aseglem asergan"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 1
});

