/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ug",
    likelySubtags: {
        ug: "ug-Arab-CN"
    },
    identity: {
        language: "ug"
    },
    territory: "CN",
    calendar: {
        patterns: {
            d: "y-MM-dd",
            D: "y d-MMMM، EEEE",
            m: "d-MMM",
            M: "d-MMMM",
            y: "y MMM",
            Y: "y MMMM",
            F: "y d-MMMM، EEEE HH:mm:ss",
            g: "y-d-M HH:mm",
            G: "y-d-M HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1}، {0}",
            short: "{1}، {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "GGGGG y-MM-dd",
                GyMMM: "y MMM G",
                GyMMMd: "y d-MMM G",
                GyMMMEd: "y d-MMM، E G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d-M",
                MEd: "d-M، E",
                MMM: "LLL",
                MMMd: "d-MMM",
                MMMEd: "d-MMM، E",
                MMMMd: "d-MMMM",
                "MMMMW-count-one": "MMMM، W-ھەپتە",
                "MMMMW-count-other": "MMMM، W-ھەپتە",
                ms: "mm:ss",
                y: "y",
                yM: "M-y",
                yMd: "y-d-M",
                yMEd: "y-d-M، E",
                yMMM: "y MMM",
                yMMMd: "y d-MMM",
                yMMMEd: "y d-MMM، E",
                yMMMM: "y MMMM",
                yQQQ: "y QQQ",
                yQQQQ: "y QQQQ",
                "yw-count-one": "Y، w-ھەپتە",
                "yw-count-other": "Y، w-ھەپتە"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "y d-MMMM، EEEE",
            long: "d-MMMM، y",
            medium: "d-MMM، y",
            short: "y-MM-dd"
        },
        days: {
            format: {
                abbreviated: [
                    "يە",
                    "دۈ",
                    "سە",
                    "چا",
                    "پە",
                    "جۈ",
                    "شە"
                ],
                narrow: [
                    "ي",
                    "د",
                    "س",
                    "چ",
                    "پ",
                    "ج",
                    "ش"
                ],
                short: [
                    "ي",
                    "د",
                    "س",
                    "چ",
                    "پ",
                    "ج",
                    "ش"
                ],
                wide: [
                    "يەكشەنبە",
                    "دۈشەنبە",
                    "سەيشەنبە",
                    "چارشەنبە",
                    "پەيشەنبە",
                    "جۈمە",
                    "شەنبە"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "يە",
                    "دۈ",
                    "سە",
                    "چا",
                    "پە",
                    "جۈ",
                    "شە"
                ],
                narrow: [
                    "ي",
                    "د",
                    "س",
                    "چ",
                    "پ",
                    "ج",
                    "ش"
                ],
                short: [
                    "ي",
                    "د",
                    "س",
                    "چ",
                    "پ",
                    "ج",
                    "ش"
                ],
                wide: [
                    "يەكشەنبە",
                    "دۈشەنبە",
                    "سەيشەنبە",
                    "چارشەنبە",
                    "پەيشەنبە",
                    "جۈمە",
                    "شەنبە"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "يانۋار",
                    "فېۋرال",
                    "مارت",
                    "ئاپرېل",
                    "ماي",
                    "ئىيۇن",
                    "ئىيۇل",
                    "ئاۋغۇست",
                    "سېنتەبىر",
                    "ئۆكتەبىر",
                    "نويابىر",
                    "دېكابىر"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "يانۋار",
                    "فېۋرال",
                    "مارت",
                    "ئاپرېل",
                    "ماي",
                    "ئىيۇن",
                    "ئىيۇل",
                    "ئاۋغۇست",
                    "سېنتەبىر",
                    "ئۆكتەبىر",
                    "نويابىر",
                    "دېكابىر"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "يانۋار",
                    "فېۋرال",
                    "مارت",
                    "ئاپرېل",
                    "ماي",
                    "ئىيۇن",
                    "ئىيۇل",
                    "ئاۋغۇست",
                    "سېنتەبىر",
                    "ئۆكتەبىر",
                    "نويابىر",
                    "دېكابىر"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "يانۋار",
                    "فېۋرال",
                    "مارت",
                    "ئاپرېل",
                    "ماي",
                    "ئىيۇن",
                    "ئىيۇل",
                    "ئاۋغۇست",
                    "سېنتەبىر",
                    "ئۆكتەبىر",
                    "نويابىر",
                    "دېكابىر"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1-پەسىل",
                    "2-پەسىل",
                    "3-پەسىل",
                    "4-پەسىل"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "بىرىنچى پەسىل",
                    "ئىككىنچى پەسىل",
                    "ئۈچىنچى پەسىل",
                    "تۆتىنچى پەسىل"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1-پەسىل",
                    "2-پەسىل",
                    "3-پەسىل",
                    "4-پەسىل"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "بىرىنچى پەسىل",
                    "ئىككىنچى پەسىل",
                    "ئۈچىنچى پەسىل",
                    "تۆتىنچى پەسىل"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "چ.ب",
                    pm: "چ.ك"
                },
                narrow: {
                    am: "ب",
                    pm: "ك"
                },
                wide: {
                    am: "چۈشتىن بۇرۇن",
                    pm: "چۈشتىن كېيىن"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "چ.ب",
                    pm: "چ.ك"
                },
                narrow: {
                    am: "چ.ب",
                    pm: "چ.ك"
                },
                wide: {
                    am: "چ.ب",
                    pm: "چ.ك"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "مىلادىيەدىن بۇرۇن",
                    "1": "مىلادىيە",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "مىلادىيە"
                },
                abbreviated: {
                    "0": "BCE",
                    "1": "مىلادىيە",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "مىلادىيە"
                },
                narrow: {
                    "0": "BCE",
                    "1": "مىلادىيە",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "مىلادىيە"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "مىلادىيە",
                short: "مىلادىيە",
                narrow: "مىلادىيە"
            },
            year: {
                wide: "يىل",
                short: "يىل",
                narrow: "يىل"
            },
            quarter: {
                wide: "Quarter",
                short: "Quarter",
                narrow: "Quarter"
            },
            month: {
                wide: "ئاي",
                short: "ئاي",
                narrow: "ئاي"
            },
            week: {
                wide: "ھەپتە",
                short: "ھەپتە",
                narrow: "ھەپتە"
            },
            weekOfMonth: {
                wide: "Week Of Month",
                short: "Week Of Month",
                narrow: "Week Of Month"
            },
            day: {
                wide: "كۈن",
                short: "كۈن",
                narrow: "كۈن"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "Day Of Year",
                narrow: "Day Of Year"
            },
            weekday: {
                wide: "ھەپتە كۈنلىرى",
                short: "ھەپتە كۈنلىرى",
                narrow: "ھەپتە كۈنلىرى"
            },
            weekdayOfMonth: {
                wide: "Weekday Of Month",
                short: "Weekday Of Month",
                narrow: "Weekday Of Month"
            },
            dayperiod: {
                short: "چۈشتىن بۇرۇن/چۈشتىن كېيىن",
                wide: "چۈشتىن بۇرۇن/چۈشتىن كېيىن",
                narrow: "چۈشتىن بۇرۇن/چۈشتىن كېيىن"
            },
            hour: {
                wide: "سائەت",
                short: "سائەت",
                narrow: "سائەت"
            },
            minute: {
                wide: "مىنۇت",
                short: "مىنۇت",
                narrow: "مىنۇت"
            },
            second: {
                wide: "سېكۇنت",
                short: "سېكۇنت",
                narrow: "سېكۇنت"
            },
            zone: {
                wide: "ۋاقىت رايونى",
                short: "ۋاقىت رايونى",
                narrow: "ۋاقىت رايونى"
            },
            millisecond: {
                narrow: "ms",
                short: "مىللىسېكۇنت",
                wide: "مىللى سېكۇنت"
            }
        }
    },
    firstDay: 0
});

