/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "ur",
    likelySubtags: {
        ur: "ur-Arab-PK"
    },
    identity: {
        language: "ur"
    },
    territory: "PK",
    calendar: {
        patterns: {
            d: "d/M/y",
            D: "EEEE، d MMMM، y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE، d MMMM، y h:mm:ss a",
            g: "d/M/y h:mm a",
            G: "d/M/y h:mm:ss a",
            t: "h:mm a",
            T: "h:mm:ss a",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "d/M/y GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "d MMM، y G",
                GyMMMEd: "E، d MMM، y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "d/M",
                MEd: "E، d/M",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E، d MMM",
                MMMMd: "d MMMM",
                "MMMMW-count-one": "MMMM کا ہفتہ W",
                "MMMMW-count-other": "MMMM کا ہفتہ W",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E، d/M/y",
                yMMM: "MMM y",
                yMMMd: "d MMM، y",
                yMMMEd: "E، d MMM، y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "Y کا w ہفتہ",
                "yw-count-other": "Y کا w ہفتہ"
            }
        },
        timeFormats: {
            full: "h:mm:ss a zzzz",
            long: "h:mm:ss a z",
            medium: "h:mm:ss a",
            short: "h:mm a"
        },
        dateFormats: {
            full: "EEEE، d MMMM، y",
            long: "d MMMM، y",
            medium: "d MMM، y",
            short: "d/M/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "اتوار",
                    "پیر",
                    "منگل",
                    "بدھ",
                    "جمعرات",
                    "جمعہ",
                    "ہفتہ"
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "W",
                    "T",
                    "F",
                    "S"
                ],
                short: [
                    "اتوار",
                    "پیر",
                    "منگل",
                    "بدھ",
                    "جمعرات",
                    "جمعہ",
                    "ہفتہ"
                ],
                wide: [
                    "اتوار",
                    "پیر",
                    "منگل",
                    "بدھ",
                    "جمعرات",
                    "جمعہ",
                    "ہفتہ"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "اتوار",
                    "پیر",
                    "منگل",
                    "بدھ",
                    "جمعرات",
                    "جمعہ",
                    "ہفتہ"
                ],
                narrow: [
                    "S",
                    "M",
                    "T",
                    "W",
                    "T",
                    "F",
                    "S"
                ],
                short: [
                    "اتوار",
                    "پیر",
                    "منگل",
                    "بدھ",
                    "جمعرات",
                    "جمعہ",
                    "ہفتہ"
                ],
                wide: [
                    "اتوار",
                    "پیر",
                    "منگل",
                    "بدھ",
                    "جمعرات",
                    "جمعہ",
                    "ہفتہ"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "جنوری",
                    "فروری",
                    "مارچ",
                    "اپریل",
                    "مئی",
                    "جون",
                    "جولائی",
                    "اگست",
                    "ستمبر",
                    "اکتوبر",
                    "نومبر",
                    "دسمبر"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "جنوری",
                    "فروری",
                    "مارچ",
                    "اپریل",
                    "مئی",
                    "جون",
                    "جولائی",
                    "اگست",
                    "ستمبر",
                    "اکتوبر",
                    "نومبر",
                    "دسمبر"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "جنوری",
                    "فروری",
                    "مارچ",
                    "اپریل",
                    "مئی",
                    "جون",
                    "جولائی",
                    "اگست",
                    "ستمبر",
                    "اکتوبر",
                    "نومبر",
                    "دسمبر"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "جنوری",
                    "فروری",
                    "مارچ",
                    "اپریل",
                    "مئی",
                    "جون",
                    "جولائی",
                    "اگست",
                    "ستمبر",
                    "اکتوبر",
                    "نومبر",
                    "دسمبر"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "پہلی سہ ماہی",
                    "دوسری سہ ماہی",
                    "تیسری سہ ماہی",
                    "چوتهی سہ ماہی"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "پہلی سہ ماہی",
                    "دوسری سہ ماہی",
                    "تیسری سہ ماہی",
                    "چوتهی سہ ماہی"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "پہلی سہ ماہی",
                    "دوسری سہ ماہی",
                    "تیسری سہ ماہی",
                    "چوتهی سہ ماہی"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "پہلی سہ ماہی",
                    "دوسری سہ ماہی",
                    "تیسری سہ ماہی",
                    "چوتهی سہ ماہی"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "آدھی رات",
                    am: "AM",
                    pm: "PM",
                    morning1: "صبح",
                    afternoon1: "دوپہر",
                    afternoon2: "سہ پہر",
                    evening1: "شام",
                    night1: "رات"
                },
                narrow: {
                    midnight: "آدھی رات",
                    am: "a",
                    pm: "p",
                    morning1: "صبح",
                    afternoon1: "دوپہر",
                    afternoon2: "سہ پہر",
                    evening1: "شام",
                    night1: "رات"
                },
                wide: {
                    midnight: "آدھی رات",
                    am: "AM",
                    pm: "PM",
                    morning1: "صبح میں",
                    afternoon1: "دوپہر میں",
                    afternoon2: "سہ پہر",
                    evening1: "شام میں",
                    night1: "رات میں"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "آدھی رات",
                    am: "AM",
                    pm: "PM",
                    morning1: "صبح",
                    afternoon1: "دوپہر",
                    afternoon2: "سہ پہر",
                    evening1: "شام",
                    night1: "رات"
                },
                narrow: {
                    midnight: "آدھی رات",
                    am: "AM",
                    pm: "PM",
                    morning1: "صبح",
                    afternoon1: "دوپہر",
                    afternoon2: "سہ پہر",
                    evening1: "شام",
                    night1: "رات"
                },
                wide: {
                    midnight: "آدھی رات",
                    am: "AM",
                    pm: "PM",
                    morning1: "صبح",
                    afternoon1: "دوپہر",
                    afternoon2: "سہ پہر",
                    evening1: "شام",
                    night1: "رات"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "قبل مسیح",
                    "1": "عیسوی",
                    "0-alt-variant": "عام دور سے قبل",
                    "1-alt-variant": "عام دور"
                },
                abbreviated: {
                    "0": "قبل مسیح",
                    "1": "عیسوی",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                narrow: {
                    "0": "قبل مسیح",
                    "1": "عیسوی",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                }
            }
        },
        gmtFormat: "GMT {0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "عہد",
                short: "عہد",
                narrow: "عہد"
            },
            year: {
                wide: "سال",
                short: "سال",
                narrow: "سال"
            },
            quarter: {
                wide: "سہ ماہی",
                short: "سہ ماہی",
                narrow: "سہ ماہی"
            },
            month: {
                wide: "مہینہ",
                short: "ماہ",
                narrow: "ماہ"
            },
            week: {
                wide: "ہفتہ",
                short: "ہفتہ",
                narrow: "ہفتہ"
            },
            weekOfMonth: {
                wide: "مہینے کا ہفتہ",
                short: "مہینے کا ہفتہ",
                narrow: "مہینے کا ہفتہ"
            },
            day: {
                wide: "دن",
                short: "دن",
                narrow: "دن"
            },
            dayOfYear: {
                wide: "یوم سال",
                short: "یوم سال",
                narrow: "یوم سال"
            },
            weekday: {
                wide: "ہفتے کا دن",
                short: "ہفتے کا دن",
                narrow: "ہفتے کا دن"
            },
            weekdayOfMonth: {
                wide: "مہینے کا یوم ہفتہ",
                short: "مہینے کا یوم ہفتہ",
                narrow: "مہینے کا یوم ہفتہ"
            },
            dayperiod: {
                short: "قبل دوپہر/بعد دوپہر",
                wide: "قبل دوپہر/بعد دوپہر",
                narrow: "قبل دوپہر/بعد دوپہر"
            },
            hour: {
                wide: "گھنٹہ",
                short: "گھنٹہ",
                narrow: "گھنٹہ"
            },
            minute: {
                wide: "منٹ",
                short: "منٹ",
                narrow: "منٹ"
            },
            second: {
                wide: "سیکنڈ",
                short: "سیکنڈ",
                narrow: "سیکنڈ"
            },
            zone: {
                wide: "منطقۂ وقت",
                short: "منطقۂ وقت",
                narrow: "منطقۂ وقت"
            },
            millisecond: {
                narrow: "ms",
                short: "ملی سیکنڈ",
                wide: "ملی سیکنڈ"
            }
        }
    },
    firstDay: 0
});

