/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "uz",
    likelySubtags: {
        uz: "uz-Latn-UZ"
    },
    identity: {
        language: "uz"
    },
    territory: "UZ",
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, d-MMMM, y",
            m: "d-MMM",
            M: "d-MMMM",
            y: "MMM, y",
            Y: "MMMM, y",
            F: "EEEE, d-MMMM, y HH:mm:ss",
            g: "dd/MM/y HH:mm",
            G: "dd/MM/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1}, {0}",
            long: "{1}, {0}",
            medium: "{1}, {0}",
            short: "{1}, {0}",
            availableFormats: {
                Bh: "B h",
                Bhm: "B h:mm",
                Bhms: "B h:mm:ss",
                d: "d",
                E: "ccc",
                EBhm: "E, B h:mm",
                EBhms: "E, B h:mm:ss",
                Ed: "d, E",
                Ehm: "E, h:mm a",
                EHm: "E, HH:mm",
                Ehms: "E, h:mm:ss a",
                EHms: "E, HH:mm:ss",
                Gy: "G y",
                GyMd: "dd.MM.y GGGGG",
                GyMMM: "MMM, G y",
                GyMMMd: "d-MMM, G y",
                GyMMMEd: "E, d-MMM, G y",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a (v)",
                Hmsv: "HH:mm:ss (v)",
                hmv: "h:mm a (v)",
                Hmv: "HH:mm (v)",
                M: "LL",
                Md: "dd/MM",
                MEd: "E, dd/MM",
                MMM: "LLL",
                MMMd: "d-MMM",
                MMMEd: "E, d-MMM",
                MMMMd: "d-MMMM",
                "MMMMW-count-one": "MMMM, W-'hafta'",
                "MMMMW-count-other": "MMMM, W-'hafta'",
                ms: "mm:ss",
                y: "y",
                yM: "MM.y",
                yMd: "dd/MM/y",
                yMEd: "E, dd/MM/y",
                yMMM: "MMM, y",
                yMMMd: "d-MMM, y",
                yMMMEd: "E, d-MMM, y",
                yMMMM: "MMMM, y",
                yQQQ: "y, QQQ",
                yQQQQ: "y, QQQQ",
                "yw-count-one": "Y, w-'hafta'",
                "yw-count-other": "Y, w-'hafta'"
            }
        },
        timeFormats: {
            full: "H:mm:ss (zzzz)",
            long: "H:mm:ss (z)",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d-MMMM, y",
            long: "d-MMMM, y",
            medium: "d-MMM, y",
            short: "dd/MM/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "Yak",
                    "Dush",
                    "Sesh",
                    "Chor",
                    "Pay",
                    "Jum",
                    "Shan"
                ],
                narrow: [
                    "Y",
                    "D",
                    "S",
                    "C",
                    "P",
                    "J",
                    "S"
                ],
                short: [
                    "Ya",
                    "Du",
                    "Se",
                    "Ch",
                    "Pa",
                    "Ju",
                    "Sh"
                ],
                wide: [
                    "yakshanba",
                    "dushanba",
                    "seshanba",
                    "chorshanba",
                    "payshanba",
                    "juma",
                    "shanba"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Yak",
                    "Dush",
                    "Sesh",
                    "Chor",
                    "Pay",
                    "Jum",
                    "Shan"
                ],
                narrow: [
                    "Y",
                    "D",
                    "S",
                    "C",
                    "P",
                    "J",
                    "S"
                ],
                short: [
                    "Ya",
                    "Du",
                    "Se",
                    "Ch",
                    "Pa",
                    "Ju",
                    "Sh"
                ],
                wide: [
                    "yakshanba",
                    "dushanba",
                    "seshanba",
                    "chorshanba",
                    "payshanba",
                    "juma",
                    "shanba"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "yan",
                    "fev",
                    "mar",
                    "apr",
                    "may",
                    "iyn",
                    "iyl",
                    "avg",
                    "sen",
                    "okt",
                    "noy",
                    "dek"
                ],
                narrow: [
                    "Y",
                    "F",
                    "M",
                    "A",
                    "M",
                    "I",
                    "I",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "yanvar",
                    "fevral",
                    "mart",
                    "aprel",
                    "may",
                    "iyun",
                    "iyul",
                    "avgust",
                    "sentabr",
                    "oktabr",
                    "noyabr",
                    "dekabr"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Yan",
                    "Fev",
                    "Mar",
                    "Apr",
                    "May",
                    "Iyn",
                    "Iyl",
                    "Avg",
                    "Sen",
                    "Okt",
                    "Noy",
                    "Dek"
                ],
                narrow: [
                    "Y",
                    "F",
                    "M",
                    "A",
                    "M",
                    "I",
                    "I",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Yanvar",
                    "Fevral",
                    "Mart",
                    "Aprel",
                    "May",
                    "Iyun",
                    "Iyul",
                    "Avgust",
                    "Sentabr",
                    "Oktabr",
                    "Noyabr",
                    "Dekabr"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "1-ch",
                    "2-ch",
                    "3-ch",
                    "4-ch"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1-chorak",
                    "2-chorak",
                    "3-chorak",
                    "4-chorak"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1-ch",
                    "2-ch",
                    "3-ch",
                    "4-ch"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "1-chorak",
                    "2-chorak",
                    "3-chorak",
                    "4-chorak"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "yarim tun",
                    am: "TO",
                    noon: "tush payti",
                    pm: "TK",
                    morning1: "ertalab",
                    afternoon1: "kunduzi",
                    evening1: "kechqurun",
                    night1: "kechasi"
                },
                narrow: {
                    midnight: "yarim tun",
                    am: "TO",
                    noon: "tush payti",
                    pm: "TK",
                    morning1: "ertalab",
                    afternoon1: "kunduzi",
                    evening1: "kechqurun",
                    night1: "kechasi"
                },
                wide: {
                    midnight: "yarim tun",
                    am: "TO",
                    noon: "tush payti",
                    pm: "TK",
                    morning1: "ertalab",
                    afternoon1: "kunduzi",
                    evening1: "kechqurun",
                    night1: "kechasi"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "yarim tun",
                    am: "TO",
                    noon: "tush payti",
                    pm: "TK",
                    morning1: "ertalab",
                    afternoon1: "kunduzi",
                    evening1: "kechqurun",
                    night1: "kechasi"
                },
                narrow: {
                    midnight: "yarim tun",
                    am: "TO",
                    noon: "tush payti",
                    pm: "TK",
                    morning1: "ertalab",
                    afternoon1: "kunduzi",
                    evening1: "kechqurun",
                    night1: "kechasi"
                },
                wide: {
                    midnight: "yarim tun",
                    am: "TO",
                    noon: "tush payti",
                    pm: "TK",
                    morning1: "ertalab",
                    afternoon1: "kunduzi",
                    evening1: "kechqurun",
                    night1: "kechasi"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "miloddan avvalgi",
                    "1": "milodiy",
                    "0-alt-variant": "eramizdan avvalgi",
                    "1-alt-variant": "mil."
                },
                abbreviated: {
                    "0": "m.a.",
                    "1": "milodiy",
                    "0-alt-variant": "e.a.",
                    "1-alt-variant": "mil."
                },
                narrow: {
                    "0": "m.a.",
                    "1": "milodiy",
                    "0-alt-variant": "e.a.",
                    "1-alt-variant": "mil."
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "era",
                short: "era",
                narrow: "era"
            },
            year: {
                wide: "yil",
                short: "yil",
                narrow: "yil"
            },
            quarter: {
                wide: "chorak",
                short: "ch",
                narrow: "ch"
            },
            month: {
                wide: "oy",
                short: "oy",
                narrow: "oy"
            },
            week: {
                wide: "hafta",
                short: "hafta",
                narrow: "hafta"
            },
            weekOfMonth: {
                wide: "oyning haftasi",
                short: "oyning haftasi",
                narrow: "oyning haftasi"
            },
            day: {
                wide: "kun",
                short: "kun",
                narrow: "kun"
            },
            dayOfYear: {
                wide: "yilning kuni",
                short: "yilning kuni",
                narrow: "yilning kuni"
            },
            weekday: {
                wide: "hafta kuni",
                short: "hafta kuni",
                narrow: "hafta kuni"
            },
            weekdayOfMonth: {
                wide: "oyning hafta kuni",
                short: "oyning hafta kuni",
                narrow: "oyning hafta kuni"
            },
            dayperiod: {
                short: "TO/TK",
                wide: "TO/TK",
                narrow: "TO/TK"
            },
            hour: {
                wide: "soat",
                short: "soat",
                narrow: "soat"
            },
            minute: {
                wide: "daqiqa",
                short: "daq.",
                narrow: "daq."
            },
            second: {
                wide: "soniya",
                short: "son.",
                narrow: "son."
            },
            zone: {
                wide: "vaqt mintaqasi",
                short: "vaqt mintaqasi",
                narrow: "vaqt mintaqasi"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "millisoniya"
            }
        }
    },
    firstDay: 1
});

