/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "vi",
    likelySubtags: {
        vi: "vi-Latn-VN"
    },
    identity: {
        language: "vi"
    },
    territory: "VN",
    calendar: {
        patterns: {
            d: "dd/MM/y",
            D: "EEEE, d MMMM, y",
            m: "d MMM",
            M: "d MMMM",
            y: "MMM y",
            Y: "MMMM 'năm' y",
            F: "EEEE, d MMMM, y HH:mm:ss",
            g: "d/M/y HH:mm",
            G: "d/M/y HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{0} {1}",
            long: "{0} {1}",
            medium: "{0}, {1}",
            short: "{0}, {1}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "E, 'ngày' d",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "y G",
                GyMd: "dd/MM/y GGGGG",
                GyMMM: "MMM y G",
                GyMMMd: "dd MMM, y G",
                GyMMMEd: "E, dd/MM/y G",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "H:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "dd/M",
                MEd: "E, dd/M",
                MMdd: "dd-MM",
                MMM: "LLL",
                MMMd: "d MMM",
                MMMEd: "E, d MMM",
                MMMMd: "d MMMM",
                MMMMEd: "E, d MMMM",
                "MMMMW-count-other": "'tuần' W 'của' 'tháng' M",
                mmss: "mm:ss",
                ms: "mm:ss",
                y: "y",
                yM: "M/y",
                yMd: "d/M/y",
                yMEd: "E, dd/M/y",
                yMM: "'tháng' MM, y",
                yMMM: "MMM y",
                yMMMd: "d MMM, y",
                yMMMEd: "E, d MMM, y",
                yMMMM: "MMMM 'năm' y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ 'năm' y",
                "yw-count-other": "'tuần' w 'của' 'năm' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, d MMMM, y",
            long: "d MMMM, y",
            medium: "d MMM, y",
            short: "dd/MM/y"
        },
        days: {
            format: {
                abbreviated: [
                    "CN",
                    "Th 2",
                    "Th 3",
                    "Th 4",
                    "Th 5",
                    "Th 6",
                    "Th 7"
                ],
                narrow: [
                    "CN",
                    "T2",
                    "T3",
                    "T4",
                    "T5",
                    "T6",
                    "T7"
                ],
                short: [
                    "CN",
                    "T2",
                    "T3",
                    "T4",
                    "T5",
                    "T6",
                    "T7"
                ],
                wide: [
                    "Chủ Nhật",
                    "Thứ Hai",
                    "Thứ Ba",
                    "Thứ Tư",
                    "Thứ Năm",
                    "Thứ Sáu",
                    "Thứ Bảy"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "CN",
                    "Th 2",
                    "Th 3",
                    "Th 4",
                    "Th 5",
                    "Th 6",
                    "Th 7"
                ],
                narrow: [
                    "CN",
                    "T2",
                    "T3",
                    "T4",
                    "T5",
                    "T6",
                    "T7"
                ],
                short: [
                    "CN",
                    "T2",
                    "T3",
                    "T4",
                    "T5",
                    "T6",
                    "T7"
                ],
                wide: [
                    "Chủ Nhật",
                    "Thứ Hai",
                    "Thứ Ba",
                    "Thứ Tư",
                    "Thứ Năm",
                    "Thứ Sáu",
                    "Thứ Bảy"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "thg 1",
                    "thg 2",
                    "thg 3",
                    "thg 4",
                    "thg 5",
                    "thg 6",
                    "thg 7",
                    "thg 8",
                    "thg 9",
                    "thg 10",
                    "thg 11",
                    "thg 12"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "tháng 1",
                    "tháng 2",
                    "tháng 3",
                    "tháng 4",
                    "tháng 5",
                    "tháng 6",
                    "tháng 7",
                    "tháng 8",
                    "tháng 9",
                    "tháng 10",
                    "tháng 11",
                    "tháng 12"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Thg 1",
                    "Thg 2",
                    "Thg 3",
                    "Thg 4",
                    "Thg 5",
                    "Thg 6",
                    "Thg 7",
                    "Thg 8",
                    "Thg 9",
                    "Thg 10",
                    "Thg 11",
                    "Thg 12"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "Tháng 1",
                    "Tháng 2",
                    "Tháng 3",
                    "Tháng 4",
                    "Tháng 5",
                    "Tháng 6",
                    "Tháng 7",
                    "Tháng 8",
                    "Tháng 9",
                    "Tháng 10",
                    "Tháng 11",
                    "Tháng 12"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "Quý 1",
                    "Quý 2",
                    "Quý 3",
                    "Quý 4"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "quý 1",
                    "quý 2",
                    "quý 3",
                    "quý 4"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "nửa đêm",
                    am: "SA",
                    noon: "TR",
                    pm: "CH",
                    morning1: "sáng",
                    afternoon1: "chiều",
                    evening1: "tối",
                    night1: "đêm"
                },
                narrow: {
                    midnight: "nửa đêm",
                    am: "s",
                    noon: "tr",
                    pm: "c",
                    morning1: "sáng",
                    afternoon1: "chiều",
                    evening1: "tối",
                    night1: "đêm"
                },
                wide: {
                    midnight: "nửa đêm",
                    am: "SA",
                    noon: "TR",
                    pm: "CH",
                    morning1: "sáng",
                    afternoon1: "chiều",
                    evening1: "tối",
                    night1: "đêm"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "nửa đêm",
                    am: "SA",
                    noon: "TR",
                    pm: "CH",
                    morning1: "sáng",
                    afternoon1: "chiều",
                    evening1: "tối",
                    night1: "đêm"
                },
                narrow: {
                    midnight: "nửa đêm",
                    am: "SA",
                    noon: "trưa",
                    pm: "CH",
                    morning1: "sáng",
                    afternoon1: "chiều",
                    evening1: "tối",
                    night1: "đêm"
                },
                wide: {
                    midnight: "nửa đêm",
                    am: "SA",
                    noon: "trưa",
                    pm: "CH",
                    morning1: "sáng",
                    afternoon1: "chiều",
                    evening1: "tối",
                    night1: "đêm"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "Trước Thiên Chúa",
                    "1": "Sau Công Nguyên",
                    "0-alt-variant": "Trước Công Nguyên",
                    "1-alt-variant": "Công Nguyên"
                },
                abbreviated: {
                    "0": "Trước CN",
                    "1": "Sau CN",
                    "0-alt-variant": "trước CN",
                    "1-alt-variant": "CN"
                },
                narrow: {
                    "0": "tr. CN",
                    "1": "sau CN",
                    "0-alt-variant": "trước CN",
                    "1-alt-variant": "CN"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "thời đại",
                short: "thời đại",
                narrow: "thời đại"
            },
            year: {
                wide: "Năm",
                short: "Năm",
                narrow: "Năm"
            },
            quarter: {
                wide: "Quý",
                short: "Quý",
                narrow: "Quý"
            },
            month: {
                wide: "Tháng",
                short: "Tháng",
                narrow: "Tháng"
            },
            week: {
                wide: "Tuần",
                short: "Tuần",
                narrow: "Tuần"
            },
            weekOfMonth: {
                wide: "tuần trong tháng",
                short: "tuần trong tháng",
                narrow: "tuần trong tháng"
            },
            day: {
                wide: "Ngày",
                short: "Ngày",
                narrow: "Ngày"
            },
            dayOfYear: {
                wide: "ngày trong năm",
                short: "ngày trong năm",
                narrow: "ngày trong năm"
            },
            weekday: {
                wide: "ngày trong tuần",
                short: "ngày trong tuần",
                narrow: "ngày trong tuần"
            },
            weekdayOfMonth: {
                wide: "ngày thường trong tháng",
                short: "ngày thường trong tháng",
                narrow: "ngày thường trong tháng"
            },
            dayperiod: {
                short: "SA/CH",
                wide: "SA/CH",
                narrow: "SA/CH"
            },
            hour: {
                wide: "Giờ",
                short: "Giờ",
                narrow: "Giờ"
            },
            minute: {
                wide: "Phút",
                short: "Phút",
                narrow: "Phút"
            },
            second: {
                wide: "Giây",
                short: "Giây",
                narrow: "Giây"
            },
            zone: {
                wide: "Múi giờ",
                short: "Múi giờ",
                narrow: "Múi giờ"
            },
            millisecond: {
                narrow: "miligiây",
                short: "mili giây",
                wide: "mili giây"
            }
        }
    },
    firstDay: 1
});

