/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "zh-Hant",
    likelySubtags: {
        zh: "zh-Hans-CN",
        "zh-Hant": "zh-Hant-TW"
    },
    identity: {
        language: "zh",
        script: "Hant"
    },
    territory: "TW",
    calendar: {
        patterns: {
            d: "y/M/d",
            D: "y年M月d日 EEEE",
            m: "M月d日",
            M: "M月d日",
            y: "y年M月",
            Y: "y年M月",
            F: "y年M月d日 EEEE Bh:mm:ss",
            g: "y/M/d Bh:mm",
            G: "y/M/d Bh:mm:ss",
            t: "Bh:mm",
            T: "Bh:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "Bh時",
                Bhm: "Bh:mm",
                Bhms: "Bh:mm:ss",
                d: "d日",
                E: "ccc",
                EBhm: "E Bh:mm",
                EBhms: "E Bh:mm:ss",
                Ed: "d E",
                Ehm: "E Bh:mm",
                EHm: "E HH:mm",
                Ehms: "E Bh:mm:ss",
                EHms: "E HH:mm:ss",
                Gy: "Gy年",
                GyMd: "G y/M/d",
                GyMMM: "Gy年M月",
                GyMMMd: "Gy年M月d日",
                GyMMMEd: "Gy年M月d日 E",
                h: "Bh時",
                H: "H時",
                hm: "Bh:mm",
                Hm: "HH:mm",
                hms: "Bh:mm:ss",
                Hms: "HH:mm:ss",
                hmsv: "Bh:mm:ss [v]",
                Hmsv: "HH:mm:ss [v]",
                hmv: "Bh:mm [v]",
                Hmv: "HH:mm [v]",
                M: "M月",
                Md: "M/d",
                MEd: "M/d（E）",
                MMdd: "MM/dd",
                MMM: "LLL",
                MMMd: "M月d日",
                MMMEd: "M月d日 E",
                MMMMd: "M月d日",
                "MMMMW-count-other": "MMMM的第W週",
                ms: "mm:ss",
                y: "y年",
                yM: "y/M",
                yMd: "y/M/d",
                yMEd: "y/M/d（E）",
                yMEEEEd: "y年M月d日 EEEE",
                yMM: "y/MM",
                yMMM: "y年M月",
                yMMMd: "y年M月d日",
                yMMMEd: "y年M月d日 E",
                yMMMM: "y年M月",
                yQQQ: "y年QQQ",
                yQQQQ: "y年QQQQ",
                "yw-count-other": "Y年的第w週"
            }
        },
        timeFormats: {
            full: "Bh:mm:ss [zzzz]",
            long: "Bh:mm:ss [z]",
            medium: "Bh:mm:ss",
            short: "Bh:mm"
        },
        dateFormats: {
            full: "y年M月d日 EEEE",
            long: "y年M月d日",
            medium: "y年M月d日",
            short: "y/M/d"
        },
        days: {
            format: {
                abbreviated: [
                    "週日",
                    "週一",
                    "週二",
                    "週三",
                    "週四",
                    "週五",
                    "週六"
                ],
                narrow: [
                    "日",
                    "一",
                    "二",
                    "三",
                    "四",
                    "五",
                    "六"
                ],
                short: [
                    "日",
                    "一",
                    "二",
                    "三",
                    "四",
                    "五",
                    "六"
                ],
                wide: [
                    "星期日",
                    "星期一",
                    "星期二",
                    "星期三",
                    "星期四",
                    "星期五",
                    "星期六"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "週日",
                    "週一",
                    "週二",
                    "週三",
                    "週四",
                    "週五",
                    "週六"
                ],
                narrow: [
                    "日",
                    "一",
                    "二",
                    "三",
                    "四",
                    "五",
                    "六"
                ],
                short: [
                    "日",
                    "一",
                    "二",
                    "三",
                    "四",
                    "五",
                    "六"
                ],
                wide: [
                    "星期日",
                    "星期一",
                    "星期二",
                    "星期三",
                    "星期四",
                    "星期五",
                    "星期六"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "1月",
                    "2月",
                    "3月",
                    "4月",
                    "5月",
                    "6月",
                    "7月",
                    "8月",
                    "9月",
                    "10月",
                    "11月",
                    "12月"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "1月",
                    "2月",
                    "3月",
                    "4月",
                    "5月",
                    "6月",
                    "7月",
                    "8月",
                    "9月",
                    "10月",
                    "11月",
                    "12月"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "1月",
                    "2月",
                    "3月",
                    "4月",
                    "5月",
                    "6月",
                    "7月",
                    "8月",
                    "9月",
                    "10月",
                    "11月",
                    "12月"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                wide: [
                    "1月",
                    "2月",
                    "3月",
                    "4月",
                    "5月",
                    "6月",
                    "7月",
                    "8月",
                    "9月",
                    "10月",
                    "11月",
                    "12月"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "第1季",
                    "第2季",
                    "第3季",
                    "第4季"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "第1季",
                    "第2季",
                    "第3季",
                    "第4季"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "第1季",
                    "第2季",
                    "第3季",
                    "第4季"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "第1季",
                    "第2季",
                    "第3季",
                    "第4季"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    midnight: "午夜",
                    am: "上午",
                    pm: "下午",
                    morning1: "清晨",
                    morning2: "上午",
                    afternoon1: "中午",
                    afternoon2: "下午",
                    evening1: "晚上",
                    night1: "凌晨"
                },
                narrow: {
                    midnight: "午夜",
                    am: "上午",
                    pm: "下午",
                    morning1: "清晨",
                    morning2: "上午",
                    afternoon1: "中午",
                    afternoon2: "下午",
                    evening1: "晚上",
                    night1: "凌晨"
                },
                wide: {
                    midnight: "午夜",
                    am: "上午",
                    pm: "下午",
                    morning1: "清晨",
                    morning2: "上午",
                    afternoon1: "中午",
                    afternoon2: "下午",
                    evening1: "晚上",
                    night1: "凌晨"
                }
            },
            "stand-alone": {
                abbreviated: {
                    midnight: "午夜",
                    am: "上午",
                    pm: "下午",
                    morning1: "清晨",
                    morning2: "上午",
                    afternoon1: "中午",
                    afternoon2: "下午",
                    evening1: "晚上",
                    night1: "凌晨"
                },
                narrow: {
                    midnight: "午夜",
                    am: "上午",
                    pm: "下午",
                    morning1: "清晨",
                    morning2: "上午",
                    afternoon1: "中午",
                    afternoon2: "下午",
                    evening1: "晚上",
                    night1: "凌晨"
                },
                wide: {
                    midnight: "午夜",
                    am: "上午",
                    pm: "下午",
                    morning1: "清晨",
                    morning2: "上午",
                    afternoon1: "中午",
                    afternoon2: "下午",
                    evening1: "晚上",
                    night1: "凌晨"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "西元前",
                    "1": "西元",
                    "0-alt-variant": "公元前",
                    "1-alt-variant": "公元"
                },
                abbreviated: {
                    "0": "西元前",
                    "1": "西元",
                    "0-alt-variant": "公元前",
                    "1-alt-variant": "公元"
                },
                narrow: {
                    "0": "西元前",
                    "1": "西元",
                    "0-alt-variant": "公元前",
                    "1-alt-variant": "公元"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "年代",
                short: "年代",
                narrow: "年代"
            },
            year: {
                wide: "年",
                short: "年",
                narrow: "年"
            },
            quarter: {
                wide: "季",
                short: "季",
                narrow: "季"
            },
            month: {
                wide: "月",
                short: "月",
                narrow: "月"
            },
            week: {
                wide: "週",
                short: "週",
                narrow: "週"
            },
            weekOfMonth: {
                wide: "週",
                short: "週",
                narrow: "週"
            },
            day: {
                wide: "日",
                short: "日",
                narrow: "日"
            },
            dayOfYear: {
                wide: "年天",
                short: "年天",
                narrow: "年天"
            },
            weekday: {
                wide: "週天",
                short: "週天",
                narrow: "週天"
            },
            weekdayOfMonth: {
                wide: "每月平日",
                short: "每月平日",
                narrow: "每月平日"
            },
            dayperiod: {
                short: "上午/下午",
                wide: "上午/下午",
                narrow: "上午/下午"
            },
            hour: {
                wide: "小時",
                short: "小時",
                narrow: "小時"
            },
            minute: {
                wide: "分鐘",
                short: "分鐘",
                narrow: "分鐘"
            },
            second: {
                wide: "秒",
                short: "秒",
                narrow: "秒"
            },
            zone: {
                wide: "時區",
                short: "時區",
                narrow: "時區"
            },
            millisecond: {
                narrow: "毫秒",
                short: "毫秒",
                wide: "毫秒"
            }
        }
    },
    firstDay: 0
});

