/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
var setData = require('@progress/kendo-angular-intl').setData;
setData({
    name: "zu",
    likelySubtags: {
        zu: "zu-Latn-ZA"
    },
    identity: {
        language: "zu"
    },
    territory: "ZA",
    calendar: {
        patterns: {
            d: "M/d/y",
            D: "EEEE, MMMM d, y",
            m: "MMM d",
            M: "MMMM d",
            y: "MMM y",
            Y: "MMMM y",
            F: "EEEE, MMMM d, y HH:mm:ss",
            g: "y-MM-dd HH:mm",
            G: "y-MM-dd HH:mm:ss",
            t: "HH:mm",
            T: "HH:mm:ss",
            s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
            u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'"
        },
        dateTimeFormats: {
            full: "{1} {0}",
            long: "{1} {0}",
            medium: "{1} {0}",
            short: "{1} {0}",
            availableFormats: {
                Bh: "h B",
                Bhm: "h:mm B",
                Bhms: "h:mm:ss B",
                d: "d",
                E: "ccc",
                EBhm: "E h:mm B",
                EBhms: "E h:mm:ss B",
                Ed: "d E",
                Ehm: "E h:mm a",
                EHm: "E HH:mm",
                Ehms: "E h:mm:ss a",
                EHms: "E HH:mm:ss",
                Gy: "G y",
                GyMd: "M/d/y GGGGG",
                GyMMM: "G y MMM",
                GyMMMd: "G y MMM d",
                GyMMMEd: "G y MMM d, E",
                h: "h a",
                H: "HH",
                hm: "h:mm a",
                Hm: "HH:mm",
                hms: "h:mm:ss a",
                Hms: "HH:mm:ss",
                hmsv: "h:mm:ss a v",
                Hmsv: "HH:mm:ss v",
                hmv: "h:mm a v",
                Hmv: "HH:mm v",
                M: "L",
                Md: "MM-dd",
                MEd: "MM-dd, E",
                MMM: "LLL",
                MMMd: "MMM d",
                MMMEd: "E, MMM d",
                MMMMd: "MMMM d",
                "MMMMW-count-one": "'week' W 'of' MMMM",
                "MMMMW-count-other": "'week' W 'of' MMMM",
                ms: "mm:ss",
                y: "y",
                yM: "y-MM",
                yMd: "y-MM-dd",
                yMEd: "y-MM-dd, E",
                yMMM: "MMM y",
                yMMMd: "MMM d, y",
                yMMMEd: "E, MMM d, y",
                yMMMM: "MMMM y",
                yQQQ: "QQQ y",
                yQQQQ: "QQQQ y",
                "yw-count-one": "'week' w 'of' Y",
                "yw-count-other": "'week' w 'of' Y"
            }
        },
        timeFormats: {
            full: "HH:mm:ss zzzz",
            long: "HH:mm:ss z",
            medium: "HH:mm:ss",
            short: "HH:mm"
        },
        dateFormats: {
            full: "EEEE, MMMM d, y",
            long: "MMMM d, y",
            medium: "MMM d, y",
            short: "M/d/yy"
        },
        days: {
            format: {
                abbreviated: [
                    "Son",
                    "Mso",
                    "Bil",
                    "Tha",
                    "Sin",
                    "Hla",
                    "Mgq"
                ],
                narrow: [
                    "S",
                    "M",
                    "B",
                    "T",
                    "S",
                    "H",
                    "M"
                ],
                short: [
                    "Son",
                    "Mso",
                    "Bil",
                    "Tha",
                    "Sin",
                    "Hla",
                    "Mgq"
                ],
                wide: [
                    "ISonto",
                    "UMsombuluko",
                    "ULwesibili",
                    "ULwesithathu",
                    "ULwesine",
                    "ULwesihlanu",
                    "UMgqibelo"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Son",
                    "Mso",
                    "Bil",
                    "Tha",
                    "Sin",
                    "Hla",
                    "Mgq"
                ],
                narrow: [
                    "S",
                    "M",
                    "B",
                    "T",
                    "S",
                    "H",
                    "M"
                ],
                short: [
                    "Son",
                    "Mso",
                    "Bil",
                    "Tha",
                    "Sin",
                    "Hla",
                    "Mgq"
                ],
                wide: [
                    "ISonto",
                    "UMsombuluko",
                    "ULwesibili",
                    "ULwesithathu",
                    "ULwesine",
                    "ULwesihlanu",
                    "UMgqibelo"
                ]
            }
        },
        months: {
            format: {
                abbreviated: [
                    "Jan",
                    "Feb",
                    "Mas",
                    "Eph",
                    "Mey",
                    "Jun",
                    "Jul",
                    "Aga",
                    "Sep",
                    "Okt",
                    "Nov",
                    "Dis"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "E",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Januwari",
                    "Februwari",
                    "Mashi",
                    "Ephreli",
                    "Meyi",
                    "Juni",
                    "Julayi",
                    "Agasti",
                    "Septhemba",
                    "Okthoba",
                    "Novemba",
                    "Disemba"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Jan",
                    "Feb",
                    "Mas",
                    "Eph",
                    "Mey",
                    "Jun",
                    "Jul",
                    "Aga",
                    "Sep",
                    "Okt",
                    "Nov",
                    "Dis"
                ],
                narrow: [
                    "J",
                    "F",
                    "M",
                    "A",
                    "M",
                    "J",
                    "J",
                    "A",
                    "S",
                    "O",
                    "N",
                    "D"
                ],
                wide: [
                    "Januwari",
                    "Februwari",
                    "Mashi",
                    "Ephreli",
                    "Meyi",
                    "Juni",
                    "Julayi",
                    "Agasti",
                    "Septhemba",
                    "Okthoba",
                    "Novemba",
                    "Disemba"
                ]
            }
        },
        quarters: {
            format: {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "ikota yesi-1",
                    "ikota yesi-2",
                    "ikota yesi-3",
                    "ikota yesi-4"
                ]
            },
            "stand-alone": {
                abbreviated: [
                    "Q1",
                    "Q2",
                    "Q3",
                    "Q4"
                ],
                narrow: [
                    "1",
                    "2",
                    "3",
                    "4"
                ],
                wide: [
                    "ikota yesi-1",
                    "ikota yesi-2",
                    "ikota yesi-3",
                    "ikota yesi-4"
                ]
            }
        },
        dayPeriods: {
            format: {
                abbreviated: {
                    am: "AM",
                    pm: "PM",
                    morning1: "entathakusa",
                    morning2: "ekuseni",
                    afternoon1: "emini",
                    evening1: "ntambama",
                    night1: "ebusuku"
                },
                narrow: {
                    am: "a",
                    pm: "p",
                    morning1: "entathakusa",
                    morning2: "ekuseni",
                    afternoon1: "emini",
                    evening1: "ntambama",
                    night1: "ebusuku"
                },
                wide: {
                    am: "AM",
                    pm: "PM",
                    morning1: "entathakusa",
                    morning2: "ekuseni",
                    afternoon1: "emini",
                    evening1: "ntambama",
                    night1: "ebusuku"
                }
            },
            "stand-alone": {
                abbreviated: {
                    am: "AM",
                    pm: "PM",
                    morning1: "entathakusa",
                    morning2: "ekuseni",
                    afternoon1: "emini",
                    evening1: "ntambama",
                    night1: "ebusuku"
                },
                narrow: {
                    am: "AM",
                    pm: "PM",
                    morning1: "entathakusa",
                    morning2: "ekuseni",
                    afternoon1: "emini",
                    evening1: "ntambama",
                    night1: "ebusuku"
                },
                wide: {
                    am: "AM",
                    pm: "PM",
                    morning1: "entathakusa",
                    morning2: "ekuseni",
                    afternoon1: "emini",
                    evening1: "ntambama",
                    night1: "ebusuku"
                }
            }
        },
        eras: {
            format: {
                wide: {
                    "0": "BC",
                    "1": "AD",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                abbreviated: {
                    "0": "BC",
                    "1": "AD",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                },
                narrow: {
                    "0": "BC",
                    "1": "AD",
                    "0-alt-variant": "BCE",
                    "1-alt-variant": "CE"
                }
            }
        },
        gmtFormat: "GMT{0}",
        gmtZeroFormat: "GMT",
        dateFields: {
            era: {
                wide: "Isikhathi",
                short: "Isikhathi",
                narrow: "Isikhathi"
            },
            year: {
                wide: "Unyaka",
                short: "Unyaka",
                narrow: "Unyaka"
            },
            quarter: {
                wide: "Ikota",
                short: "Ikota",
                narrow: "Ikota"
            },
            month: {
                wide: "Inyanga",
                short: "Inyanga",
                narrow: "Inyanga"
            },
            week: {
                wide: "Iviki",
                short: "Iviki",
                narrow: "Iviki"
            },
            weekOfMonth: {
                wide: "Iviki leNyanga",
                short: "Iviki leNyanga",
                narrow: "Iviki leNyanga"
            },
            day: {
                wide: "Usuku",
                short: "Usuku",
                narrow: "Usuku"
            },
            dayOfYear: {
                wide: "Day Of Year",
                short: "usuku lonyaka",
                narrow: "usuku lonyaka"
            },
            weekday: {
                wide: "Usuku evikini",
                short: "Usuku evikini",
                narrow: "Usuku evikini"
            },
            weekdayOfMonth: {
                wide: "usuku lwenyanga",
                short: "usuku lwenyanga",
                narrow: "usuku lwenyanga"
            },
            dayperiod: {
                short: "AM/PM",
                wide: "AM/PM",
                narrow: "AM/PM"
            },
            hour: {
                wide: "Ihora",
                short: "Ihora",
                narrow: "Ihora"
            },
            minute: {
                wide: "Iminithi",
                short: "Iminithi",
                narrow: "Iminithi"
            },
            second: {
                wide: "Isekhondi",
                short: "Isekhondi",
                narrow: "Isekhondi"
            },
            zone: {
                wide: "Isikhathi sendawo",
                short: "Isikhathi sendawo",
                narrow: "Isikhathi sendawo"
            },
            millisecond: {
                narrow: "ms",
                short: "ms",
                wide: "ms"
            }
        }
    },
    firstDay: 0
});

