/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AfterContentInit, ElementRef, Renderer2 } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { LabelDirective } from './../label.directive';
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI Label component for Angular]({% slug overview_label %}).
 *
 * Associates a label with input elements or components.
 *
 * @example
 * ```ts
 *
 * _@Component({
 *   selector: 'my-app',
 *   template: `
 *     <kendo-label [for]="input" text="First name">
 *       <input [(ngModel)]="name" kendoTextBox #input />
 *     </kendo-label>
 *   `
 * })
 * class AppComponent {
 *     public name = 'John';
 * }
 *
 * ```
 */
export declare class LabelComponent implements AfterContentInit {
    private elementRef;
    private renderer;
    private localization;
    /**
     * @hidden
     */
    direction: string;
    /**
     * Specifies the text content of the label which describes the input.
     */
    text: string;
    /**
     * Associates the label with a component by a template reference, or with an HTML element by id.
     */
    for: any;
    /**
     * Allows marking a form field as optional. By default renders the `Optional` text when enabled.
     * The text can be customized by providing a custom message ([see example]({% slug label_globalization %}#toc-custom-messages)).
     *
     * The default value is `false`.
     */
    optional: boolean;
    /**
     * Sets the CSS Styles that will be rendered on the actual label element.
     * Supports the type of values that are supported by [ngStyle](link:site.data.urls.angular['ngstyleapi']) directive.
     */
    labelCssStyle: any;
    /**
     * Sets the CSS Classes that will be rendered on the actual label element.
     * Supports the type of values that are supported by [ngClass](link:site.data.urls.angular['ngclassapi']) directive.
     */
    labelCssClass: any;
    labelDirective: LabelDirective;
    kendoInput: any;
    /**
     * @hidden
     */
    control: string | {
        focus: Function;
    };
    private subscriptions;
    constructor(elementRef: ElementRef, renderer: Renderer2, localization: LocalizationService);
    /**
     * @hidden
     */
    ngAfterContentInit(): void;
    /**
     * @hidden
     */
    ngOnInit(): void;
    /**
     * @hidden
     */
    ngAfterViewInit(): void;
    /**
     * @hidden
     */
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    textFor(key: string): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<LabelComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<LabelComponent, "kendo-label", ["kendoLabel"], { "text": "text"; "for": "for"; "optional": "optional"; "labelCssStyle": "labelCssStyle"; "labelCssClass": "labelCssClass"; }, {}, ["kendoInput"], ["*"]>;
}
