/**-----------------------------------------------------------------------------------------
* Copyright © 2023 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
export declare enum DataSource {
    /**
     * An example data source will be added to the project with predefined column definitions.
     * The data and column definitions can not be modified.
     *
     * This is the default.
     */
    "Example" = "Example",
    /**
     * The user is expected to provide column definitions.
     * A mock data will be generated out of the column definitions.
     */
    "Mock Data" = "Mock Data",
    /**
     * The user can specify a basic module to bind to and provide column definitions,
     * but in general the user will have to author some code to connect the data.
     */
    "Existing App Data" = "Existing App Data"
}
export declare enum SeriesType {
    "area" = "area",
    "bar" = "bar",
    "bullet" = "bullet",
    "column" = "column",
    "horizontalWaterfall" = "horizontalWaterfall",
    "line" = "line",
    "radarArea" = "radarArea",
    "radarColumn" = "radarColumn",
    "radarLine" = "radarLine",
    "rangeArea" = "rangeArea",
    "rangeBar" = "rangeBar",
    "rangeColumn" = "rangeColumn",
    "waterfall" = "waterfall"
}
export interface Series {
    type: SeriesType;
    categoryField: string;
    currentField: string;
    field: string;
    name: string;
    width: number;
}
export declare enum CategoryAxisType {
    "category" = "category",
    "date" = "date"
}
export interface CategoryAxis {
    name?: string;
    title?: string;
    type: CategoryAxisType;
}
export declare enum ValueAxisType {
    "numeric" = "numeric",
    "log" = "log"
}
export interface ValueAxis {
    name?: string;
    title?: string;
    type: ValueAxisType;
}
export interface Schema {
    path?: string;
    name: string;
    inlineStyle: boolean;
    inlineTemplate: boolean;
    skipTests: boolean;
    titleText?: string;
    titlePosition?: 'top' | 'bottom';
    titleAlign?: 'left' | 'right' | 'center';
    renderAs?: 'canvas' | 'svg';
    legend?: boolean;
    legendTitleText?: string;
    legendTitleAlign?: 'left' | 'right' | 'center';
    legendTitlePosition?: 'top' | 'bottom';
    legendAlign?: 'center' | 'start' | 'end';
    legendOrientation?: 'vertical' | 'horizontal';
    legendPosition?: 'top' | 'bottom' | 'left' | 'right' | 'custom';
    dataSource: DataSource;
    series?: Series[];
    categoryAxis?: CategoryAxis[];
    valueAxis?: ValueAxis[];
    dataPath?: string;
    dataName: string;
    dataSourceType?: string;
    dataSourceModule?: string;
    dataSourceMember?: string;
    dataSourceMethod?: string;
}
